package android.car;

import android.car.CarBugreportManager;
import android.car.ICarBugreportCallback;
import android.car.ICarBugreportService;
import android.os.Handler;
import android.os.IBinder;
import android.os.ParcelFileDescriptor;
import android.os.RemoteException;
import java.lang.ref.WeakReference;
import java.util.Objects;
import libcore.io.IoUtils;

public final class CarBugreportManager extends CarManagerBase {
    private final ICarBugreportService mService;

    public static abstract class CarBugreportManagerCallback {
        public static final int CAR_BUGREPORT_DUMPSTATE_CONNECTION_FAILED;
        public static final int CAR_BUGREPORT_DUMPSTATE_FAILED;
        public static final int CAR_BUGREPORT_IN_PROGRESS;
        public static final int CAR_BUGREPORT_SERVICE_NOT_AVAILABLE;

        public @interface CarBugreportErrorCode {
        }

        public void onError(int i) {
        }

        public void onFinished() {
        }

        public void onProgress(float f) {
        }
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
    }

    public static final class CarBugreportManagerCallbackWrapper extends ICarBugreportCallback.Stub {
        private final WeakReference<CarBugreportManagerCallback> mWeakCallback;
        private final WeakReference<Handler> mWeakHandler;

        CarBugreportManagerCallbackWrapper(CarBugreportManagerCallback carBugreportManagerCallback, Handler handler) {
            this.mWeakCallback = new WeakReference<>(carBugreportManagerCallback);
            this.mWeakHandler = new WeakReference<>(handler);
        }

        @Override // android.car.ICarBugreportCallback
        public void onProgress(float f) {
            CarBugreportManagerCallback carBugreportManagerCallback = this.mWeakCallback.get();
            Handler handler = this.mWeakHandler.get();
            if (handler != null && carBugreportManagerCallback != null) {
                handler.post(new Runnable(f) {
                    /* class android.car.$$Lambda$CarBugreportManager$CarBugreportManagerCallbackWrapper$5pXcIPnRftCw8hyLqjiwPAD2xI */
                    public final /* synthetic */ float f$1;

                    {
                        this.f$1 = r2;
                    }

                    public final void run() {
                        CarBugreportManager.CarBugreportManagerCallbackWrapper.lambda$onProgress$0(CarBugreportManager.CarBugreportManagerCallback.this, this.f$1);
                    }
                });
            }
        }

        @Override // android.car.ICarBugreportCallback
        public void onError(int i) {
            CarBugreportManagerCallback carBugreportManagerCallback = this.mWeakCallback.get();
            Handler handler = this.mWeakHandler.get();
            if (handler != null && carBugreportManagerCallback != null) {
                handler.post(new Runnable(i) {
                    /* class android.car.$$Lambda$CarBugreportManager$CarBugreportManagerCallbackWrapper$2TJ4TDndOeNdbxQG5rgu6AcIM */
                    public final /* synthetic */ int f$1;

                    {
                        this.f$1 = r2;
                    }

                    public final void run() {
                        CarBugreportManager.CarBugreportManagerCallbackWrapper.lambda$onError$1(CarBugreportManager.CarBugreportManagerCallback.this, this.f$1);
                    }
                });
            }
        }

        @Override // android.car.ICarBugreportCallback
        public void onFinished() {
            CarBugreportManagerCallback carBugreportManagerCallback = this.mWeakCallback.get();
            Handler handler = this.mWeakHandler.get();
            if (handler != null && carBugreportManagerCallback != null) {
                Objects.requireNonNull(carBugreportManagerCallback);
                handler.post(new Runnable() {
                    /* class android.car.$$Lambda$LmNSmwuvl7_uhjViZ5ZcabxREzw */

                    public final void run() {
                        CarBugreportManager.CarBugreportManagerCallback.this.onFinished();
                    }
                });
            }
        }
    }

    public CarBugreportManager(Car car, IBinder iBinder) {
        super(car);
        this.mService = ICarBugreportService.Stub.asInterface(iBinder);
    }

    public void requestBugreport(ParcelFileDescriptor parcelFileDescriptor, ParcelFileDescriptor parcelFileDescriptor2, CarBugreportManagerCallback carBugreportManagerCallback) {
        Objects.requireNonNull(parcelFileDescriptor);
        Objects.requireNonNull(parcelFileDescriptor2);
        Objects.requireNonNull(carBugreportManagerCallback);
        try {
            this.mService.requestBugreport(parcelFileDescriptor, parcelFileDescriptor2, new CarBugreportManagerCallbackWrapper(carBugreportManagerCallback, getEventHandler()));
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        } catch (Throwable th) {
            IoUtils.closeQuietly(parcelFileDescriptor);
            IoUtils.closeQuietly(parcelFileDescriptor2);
            throw th;
        }
        IoUtils.closeQuietly(parcelFileDescriptor);
        IoUtils.closeQuietly(parcelFileDescriptor2);
    }

    public void cancelBugreport() {
        try {
            this.mService.cancelBugreport();
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }
}
