package android.car.hardware;

import android.annotation.SystemApi;
import android.car.Car;
import android.car.CarManagerBase;
import android.car.hardware.property.CarPropertyManager;
import android.car.hardware.property.ICarProperty;
import android.os.IBinder;
import android.util.ArraySet;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.List;

@SystemApi
@Deprecated
public final class CarVendorExtensionManager extends CarManagerBase {
    private static final boolean DBG = false;
    private static final String TAG = "CarVendorExtensionManager";
    private final ArraySet<CarVendorExtensionCallback> mCallbacks = new ArraySet<>();
    private CarPropertyEventListenerToBase mListenerToBase = null;
    private final Object mLock = new Object();
    private final CarPropertyManager mPropertyManager;

    public interface CarVendorExtensionCallback {
        void onChangeEvent(CarPropertyValue carPropertyValue);

        void onErrorEvent(int i, int i2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleOnChangeEvent(CarPropertyValue carPropertyValue) {
        ArrayList<CarVendorExtensionCallback> arrayList;
        synchronized (this.mLock) {
            arrayList = new ArrayList(this.mCallbacks);
        }
        for (CarVendorExtensionCallback carVendorExtensionCallback : arrayList) {
            carVendorExtensionCallback.onChangeEvent(carPropertyValue);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleOnErrorEvent(int i, int i2) {
        ArrayList<CarVendorExtensionCallback> arrayList;
        synchronized (this.mLock) {
            arrayList = new ArrayList(this.mCallbacks);
        }
        for (CarVendorExtensionCallback carVendorExtensionCallback : arrayList) {
            carVendorExtensionCallback.onErrorEvent(i, i2);
        }
    }

    public CarVendorExtensionManager(Car car, IBinder iBinder) {
        super(car);
        this.mPropertyManager = new CarPropertyManager(car, ICarProperty.Stub.asInterface(iBinder));
    }

    public void registerCallback(CarVendorExtensionCallback carVendorExtensionCallback) {
        synchronized (this.mLock) {
            if (this.mCallbacks.isEmpty()) {
                this.mListenerToBase = new CarPropertyEventListenerToBase(this);
            }
            for (CarPropertyConfig carPropertyConfig : this.mPropertyManager.getPropertyList()) {
                this.mPropertyManager.registerCallback(this.mListenerToBase, carPropertyConfig.getPropertyId(), 0.0f);
            }
            this.mCallbacks.add(carVendorExtensionCallback);
        }
    }

    public void unregisterCallback(CarVendorExtensionCallback carVendorExtensionCallback) {
        synchronized (this.mLock) {
            this.mCallbacks.remove(carVendorExtensionCallback);
            for (CarPropertyConfig carPropertyConfig : this.mPropertyManager.getPropertyList()) {
                this.mPropertyManager.unregisterCallback(this.mListenerToBase, carPropertyConfig.getPropertyId());
            }
            if (this.mCallbacks.isEmpty()) {
                this.mListenerToBase = null;
            }
        }
    }

    public List<CarPropertyConfig> getProperties() {
        return this.mPropertyManager.getPropertyList();
    }

    public boolean isPropertyAvailable(int i, int i2) {
        return this.mPropertyManager.isPropertyAvailable(i, i2);
    }

    public <E> E getGlobalProperty(Class<E> cls, int i) {
        return (E) getProperty(cls, i, 0);
    }

    public <E> E getProperty(Class<E> cls, int i, int i2) {
        return this.mPropertyManager.getProperty(cls, i, i2).getValue();
    }

    public <E> void setGlobalProperty(Class<E> cls, int i, E e) {
        this.mPropertyManager.setProperty(cls, i, 0, e);
    }

    public <E> void setProperty(Class<E> cls, int i, int i2, E e) {
        this.mPropertyManager.setProperty(cls, i, i2, e);
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
        synchronized (this.mLock) {
            this.mCallbacks.clear();
        }
        this.mPropertyManager.onCarDisconnected();
    }

    private static class CarPropertyEventListenerToBase implements CarPropertyManager.CarPropertyEventCallback {
        private final WeakReference<CarVendorExtensionManager> mManager;

        CarPropertyEventListenerToBase(CarVendorExtensionManager carVendorExtensionManager) {
            this.mManager = new WeakReference<>(carVendorExtensionManager);
        }

        @Override // android.car.hardware.property.CarPropertyManager.CarPropertyEventCallback
        public void onChangeEvent(CarPropertyValue carPropertyValue) {
            CarVendorExtensionManager carVendorExtensionManager = this.mManager.get();
            if (carVendorExtensionManager != null) {
                carVendorExtensionManager.handleOnChangeEvent(carPropertyValue);
            }
        }

        @Override // android.car.hardware.property.CarPropertyManager.CarPropertyEventCallback
        public void onErrorEvent(int i, int i2) {
            CarVendorExtensionManager carVendorExtensionManager = this.mManager.get();
            if (carVendorExtensionManager != null) {
                carVendorExtensionManager.handleOnErrorEvent(i, i2);
            }
        }
    }
}
