package android.car.media;

import android.annotation.SystemApi;
import android.car.Car;
import android.car.CarLibLog;
import android.car.CarManagerBase;
import android.car.media.ICarAudio;
import android.car.media.ICarAudioFocusCallback;
import android.car.media.ICarCustomSettingCallback;
import android.car.media.ICarExtVolumeCallback;
import android.car.media.ICarVolumeCallback;
import android.media.AudioDeviceAttributes;
import android.media.AudioDeviceInfo;
import android.media.AudioManager;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.CopyOnWriteArrayList;

public final class CarAudioManager extends CarManagerBase {
    @SystemApi
    public static final String AUDIOFOCUS_EXTRA_RECEIVE_DUCKING_EVENTS = "android.car.media.AUDIOFOCUS_EXTRA_RECEIVE_DUCKING_EVENTS";
    public static final String AUDIOFOCUS_EXTRA_REQUEST_ZONE_ID = "android.car.media.AUDIOFOCUS_EXTRA_REQUEST_ZONE_ID";
    @SystemApi
    public static final int BASIC_STEREO_ALL = 0;
    @SystemApi
    public static final int BASIC_STEREO_DRIVE = 1;
    @SystemApi
    public static final int BASIC_STEREO_PASSENGER = 7;
    @SystemApi
    public static final int BASIC_STEREO_REAR = 2;
    @SystemApi
    public static final int BMT_FILTER_BASS = 0;
    @SystemApi
    public static final int BMT_FILTER_MIDDLE = 1;
    @SystemApi
    public static final int BMT_FILTER_TREBLE = 2;
    @SystemApi
    public static final int CUSTOM_PEQ_BAND_10000 = 3;
    @SystemApi
    public static final int CUSTOM_PEQ_BAND_16000 = 4;
    @SystemApi
    public static final int CUSTOM_PEQ_BAND_500 = 1;
    @SystemApi
    public static final int CUSTOM_PEQ_BAND_5000 = 2;
    @SystemApi
    public static final int CUSTOM_PEQ_BAND_80 = 0;
    @SystemApi
    public static final int CUSTOM_PEQ_BAND_NUMBER = 5;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_BT_CALL_NB = 1;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_BT_CALL_WB = 2;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_E_CALL = 6;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_HICAR_CALL = 29;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_HICAR_CALL_WIFI = 30;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_HICAR_VR = 27;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_HICAR_VR_WIFI = 28;
    @SystemApi
    public static final int ECNR_CONFIG_TYPE_NONE = 0;
    @SystemApi
    public static final int ECNR_MODE_BLUETOOTH = 0;
    @SystemApi
    public static final int ECNR_MODE_BYPASS = 1;
    @SystemApi
    public static final int ECNR_MODE_CLOSE_MUTE = 5;
    @SystemApi
    public static final int ECNR_MODE_NONE = 3;
    @SystemApi
    public static final int ECNR_MODE_OMN = 2;
    @SystemApi
    public static final int ECNR_MODE_OPEN_MUTE = 4;
    @SystemApi
    public static final int ECNR_USE_CASE_TYPE_BT_CALL = 1;
    @SystemApi
    public static final int ECNR_USE_CASE_TYPE_E_CALL = 3;
    @SystemApi
    public static final int ECNR_USE_CASE_TYPE_HICAR_CALL = 5;
    @SystemApi
    public static final int ECNR_USE_CASE_TYPE_HICAR_VR = 4;
    @SystemApi
    public static final int ECNR_USE_CASE_TYPE_NONE = 0;
    @SystemApi
    public static final int EFFECT_TYPE_BASIC = 0;
    @SystemApi
    public static final int EQ_MODE_CLASSIC = 4;
    @SystemApi
    public static final int EQ_MODE_CUSTOM = 6;
    @SystemApi
    public static final int EQ_MODE_FLAT = 0;
    @SystemApi
    public static final int EQ_MODE_JAZZ = 3;
    @SystemApi
    public static final int EQ_MODE_NUMBER = 7;
    @SystemApi
    public static final int EQ_MODE_POP = 1;
    @SystemApi
    public static final int EQ_MODE_ROCK = 2;
    @SystemApi
    public static final int EQ_MODE_VOCAL = 5;
    @SystemApi
    public static final int HEADREST_DRIVE = 1;
    @SystemApi
    public static final int HEADREST_PRIVATE = 2;
    @SystemApi
    public static final int HEADREST_SHARE = 0;
    @SystemApi
    public static final int INVALID_AUDIO_ZONE = -1;
    public static final int INVALID_VOLUME_GROUP_ID = -1;
    @SystemApi
    public static final int KTV_MODE_OFF = 0;
    @SystemApi
    public static final int KTV_MODE_ON = 1;
    @SystemApi
    public static final int PARAM_BOSE = 3;
    @SystemApi
    public static final int PARAM_CAE = 4;
    @SystemApi
    public static final int PARAM_CHIME_VOL_LEVEL = 0;
    @SystemApi
    public static final int PARAM_DTS_MODE = 12;
    @SystemApi
    public static final int PARAM_DTS_MODE_VALUE_CLEAR = 3;
    @SystemApi
    public static final int PARAM_DTS_MODE_VALUE_NATRUAL = 1;
    @SystemApi
    public static final int PARAM_DTS_MODE_VALUE_PASSION = 2;
    @SystemApi
    public static final int PARAM_DTS_MODE_VALUE_SHOCK = 4;
    @SystemApi
    public static final int PARAM_EQ_MODE_SETTING = 7;
    @SystemApi
    public static final int PARAM_EXT_AMP_PRIV_MODE = 10;
    public static final int PARAM_EXT_AMP_PRIV_MODE_GET_USER = 101;
    public static final int PARAM_EXT_AMP_PRIV_MODE_SET_INTELLIGENT = 100;
    @SystemApi
    public static final int PARAM_EXT_AMP_SOUND_EFFECT_BASIC = 8;
    @SystemApi
    public static final int PARAM_HEADREST_MODE_INTELLIGENT = 11;
    @SystemApi
    public static final int PARAM_INVALID = -1;
    @SystemApi
    public static final int PARAM_MIX_SOURCE = 5;
    @SystemApi
    public static final int PARAM_PDC_WARNING = 1;
    @SystemApi
    public static final int PARAM_QLI_SURROUND_SWITCH = 9;
    @SystemApi
    public static final int PARAM_SOUND_EFFECTS_STATUS = 2;
    @SystemApi
    public static final int PARAM_VOLUME_ADJUST_BY_SPEED = 6;
    @SystemApi
    public static final int PRIMARY_AUDIO_ZONE = 0;
    @SystemApi
    public static final int WARNING_VOL_LEVEL_HIGH = 3;
    @SystemApi
    public static final int WARNING_VOL_LEVEL_LOW = 1;
    @SystemApi
    public static final int WARNING_VOL_LEVEL_MIDDLE = 2;
    private final AudioManager mAudioManager;
    private int mAudioMode = 0;
    private final ICarAudioFocusCallback mCarAudioFocusCallbackImpl = new ICarAudioFocusCallback.Stub() {
        /* class android.car.media.CarAudioManager.AnonymousClass3 */

        @Override // android.car.media.ICarAudioFocusCallback
        public void onAudioFocusGrant(String str, int i, int i2, int i3) {
            Iterator it = CarAudioManager.this.mCarAudioFocusCallbacks.iterator();
            while (it.hasNext()) {
                ((CarAudioFocusCallback) it.next()).onAudioFocusGrant(str, i, i2, i3);
            }
        }

        @Override // android.car.media.ICarAudioFocusCallback
        public void onAudioFocusLoss(String str, int i, int i2, boolean z) {
            Iterator it = CarAudioManager.this.mCarAudioFocusCallbacks.iterator();
            while (it.hasNext()) {
                ((CarAudioFocusCallback) it.next()).onAudioFocusLoss(str, i, i2, z);
            }
        }
    };
    private final CopyOnWriteArrayList<CarAudioFocusCallback> mCarAudioFocusCallbacks;
    private final ICarCustomSettingCallback mCarCustomSettingCallbackImpl = new ICarCustomSettingCallback.Stub() {
        /* class android.car.media.CarAudioManager.AnonymousClass4 */

        @Override // android.car.media.ICarCustomSettingCallback
        public void onEnableChanged(int i, int i2, boolean z) {
            Iterator it = CarAudioManager.this.mCarCustomSettingCallbacks.iterator();
            while (it.hasNext()) {
                CarCustomSettingCallback carCustomSettingCallback = (CarCustomSettingCallback) it.next();
                Log.i(CarLibLog.TAG_CAR, "onEnableChanged callback=" + carCustomSettingCallback);
                carCustomSettingCallback.onEnableChanged(i, i2, z);
            }
        }

        @Override // android.car.media.ICarCustomSettingCallback
        public void onValueChanged(int i, int i2, int i3) {
            Iterator it = CarAudioManager.this.mCarCustomSettingCallbacks.iterator();
            while (it.hasNext()) {
                CarCustomSettingCallback carCustomSettingCallback = (CarCustomSettingCallback) it.next();
                Log.i(CarLibLog.TAG_CAR, "onValueChanged callback=" + carCustomSettingCallback);
                carCustomSettingCallback.onValueChanged(i, i2, i3);
            }
        }
    };
    private final CopyOnWriteArrayList<CarCustomSettingCallback> mCarCustomSettingCallbacks;
    private final ICarExtVolumeCallback mCarExtVolumeCallbackImpl = new ICarExtVolumeCallback.Stub() {
        /* class android.car.media.CarAudioManager.AnonymousClass2 */

        @Override // android.car.media.ICarExtVolumeCallback
        public void onGroupVolumeChanged(int i, int i2, int i3, int i4) {
            Iterator it = CarAudioManager.this.mCarExtVolumeCallbacks.iterator();
            while (it.hasNext()) {
                ((CarExtVolumeCallback) it.next()).onGroupVolumeChanged(i, i2, i3, i4);
            }
        }

        @Override // android.car.media.ICarExtVolumeCallback
        public void onGroupMuteChanged(int i, int i2, boolean z, int i3) {
            Iterator it = CarAudioManager.this.mCarExtVolumeCallbacks.iterator();
            while (it.hasNext()) {
                ((CarExtVolumeCallback) it.next()).onGroupMuteChanged(i, i2, z, i3);
            }
        }
    };
    private final CopyOnWriteArrayList<CarExtVolumeCallback> mCarExtVolumeCallbacks;
    private final ICarVolumeCallback mCarVolumeCallbackImpl = new ICarVolumeCallback.Stub() {
        /* class android.car.media.CarAudioManager.AnonymousClass1 */

        @Override // android.car.media.ICarVolumeCallback
        public void onGroupVolumeChanged(int i, int i2, int i3) {
            Iterator it = CarAudioManager.this.mCarVolumeCallbacks.iterator();
            while (it.hasNext()) {
                ((CarVolumeCallback) it.next()).onGroupVolumeChanged(i, i2, i3);
            }
        }

        @Override // android.car.media.ICarVolumeCallback
        public void onMasterMuteChanged(int i, int i2) {
            Iterator it = CarAudioManager.this.mCarVolumeCallbacks.iterator();
            while (it.hasNext()) {
                ((CarVolumeCallback) it.next()).onMasterMuteChanged(i, i2);
            }
        }
    };
    private final CopyOnWriteArrayList<CarVolumeCallback> mCarVolumeCallbacks;
    private final ICarAudio mService;

    public static abstract class CarAudioFocusCallback {
        public void onAudioFocusGrant(String str, int i, int i2, int i3) {
        }

        public void onAudioFocusLoss(String str, int i, int i2, boolean z) {
        }
    }

    public static abstract class CarCustomSettingCallback {
        public void onEnableChanged(int i, int i2, boolean z) {
        }

        public void onValueChanged(int i, int i2, int i3) {
        }
    }

    public static abstract class CarExtVolumeCallback {
        public void onGroupMuteChanged(int i, int i2, boolean z, int i3) {
        }

        public void onGroupVolumeChanged(int i, int i2, int i3, int i4) {
        }
    }

    public static abstract class CarVolumeCallback {
        public void onGroupVolumeChanged(int i, int i2, int i3) {
        }

        public void onMasterMuteChanged(int i, int i2) {
        }
    }

    public boolean isDynamicRoutingEnabled() {
        try {
            return this.mService.isDynamicRoutingEnabled();
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    @SystemApi
    public void setGroupVolume(int i, int i2, int i3) {
        setGroupVolume(0, i, i2, i3);
    }

    @SystemApi
    public void setGroupVolume(int i, int i2, int i3, int i4) {
        try {
            this.mService.setGroupVolume(i, i2, i3, i4);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getGroupMaxVolume(int i) {
        return getGroupMaxVolume(0, i);
    }

    @SystemApi
    public int getGroupMaxVolume(int i, int i2) {
        try {
            return this.mService.getGroupMaxVolume(i, i2);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public int getGroupMinVolume(int i) {
        return getGroupMinVolume(0, i);
    }

    @SystemApi
    public int getGroupMinVolume(int i, int i2) {
        try {
            return this.mService.getGroupMinVolume(i, i2);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public int getGroupVolume(int i) {
        return getGroupVolume(0, i);
    }

    @SystemApi
    public int getGroupVolume(int i, int i2) {
        try {
            return this.mService.getGroupVolume(i, i2);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public boolean isGroupMuteByPower(int i) {
        return isGroupMuteByPower(0, i);
    }

    @SystemApi
    public boolean isGroupMuteByPower(int i, int i2) {
        try {
            return this.mService.isGroupMuteByPower(i, i2);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    @SystemApi
    public void setGroupMuteByPower(int i, boolean z) {
        setGroupMuteByPower(0, i, z);
    }

    @SystemApi
    public void setGroupMuteByPower(int i, int i2, boolean z) {
        try {
            this.mService.setGroupMuteByPower(i, i2, z);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public void setGroupMute(int i, boolean z, int i2) {
        setGroupMute(0, i, z, i2);
    }

    @SystemApi
    public void setGroupMute(int i, int i2, boolean z, int i3) {
        try {
            this.mService.setGroupMute(i, i2, z, i3);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public boolean isGroupMute(int i) {
        return isGroupMute(0, i);
    }

    @SystemApi
    public boolean isGroupMute(int i, int i2) {
        try {
            return this.mService.isGroupMute(i, i2);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    @SystemApi
    public boolean isGroupSupportMute(int i) {
        return isGroupSupportMute(0, i);
    }

    @SystemApi
    public boolean isGroupSupportMute(int i, int i2) {
        try {
            return this.mService.isGroupSupportMute(i, i2);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    @SystemApi
    public int getFadeTowardFront() {
        try {
            return this.mService.getFadeTowardFront();
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public int getBalanceTowardRight() {
        try {
            return this.mService.getBalanceTowardRight();
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public void setFadeTowardFront(float f) {
        try {
            this.mService.setFadeTowardFront(f);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public void setBalanceTowardRight(float f) {
        try {
            this.mService.setBalanceTowardRight(f);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public boolean isCustomSettingSupport(int i) {
        return isCustomSettingSupport(0, i);
    }

    @SystemApi
    public boolean isCustomSettingSupport(int i, int i2) {
        try {
            return this.mService.isCustomSettingSupport(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return false;
        }
    }

    @SystemApi
    public void setCustomSettingEnable(int i, boolean z) {
        setCustomSettingEnable(0, i, z);
    }

    @SystemApi
    public void setCustomSettingEnable(int i, int i2, boolean z) {
        try {
            this.mService.setCustomSettingEnable(i, i2, z);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public boolean getCustomSettingEnable(int i) {
        return getCustomSettingEnable(0, i);
    }

    @SystemApi
    public boolean getCustomSettingEnable(int i, int i2) {
        try {
            return this.mService.getCustomSettingEnable(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return false;
        }
    }

    @SystemApi
    public void setCustomSettingValue(int i, int i2) {
        setCustomSettingValue(0, i, i2);
    }

    @SystemApi
    public void setCustomSettingValue(int i, int i2, int i3) {
        try {
            this.mService.setCustomSettingValue(i, i2, i3);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getCustomSettingValue(int i) {
        return getCustomSettingValue(0, i);
    }

    @SystemApi
    public int getCustomSettingValue(int i, int i2) {
        try {
            return this.mService.getCustomSettingValue(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return -1;
        }
    }

    @SystemApi
    public void setCustomPeqLevel(int i, int i2) {
        setCustomPeqLevel(0, i, i2);
    }

    @SystemApi
    public void setCustomPeqLevel(int i, int i2, int i3) {
        try {
            this.mService.setCustomPeqLevel(i, i2, i3);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getCustomPeqLevel(int i) {
        return getCustomPeqLevel(0, i);
    }

    @SystemApi
    public int getCustomPeqLevel(int i, int i2) {
        try {
            return this.mService.getCustomPeqLevel(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return 0;
        }
    }

    @SystemApi
    public int getCustomPeqCenterFreq(int i) {
        return getCustomPeqCenterFreq(0, i);
    }

    @SystemApi
    public int getCustomPeqCenterFreq(int i, int i2) {
        try {
            return this.mService.getCustomPeqCenterFreq(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return 0;
        }
    }

    @SystemApi
    public void setBMTFilterValue(int i, int i2) {
        setBMTFilterValue(0, i, i2);
    }

    @SystemApi
    public void setBMTFilterValue(int i, int i2, int i3) {
        try {
            this.mService.setBMTFilterValue(i, i2, i3);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getBMTFilterValue(int i) {
        return getBMTFilterValue(0, i);
    }

    @SystemApi
    public int getBMTFilterValue(int i, int i2) {
        try {
            return this.mService.getBMTFilterValue(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return 0;
        }
    }

    @SystemApi
    public void setKTVMode(int i) {
        try {
            this.mService.setKTVMode(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public void setEcnrConfiguration(int i, int i2) {
        try {
            this.mService.setEcnrConfiguration(i, i2);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public void setEcnrMode(int i) {
        try {
            this.mService.setEcnrMode(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getEcnrMode() {
        try {
            return this.mService.getEcnrMode();
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return 3;
        }
    }

    @SystemApi
    public void setDigKeyVolumeLimit(boolean z) {
        try {
            this.mService.setDigKeyVolumeLimit(z);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getActiveAudioFocusUsage() {
        return getActiveAudioFocusUsage(0);
    }

    @SystemApi
    public int getActiveAudioFocusUsage(int i) {
        try {
            return this.mService.getActiveAudioFocusUsage(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return 0;
        }
    }

    @SystemApi
    public String[] getExternalSources() {
        try {
            return this.mService.getExternalSources();
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return new String[0];
        }
    }

    @SystemApi
    public CarAudioPatchHandle createAudioPatch(String str, int i, int i2) {
        try {
            return this.mService.createAudioPatch(str, i, i2);
        } catch (RemoteException e) {
            return (CarAudioPatchHandle) handleRemoteExceptionFromCarService(e, null);
        }
    }

    @SystemApi
    public void releaseAudioPatch(CarAudioPatchHandle carAudioPatchHandle) {
        try {
            this.mService.releaseAudioPatch(carAudioPatchHandle);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    @SystemApi
    public int getVolumeGroupCount() {
        return getVolumeGroupCount(0);
    }

    @SystemApi
    public int getVolumeGroupCount(int i) {
        try {
            return this.mService.getVolumeGroupCount(i);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public int getVolumeGroupIdForUsage(int i) {
        return getVolumeGroupIdForUsage(0, i);
    }

    @SystemApi
    public int getVolumeGroupIdForUsage(int i, int i2) {
        try {
            return this.mService.getVolumeGroupIdForUsage(i, i2);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    @SystemApi
    public int[] getUsagesForVolumeGroupId(int i) {
        return getUsagesForVolumeGroupId(0, i);
    }

    @SystemApi
    public int[] getUsagesForVolumeGroupId(int i, int i2) {
        try {
            return this.mService.getUsagesForVolumeGroupId(i, i2);
        } catch (RemoteException e) {
            return (int[]) handleRemoteExceptionFromCarService(e, new int[0]);
        }
    }

    @SystemApi
    public List<Integer> getAudioZoneIds() {
        try {
            int[] audioZoneIds = this.mService.getAudioZoneIds();
            ArrayList arrayList = new ArrayList(audioZoneIds.length);
            for (int i : audioZoneIds) {
                arrayList.add(Integer.valueOf(i));
            }
            return arrayList;
        } catch (RemoteException e) {
            return (List) handleRemoteExceptionFromCarService(e, Collections.emptyList());
        }
    }

    public int getZoneIdForUid(int i) {
        try {
            return this.mService.getZoneIdForUid(i);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    public boolean setZoneIdForUid(int i, int i2) {
        try {
            return this.mService.setZoneIdForUid(i, i2);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    public boolean clearZoneIdForUid(int i) {
        try {
            return this.mService.clearZoneIdForUid(i);
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    @SystemApi
    public AudioDeviceInfo getOutputDeviceForUsage(int i, int i2) {
        try {
            String outputDeviceAddressForUsage = this.mService.getOutputDeviceAddressForUsage(i, i2);
            if (outputDeviceAddressForUsage == null) {
                return null;
            }
            AudioDeviceInfo[] devices = this.mAudioManager.getDevices(2);
            for (AudioDeviceInfo audioDeviceInfo : devices) {
                if (audioDeviceInfo.getAddress().equals(outputDeviceAddressForUsage)) {
                    return audioDeviceInfo;
                }
            }
            return null;
        } catch (RemoteException e) {
            return (AudioDeviceInfo) handleRemoteExceptionFromCarService(e, null);
        }
    }

    @SystemApi
    public List<AudioDeviceInfo> getInputDevicesForZoneId(int i) {
        try {
            return convertInputDevicesToDeviceInfos(this.mService.getInputDevicesForZoneId(i), 1);
        } catch (RemoteException e) {
            return (List) handleRemoteExceptionFromCarService(e, new ArrayList());
        }
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
        if (this.mService != null) {
            unregisterVolumeCallback();
        }
    }

    public CarAudioManager(Car car, IBinder iBinder) {
        super(car);
        this.mService = ICarAudio.Stub.asInterface(iBinder);
        this.mAudioManager = (AudioManager) getContext().getSystemService(AudioManager.class);
        this.mCarVolumeCallbacks = new CopyOnWriteArrayList<>();
        this.mCarExtVolumeCallbacks = new CopyOnWriteArrayList<>();
        this.mCarAudioFocusCallbacks = new CopyOnWriteArrayList<>();
        this.mCarCustomSettingCallbacks = new CopyOnWriteArrayList<>();
    }

    public void registerCarVolumeCallback(CarVolumeCallback carVolumeCallback) {
        Objects.requireNonNull(carVolumeCallback);
        if (this.mCarVolumeCallbacks.isEmpty()) {
            registerVolumeCallback();
        }
        this.mCarVolumeCallbacks.add(carVolumeCallback);
    }

    public void unregisterCarVolumeCallback(CarVolumeCallback carVolumeCallback) {
        Objects.requireNonNull(carVolumeCallback);
        if (this.mCarVolumeCallbacks.remove(carVolumeCallback) && this.mCarVolumeCallbacks.isEmpty()) {
            unregisterVolumeCallback();
        }
    }

    public void registerCarVolumeCallback(CarExtVolumeCallback carExtVolumeCallback) {
        Objects.requireNonNull(carExtVolumeCallback);
        if (this.mCarExtVolumeCallbacks.isEmpty()) {
            registerExtVolumeCallback();
        }
        this.mCarExtVolumeCallbacks.add(carExtVolumeCallback);
    }

    public void unregisterCarVolumeCallback(CarExtVolumeCallback carExtVolumeCallback) {
        Objects.requireNonNull(carExtVolumeCallback);
        if (this.mCarExtVolumeCallbacks.remove(carExtVolumeCallback) && this.mCarExtVolumeCallbacks.isEmpty()) {
            unregisterExtVolumeCallback();
        }
    }

    private void registerVolumeCallback() {
        try {
            this.mService.registerVolumeCallback(this.mCarVolumeCallbackImpl.asBinder());
        } catch (RemoteException e) {
            Log.e(CarLibLog.TAG_CAR, "registerVolumeCallback failed", e);
        }
    }

    private void unregisterVolumeCallback() {
        try {
            this.mService.unregisterVolumeCallback(this.mCarVolumeCallbackImpl.asBinder());
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    private void registerExtVolumeCallback() {
        try {
            this.mService.registerExtVolumeCallback(this.mCarExtVolumeCallbackImpl.asBinder());
        } catch (RemoteException e) {
            Log.e(CarLibLog.TAG_CAR, "registerVolumeCallback failed", e);
        }
    }

    private void unregisterExtVolumeCallback() {
        try {
            this.mService.unregisterExtVolumeCallback(this.mCarExtVolumeCallbackImpl.asBinder());
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public void registerCarAudioFocusCallback(CarAudioFocusCallback carAudioFocusCallback) {
        Objects.requireNonNull(carAudioFocusCallback);
        if (this.mCarAudioFocusCallbacks.isEmpty()) {
            registerAudioFocusCallback();
        }
        this.mCarAudioFocusCallbacks.add(carAudioFocusCallback);
    }

    public void unregisterCarAudioFocusCallback(CarAudioFocusCallback carAudioFocusCallback) {
        Objects.requireNonNull(carAudioFocusCallback);
        if (this.mCarAudioFocusCallbacks.remove(carAudioFocusCallback) && this.mCarAudioFocusCallbacks.isEmpty()) {
            unregisterAudioFocusCallback();
        }
    }

    private void registerAudioFocusCallback() {
        try {
            this.mService.registerAudioFocusCallback(0, this.mCarAudioFocusCallbackImpl.asBinder());
        } catch (RemoteException e) {
            Log.e(CarLibLog.TAG_CAR, "registerAudioFocusCallback failed", e);
        }
    }

    private void unregisterAudioFocusCallback() {
        try {
            this.mService.unregisterAudioFocusCallback(0, this.mCarAudioFocusCallbackImpl.asBinder());
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public void registerCarCustomSettingCallback(CarCustomSettingCallback carCustomSettingCallback) {
        Objects.requireNonNull(carCustomSettingCallback);
        Log.i(CarLibLog.TAG_CAR, "registerCarCustomSettingCallback callback=" + carCustomSettingCallback);
        if (this.mCarCustomSettingCallbacks.isEmpty()) {
            registerCustomSettingCallback();
        }
        this.mCarCustomSettingCallbacks.add(carCustomSettingCallback);
    }

    public void unregisterCarCustomSettingCallback(CarCustomSettingCallback carCustomSettingCallback) {
        Objects.requireNonNull(carCustomSettingCallback);
        if (this.mCarCustomSettingCallbacks.remove(carCustomSettingCallback) && this.mCarCustomSettingCallbacks.isEmpty()) {
            unregisterCustomSettingCallback();
        }
    }

    private void registerCustomSettingCallback() {
        try {
            this.mService.registerCustomSettingCallback(0, this.mCarCustomSettingCallbackImpl.asBinder());
        } catch (RemoteException e) {
            Log.e(CarLibLog.TAG_CAR, "registerCustomSettingCallback failed", e);
        }
    }

    private void unregisterCustomSettingCallback() {
        try {
            this.mService.unregisterCustomSettingCallback(0, this.mCarCustomSettingCallbackImpl.asBinder());
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    private List<AudioDeviceInfo> convertInputDevicesToDeviceInfos(List<AudioDeviceAttributes> list, int i) {
        int size = list.size();
        HashSet hashSet = new HashSet(size);
        for (int i2 = 0; i2 < size; i2++) {
            hashSet.add(list.get(i2).getAddress());
        }
        ArrayList arrayList = new ArrayList(list.size());
        AudioDeviceInfo[] devices = this.mAudioManager.getDevices(i);
        for (AudioDeviceInfo audioDeviceInfo : devices) {
            if (audioDeviceInfo.isSource() && hashSet.contains(audioDeviceInfo.getAddress())) {
                arrayList.add(audioDeviceInfo);
            }
        }
        return arrayList;
    }

    public boolean setExternalSpeakersVolume(int i) {
        try {
            return this.mService.setExternalSpeakersVolume(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return false;
        }
    }

    public int getExternalSpeakersVolume() {
        try {
            return this.mService.getExternalSpeakersVolume();
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
            return 0;
        }
    }

    public boolean setExternalSpeakersMediaPlayMode(int i) {
        this.mAudioMode = i;
        String str = "OCC_MEDIA_MODE=" + i + ";INSIDE_ADDRESS=" + "bus0_media_out" + ";OUTSIDE_ADDRESS=" + "bus14_ext_audio_interation_out" + ";";
        Log.i(CarLibLog.TAG_CAR, "setExternalSpeakersMediaPlayMode input = " + str);
        setOccMode(i);
        this.mAudioManager.setParameters(str);
        return true;
    }

    public int getExternalSpeakersMediaPlayMode() {
        return this.mAudioMode;
    }

    public void setOccMode(int i) {
        try {
            Log.i(CarLibLog.TAG_CAR, "setOccMode mode = " + i);
            this.mService.setOccMode(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public void setPsdEarPhoneVolume(int i) {
        try {
            this.mService.setPsdEarPhoneVolume(i);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    public void setPsdEarPhoneVolumeMute(boolean z) {
        try {
            this.mService.setPsdEarPhoneVolumeMute(z);
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }
}
