package android.car.media;

import android.annotation.SystemApi;
import android.media.AudioDevicePort;
import android.media.AudioPatch;
import android.os.Parcel;
import android.os.Parcelable;
import com.android.internal.util.Preconditions;

@SystemApi
public final class CarAudioPatchHandle implements Parcelable {
    public static final Parcelable.Creator<CarAudioPatchHandle> CREATOR = new Parcelable.Creator<CarAudioPatchHandle>() {
        /* class android.car.media.CarAudioPatchHandle.AnonymousClass1 */

        @Override // android.os.Parcelable.Creator
        public CarAudioPatchHandle createFromParcel(Parcel parcel) {
            return new CarAudioPatchHandle(parcel);
        }

        @Override // android.os.Parcelable.Creator
        public CarAudioPatchHandle[] newArray(int i) {
            return new CarAudioPatchHandle[i];
        }
    };
    private final int mHandleId;
    private final String mSinkAddress;
    private final String mSourceAddress;

    public int describeContents() {
        return 0;
    }

    public CarAudioPatchHandle(AudioPatch audioPatch) {
        boolean z = true;
        Preconditions.checkArgument(audioPatch.sources().length == 1 && (audioPatch.sources()[0].port() instanceof AudioDevicePort), "Accepts exactly one device port as source");
        Preconditions.checkArgument((audioPatch.sinks().length != 1 || !(audioPatch.sinks()[0].port() instanceof AudioDevicePort)) ? false : z, "Accepts exactly one device port as sink");
        this.mHandleId = audioPatch.id();
        this.mSourceAddress = audioPatch.sources()[0].port().address();
        this.mSinkAddress = audioPatch.sinks()[0].port().address();
    }

    public boolean represents(AudioPatch audioPatch) {
        return audioPatch.id() == this.mHandleId;
    }

    public String toString() {
        return "Patch (mHandleId=" + this.mHandleId + "): " + this.mSourceAddress + " => " + this.mSinkAddress;
    }

    private CarAudioPatchHandle(Parcel parcel) {
        this.mHandleId = parcel.readInt();
        this.mSourceAddress = parcel.readString();
        this.mSinkAddress = parcel.readString();
    }

    public void writeToParcel(Parcel parcel, int i) {
        parcel.writeInt(this.mHandleId);
        parcel.writeString(this.mSourceAddress);
        parcel.writeString(this.mSinkAddress);
    }
}
