package android.car.storagemonitoring;

import android.annotation.SystemApi;
import android.car.storagemonitoring.IoStatsEntry;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.JsonWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

@SystemApi
public final class IoStats implements Parcelable {
    public static final Parcelable.Creator<IoStats> CREATOR = new Parcelable.Creator<IoStats>() {
        /* class android.car.storagemonitoring.IoStats.AnonymousClass1 */

        @Override // android.os.Parcelable.Creator
        public IoStats createFromParcel(Parcel parcel) {
            return new IoStats(parcel);
        }

        @Override // android.os.Parcelable.Creator
        public IoStats[] newArray(int i) {
            return new IoStats[i];
        }
    };
    private final List<IoStatsEntry> mStats;
    private final long mUptimeTimestamp;

    public int describeContents() {
        return 0;
    }

    public IoStats(List<IoStatsEntry> list, long j) {
        this.mStats = list;
        this.mUptimeTimestamp = j;
    }

    public IoStats(Parcel parcel) {
        this.mStats = parcel.createTypedArrayList(IoStatsEntry.CREATOR);
        this.mUptimeTimestamp = parcel.readLong();
    }

    public IoStats(JSONObject jSONObject) throws JSONException {
        this.mUptimeTimestamp = (long) jSONObject.getInt("uptime");
        JSONArray jSONArray = jSONObject.getJSONArray("stats");
        this.mStats = new ArrayList();
        for (int i = 0; i < jSONArray.length(); i++) {
            this.mStats.add(new IoStatsEntry(jSONArray.getJSONObject(i)));
        }
    }

    public void writeToParcel(Parcel parcel, int i) {
        parcel.writeTypedList(this.mStats);
        parcel.writeLong(this.mUptimeTimestamp);
    }

    public void writeToJson(JsonWriter jsonWriter) throws IOException {
        jsonWriter.beginObject();
        jsonWriter.name("uptime").value(this.mUptimeTimestamp);
        jsonWriter.name("stats").beginArray();
        for (IoStatsEntry ioStatsEntry : this.mStats) {
            ioStatsEntry.writeToJson(jsonWriter);
        }
        jsonWriter.endArray();
        jsonWriter.endObject();
    }

    public long getTimestamp() {
        return this.mUptimeTimestamp;
    }

    public List<IoStatsEntry> getStats() {
        return this.mStats;
    }

    public int hashCode() {
        return Objects.hash(this.mStats, Long.valueOf(this.mUptimeTimestamp));
    }

    public IoStatsEntry getUserIdStats(int i) {
        for (IoStatsEntry ioStatsEntry : getStats()) {
            if (ioStatsEntry.uid == i) {
                return ioStatsEntry;
            }
        }
        return null;
    }

    public IoStatsEntry.Metrics getForegroundTotals() {
        long j = 0;
        long j2 = 0;
        long j3 = 0;
        long j4 = 0;
        long j5 = 0;
        for (IoStatsEntry ioStatsEntry : getStats()) {
            j += ioStatsEntry.foreground.bytesRead;
            j2 += ioStatsEntry.foreground.bytesWritten;
            j3 += ioStatsEntry.foreground.bytesReadFromStorage;
            j4 += ioStatsEntry.foreground.bytesWrittenToStorage;
            j5 += ioStatsEntry.foreground.fsyncCalls;
        }
        return new IoStatsEntry.Metrics(j, j2, j3, j4, j5);
    }

    public IoStatsEntry.Metrics getBackgroundTotals() {
        long j = 0;
        long j2 = 0;
        long j3 = 0;
        long j4 = 0;
        long j5 = 0;
        for (IoStatsEntry ioStatsEntry : getStats()) {
            j += ioStatsEntry.background.bytesRead;
            j2 += ioStatsEntry.background.bytesWritten;
            j3 += ioStatsEntry.background.bytesReadFromStorage;
            j4 += ioStatsEntry.background.bytesWrittenToStorage;
            j5 += ioStatsEntry.background.fsyncCalls;
        }
        return new IoStatsEntry.Metrics(j, j2, j3, j4, j5);
    }

    public IoStatsEntry.Metrics getTotals() {
        IoStatsEntry.Metrics foregroundTotals = getForegroundTotals();
        IoStatsEntry.Metrics backgroundTotals = getBackgroundTotals();
        return new IoStatsEntry.Metrics(foregroundTotals.bytesRead + backgroundTotals.bytesRead, foregroundTotals.bytesWritten + backgroundTotals.bytesWritten, foregroundTotals.bytesReadFromStorage + backgroundTotals.bytesReadFromStorage, foregroundTotals.bytesWrittenToStorage + backgroundTotals.bytesWrittenToStorage, foregroundTotals.fsyncCalls + backgroundTotals.fsyncCalls);
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof IoStats)) {
            return false;
        }
        IoStats ioStats = (IoStats) obj;
        if (ioStats.getTimestamp() != getTimestamp() || !ioStats.getStats().equals(getStats())) {
            return false;
        }
        return true;
    }

    public String toString() {
        StringJoiner stringJoiner = new StringJoiner(", ");
        for (IoStatsEntry ioStatsEntry : getStats()) {
            stringJoiner.add(ioStatsEntry.toString());
        }
        return "timestamp = " + getTimestamp() + ", stats = " + stringJoiner.toString();
    }
}
