package android.car.user;

import android.annotation.SystemApi;
import android.car.Car;
import android.car.CarManagerBase;
import android.car.ICarUserService;
import android.car.user.CarUserManager;
import android.content.pm.UserInfo;
import android.os.Bundle;
import android.os.IBinder;
import android.os.Process;
import android.os.RemoteException;
import android.os.UserHandle;
import android.os.UserManager;
import android.provider.Settings;
import android.sysprop.CarProperties;
import android.util.ArrayMap;
import android.util.EventLog;
import android.util.Log;
import com.android.internal.car.EventLogTags;
import com.android.internal.infra.AndroidFuture;
import com.android.internal.os.IResultReceiver;
import com.android.internal.util.ArrayUtils;
import com.android.internal.util.Preconditions;
import com.geely.lib.oneosapi.user.bean.LoginType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.Executor;

@SystemApi
public final class CarUserManager extends CarManagerBase {
    public static final String BUNDLE_PARAM_ACTION = "action";
    public static final String BUNDLE_PARAM_PREVIOUS_USER_ID = "previous_user";
    private static final boolean DBG = false;
    private static final int HAL_TIMEOUT_MS = ((Integer) CarProperties.user_hal_timeout().orElse(5000)).intValue();
    private static final String TAG = "CarUserManager";
    @SystemApi
    public static final int USER_LIFECYCLE_EVENT_TYPE_STARTING = 1;
    @SystemApi
    public static final int USER_LIFECYCLE_EVENT_TYPE_STOPPED = 6;
    @SystemApi
    public static final int USER_LIFECYCLE_EVENT_TYPE_STOPPING = 5;
    @SystemApi
    public static final int USER_LIFECYCLE_EVENT_TYPE_SWITCHING = 2;
    @SystemApi
    public static final int USER_LIFECYCLE_EVENT_TYPE_UNLOCKED = 4;
    @SystemApi
    public static final int USER_LIFECYCLE_EVENT_TYPE_UNLOCKING = 3;
    private ArrayMap<UserLifecycleListener, Executor> mListeners;
    private final Object mLock;
    private LifecycleResultReceiver mReceiver;
    private final ICarUserService mService;
    private final UserManager mUserManager;

    @Retention(RetentionPolicy.SOURCE)
    public @interface UserLifecycleEventType {
    }

    @SystemApi
    public interface UserLifecycleListener {
        void onEvent(UserLifecycleEvent userLifecycleEvent);
    }

    public interface UserSwitchUiCallback {
        void showUserSwitchDialog(int i);
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
    }

    public CarUserManager(Car car, IBinder iBinder) {
        this(car, ICarUserService.Stub.asInterface(iBinder), UserManager.get(car.getContext()));
    }

    public CarUserManager(Car car, ICarUserService iCarUserService, UserManager userManager) {
        super(car);
        this.mLock = new Object();
        this.mService = iCarUserService;
        this.mUserManager = userManager;
    }

    public AndroidFuture<UserSwitchResult> switchUser(final int i) {
        final int myUid = Process.myUid();
        if (this.mUserManager.getUserSwitchability() != 0) {
            return newSwitchResuiltForFailure(104);
        }
        try {
            AndroidFuture<UserSwitchResult> r1 = new AndroidFuture<UserSwitchResult>() {
                /* class android.car.user.CarUserManager.AnonymousClass1 */

                /* access modifiers changed from: protected */
                public void onCompleted(UserSwitchResult userSwitchResult, Throwable th) {
                    if (userSwitchResult != null) {
                        EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_SWITCH_USER_RESP, Integer.valueOf(myUid), Integer.valueOf(userSwitchResult.getStatus()), userSwitchResult.getErrorMessage());
                    } else {
                        Log.w(CarUserManager.TAG, "switchUser(" + i + ") failed: " + th);
                    }
                    CarUserManager.super.onCompleted(userSwitchResult, th);
                }
            };
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_SWITCH_USER_REQ, Integer.valueOf(myUid), Integer.valueOf(i));
            this.mService.switchUser(i, HAL_TIMEOUT_MS, r1);
            return r1;
        } catch (RemoteException e) {
            return (AndroidFuture) handleRemoteExceptionFromCarService(e, newSwitchResuiltForFailure(4));
        }
    }

    private AndroidFuture<UserSwitchResult> newSwitchResuiltForFailure(int i) {
        AndroidFuture<UserSwitchResult> androidFuture = new AndroidFuture<>();
        androidFuture.complete(new UserSwitchResult(i, null));
        return androidFuture;
    }

    public AndroidFuture<UserCreationResult> createUser(String str, final String str2, final int i) {
        final int myUid = Process.myUid();
        try {
            AndroidFuture<UserCreationResult> r8 = new AndroidFuture<UserCreationResult>() {
                /* class android.car.user.CarUserManager.AnonymousClass2 */

                /* access modifiers changed from: protected */
                public void onCompleted(UserCreationResult userCreationResult, Throwable th) {
                    if (userCreationResult != null) {
                        EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_CREATE_USER_RESP, Integer.valueOf(myUid), Integer.valueOf(userCreationResult.getStatus()), userCreationResult.getErrorMessage());
                        UserInfo user = userCreationResult.getUser();
                        if (userCreationResult.isSuccess() && user != null && user.isGuest()) {
                            CarUserManager.this.onGuestCreated(user);
                        }
                    } else {
                        Log.w(CarUserManager.TAG, "createUser(" + str2 + "," + UserInfo.flagsToString(i) + ") failed: " + th);
                    }
                    CarUserManager.super.onCompleted(userCreationResult, th);
                }
            };
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_CREATE_USER_REQ, Integer.valueOf(myUid), safeName(str), str2, Integer.valueOf(i));
            this.mService.createUser(str, str2, i, HAL_TIMEOUT_MS, r8);
            return r8;
        } catch (RemoteException e) {
            AndroidFuture androidFuture = new AndroidFuture();
            androidFuture.complete(new UserCreationResult(4, null, null));
            return (AndroidFuture) handleRemoteExceptionFromCarService(e, androidFuture);
        }
    }

    public AndroidFuture<UserCreationResult> createGuest(String str) {
        return createUser(str, "android.os.usertype.full.GUEST", 0);
    }

    public AndroidFuture<UserCreationResult> createUser(String str, int i) {
        return createUser(str, "android.os.usertype.full.SECONDARY", i);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onGuestCreated(UserInfo userInfo) {
        Settings.Secure.putStringForUser(getContext().getContentResolver(), "skip_first_use_hints", LoginType.QR_CODE, userInfo.id);
    }

    public UserRemovalResult removeUser(int i) {
        int myUid = Process.myUid();
        EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_REMOVE_USER_REQ, Integer.valueOf(myUid), Integer.valueOf(i));
        try {
            UserRemovalResult removeUser = this.mService.removeUser(i);
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_REMOVE_USER_RESP, Integer.valueOf(myUid), Integer.valueOf(removeUser.getStatus()));
            return removeUser;
        } catch (RemoteException e) {
            UserRemovalResult userRemovalResult = (UserRemovalResult) handleRemoteExceptionFromCarService(e, new UserRemovalResult(4));
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_REMOVE_USER_RESP, Integer.valueOf(myUid), 4);
            return userRemovalResult;
        } catch (Throwable th) {
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_REMOVE_USER_RESP, Integer.valueOf(myUid), 4);
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0029  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0047  */
    @SystemApi
    public void addListener(Executor executor, UserLifecycleListener userLifecycleListener) {
        boolean z;
        Objects.requireNonNull(executor, "executor cannot be null");
        Objects.requireNonNull(userLifecycleListener, "listener cannot be null");
        int myUid = Process.myUid();
        synchronized (this.mLock) {
            ArrayMap<UserLifecycleListener, Executor> arrayMap = this.mListeners;
            if (arrayMap != null) {
                if (arrayMap.containsKey(userLifecycleListener)) {
                    z = false;
                    Preconditions.checkState(z, "already called for this listener");
                    if (this.mReceiver == null) {
                        this.mReceiver = new LifecycleResultReceiver();
                        try {
                            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_ADD_LISTENER, myUid);
                            this.mService.setLifecycleListenerForUid(this.mReceiver);
                        } catch (RemoteException e) {
                            handleRemoteExceptionFromCarService(e);
                        }
                    }
                    if (this.mListeners == null) {
                        this.mListeners = new ArrayMap<>(1);
                    }
                    this.mListeners.put(userLifecycleListener, executor);
                }
            }
            z = true;
            Preconditions.checkState(z, "already called for this listener");
            if (this.mReceiver == null) {
            }
            if (this.mListeners == null) {
            }
            this.mListeners.put(userLifecycleListener, executor);
        }
    }

    @SystemApi
    public void removeListener(UserLifecycleListener userLifecycleListener) {
        Objects.requireNonNull(userLifecycleListener, "listener cannot be null");
        int myUid = Process.myUid();
        synchronized (this.mLock) {
            ArrayMap<UserLifecycleListener, Executor> arrayMap = this.mListeners;
            Preconditions.checkState(arrayMap != null && arrayMap.containsKey(userLifecycleListener), "not called for this listener yet");
            this.mListeners.remove(userLifecycleListener);
            if (this.mListeners.isEmpty()) {
                this.mListeners = null;
                if (this.mReceiver == null) {
                    Log.wtf(TAG, "removeListener(): receiver already null");
                    return;
                }
                EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_REMOVE_LISTENER, myUid);
                try {
                    this.mService.resetLifecycleListenerForUid();
                    this.mReceiver = null;
                } catch (RemoteException e) {
                    handleRemoteExceptionFromCarService(e);
                }
            }
        }
    }

    public boolean isUserHalUserAssociationSupported() {
        try {
            return this.mService.isUserHalUserAssociationSupported();
        } catch (RemoteException e) {
            return ((Boolean) handleRemoteExceptionFromCarService(e, false)).booleanValue();
        }
    }

    public UserIdentificationAssociationResponse getUserIdentificationAssociation(int... iArr) {
        Preconditions.checkArgument(!ArrayUtils.isEmpty(iArr), "must have at least one type");
        EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_GET_USER_AUTH_REQ, iArr.length);
        try {
            UserIdentificationAssociationResponse userIdentificationAssociation = this.mService.getUserIdentificationAssociation(iArr);
            if (userIdentificationAssociation != null) {
                int[] values = userIdentificationAssociation.getValues();
                EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_GET_USER_AUTH_RESP, values != null ? values.length : 0);
            }
            return userIdentificationAssociation;
        } catch (RemoteException e) {
            return (UserIdentificationAssociationResponse) handleRemoteExceptionFromCarService(e, null);
        }
    }

    public AndroidFuture<UserIdentificationAssociationResponse> setUserIdentificationAssociation(final int[] iArr, final int[] iArr2) {
        Preconditions.checkArgument(!ArrayUtils.isEmpty(iArr), "must have at least one type");
        Preconditions.checkArgument(!ArrayUtils.isEmpty(iArr2), "must have at least one value");
        if (iArr.length == iArr2.length) {
            Integer[] numArr = new Integer[(iArr.length * 2)];
            for (int i = 0; i < iArr.length; i++) {
                int i2 = i * 2;
                numArr[i2] = Integer.valueOf(iArr[i]);
                numArr[i2 + 1] = Integer.valueOf(iArr2[i]);
            }
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_SET_USER_AUTH_REQ, numArr);
            try {
                AndroidFuture<UserIdentificationAssociationResponse> r0 = new AndroidFuture<UserIdentificationAssociationResponse>() {
                    /* class android.car.user.CarUserManager.AnonymousClass3 */

                    /* access modifiers changed from: protected */
                    public void onCompleted(UserIdentificationAssociationResponse userIdentificationAssociationResponse, Throwable th) {
                        if (userIdentificationAssociationResponse != null) {
                            int[] values = userIdentificationAssociationResponse.getValues();
                            if (values != null) {
                                Object[] objArr = new Object[values.length];
                                for (int i = 0; i < values.length; i++) {
                                    objArr[i] = Integer.valueOf(values[i]);
                                }
                                EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_SET_USER_AUTH_RESP, objArr);
                            }
                        } else {
                            Log.w(CarUserManager.TAG, "setUserIdentificationAssociation(" + Arrays.toString(iArr) + ", " + Arrays.toString(iArr2) + ") failed: " + th);
                        }
                        CarUserManager.super.onCompleted(userIdentificationAssociationResponse, th);
                    }
                };
                this.mService.setUserIdentificationAssociation(HAL_TIMEOUT_MS, iArr, iArr2, r0);
                return r0;
            } catch (RemoteException e) {
                AndroidFuture androidFuture = new AndroidFuture();
                androidFuture.complete(UserIdentificationAssociationResponse.forFailure());
                return (AndroidFuture) handleRemoteExceptionFromCarService(e, androidFuture);
            }
        } else {
            throw new IllegalArgumentException("types (" + Arrays.toString(iArr) + ") and values (" + Arrays.toString(iArr2) + ") should have the same length");
        }
    }

    public void setUserSwitchUiCallback(UserSwitchUiCallback userSwitchUiCallback) {
        Preconditions.checkArgument(userSwitchUiCallback != null, "Null callback");
        try {
            this.mService.setUserSwitchUiCallback(new UserSwitchUiCallbackReceiver(userSwitchUiCallback));
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    private final class UserSwitchUiCallbackReceiver extends IResultReceiver.Stub {
        private final UserSwitchUiCallback mUserSwitchUiCallback;

        UserSwitchUiCallbackReceiver(UserSwitchUiCallback userSwitchUiCallback) {
            this.mUserSwitchUiCallback = userSwitchUiCallback;
        }

        public void send(int i, Bundle bundle) throws RemoteException {
            this.mUserSwitchUiCallback.showUserSwitchDialog(i);
        }
    }

    /* access modifiers changed from: private */
    public class LifecycleResultReceiver extends IResultReceiver.Stub {
        private LifecycleResultReceiver() {
        }

        public void send(int i, Bundle bundle) {
            ArrayMap arrayMap;
            if (bundle == null) {
                Log.w(CarUserManager.TAG, "Received result (" + i + ") without data");
                return;
            }
            int i2 = bundle.getInt(CarUserManager.BUNDLE_PARAM_PREVIOUS_USER_ID, -10000);
            int i3 = bundle.getInt(CarUserManager.BUNDLE_PARAM_ACTION);
            UserLifecycleEvent userLifecycleEvent = new UserLifecycleEvent(i3, i2, i);
            synchronized (CarUserManager.this.mLock) {
                arrayMap = CarUserManager.this.mListeners;
            }
            if (arrayMap == null) {
                Log.w(CarUserManager.TAG, "No listeners for event " + userLifecycleEvent);
                return;
            }
            int size = arrayMap.size();
            EventLog.writeEvent((int) EventLogTags.CAR_USER_MGR_NOTIFY_LIFECYCLE_LISTENER, Integer.valueOf(size), Integer.valueOf(i3), Integer.valueOf(i2), Integer.valueOf(i));
            for (int i4 = 0; i4 < size; i4++) {
                ((Executor) arrayMap.valueAt(i4)).execute(new Runnable(userLifecycleEvent) {
                    /* class android.car.user.$$Lambda$CarUserManager$LifecycleResultReceiver$lTgQiNxB4maCgvTcDAKy123DFJM */
                    public final /* synthetic */ CarUserManager.UserLifecycleEvent f$1;

                    {
                        this.f$1 = r2;
                    }

                    public final void run() {
                        CarUserManager.UserLifecycleListener.this.onEvent(this.f$1);
                    }
                });
            }
        }
    }

    public static String lifecycleEventTypeToString(int i) {
        switch (i) {
            case 1:
                return "STARTING";
            case 2:
                return "SWITCHING";
            case 3:
                return "UNLOCKING";
            case 4:
                return "UNLOCKED";
            case 5:
                return "STOPPING";
            case 6:
                return "STOPPED";
            default:
                return "UNKNOWN-" + i;
        }
    }

    /* access modifiers changed from: package-private */
    public ExperimentalCarUserManager newExperimentalCarUserManager() {
        return new ExperimentalCarUserManager(this.mCar, this.mService);
    }

    public boolean isValidUser(int i) {
        List users = this.mUserManager.getUsers(true);
        for (int i2 = 0; i2 < users.size(); i2++) {
            if (((UserInfo) users.get(i2)).id == i && !(i == 0 && UserManager.isHeadlessSystemUserMode())) {
                return true;
            }
        }
        return false;
    }

    private boolean isHeadlessSystemUser(int i) {
        return i == 0 && UserManager.isHeadlessSystemUserMode();
    }

    private static String safeName(String str) {
        return str == null ? str : str.length() + "_chars";
    }

    @SystemApi
    public static final class UserLifecycleEvent {
        private final int mEventType;
        private final int mPreviousUserId;
        private final int mUserId;

        public UserLifecycleEvent(int i, int i2, int i3) {
            this.mEventType = i;
            this.mPreviousUserId = i2;
            this.mUserId = i3;
        }

        public UserLifecycleEvent(int i, int i2) {
            this(i, -10000, i2);
        }

        public int getEventType() {
            return this.mEventType;
        }

        public int getUserId() {
            return this.mUserId;
        }

        public UserHandle getUserHandle() {
            return UserHandle.of(this.mUserId);
        }

        public int getPreviousUserId() {
            return this.mPreviousUserId;
        }

        public UserHandle getPreviousUserHandle() {
            int i = this.mPreviousUserId;
            if (i == -10000) {
                return null;
            }
            return UserHandle.of(i);
        }

        public String toString() {
            StringBuilder append = new StringBuilder("Event[type=").append(CarUserManager.lifecycleEventTypeToString(this.mEventType));
            if (this.mPreviousUserId != -10000) {
                append.append(",from=").append(this.mPreviousUserId).append(",to=").append(this.mUserId);
            } else {
                append.append(",user=").append(this.mUserId);
            }
            return append.append(']').toString();
        }
    }
}
