package android.car.user;

import android.content.pm.UserInfo;
import android.os.Parcel;
import android.os.Parcelable;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

public final class UserCreationResult implements Parcelable {
    public static final Parcelable.Creator<UserCreationResult> CREATOR = new Parcelable.Creator<UserCreationResult>() {
        /* class android.car.user.UserCreationResult.AnonymousClass1 */

        @Override // android.os.Parcelable.Creator
        public UserCreationResult[] newArray(int i) {
            return new UserCreationResult[i];
        }

        @Override // android.os.Parcelable.Creator
        public UserCreationResult createFromParcel(Parcel parcel) {
            return new UserCreationResult(parcel);
        }
    };
    public static final int STATUS_ANDROID_FAILURE = 2;
    public static final int STATUS_HAL_FAILURE = 3;
    public static final int STATUS_HAL_INTERNAL_FAILURE = 4;
    public static final int STATUS_INVALID_REQUEST = 5;
    public static final int STATUS_SUCCESSFUL = 1;
    private final String mErrorMessage;
    private final int mStatus;
    private final UserInfo mUser;

    @Retention(RetentionPolicy.SOURCE)
    public @interface Status {
    }

    @Deprecated
    private void __metadata() {
    }

    public int describeContents() {
        return 0;
    }

    public boolean isSuccess() {
        return this.mStatus == 1;
    }

    public static String statusToString(int i) {
        if (i == 1) {
            return "STATUS_SUCCESSFUL";
        }
        if (i == 2) {
            return "STATUS_ANDROID_FAILURE";
        }
        if (i == 3) {
            return "STATUS_HAL_FAILURE";
        }
        if (i != 4) {
            return i != 5 ? Integer.toHexString(i) : "STATUS_INVALID_REQUEST";
        }
        return "STATUS_HAL_INTERNAL_FAILURE";
    }

    public UserCreationResult(int i, UserInfo userInfo, String str) {
        this.mStatus = i;
        if (i == 1 || i == 2 || i == 3 || i == 4 || i == 5) {
            this.mUser = userInfo;
            this.mErrorMessage = str;
            return;
        }
        throw new IllegalArgumentException("status was " + i + " but must be one of: STATUS_SUCCESSFUL(" + 1 + "), STATUS_ANDROID_FAILURE(" + 2 + "), STATUS_HAL_FAILURE(" + 3 + "), STATUS_HAL_INTERNAL_FAILURE(" + 4 + "), STATUS_INVALID_REQUEST(" + 5 + ")");
    }

    public int getStatus() {
        return this.mStatus;
    }

    public UserInfo getUser() {
        return this.mUser;
    }

    public String getErrorMessage() {
        return this.mErrorMessage;
    }

    public String toString() {
        return "UserCreationResult { status = " + statusToString(this.mStatus) + ", user = " + this.mUser + ", errorMessage = " + this.mErrorMessage + " }";
    }

    public void writeToParcel(Parcel parcel, int i) {
        byte b = this.mUser != null ? (byte) 2 : 0;
        if (this.mErrorMessage != null) {
            b = (byte) (b | 4);
        }
        parcel.writeByte(b);
        parcel.writeInt(this.mStatus);
        UserInfo userInfo = this.mUser;
        if (userInfo != null) {
            parcel.writeTypedObject(userInfo, i);
        }
        String str = this.mErrorMessage;
        if (str != null) {
            parcel.writeString(str);
        }
    }

    UserCreationResult(Parcel parcel) {
        UserInfo userInfo;
        byte readByte = parcel.readByte();
        int readInt = parcel.readInt();
        String str = null;
        if ((readByte & 2) == 0) {
            userInfo = null;
        } else {
            userInfo = (UserInfo) parcel.readTypedObject(UserInfo.CREATOR);
        }
        str = (readByte & 4) != 0 ? parcel.readString() : str;
        this.mStatus = readInt;
        if (readInt == 1 || readInt == 2 || readInt == 3 || readInt == 4 || readInt == 5) {
            this.mUser = userInfo;
            this.mErrorMessage = str;
            return;
        }
        throw new IllegalArgumentException("status was " + readInt + " but must be one of: STATUS_SUCCESSFUL(" + 1 + "), STATUS_ANDROID_FAILURE(" + 2 + "), STATUS_HAL_FAILURE(" + 3 + "), STATUS_HAL_INTERNAL_FAILURE(" + 4 + "), STATUS_INVALID_REQUEST(" + 5 + ")");
    }
}
