package android.car.vms;

import android.annotation.SystemApi;
import android.car.Car;
import android.car.CarManagerBase;
import android.car.vms.IVmsBrokerService;
import android.car.vms.VmsClientManager;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.ArrayMap;
import android.util.Log;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.Executor;
import java.util.function.Consumer;

@SystemApi
public final class VmsClientManager extends CarManagerBase {
    private static final boolean DBG = false;
    private static final String TAG = "VmsClientManager";
    private final IVmsBrokerService mBrokerService;
    private final Map<VmsClientCallback, VmsClient> mClients = new ArrayMap();
    private final Object mLock = new Object();

    public interface VmsClientCallback {
        void onClientConnected(VmsClient vmsClient);

        void onLayerAvailabilityChanged(VmsAvailableLayers vmsAvailableLayers);

        void onPacketReceived(int i, VmsLayer vmsLayer, byte[] bArr);

        void onSubscriptionStateChanged(VmsSubscriptionState vmsSubscriptionState);
    }

    public VmsClientManager(Car car, IBinder iBinder) {
        super(car);
        this.mBrokerService = IVmsBrokerService.Stub.asInterface(iBinder);
    }

    public void registerVmsClientCallback(Executor executor, VmsClientCallback vmsClientCallback) {
        registerVmsClientCallback(executor, vmsClientCallback, false);
    }

    /* access modifiers changed from: package-private */
    public void registerVmsClientCallback(Executor executor, VmsClientCallback vmsClientCallback, boolean z) {
        Objects.requireNonNull(executor, "executor cannot be null");
        Objects.requireNonNull(vmsClientCallback, "callback cannot be null");
        synchronized (this.mLock) {
            if (this.mClients.containsKey(vmsClientCallback)) {
                Log.w(TAG, "VmsClient already registered");
                return;
            }
            VmsClient vmsClient = new VmsClient(this.mBrokerService, executor, vmsClientCallback, z, true, new Consumer() {
                /* class android.car.vms.$$Lambda$VmsClientManager$unCFD_jeaSK5W7JayOFRkrF3Y4 */

                @Override // java.util.function.Consumer
                public final void accept(Object obj) {
                    VmsClientManager.this.handleRemoteExceptionFromCarService((RemoteException) obj);
                }
            });
            this.mClients.put(vmsClientCallback, vmsClient);
            try {
                vmsClient.register();
                executor.execute(new Runnable(vmsClient, z) {
                    /* class android.car.vms.$$Lambda$VmsClientManager$Xjk1wR5EnN1NxPMDTleTqodGs4 */
                    public final /* synthetic */ VmsClient f$1;
                    public final /* synthetic */ boolean f$2;

                    {
                        this.f$1 = r2;
                        this.f$2 = r3;
                    }

                    public final void run() {
                        VmsClientManager.lambda$registerVmsClientCallback$0(VmsClientManager.VmsClientCallback.this, this.f$1, this.f$2);
                    }
                });
            } catch (RemoteException e) {
                Log.e(TAG, "Error while registering", e);
                synchronized (this.mLock) {
                    this.mClients.remove(vmsClientCallback);
                    handleRemoteExceptionFromCarService(e);
                }
            }
        }
    }

    static /* synthetic */ void lambda$registerVmsClientCallback$0(VmsClientCallback vmsClientCallback, VmsClient vmsClient, boolean z) {
        vmsClientCallback.onClientConnected(vmsClient);
        if (!z) {
            vmsClientCallback.onLayerAvailabilityChanged(vmsClient.getAvailableLayers());
            vmsClientCallback.onSubscriptionStateChanged(vmsClient.getSubscriptionState());
        }
    }

    public void unregisterVmsClientCallback(VmsClientCallback vmsClientCallback) {
        VmsClient remove;
        synchronized (this.mLock) {
            remove = this.mClients.remove(vmsClientCallback);
        }
        if (remove == null) {
            Log.w(TAG, "Unregister called for unknown callback");
            return;
        }
        try {
            remove.unregister();
        } catch (RemoteException e) {
            handleRemoteExceptionFromCarService(e);
        }
    }

    /* access modifiers changed from: protected */
    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
        synchronized (this.mLock) {
            Log.w(TAG, "Car disconnected with " + this.mClients.size() + " active clients");
            this.mClients.clear();
        }
    }
}
