package android.car.vms;

import android.util.ArrayMap;
import android.util.ArraySet;
import android.util.SparseBooleanArray;
import java.util.Collections;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.function.Consumer;
import java.util.function.Predicate;
import java.util.stream.Collectors;
import java.util.stream.Stream;

public final class VmsSubscriptionHelper {
    private final Set<VmsLayer> mLayerSubscriptions = new ArraySet();
    private final Object mLock = new Object();
    private boolean mPendingUpdate;
    private final Map<VmsLayer, SparseBooleanArray> mPublisherSubscriptions = new ArrayMap();
    private final Consumer<Set<VmsAssociatedLayer>> mUpdateHandler;

    public VmsSubscriptionHelper(Consumer<Set<VmsAssociatedLayer>> consumer) {
        this.mUpdateHandler = (Consumer) Objects.requireNonNull(consumer, "updateHandler cannot be null");
    }

    public void subscribe(VmsLayer vmsLayer) {
        Objects.requireNonNull(vmsLayer, "layer cannot be null");
        synchronized (this.mLock) {
            if (this.mLayerSubscriptions.add(vmsLayer)) {
                this.mPendingUpdate = true;
            }
            publishSubscriptionUpdate();
        }
    }

    public void subscribe(VmsLayer vmsLayer, int i) {
        Objects.requireNonNull(vmsLayer, "layer cannot be null");
        synchronized (this.mLock) {
            SparseBooleanArray computeIfAbsent = this.mPublisherSubscriptions.computeIfAbsent(vmsLayer, $$Lambda$VmsSubscriptionHelper$aBxHnS9RgDI9S9qLgLEvxGUh8JI.INSTANCE);
            if (!computeIfAbsent.get(i)) {
                computeIfAbsent.put(i, true);
                this.mPendingUpdate = true;
            }
            publishSubscriptionUpdate();
        }
    }

    static /* synthetic */ SparseBooleanArray lambda$subscribe$0(VmsLayer vmsLayer) {
        return new SparseBooleanArray();
    }

    public void unsubscribe(VmsLayer vmsLayer) {
        Objects.requireNonNull(vmsLayer, "layer cannot be null");
        synchronized (this.mLock) {
            if (this.mLayerSubscriptions.remove(vmsLayer)) {
                this.mPendingUpdate = true;
            }
            publishSubscriptionUpdate();
        }
    }

    public void unsubscribe(VmsLayer vmsLayer, int i) {
        Objects.requireNonNull(vmsLayer, "layer cannot be null");
        synchronized (this.mLock) {
            SparseBooleanArray sparseBooleanArray = this.mPublisherSubscriptions.get(vmsLayer);
            if (sparseBooleanArray != null && sparseBooleanArray.get(i)) {
                sparseBooleanArray.delete(i);
                if (sparseBooleanArray.size() == 0) {
                    this.mPublisherSubscriptions.remove(vmsLayer);
                }
                this.mPendingUpdate = true;
            }
            publishSubscriptionUpdate();
        }
    }

    public Set<VmsAssociatedLayer> getSubscriptions() {
        return (Set) Stream.concat(this.mLayerSubscriptions.stream().map($$Lambda$VmsSubscriptionHelper$tO_Sh5ke2msljeSBeQrPUBBX0wA.INSTANCE), this.mPublisherSubscriptions.entrySet().stream().filter(new Predicate() {
            /* class android.car.vms.$$Lambda$VmsSubscriptionHelper$wTinCCd0PGvDZA0QZgzIueMSkA */

            @Override // java.util.function.Predicate
            public final boolean test(Object obj) {
                return VmsSubscriptionHelper.this.lambda$getSubscriptions$2$VmsSubscriptionHelper((Map.Entry) obj);
            }
        }).map($$Lambda$VmsSubscriptionHelper$R2fBZEr4MfbHF6MnEvG14vvLHeQ.INSTANCE)).collect(Collectors.toSet());
    }

    static /* synthetic */ VmsAssociatedLayer lambda$getSubscriptions$1(VmsLayer vmsLayer) {
        return new VmsAssociatedLayer(vmsLayer, Collections.emptySet());
    }

    public /* synthetic */ boolean lambda$getSubscriptions$2$VmsSubscriptionHelper(Map.Entry entry) {
        return !this.mLayerSubscriptions.contains(entry.getKey());
    }

    private void publishSubscriptionUpdate() {
        synchronized (this.mLock) {
            if (this.mPendingUpdate) {
                this.mUpdateHandler.accept(getSubscriptions());
            }
            this.mPendingUpdate = false;
        }
    }

    /* access modifiers changed from: private */
    public static VmsAssociatedLayer toAssociatedLayer(Map.Entry<VmsLayer, SparseBooleanArray> entry) {
        SparseBooleanArray value = entry.getValue();
        ArraySet arraySet = new ArraySet(value.size());
        for (int i = 0; i < value.size(); i++) {
            arraySet.add(Integer.valueOf(value.keyAt(i)));
        }
        return new VmsAssociatedLayer(entry.getKey(), arraySet);
    }
}
