package com.android.car.internal;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import java.util.List;
import java.util.function.Consumer;

public abstract class SingleMessageHandler<EventType> implements Handler.Callback {
    private final int mHandledMessageWhat;
    private final Handler mHandler;

    /* access modifiers changed from: protected */
    public abstract void handleEvent(EventType eventtype);

    public SingleMessageHandler(Looper looper, int i) {
        this.mHandledMessageWhat = i;
        this.mHandler = new Handler(looper, this);
    }

    public SingleMessageHandler(Handler handler, int i) {
        this(handler.getLooper(), i);
    }

    public boolean handleMessage(Message message) {
        if (message.what != this.mHandledMessageWhat) {
            return true;
        }
        ((List) message.obj).forEach(new Consumer<EventType>() {
            /* class com.android.car.internal.SingleMessageHandler.AnonymousClass1 */

            @Override // java.util.function.Consumer
            public void accept(EventType eventtype) {
                SingleMessageHandler.this.handleEvent(eventtype);
            }
        });
        return true;
    }

    public void sendEvents(List<EventType> list) {
        Handler handler = this.mHandler;
        handler.sendMessage(handler.obtainMessage(this.mHandledMessageWhat, list));
    }
}
