package com.geely.carlink;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.res.Configuration;
import android.os.Bundle;
import android.os.CountDownTimer;
import android.os.IBinder;
import android.os.Message;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.Surface;
import android.view.SurfaceHolder;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import androidx.appcompat.app.ActionBar;
import com.geely.carlink.UCarAlertUtil;
import com.geely.carlink.app.HmiApp;
import com.geely.carlink.broadcast.BroadCastProxy;
import com.geely.carlink.constant.Const;
import com.geely.carlink.ext.HandlerManager;
import com.geely.carlink.listener.ServiceListener;
import com.geely.carlink.service.CarLinkService;
import com.geely.carlink.utils.TgSystem;
import com.geely.carlink.widget.UCarAlertView;
import com.geely.carlink.widget.UCarPinCodeView;
import com.geely.carlink.widget.UCarProgressBar;
import com.ucar.sdk.BuildConfig;
import com.ucar.vehiclesdk.UCarAdapter;
import com.ucar.vehiclesdk.UCarCommon;
import com.ucar.vehiclesdk.UCarSurfaceView;
import java.util.Objects;

public class MainActivity extends PermissionsReqActivity implements ServiceConnection {
    private static final int PROCESS_0 = 0;
    private static final int PROCESS_COMPLETE = 100;
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private BroadCastProxy broadCastProxy;
    private TextView callTime;
    private CarLinkService carService;
    private boolean isBind = false;
    private boolean isNeedReInit = false;
    private TextView mDeviceName;
    private UCarAlertView mDialog;
    private int mDisplayDensityDpi;
    private int mExpectedDisplayHeight;
    private int mExpectedDisplayWidth;
    private int mFullDisplayHeight;
    private int mFullDisplayWidth;
    private boolean mIsDeviceConnected = false;
    private boolean mIsPendingCheckExitProcess = false;
    private boolean mIsProgressShown;
    private UCarPinCodeView mPinCodeView;
    private UCarProgressBar mProgress;
    private FrameLayout mRootLayout;
    private View mRootView;
    private final ServiceListener mServiceListener = new CarLinkServiceListener();
    private SurfaceHolder.Callback mSurfaceHolderCallback;
    private UCarSurfaceView mSurfaceView;
    private float mX1 = 0.0f;
    private float mX2 = 0.0f;
    private float mY1 = 0.0f;
    private float mY2 = 0.0f;
    private CountDownTimer timer;

    /* access modifiers changed from: protected */
    @Override // com.geely.carlink.PermissionsReqActivity
    public String[] getPermissions() {
        return new String[]{"android.permission.ACCESS_FINE_LOCATION", "android.permission.WRITE_EXTERNAL_STORAGE", "android.permission.RECORD_AUDIO", "android.permission.CAMERA"};
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.carlink.PermissionsReqActivity
    public void onPermissionsGranted() {
        setActions();
    }

    private void setActions() {
        findViewById(R.id.tv_exit).setOnClickListener(new View.OnClickListener() {
            /* class com.geely.carlink.$$Lambda$MainActivity$k4wqDCY6PgoQIlmo5A16FhqRZ0 */

            public final void onClick(View view) {
                MainActivity.this.lambda$setActions$0$MainActivity(view);
            }
        });
        this.mDeviceName = (TextView) findViewById(R.id.tv_device_name);
        this.mPinCodeView = (UCarPinCodeView) findViewById(R.id.upc_pin_code);
    }

    public /* synthetic */ void lambda$setActions$0$MainActivity(View view) {
        this.mProgress.hide();
        finish();
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.carlink.PermissionsReqActivity
    public void onPermissionsDenied() {
        finish();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        Log.i(this.TAG, "onCreate ====================================" + this);
        start();
    }

    private void start() {
        requestWindowFeature(1);
        getWindow().setFlags(1024, 1024);
        int intExtra = getIntent().getIntExtra("launcherDisplayId", 0);
        Log.i(this.TAG, "onCreate: currentDisplayId = " + intExtra);
        HmiApp.getInstance().setDisplayId(intExtra);
        setContentView(R.layout.activity_ucar_cast);
        ((ActionBar) Objects.requireNonNull(getSupportActionBar())).hide();
        this.broadCastProxy = new BroadCastProxy(this);
        this.mRootLayout = (FrameLayout) findViewById(R.id.fl_root);
        this.mProgress = new UCarProgressBar(this, this.mRootLayout);
        setSdkVersion();
        startCarService();
    }

    private void startCarService() {
        Log.i(this.TAG, "bindService");
        this.isBind = bindService(new Intent(this, CarLinkService.class), this, 1);
    }

    public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
        Log.i(this.TAG, "onServiceConnected;");
        CarLinkService service = ((CarLinkService.MyBind) iBinder).getService();
        this.carService = service;
        service.registerServiceListener(this.mServiceListener);
        if (!this.carService.isCarLinkSDKInitSuccess()) {
            Log.i(this.TAG, "carService.initUCarSDK();");
            this.carService.initCarLinkCarSDK();
            Log.e(this.TAG, "onServiceConnected: to init sdk");
            return;
        }
        Log.i(this.TAG, "sdk inited;");
        if (!this.carService.isDeviceConnected() && !this.carService.isCastSucceed()) {
            Log.e(this.TAG, "when onServiceConnected try connect (wifi)");
            this.carService.tryReconnect();
        } else if (this.carService.isDeviceConnected()) {
            handleCastConnected();
        }
    }

    public void onServiceDisconnected(ComponentName componentName) {
        this.carService = null;
    }

    private class CarLinkServiceListener implements ServiceListener {
        @Override // com.geely.carlink.listener.ServiceListener
        public void onResumeProjection() {
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onSDKLoading() {
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onSDKServiceDied() {
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void startMainActivity() {
        }

        private CarLinkServiceListener() {
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onSDKInitSuccess() {
            if (MainActivity.this.carService != null) {
                Log.i(MainActivity.this.TAG, "onSDKInitSuccess: try connect (wifi)");
                MainActivity.this.carService.tryConnect(2);
            }
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onSDKInitFail(int i) {
            MainActivity.this.handleConnectFailed(i);
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onPinCodeRefresh(Message message) {
            MainActivity.this.setPinCode(message);
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onDisconnected(Message message) {
            MainActivity.this.handleDisconnected(message);
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onCastConnected() {
            MainActivity.this.handleCastConnected();
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onCastDisConnected() {
            Log.i(MainActivity.this.TAG, "onCastDisConnected()");
            MainActivity.this.finish();
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onConnectFail(int i) {
            MainActivity.this.handleConnectFailed(i);
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onConnectSuccess() {
            MainActivity.this.handleConnectSuccess();
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onProgress(Message message) {
            MainActivity.this.setProgress(message);
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void goToHome() {
            MainActivity.this.backToHome();
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onHeadUnitDeactivate() {
            MainActivity.this.finish();
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void setTopApp() {
            Log.i(MainActivity.this.TAG, "setTopApp()");
            TgSystem.setTopApp(MainActivity.this);
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onPermitted() {
            Log.i(MainActivity.this.TAG, "onPermitted: ");
            if (MainActivity.this.carService == null) {
                Log.e(MainActivity.this.TAG, "onPermitted: service null");
            } else {
                MainActivity.this.carService.startAvd();
            }
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onDenied() {
            Log.i(MainActivity.this.TAG, "onDenied: ");
            MainActivity.this.finish();
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onCallStateRinging() {
            Log.i(MainActivity.this.TAG, "onCallStateRinging: ");
            MainActivity.this.removePreviousView();
            if (!TgSystem.isTopActivity(MainActivity.this)) {
                MainActivity.this.showCallWindow(UCarCommon.ModemCallState.RINGING);
            }
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onCallStateOffhook() {
            Log.i(MainActivity.this.TAG, "onCallStatoffhook: ");
            MainActivity.this.startTimer();
            MainActivity.this.removePreviousView();
            if (!TgSystem.isTopActivity(MainActivity.this)) {
                MainActivity.this.showCallWindow(UCarCommon.ModemCallState.OFFHOOK);
            }
        }

        @Override // com.geely.carlink.listener.ServiceListener
        public void onCallStateIdle() {
            Log.i(MainActivity.this.TAG, "onCallStatIdle: ");
            if (MainActivity.this.timer != null) {
                MainActivity.this.timer.cancel();
                MainActivity.this.timer = null;
            }
            MainActivity.this.removePreviousView();
        }
    }

    private void setSdkVersion() {
        ((TextView) findViewById(R.id.tv_sdk_version)).setText(BuildConfig.SDK_VERSION);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setProgress(Message message) {
        Bundle bundle = (Bundle) message.obj;
        String string = bundle.getString("NAME");
        int i = bundle.getInt("PROGRESS");
        if (i == 0) {
            hideProgress();
        } else if (i == 100) {
            hideProgress();
        } else {
            this.mIsProgressShown = true;
            this.mProgress.updateProgress(string, i);
            this.mProgress.show();
            UCarAlertView uCarAlertView = this.mDialog;
            if (uCarAlertView != null && uCarAlertView.isShowing()) {
                this.mDialog.dismiss();
            }
        }
    }

    private void hideProgress() {
        if (this.mIsProgressShown) {
            this.mProgress.hide();
            this.mIsProgressShown = false;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setPinCode(Message message) {
        Bundle bundle = (Bundle) message.obj;
        String string = bundle.getString("PIN_CODE");
        String string2 = bundle.getString("DEVICE_NAME");
        Log.e(this.TAG, "setPinCode" + string + "/" + string2);
        this.mPinCodeView.setPinCode(string);
        this.mDeviceName.setText(string2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleDisconnected(Message message) {
        this.mIsDeviceConnected = false;
        Bundle bundle = (Bundle) message.obj;
        String string = bundle.getString("ID");
        boolean z = bundle.getInt("PARAMETER") == 11;
        if (this.mIsPendingCheckExitProcess) {
            this.mIsPendingCheckExitProcess = false;
            int connectType = UCarAdapter.getInstance().getConnectType(string);
            if (z || !(connectType == 1 || connectType == 3)) {
                finish();
            } else {
                Log.i(this.TAG, "prepare for auto reconnection");
                this.carService.tryReconnect();
                setCastSurfaceVisibility(false);
            }
        }
        hideProgress();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleConnectSuccess() {
        this.mIsDeviceConnected = true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleConnectFailed(int i) {
        Log.i(this.TAG, "ucar connect failed, error code:" + i);
        UCarAlertView uCarAlertView = this.mDialog;
        if (uCarAlertView != null) {
            uCarAlertView.show();
            return;
        }
        String string = getString(R.string.connect_failed);
        String str = "\n" + getString(R.string.wireless_reconnect_method) + "\n" + getString(R.string.usb_reconnect_method) + "\n" + getString(R.string.need_user_intervention_method) + "\n" + getString(R.string.unsupport_wireless_method) + "\n" + getString(R.string.restart_car_method) + "\n";
        Log.i(this.TAG, "error message:" + str);
        hideProgress();
        UCarAlertView makeDialog = UCarAlertUtil.makeDialog(this, R.layout.dialog_connect_failed_notice, 0, string, str, getString(R.string.reconnect), getString(R.string.cancel), new UCarAlertUtil.OnClickListener() {
            /* class com.geely.carlink.$$Lambda$MainActivity$AhZsc1RN0ikzY3i5JEG0TlGAHYE */

            @Override // com.geely.carlink.UCarAlertUtil.OnClickListener
            public final boolean onClick() {
                return MainActivity.this.lambda$handleConnectFailed$1$MainActivity();
            }
        }, new UCarAlertUtil.OnClickListener() {
            /* class com.geely.carlink.$$Lambda$MainActivity$6ntWsG1gGhTuQ3wnnGqijN4D1Ts */

            @Override // com.geely.carlink.UCarAlertUtil.OnClickListener
            public final boolean onClick() {
                return MainActivity.this.lambda$handleConnectFailed$2$MainActivity();
            }
        });
        this.mDialog = makeDialog;
        makeDialog.show();
    }

    public /* synthetic */ boolean lambda$handleConnectFailed$1$MainActivity() {
        if (this.carService == null) {
            Log.e(this.TAG, "handleConnectFailed: service null");
            return false;
        }
        Log.i(this.TAG, "handleConnectFailed: try connect (wifi)");
        this.carService.tryConnect(2);
        return false;
    }

    public /* synthetic */ boolean lambda$handleConnectFailed$2$MainActivity() {
        finish();
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleCastConnected() {
        Log.i(this.TAG, "handleCastConnected()");
        this.mIsPendingCheckExitProcess = true;
        setCastSurfaceVisibility(true);
        hideProgress();
    }

    private void handleCastDisConnected() {
        setCastSurfaceVisibility(false);
    }

    private void setCastSurfaceVisibility(boolean z) {
        Log.i(this.TAG, "setCastSurfaceVisibility : " + z);
        View findViewById = findViewById(R.id.cl_ucar_connect_container);
        View findViewById2 = findViewById(R.id.rl_cast_player);
        if (z) {
            setCastSurface();
            findViewById2.setVisibility(0);
            findViewById.setVisibility(8);
            HandlerManager.getInstance().getExpandHandler().updatePlayState(2);
            return;
        }
        unsetCastSurface();
        findViewById.setVisibility(0);
        findViewById2.setVisibility(8);
    }

    private void setAllGONE() {
        Log.i(this.TAG, "setAllGONE()");
        View findViewById = findViewById(R.id.cl_ucar_connect_container);
        View findViewById2 = findViewById(R.id.rl_cast_player);
        unsetCastSurface();
        findViewById.setVisibility(8);
        findViewById2.setVisibility(8);
    }

    private void setCastSurface() {
        if (this.mSurfaceHolderCallback == null) {
            Log.i(this.TAG, "create mSurfaceHolderCallback!!");
            this.mSurfaceHolderCallback = new SurfaceHolder.Callback() {
                /* class com.geely.carlink.MainActivity.AnonymousClass1 */

                public void surfaceCreated(SurfaceHolder surfaceHolder) {
                    Log.i(MainActivity.this.TAG, "surfaceCreated");
                    surfaceHolder.setSizeFromLayout();
                }

                public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i2, int i3) {
                    Log.i(MainActivity.this.TAG, "surfaceChanged, width:" + i2 + ",height:" + i3);
                    if (i2 == 1440 && i3 == 1080) {
                        MainActivity.this.findViewById(R.id.rl_cast_player).setVisibility(8);
                    }
                    if (surfaceHolder == null || surfaceHolder.getSurface() == null || !surfaceHolder.getSurface().isValid()) {
                        Log.i(MainActivity.this.TAG, "SurfaceHolder or Surface is null or invalid");
                        UCarAdapter.getInstance().pauseCast();
                        return;
                    }
                    UCarAdapter.getInstance().startCast(surfaceHolder.getSurface(), i2, i3);
                }

                public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
                    Log.i(MainActivity.this.TAG, "surfaceDestroyed");
                    UCarAdapter.getInstance().pauseCast();
                }
            };
            Log.i(this.TAG, "get mSurfaceView!!");
            UCarSurfaceView uCarSurfaceView = (UCarSurfaceView) findViewById(R.id.surface_view);
            this.mSurfaceView = uCarSurfaceView;
            if (uCarSurfaceView != null && uCarSurfaceView.getHolder() != null) {
                Log.i(this.TAG, "add surface holder callback!!");
                resizeSurfaceAccordingToCastSize();
                this.mSurfaceView.getHolder().addCallback(this.mSurfaceHolderCallback);
                Surface surface = this.mSurfaceView.getHolder().getSurface();
                if (surface != null && surface.isValid()) {
                    Log.i(this.TAG, "startCast mSurfaceView.getWidth() = " + this.mSurfaceView.getWidth() + "mSurfaceView.getHeight()=" + this.mSurfaceView.getHeight());
                    UCarAdapter.getInstance().startCast(surface, this.mSurfaceView.getWidth(), this.mSurfaceView.getHeight());
                }
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void unsetCastSurface() {
        UCarSurfaceView uCarSurfaceView = this.mSurfaceView;
        if (uCarSurfaceView != null && uCarSurfaceView.getHolder() != null) {
            Log.i(this.TAG, "remove surface holder callback");
            this.mSurfaceView.getHolder().removeCallback(this.mSurfaceHolderCallback);
            this.mSurfaceHolderCallback = null;
            this.mSurfaceView = null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void backToHome() {
        Log.i(this.TAG, "backToHome(): ");
        moveTaskToBack(false);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onStart() {
        super.onStart();
        Log.i(this.TAG, "onStart" + this);
        Log.i(this.TAG, "onStart: currentDisplayId = " + getIntent().getIntExtra("launcherDisplayId", 0));
        this.broadCastProxy.sendMainActivityStateByBroadCast(true);
        CarLinkService carLinkService = this.carService;
        if (carLinkService == null) {
            Log.e(this.TAG, "onStart: service null");
        } else if (!carLinkService.isCarLinkSDKInitSuccess()) {
            Log.e(this.TAG, "onStart: when service is not ready or init not finished");
        } else {
            Log.i(this.TAG, "onStart: sdk init success");
            if (!this.carService.isCastSucceed()) {
                Log.i(this.TAG, "cast = false");
                Log.i(this.TAG, "onStart: try connect (wifi)");
                this.carService.tryReconnect();
                return;
            }
            Log.i(this.TAG, "cast = true");
            handleCastConnected();
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.FragmentActivity
    public void onResume() {
        super.onResume();
        Log.i(this.TAG, "onResume" + this);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onStop() {
        super.onStop();
        Log.i(this.TAG, "onStop" + this);
        CarLinkService carLinkService = this.carService;
        if (carLinkService != null) {
            if (carLinkService.isCastSucceed()) {
                new Thread(new Runnable() {
                    /* class com.geely.carlink.$$Lambda$MainActivity$3g6ENVn1TTE8aupnipS4BqnjhLw */

                    public final void run() {
                        MainActivity.this.lambda$onStop$3$MainActivity();
                    }
                }).start();
                unsetCastSurface();
                if (!(this.carService.isMusicPlaying() || HandlerManager.getInstance() == null || HandlerManager.getInstance().getExpandHandler() == null)) {
                    HandlerManager.getInstance().getExpandHandler().updatePlayState(1);
                }
                Log.i(this.TAG, "carService.setCastSucceed(false);");
            }
            if (this.carService.isAdvertising()) {
                this.carService.stopAdv();
                Log.e(this.TAG, "onStop()CarLinkService.isAdvertising() = true");
            } else {
                Log.e(this.TAG, "onStop()CarLinkService.isAdvertising() = false");
            }
            this.broadCastProxy.sendMainActivityStateByBroadCast(false);
            this.carService.disableUsbDeviceDetection();
            if (this.carService.isCalling()) {
                showCallWindow(this.carService.getCallState());
            }
        }
    }

    public /* synthetic */ void lambda$onStop$3$MainActivity() {
        Log.i(this.TAG, "pause cast");
        UCarAdapter.getInstance().pauseCast();
    }

    public void onWindowFocusChanged(boolean z) {
        super.onWindowFocusChanged(z);
        Log.i(this.TAG, "onWindowFocusChanged: " + z);
        if (z) {
            hideSystemUi();
            CarLinkService carLinkService = this.carService;
            if (carLinkService != null && carLinkService.isCarLinkSDKInitSuccess()) {
                UCarAdapter.getInstance().allowGainAudioFocus();
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onDestroy() {
        Log.i(this.TAG, "onDestroy carService = null" + this);
        UCarAlertView uCarAlertView = this.mDialog;
        if (uCarAlertView != null && uCarAlertView.isShowing()) {
            this.mDialog.dismiss();
        }
        CarLinkService carLinkService = this.carService;
        if (carLinkService != null) {
            carLinkService.sendDisConnectBroadCast();
        }
        super.onDestroy();
        if (this.isBind) {
            unbindService(this);
        }
    }

    public void finish() {
        Log.e(this.TAG, "finish()===>" + hashCode());
        CarLinkService carLinkService = this.carService;
        if (carLinkService != null) {
            carLinkService.unregisterServiceListener();
            if (this.carService.isAdvertising()) {
                this.carService.stopAdv();
                HandlerManager.getInstance().getExpandHandler().updatePlayState(1);
                Log.e(this.TAG, "finish()===>CarLinkService.isAdvertising() = true");
            } else {
                Log.e(this.TAG, "finish()===>CarLinkService.isAdvertising() = false");
            }
        }
        super.finish();
    }

    private void hideSystemUi() {
        if (BuildConfig.flavorType.intValue() != 2) {
            getWindow().getDecorView().setSystemUiVisibility(4102);
            Log.i(this.TAG, "kx11 decorView hide");
        } else if (HandlerManager.getInstance() == null || HandlerManager.getInstance().getExpandHandler() == null) {
            Log.i(this.TAG, "HandlerManager.getInstance()==null");
        } else {
            HandlerManager.getInstance().getExpandHandler().hideDockView();
            Log.i(this.TAG, "ex11 decorView hide");
        }
    }

    private void initDisplayMetrics() {
        Display defaultDisplay = ((WindowManager) getApplicationContext().getSystemService("window")).getDefaultDisplay();
        DisplayMetrics displayMetrics = new DisplayMetrics();
        defaultDisplay.getMetrics(displayMetrics);
        this.mDisplayDensityDpi = displayMetrics.densityDpi;
        this.mFullDisplayWidth = displayMetrics.widthPixels;
        Log.i(this.TAG, "mFullDisplayWidth=" + this.mFullDisplayWidth);
        if (BuildConfig.flavorType.intValue() == 0) {
            this.mFullDisplayWidth += 120;
        }
        this.mFullDisplayHeight = displayMetrics.heightPixels;
        if (BuildConfig.flavorType.intValue() == 4 && HmiApp.getInstance().getDisplayId() == 2 && this.mFullDisplayWidth != 2880) {
            this.mFullDisplayWidth = Const.G636_CSD_WIDTH;
            this.mFullDisplayHeight = Const.G636_CSD_HEIGHT;
            Log.i(this.TAG, "636 CSD");
        }
        Log.i(this.TAG, "mFullDisplayWidth=" + this.mFullDisplayWidth + "mFullDisplayHeight=" + this.mFullDisplayHeight + "mDisplayDensityDpi=" + this.mDisplayDensityDpi);
        this.mExpectedDisplayWidth = this.mFullDisplayWidth;
        this.mExpectedDisplayHeight = this.mFullDisplayHeight;
    }

    private void resizeSurfaceAccordingToCastSize() {
        initDisplayMetrics();
        this.mSurfaceView.setLayoutParams(new RelativeLayout.LayoutParams(this.mExpectedDisplayWidth, this.mExpectedDisplayHeight));
    }

    @Override // androidx.activity.ComponentActivity
    public void onBackPressed() {
        Log.i(this.TAG, "onBackPressed: ");
        moveTaskToBack(true);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.FragmentActivity
    public void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        Log.i(this.TAG, "onNewIntent");
        if (intent != null && BuildConfig.flavorType.intValue() == 4) {
            int intExtra = intent.getIntExtra("launcherDisplayId", 0);
            Log.i(this.TAG, "onNewIntent: displayId = " + intExtra);
            if (intExtra != HmiApp.getInstance().getDisplayId()) {
                HmiApp.getInstance().setDisplayId(intExtra);
                setAllGONE();
                unbindService(this);
                this.isBind = false;
                finish();
                reStart(intExtra);
            }
        }
    }

    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onConfigurationChanged(Configuration configuration) {
        Log.i(this.TAG, "onConfigurationChanged: ");
        int displayId = HmiApp.getInstance().getDisplayId();
        int i = configuration.orientation;
        String str = "当前主屏";
        boolean z = true;
        if (i == 1) {
            if (displayId != 2) {
                z = false;
            }
            String str2 = this.TAG;
            StringBuilder append = new StringBuilder().append("onConfigurationChanged: 竖屏  ");
            if (displayId != 0) {
                str = "当前副屏";
            }
            Log.d(str2, append.append(str).append(" layout changed = ").append(z).toString());
        } else if (i != 2) {
            z = false;
        } else {
            if (displayId != 0) {
                z = false;
            }
            String str3 = this.TAG;
            StringBuilder append2 = new StringBuilder().append("onConfigurationChanged: 横屏  ");
            if (displayId != 0) {
                str = "当前副屏";
            }
            Log.d(str3, append2.append(str).append(" layout changed = ").append(z).toString());
        }
        if (BuildConfig.flavorType.intValue() == 4 && z) {
            if (displayId == 2) {
                displayId = 0;
            } else if (displayId == 0) {
                displayId = 2;
            }
            setAllGONE();
            unbindService(this);
            this.isBind = false;
            finish();
            reStart(displayId);
        }
        super.onConfigurationChanged(configuration);
    }

    private void reStart(int i) {
        Log.i(this.TAG, "reStart: currentDisplayId=" + i);
        Intent launchIntentForPackage = getPackageManager().getLaunchIntentForPackage(getPackageName());
        launchIntentForPackage.addFlags(67108864);
        launchIntentForPackage.putExtra("launcherDisplayId", i);
        startActivity(launchIntentForPackage);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showCallWindow(UCarCommon.ModemCallState modemCallState) {
        int i;
        if (modemCallState == UCarCommon.ModemCallState.RINGING) {
            i = R.layout.calling_mini_ring;
        } else {
            i = modemCallState == UCarCommon.ModemCallState.OFFHOOK ? R.layout.calling_mini_active : 0;
        }
        View inflate = LayoutInflater.from(this).inflate(i, (ViewGroup) null, false);
        addViewListener(inflate, modemCallState);
        addPanelToWMS(inflate, this);
        this.mRootView = inflate;
    }

    private void addViewListener(View view, UCarCommon.ModemCallState modemCallState) {
        Log.d(this.TAG, "addViewListener :" + view);
        if (view != null) {
            if (modemCallState == UCarCommon.ModemCallState.OFFHOOK) {
                this.callTime = (TextView) view.findViewById(R.id.callTime);
            }
            View findViewById = view.findViewById(R.id.answerCall);
            if (findViewById != null) {
                findViewById.setOnClickListener(new View.OnClickListener() {
                    /* class com.geely.carlink.$$Lambda$MainActivity$rvI2TMjvqT1lelIrsz0YB7myiVE */

                    public final void onClick(View view) {
                        MainActivity.this.lambda$addViewListener$4$MainActivity(view);
                    }
                });
            }
            View findViewById2 = view.findViewById(R.id.rejectCallBtn);
            if (findViewById2 != null) {
                findViewById2.setOnClickListener(new View.OnClickListener() {
                    /* class com.geely.carlink.$$Lambda$MainActivity$WWCHj3D3aQNqEhWR7cBHcHOWco */

                    public final void onClick(View view) {
                        MainActivity.this.lambda$addViewListener$5$MainActivity(view);
                    }
                });
            }
            view.setOnClickListener(new View.OnClickListener() {
                /* class com.geely.carlink.$$Lambda$MainActivity$1uv_aes4eDZfsJNIQIPF3Khpuo */

                public final void onClick(View view) {
                    MainActivity.this.lambda$addViewListener$6$MainActivity(view);
                }
            });
        }
    }

    public /* synthetic */ void lambda$addViewListener$4$MainActivity(View view) {
        if (this.carService != null) {
            dissMissUiShowClickBtn();
            this.carService.sendKeyEventInternal(5);
            TgSystem.setTopApp(this);
        }
    }

    public /* synthetic */ void lambda$addViewListener$5$MainActivity(View view) {
        CarLinkService carLinkService = this.carService;
        if (carLinkService != null) {
            carLinkService.sendKeyEventInternal(6);
            dissMissUiShowClickBtn();
        }
    }

    public /* synthetic */ void lambda$addViewListener$6$MainActivity(View view) {
        dissMissUiShowClickBtn();
        TgSystem.setTopApp(this);
    }

    private void dissMissUiShowClickBtn() {
        Log.d(this.TAG, " dissMissUiShowClickBtn :" + Log.getStackTraceString(new Throwable()));
        View view = this.mRootView;
        if (view != null && view.isShown()) {
            removePreviousView();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void removePreviousView() {
        View view = this.mRootView;
        if (view != null) {
            if (!view.isAttachedToWindow()) {
                Log.e(this.TAG, "  View is not AttachedToWindow");
            }
            Log.d(this.TAG, "getWindowManager().removeView");
            try {
                getWindowManager().removeView(this.mRootView);
                this.mRootView = null;
            } catch (Exception e) {
                Log.d(this.TAG, "Exception " + Log.getStackTraceString(e));
                e.printStackTrace();
            }
        }
    }

    public void addPanelToWMS(View view, Context context) {
        if (this.mRootView != null) {
            Log.d(this.TAG, "     addPanelToWMS     ");
            removePreviousView();
        }
        Log.d(this.TAG, "windowType:" + 2051);
        WindowManager.LayoutParams layoutParams = new WindowManager.LayoutParams();
        layoutParams.type = 2051;
        layoutParams.format = 1;
        layoutParams.gravity = 49;
        layoutParams.flags = 32;
        layoutParams.width = -2;
        layoutParams.height = -2;
        layoutParams.windowAnimations = R.style.WindowAnimation_alpha_style;
        layoutParams.y = TgSystem.dip2px(this, 72.0f);
        layoutParams.packageName = context.getPackageName();
        ((WindowManager) getSystemService("window")).addView(view, layoutParams);
        setViewOnTouchListener(view);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startTimer() {
        Log.d(this.TAG, "startTimer====");
        AnonymousClass2 r0 = new CountDownTimer(86400000, 1000) {
            /* class com.geely.carlink.MainActivity.AnonymousClass2 */

            public void onTick(long j) {
                Log.d(MainActivity.this.TAG, "onTick" + j);
                if (MainActivity.this.callTime != null) {
                    MainActivity.this.callTime.setText(TgSystem.formatTime((86400000 - j) / 1000));
                }
            }

            public void onFinish() {
                Log.d(MainActivity.this.TAG, "timer onFinish====");
            }
        };
        this.timer = r0;
        r0.start();
    }

    private void setViewOnTouchListener(View view) {
        view.setOnTouchListener(new View.OnTouchListener() {
            /* class com.geely.carlink.MainActivity.AnonymousClass3 */

            public boolean onTouch(View view, MotionEvent motionEvent) {
                if (motionEvent.getAction() == 0) {
                    MainActivity.this.mX1 = motionEvent.getX();
                    MainActivity.this.mY1 = motionEvent.getY();
                }
                if (motionEvent.getAction() != 1) {
                    return false;
                }
                MainActivity.this.mX2 = motionEvent.getX();
                MainActivity.this.mY2 = motionEvent.getY();
                if (MainActivity.this.mY1 - MainActivity.this.mY2 > 50.0f) {
                    Log.d(MainActivity.this.TAG, "y1 - y2 > 50");
                    MainActivity.this.removePreviousView();
                    return true;
                } else if (MainActivity.this.mY2 - MainActivity.this.mY1 > 50.0f) {
                    Log.d(MainActivity.this.TAG, "y2 - y1 > 50");
                    return false;
                } else if (MainActivity.this.mX1 - MainActivity.this.mX2 > 50.0f) {
                    Log.d(MainActivity.this.TAG, "x1 - x2 > 50");
                    return false;
                } else if (MainActivity.this.mX2 - MainActivity.this.mX1 <= 50.0f) {
                    return false;
                } else {
                    Log.d(MainActivity.this.TAG, "x2 - x1 > 50");
                    return false;
                }
            }
        });
    }
}
