package com.geely.carlink.ext;

import android.content.Context;
import com.geely.carlink.handler.call.CallHandler;
import com.geely.carlink.handler.daynight.DayNightHandler;
import com.geely.carlink.handler.dockbar.DockBarHandler;
import com.geely.carlink.handler.key.KeyHandler;
import com.geely.carlink.handler.link.LinkHandler;
import com.geely.carlink.handler.navi.NaviHandler;
import com.geely.carlink.handler.sensor.SensorHandler;
import com.geely.carlink.handler.systemmode.SystemModeHandler;
import com.geely.carlink.handler.vr.VrHandler;
import java.util.concurrent.ConcurrentHashMap;

public class HandlerManager {
    private static volatile HandlerManager instance;
    private ExpandHandlerProxy expandHandlerProxy;
    private final ConcurrentHashMap<String, IHandler> handlers = new ConcurrentHashMap<>();

    HandlerManager() {
    }

    public static HandlerManager getInstance() {
        if (instance == null) {
            synchronized (HandlerManager.class) {
                if (instance == null) {
                    instance = new HandlerManager();
                }
            }
        }
        return instance;
    }

    public void init(Context context) {
        if (instance != null) {
            this.expandHandlerProxy = new ExpandHandlerProxy();
            registerHandler(context, new DockBarHandler());
            registerHandler(context, new CallHandler());
            registerHandler(context, new DayNightHandler());
            registerHandler(context, new KeyHandler());
            registerHandler(context, new NaviHandler());
            registerHandler(context, new SensorHandler());
            registerHandler(context, new SystemModeHandler());
            registerHandler(context, new LinkHandler());
            registerHandler(context, new VrHandler());
            return;
        }
        throw new IllegalStateException("instance don't initiate");
    }

    /* access modifiers changed from: protected */
    public <T extends IHandler> T getSpecialHandler(Class<T> cls) {
        return (T) this.handlers.get(cls.getSimpleName());
    }

    public ExpandHandlerProxy getExpandHandler() {
        return this.expandHandlerProxy;
    }

    /* access modifiers changed from: package-private */
    public void registerHandler(Context context, IHandler... iHandlerArr) {
        if (iHandlerArr != null && iHandlerArr.length > 0) {
            for (IHandler iHandler : iHandlerArr) {
                this.handlers.put(iHandler.getHandlerName(), iHandler);
                iHandler.init(context);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void unRegisterHandler(IHandler... iHandlerArr) {
        if (iHandlerArr != null && iHandlerArr.length > 0) {
            for (IHandler iHandler : iHandlerArr) {
                this.handlers.remove(iHandler.getHandlerName());
                iHandler.deInit();
            }
        }
    }

    public void deInit() {
        for (IHandler iHandler : this.handlers.values()) {
            iHandler.deInit();
        }
        this.handlers.clear();
    }
}
