package com.geely.carlink.handler.call;

import android.content.Context;
import android.util.Log;
import android.view.KeyEvent;
import android.widget.Toast;
import com.ecarx.xui.adaptapi.binder.IConnectable;
import com.ecarx.xui.adaptapi.oncall.Call;
import com.ecarx.xui.adaptapi.oncall.OnCall;
import com.geely.carlink.MainActivity;
import com.geely.carlink.constant.Const;
import com.geely.carlink.ext.IHandler;
import com.geely.carlink.service.CarLinkService;

public class CallHandler implements IHandler, OnCall.ICallListener {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private Context context;
    private OnCall mOnCall;

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context2) {
        this.context = context2;
        try {
            Log.i(this.TAG, "OnCall init");
            OnCall create = OnCall.create(context2);
            this.mOnCall = create;
            if (create == null) {
                Log.i(this.TAG, "OnCall = null");
            } else if (create instanceof IConnectable) {
                Log.i(this.TAG, "OnCall is instanceof IConnectable");
                IConnectable iConnectable = this.mOnCall;
                iConnectable.registerConnectWatcher(new IConnectable.IConnectWatcher() {
                    /* class com.geely.carlink.handler.call.CallHandler.AnonymousClass1 */

                    public void onConnected() {
                        Log.i(CallHandler.this.TAG, "OnCall onConnected");
                        CallHandler.this.registerListener();
                    }

                    public void onDisConnected() {
                        Log.d(CallHandler.this.TAG, "OnCall onDisConnected");
                    }
                });
                iConnectable.connect();
            } else {
                Log.d(this.TAG, "OnCall is not instanceof IConnectable");
                registerListener();
            }
        } catch (Exception e) {
            Log.d(this.TAG, "OnCall input error: " + e.toString());
            e.printStackTrace();
        }
    }

    public void registerListener() {
        Log.d(this.TAG, "registerListener: ");
        OnCall onCall = this.mOnCall;
        if (onCall != null) {
            onCall.registerCallListener(this);
        }
    }

    @Override // com.geely.carlink.ext.IHandler
    public void deInit() {
        OnCall onCall = this.mOnCall;
        if (onCall != null) {
            onCall.unregisterCallListener(this);
        }
    }

    public void onCallCreate(Call call) {
        Log.d(this.TAG, "onCallCreate: ");
    }

    public void onCallStatusChanged(int i, int i2) {
        Toast.makeText(this.context, "onCallStatusChanged: type==>" + i + "status===>" + i2, 0).show();
        Log.d(this.TAG, "onCallStatusChanged: type==>" + i + "status===>" + i2);
        if (i2 == 0 || 15 == i2) {
            Log.d(this.TAG, "onCallStatusChanged:  not call");
            sendOnCallState(false);
            return;
        }
        sendOnCallState(true);
        Log.d(this.TAG, "onCallStatusChanged: be calling");
    }

    private void sendOnCallState(boolean z) {
        Context context2 = this.context;
        if (context2 instanceof MainActivity) {
            CarLinkService carLinkService = (CarLinkService) context2;
            if (z) {
                carLinkService.sendKeyEventInternal(new KeyEvent(0, 6));
            } else {
                carLinkService.sendKeyEventInternal(new KeyEvent(0, 5));
            }
        }
    }
}
