package com.geely.carlink.handler.dockbar;

import android.content.Context;
import android.util.Log;
import com.geely.carlink.BuildConfig;
import com.geely.carlink.constant.Const;
import com.geely.lib.oneosapi.OneOSApiManager;
import com.geely.lib.oneosapi.listener.ApiConnectCallBack;
import com.geely.lib.oneosapi.listener.ServiceConnectionListener;
import com.geely.lib.oneosapi.systemui.DockBarManager;

public class DockBarHandler implements IDockBarHandler {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private DockBarManager mDockBarManager;
    private OneOSApiManager mOneOSApiManager;

    @Override // com.geely.carlink.ext.IHandler
    public String getHandlerName() {
        return getClass().getSimpleName();
    }

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context) {
        Log.d(this.TAG, "init: ");
        instanceManager(context);
    }

    @Override // com.geely.carlink.ext.IHandler
    public void deInit() {
        Log.d(this.TAG, "deInit: ");
        if (this.mDockBarManager != null) {
            super.deInit();
        }
    }

    private void instanceManager(Context context) {
        OneOSApiManager instance = OneOSApiManager.getInstance(context);
        this.mOneOSApiManager = instance;
        if (instance != null) {
            instance.registerServiceConnectionListener(new ServiceConnectionListener() {
                /* class com.geely.carlink.handler.dockbar.DockBarHandler.AnonymousClass1 */

                @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
                public void onServiceConnectionChanged(boolean z) {
                    Log.d(DockBarHandler.this.TAG, "onServiceConnectionChanged() connectionState = " + z);
                    if (z) {
                        DockBarHandler dockBarHandler = DockBarHandler.this;
                        dockBarHandler.mDockBarManager = dockBarHandler.mOneOSApiManager.getDockBarManager();
                    }
                }

                @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
                public void onServiceBinderUpdated(int i) {
                    if (i == 21) {
                        Log.d(DockBarHandler.this.TAG, "onServiceBinderUpdated: ");
                        DockBarHandler dockBarHandler = DockBarHandler.this;
                        dockBarHandler.mDockBarManager = dockBarHandler.mOneOSApiManager.getDockBarManager();
                    }
                }
            });
            this.mOneOSApiManager.init(new ApiConnectCallBack() {
                /* class com.geely.carlink.handler.dockbar.DockBarHandler.AnonymousClass2 */

                @Override // com.geely.lib.oneosapi.listener.ApiConnectCallBack
                public void fail() {
                }

                @Override // com.geely.lib.oneosapi.listener.ApiConnectCallBack
                public void success() {
                    if (BuildConfig.flavorType.intValue() == 2) {
                        DockBarHandler dockBarHandler = DockBarHandler.this;
                        dockBarHandler.mDockBarManager = dockBarHandler.mOneOSApiManager.getDockBarManager();
                        DockBarHandler.this.hideDock();
                    }
                }
            });
        }
    }

    public void hideDock() {
        DockBarManager dockBarManager = this.mDockBarManager;
        if (dockBarManager != null) {
            dockBarManager.showDock(3);
        }
    }
}
