package com.geely.carlink.handler.key;

import android.content.Context;
import android.util.Log;
import android.view.KeyEvent;
import com.geely.carlink.constant.Const;
import com.geely.carlink.service.CarLinkService;
import com.geely.lib.oneosapi.OneOSApiManager;
import com.geely.lib.oneosapi.input.KeyCode;
import com.geely.lib.oneosapi.input.KeyInputManager;
import com.geely.lib.oneosapi.listener.ServiceConnectionListener;

public class KeyHandlerImpl implements IKeyHandler {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private Context context;
    private final KeyInputManager.BaseInputListener mInputListener = new KeyInputManager.BaseInputListener() {
        /* class com.geely.carlink.handler.key.KeyHandlerImpl.AnonymousClass2 */

        @Override // com.geely.lib.oneosapi.input.IInputListener, com.geely.lib.oneosapi.input.KeyInputManager.BaseInputListener
        public void onDoubleClick(int i, int i2) {
        }

        @Override // com.geely.lib.oneosapi.input.IInputListener, com.geely.lib.oneosapi.input.KeyInputManager.BaseInputListener
        public void onHoldingPressStarted(int i, int i2) {
        }

        @Override // com.geely.lib.oneosapi.input.IInputListener, com.geely.lib.oneosapi.input.KeyInputManager.BaseInputListener
        public void onHoldingPressStopped(int i, int i2) {
        }

        @Override // com.geely.lib.oneosapi.input.IInputListener, com.geely.lib.oneosapi.input.KeyInputManager.BaseInputListener
        public void onKeyCodeEvent(int i, int i2, int i3) {
        }

        @Override // com.geely.lib.oneosapi.input.IInputListener, com.geely.lib.oneosapi.input.KeyInputManager.BaseInputListener
        public void onShortClick(int i, int i2) {
            Log.i(KeyHandlerImpl.this.TAG, "mKeyInputManager.getKeyController() =" + KeyHandlerImpl.this.mKeyInputManager.getKeyController());
        }

        @Override // com.geely.lib.oneosapi.input.IInputListener, com.geely.lib.oneosapi.input.KeyInputManager.BaseInputListener
        public void onLongPressTriggered(int i, int i2) {
            Log.i(KeyHandlerImpl.this.TAG, "onLongPressTriggered: keyCode = " + i);
            if (!KeyHandlerImpl.this.checkVoiceAssistant(i)) {
                return;
            }
            if (KeyHandlerImpl.this.context instanceof CarLinkService) {
                Log.i(KeyHandlerImpl.this.TAG, "onLongPressTriggered: current event is VR");
                ((CarLinkService) KeyHandlerImpl.this.context).handleWakeUpLongPressKeyEvent();
                return;
            }
            Log.e(KeyHandlerImpl.this.TAG, "onLongPressTriggered: context type error");
        }
    };
    private KeyInputManager mKeyInputManager;
    private OneOSApiManager mOneOSApiManager;

    private boolean checkMediaKey(int i) {
        return i == 200087 || i == 200088 || i == 200085;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean checkVoiceAssistant(int i) {
        return i == 200231;
    }

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context2) {
        Log.i(this.TAG, "InputOnCreate");
        this.context = context2;
        instanceInput(context2);
    }

    private void instanceInput(Context context2) {
        OneOSApiManager instance = OneOSApiManager.getInstance(context2);
        this.mOneOSApiManager = instance;
        instance.init();
        this.mOneOSApiManager.registerServiceConnectionListener(new ServiceConnectionListener() {
            /* class com.geely.carlink.handler.key.KeyHandlerImpl.AnonymousClass1 */

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceBinderUpdated(int i) {
            }

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceConnectionChanged(boolean z) {
                Log.i(KeyHandlerImpl.this.TAG, "onServiceConnectionChanged() connectionState = " + z);
                if (z) {
                    KeyHandlerImpl keyHandlerImpl = KeyHandlerImpl.this;
                    keyHandlerImpl.mKeyInputManager = keyHandlerImpl.mOneOSApiManager.getKeyInputManager();
                    KeyHandlerImpl.this.registerKeyEventListener();
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerKeyEventListener() {
        Log.i(this.TAG, "registerKeyEventListener() ");
        this.mKeyInputManager.registerListener(this.mInputListener, this.context.getPackageName(), new int[]{KeyCode.KEYCODE_R_VOICE_ASSIST, KeyCode.KEYCODE_R_MEDIA_NEXT, KeyCode.KEYCODE_R_MEDIA_PREVIOUS, KeyCode.KEYCODE_R_MEDIA_PLAY_PAUSE});
    }

    private void onKeyPressed(int i) {
        try {
            Log.i(this.TAG, "key event pressed: " + i);
            onKeyEvent(new KeyEvent(0, i));
        } catch (Exception e) {
            e.printStackTrace();
            Log.i(this.TAG, "onKeyPressed: " + e.getMessage());
        }
    }

    public void onKeyEvent(KeyEvent keyEvent) {
        KeyInputManager keyInputManager = this.mKeyInputManager;
        if (keyInputManager != null && keyInputManager.getKeyController() != 2) {
            Log.i(this.TAG, "KeyController() ！=2 return");
        } else if (checkMediaKey(keyEvent.getKeyCode())) {
            Context context2 = this.context;
            if (!(context2 instanceof CarLinkService)) {
                Log.e(this.TAG, "onKeyEvent: context type error");
                return;
            }
            KeyEvent transferKeyCode = transferKeyCode(keyEvent);
            if (((CarLinkService) context2).isCalling()) {
                Log.i(this.TAG, "onKeyEvent: when phone is calling");
                onCallingKeyEvent(transferKeyCode);
                return;
            }
            sendKeyEventInternal(transferKeyCode);
        }
    }

    public void sendKeyEventInternal(KeyEvent keyEvent) {
        Log.i(this.TAG, "sendKeyEventInternal: " + keyEvent.getKeyCode());
        CarLinkService carLinkService = (CarLinkService) this.context;
        if (carLinkService != null) {
            carLinkService.sendKeyEventInternal(keyEvent);
        }
    }

    @Override // com.geely.carlink.ext.IHandler
    public void deInit() {
        KeyInputManager keyInputManager = this.mKeyInputManager;
        if (keyInputManager != null) {
            keyInputManager.unregisterListener(this.mInputListener, this.context.getPackageName());
        }
    }

    /* access modifiers changed from: protected */
    public void onCallingKeyEvent(KeyEvent keyEvent) {
        int keyCode = keyEvent.getKeyCode();
        if (keyCode == 87) {
            Log.i(this.TAG, "dispatchEvent: dispatch end call ");
            sendKeyEventInternal(new KeyEvent(keyEvent.getAction(), 6));
        } else if (keyCode != 88) {
            Log.i(this.TAG, "when phone is focus:  dispatchEvent default=>" + keyEvent.getKeyCode());
        } else {
            Log.i(this.TAG, "dispatchEvent: dispatch call");
            sendKeyEventInternal(new KeyEvent(keyEvent.getAction(), 5));
        }
    }

    /* access modifiers changed from: protected */
    public KeyEvent transferKeyCode(KeyEvent keyEvent) {
        int i;
        switch (keyEvent.getKeyCode()) {
            case KeyCode.KEYCODE_R_MEDIA_PLAY_PAUSE /*{ENCODED_INT: 200085}*/:
                CarLinkService carLinkService = (CarLinkService) this.context;
                if (carLinkService != null) {
                    if (!carLinkService.isMusicPlaying()) {
                        i = 126;
                        break;
                    } else {
                        i = 127;
                        break;
                    }
                }
            case 200086:
            default:
                i = -1;
                break;
            case KeyCode.KEYCODE_R_MEDIA_NEXT /*{ENCODED_INT: 200087}*/:
                i = 87;
                break;
            case KeyCode.KEYCODE_R_MEDIA_PREVIOUS /*{ENCODED_INT: 200088}*/:
                i = 88;
                break;
        }
        Log.i(this.TAG, "finally transferKeyCode ===>: " + i);
        return new KeyEvent(keyEvent.getAction(), i);
    }
}
