package com.geely.carlink.handler.link;

import android.content.Context;
import android.os.RemoteException;
import android.util.Log;
import com.geely.carlink.constant.Const;
import com.geely.carlink.service.CarLinkService;
import com.geely.lib.oneosapi.OneOSApiManager;
import com.geely.lib.oneosapi.linkmanager.LinkManager;
import com.geely.lib.oneosapi.listener.ServiceConnectionListener;

public class LinkHandler implements ILinkHandler {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private Context mContext;
    private final LinkManager.BaseLinkListener mLinkListener = new LinkManager.BaseLinkListener() {
        /* class com.geely.carlink.handler.link.LinkHandler.AnonymousClass2 */

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onConnectStatusChange(int i, int i2, int i3) {
            Log.d(LinkHandler.this.TAG, "onConnectStatusChange: connect = " + i + " brand = " + i2 + " type = " + i3);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onDisconnectRequest(int i, int i2) {
            Log.d(LinkHandler.this.TAG, "onConnectStatusChange:  brand = " + i + " type = " + i2);
            if (i == 2) {
                Log.d(LinkHandler.this.TAG, "onDisconnectRequest: disconnect carlink for other smartphone try connect");
                if (LinkHandler.this.mContext instanceof CarLinkService) {
                    ((CarLinkService) LinkHandler.this.mContext).disconnect();
                }
            }
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onSourceActivated(boolean z) throws RemoteException {
            Log.d(LinkHandler.this.TAG, "onSourceActivated: " + z);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onPlay() throws RemoteException {
            Log.d(LinkHandler.this.TAG, "onPlay: ");
            ((CarLinkService) LinkHandler.this.mContext).sendKeyEventInternal(((CarLinkService) LinkHandler.this.mContext).isMusicPlaying() ? 127 : 126);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onStop() throws RemoteException {
            Log.d(LinkHandler.this.TAG, "onStop: ");
            ((CarLinkService) LinkHandler.this.mContext).sendKeyEventInternal(((CarLinkService) LinkHandler.this.mContext).isMusicPlaying() ? 127 : 126);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onNext() throws RemoteException {
            if (((CarLinkService) LinkHandler.this.mContext).isCalling()) {
                Log.d(LinkHandler.this.TAG, "onNext: in call, end call");
                ((CarLinkService) LinkHandler.this.mContext).sendKeyEventInternal(6);
                return;
            }
            Log.d(LinkHandler.this.TAG, "onNext: next");
            ((CarLinkService) LinkHandler.this.mContext).sendKeyEventInternal(87);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onPrevious() throws RemoteException {
            if (((CarLinkService) LinkHandler.this.mContext).isCalling()) {
                Log.d(LinkHandler.this.TAG, "onPrevious: in call, call");
                ((CarLinkService) LinkHandler.this.mContext).sendKeyEventInternal(5);
                return;
            }
            Log.d(LinkHandler.this.TAG, "onPrevious: Previous");
            ((CarLinkService) LinkHandler.this.mContext).sendKeyEventInternal(88);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onFastForward() throws RemoteException {
            Log.d(LinkHandler.this.TAG, "onFastForward: ");
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseLinkListener, com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onFastBackward() throws RemoteException {
            Log.d(LinkHandler.this.TAG, "onFastBackward: ");
        }
    };
    private LinkManager mLinkManager;
    private OneOSApiManager mOneOSApiManager;
    private boolean mTryConnect = false;
    private final LinkManager.BaseTryConnectCallback mTryConnectCallback = new LinkManager.BaseTryConnectCallback() {
        /* class com.geely.carlink.handler.link.LinkHandler.AnonymousClass3 */

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseTryConnectCallback, com.geely.lib.oneosapi.linkmanager.ITryConnectCallback
        public void permitted() {
            Log.d(LinkHandler.this.TAG, "permitted: ");
            if (LinkHandler.this.mContext instanceof CarLinkService) {
                ((CarLinkService) LinkHandler.this.mContext).onPermitted();
            }
        }

        @Override // com.geely.lib.oneosapi.linkmanager.LinkManager.BaseTryConnectCallback, com.geely.lib.oneosapi.linkmanager.ITryConnectCallback
        public void denied() {
            Log.d(LinkHandler.this.TAG, "denied: ");
            if (LinkHandler.this.mContext instanceof CarLinkService) {
                ((CarLinkService) LinkHandler.this.mContext).onDenied();
            }
        }
    };

    @Override // com.geely.carlink.ext.IHandler
    public String getHandlerName() {
        return getClass().getSimpleName();
    }

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context) {
        Log.d(this.TAG, "init: ");
        this.mContext = context;
        instanceLinkManager(context);
    }

    @Override // com.geely.carlink.ext.IHandler
    public void deInit() {
        Log.d(this.TAG, "deInit: ");
        if (this.mLinkManager != null) {
            sessionDisconnected(2, 2);
            this.mLinkManager.unregisterListener(this.mLinkListener, this.mContext.getPackageName());
        }
    }

    private void instanceLinkManager(Context context) {
        OneOSApiManager instance = OneOSApiManager.getInstance(context);
        this.mOneOSApiManager = instance;
        instance.registerServiceConnectionListener(new ServiceConnectionListener() {
            /* class com.geely.carlink.handler.link.LinkHandler.AnonymousClass1 */

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceConnectionChanged(boolean z) {
                Log.d(LinkHandler.this.TAG, "onServiceConnectionChanged() connectionState = " + z);
                if (z) {
                    LinkHandler linkHandler = LinkHandler.this;
                    linkHandler.mLinkManager = linkHandler.mOneOSApiManager.getLinkManager();
                    LinkHandler.this.mLinkManager.registerListener(LinkHandler.this.mLinkListener, LinkHandler.this.mContext.getPackageName());
                }
            }

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceBinderUpdated(int i) {
                if (i == 19) {
                    Log.d(LinkHandler.this.TAG, "onServiceBinderUpdated: ");
                    LinkHandler linkHandler = LinkHandler.this;
                    linkHandler.mLinkManager = linkHandler.mOneOSApiManager.getLinkManager();
                    LinkHandler.this.mLinkManager.registerListener(LinkHandler.this.mLinkListener, LinkHandler.this.mContext.getPackageName());
                }
            }
        });
        this.mOneOSApiManager.init();
    }

    public void sessionConnected(int i, int i2) {
        Log.d(this.TAG, "sessionConnected: brand = " + i + " type = " + i2);
        LinkManager linkManager = this.mLinkManager;
        if (linkManager == null) {
            Log.e(this.TAG, "sessionConnected: mLinkManager null");
        } else {
            linkManager.sessionConnected(i, i2);
        }
    }

    public void sessionDisconnected(int i, int i2) {
        Log.d(this.TAG, "sessionDisconnected: brand = " + i + " type = " + i2);
        LinkManager linkManager = this.mLinkManager;
        if (linkManager == null) {
            Log.e(this.TAG, "sessionDisconnected: mLinkManager null");
        } else {
            linkManager.sessionDisconnected(i, i2);
        }
    }

    public boolean isSessionConnected() {
        LinkManager linkManager = this.mLinkManager;
        if (linkManager != null) {
            return linkManager.isSessionConnected();
        }
        Log.e(this.TAG, "isSessionConnected: mLinkManager null");
        return false;
    }

    public int getConnectedSessionBrand() {
        LinkManager linkManager = this.mLinkManager;
        if (linkManager != null) {
            return linkManager.getConnectedSessionBrand();
        }
        Log.e(this.TAG, "getConnectedSessionBrand: mLinkManager null");
        return 0;
    }

    public int getConnectedSessionType() {
        LinkManager linkManager = this.mLinkManager;
        if (linkManager != null) {
            return linkManager.getConnectedSessionType();
        }
        Log.e(this.TAG, "getConnectedSessionType: mLinkManager null");
        return 0;
    }

    public void tryConnect(int i) {
        if (this.mTryConnectCallback != null) {
            if (!isSessionConnected()) {
                Log.d(this.TAG, "tryConnect: no smartphone connected, notice self");
                this.mTryConnectCallback.permitted();
                return;
            }
            int i2 = 1;
            if (!(i == 2 || i == 1)) {
                Log.e(this.TAG, "tryConnect: type error");
            }
            Log.d(this.TAG, "tryConnect: other smartphone connected");
            LinkManager linkManager = this.mLinkManager;
            if (i == 2) {
                i2 = 2;
            }
            linkManager.tryConnect(2, i2, this.mTryConnectCallback);
        }
    }

    public void updatePlayStatus(int i) {
        Log.d(this.TAG, "updatePlayStatus: " + i);
        LinkManager linkManager = this.mLinkManager;
        if (linkManager == null) {
            Log.e(this.TAG, "updatePlayStatus: linkManager null");
        } else if (i == 1) {
            linkManager.updatePlayState(0, 2);
        } else if (i == 2 || i == 3) {
            linkManager.updatePlayState(1, 2);
        } else {
            Log.e(this.TAG, "updatePlayStatus  unknown state");
        }
    }

    public void testKeyFunc(int i) {
        Log.d(this.TAG, "testKeyFunc: " + i);
        if (i == 87) {
            this.mLinkManager.next();
        } else if (i == 88) {
            this.mLinkManager.previous();
        } else if (i == 127) {
            this.mLinkManager.play();
        }
    }
}
