package com.geely.carlink.handler.navi;

import android.content.Context;
import android.util.Log;
import com.geely.carlink.constant.Const;
import com.geely.carlink.service.CarLinkService;
import com.geely.lib.oneosapi.OneOSApiManager;
import com.geely.lib.oneosapi.listener.ServiceConnectionListener;
import com.geely.lib.oneosapi.navi.INaviAPICallback;
import com.geely.lib.oneosapi.navi.INaviEventListener;
import com.geely.lib.oneosapi.navi.NaviManager;
import com.geely.lib.oneosapi.navi.model.base.NaviBaseModel;
import com.geely.lib.oneosapi.navi.model.base.NaviErrorModel;
import com.geely.lib.oneosapi.navi.model.service.RspIsInNaviStatus;
import com.geely.lib.oneosapi.navi.model.service.RspMapStatus;

public class NaviHandlerImpl implements INaviHandler {
    private int NATIVE_NAVI_OFF = 1;
    private int NATIVE_NAVI_ON = 0;
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private Context context;
    private INaviEventListener listener = new INaviEventListener() {
        /* class com.geely.carlink.handler.navi.NaviHandlerImpl.AnonymousClass2 */

        @Override // com.geely.lib.oneosapi.navi.INaviEventListener
        public void onNaviEvent(NaviBaseModel naviBaseModel) {
            if (naviBaseModel.getProtocolID() == 1001 && NaviHandlerImpl.this.getNativeNaviStatus(naviBaseModel)) {
                Log.e(NaviHandlerImpl.this.TAG, "stop carlink navi: ");
                if (NaviHandlerImpl.this.context != null) {
                    ((CarLinkService) NaviHandlerImpl.this.context).stopCarLinkNav();
                }
            }
        }
    };
    NaviManager mNaviManager = null;
    OneOSApiManager mOneOSApiManager = null;

    @Override // com.geely.carlink.ext.IHandler
    public void deInit() {
    }

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context2) {
        this.context = context2;
        OneOSApiManager instance = OneOSApiManager.getInstance(context2);
        this.mOneOSApiManager = instance;
        if (instance == null) {
            Log.e(this.TAG, "oneOSApiManager is null !");
            return;
        }
        Log.i(this.TAG, "get oneOSApiManager");
        this.mOneOSApiManager.registerServiceConnectionListener(new ServiceConnectionListener() {
            /* class com.geely.carlink.handler.navi.NaviHandlerImpl.AnonymousClass1 */

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceConnectionChanged(boolean z) {
                if (z) {
                    NaviHandlerImpl naviHandlerImpl = NaviHandlerImpl.this;
                    naviHandlerImpl.mNaviManager = naviHandlerImpl.mOneOSApiManager.getNaviManager();
                    Log.i(NaviHandlerImpl.this.TAG, "oneOSApiManager service connected");
                    Log.i(NaviHandlerImpl.this.TAG, "oneOSApiManager inited");
                    if (NaviHandlerImpl.this.mNaviManager != null) {
                        NaviHandlerImpl.this.mNaviManager.setNaviEventListener(NaviHandlerImpl.this.listener);
                    }
                }
            }

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceBinderUpdated(int i) {
                if (i == 1) {
                    Log.i(NaviHandlerImpl.this.TAG, "oneOSApiManager onServiceBinderUpdated");
                    NaviHandlerImpl naviHandlerImpl = NaviHandlerImpl.this;
                    naviHandlerImpl.mNaviManager = naviHandlerImpl.mOneOSApiManager.getNaviManager();
                    if (NaviHandlerImpl.this.mNaviManager != null) {
                        NaviHandlerImpl.this.mNaviManager.setNaviEventListener(NaviHandlerImpl.this.listener);
                    }
                }
            }
        });
        this.mOneOSApiManager.init();
        Log.i(this.TAG, "oneOSApiManager init end");
    }

    @Override // com.geely.carlink.handler.navi.INaviHandler
    public void cancelNavi() {
        if (this.mNaviManager == null) {
            Log.e(this.TAG, "cancelNavi mNaviManager is null");
        } else {
            Log.d(this.TAG, "cancelNavi: " + this.mNaviManager.mapInOnNaviStatus(new INaviAPICallback() {
                /* class com.geely.carlink.handler.navi.NaviHandlerImpl.AnonymousClass3 */

                @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
                public void onSuccess(NaviBaseModel naviBaseModel) {
                    RspIsInNaviStatus rspIsInNaviStatus = (RspIsInNaviStatus) naviBaseModel;
                    Log.d(NaviHandlerImpl.this.TAG, "地图导航状态成功:" + rspIsInNaviStatus.getIsInNaviStatus());
                    if (rspIsInNaviStatus.getIsInNaviStatus() != NaviHandlerImpl.this.NATIVE_NAVI_OFF) {
                        NaviHandlerImpl.this.mNaviManager.cancelNavi(new INaviAPICallback() {
                            /* class com.geely.carlink.handler.navi.NaviHandlerImpl.AnonymousClass3.AnonymousClass1 */

                            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
                            public void onSuccess(NaviBaseModel naviBaseModel) {
                                Log.d(NaviHandlerImpl.this.TAG, "结束导航成功:" + naviBaseModel.toString());
                            }

                            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
                            public void onFail(NaviErrorModel naviErrorModel) {
                                Log.d(NaviHandlerImpl.this.TAG, "结束导航失败:" + naviErrorModel.toString());
                            }
                        });
                    }
                }

                @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
                public void onFail(NaviErrorModel naviErrorModel) {
                    Log.d(NaviHandlerImpl.this.TAG, "地图导航状态失败:" + naviErrorModel.toString());
                }
            }));
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean getNativeNaviStatus(NaviBaseModel naviBaseModel) {
        if (!(naviBaseModel instanceof RspMapStatus)) {
            return false;
        }
        RspMapStatus rspMapStatus = (RspMapStatus) naviBaseModel;
        Log.d(this.TAG, "getNativeNaviStatus: " + rspMapStatus.toString());
        if (rspMapStatus.getMapStatus() == 16 || rspMapStatus.getMapStatus() == 33) {
            Log.d(this.TAG, "getNativeNaviStatus: 导航开始");
            return true;
        } else if (rspMapStatus.getMapStatus() != 17 && rspMapStatus.getMapStatus() != 35) {
            return false;
        } else {
            Log.d(this.TAG, "getNativeNaviStatus: 导航结束");
            return false;
        }
    }
}
