package com.geely.carlink.handler.sensor;

import android.content.Context;
import android.util.Log;
import com.ecarx.xui.adaptapi.FunctionStatus;
import com.ecarx.xui.adaptapi.binder.IConnectable;
import com.ecarx.xui.adaptapi.car.Car;
import com.ecarx.xui.adaptapi.car.ICar;
import com.ecarx.xui.adaptapi.car.sensor.ISensor;
import com.geely.carlink.constant.Const;
import com.geely.carlink.ext.IHandler;
import com.geely.carlink.service.CarLinkService;
import com.ucar.vehiclesdk.UCarAdapter;
import com.ucar.vehiclesdk.UCarCommon;

public class SensorHandler implements IHandler {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private Context context;
    UCarCommon.GearStateInfo info;
    private ISensor.ISensorListener mCarSensorListener = new ISensor.ISensorListener() {
        /* class com.geely.carlink.handler.sensor.SensorHandler.AnonymousClass1 */

        public void onSensorSupportChanged(int i, FunctionStatus functionStatus) {
        }

        public void onSensorEventChanged(int i, int i2) {
            if (i == 2097408) {
                if (2097410 == i2 || 2097411 == i2) {
                    Log.d(SensorHandler.this.TAG, "Car acc state change:off");
                } else if (-1 == i2) {
                    Log.d(SensorHandler.this.TAG, "Car acc state change:unknow");
                } else {
                    Log.d(SensorHandler.this.TAG, "Car acc state change:on");
                }
            }
            if (i == 2097664) {
                Log.d(SensorHandler.this.TAG, "Car gear change:" + "unknow");
                Log.d(SensorHandler.this.TAG, "Car gear value:" + i2);
                SensorHandler.this.info.gearState = UCarCommon.GearState.fromInt(i2);
                SensorHandler sensorHandler = SensorHandler.this;
                sensorHandler.uploadGearMode(sensorHandler.info);
            }
        }

        public void onSensorValueChanged(int i, float f) {
            if (i == 1048832) {
                SensorHandler.this.info.currentSpeed = Math.round(f);
                SensorHandler sensorHandler = SensorHandler.this;
                sensorHandler.uploadGearMode(sensorHandler.info);
            }
        }
    };
    private IConnectable.IConnectWatcher mConnectWatcher = new IConnectable.IConnectWatcher() {
        /* class com.geely.carlink.handler.sensor.SensorHandler.AnonymousClass2 */

        public void onConnected() {
            Log.d(SensorHandler.this.TAG, "++++++++++++ onConnected +++++++++++");
            SensorHandler.this.registerCarSensorListener();
        }

        public void onDisConnected() {
            Log.d(SensorHandler.this.TAG, "------------ onConnected -----------");
            SensorHandler.this.unregisterCarSensorListener();
        }
    };
    private ICar mICar;
    private ISensor mSensor;

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context2) {
        this.context = context2;
        ICar create = Car.create(context2);
        this.mICar = create;
        if (create != null) {
            Log.e(this.TAG, "mICar!=null");
            this.mSensor = this.mICar.getSensorManager();
            if (this.mICar instanceof IConnectable) {
                Log.e(this.TAG, "mICar instanceof IConnectable");
                IConnectable iConnectable = this.mICar;
                iConnectable.registerConnectWatcher(this.mConnectWatcher);
                iConnectable.connect();
                return;
            }
            Log.e(this.TAG, "mICar not instanceof IConnectable");
            registerCarSensorListener();
            return;
        }
        Log.e(this.TAG, "adapterAPI mICar=Car.create fail !!!!!!!!");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerCarSensorListener() {
        if (this.mICar != null) {
            if (this.mSensor != null) {
                Log.d(this.TAG, "register Car Sensor Listener...");
                if (this.mSensor.registerListener(this.mCarSensorListener, 1048832, 3)) {
                    Log.e(this.TAG, "register Car Speed Sensor Listener success");
                }
                if (this.mSensor.registerListener(this.mCarSensorListener, 2097664, 3)) {
                    Log.e(this.TAG, "register Car Gear Sensor Listener success");
                }
            }
            uploadGearMode(getCurrentGearValue());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void unregisterCarSensorListener() {
        if (this.mSensor != null) {
            Log.d(this.TAG, "unregister Car Sensor Listener...");
            this.mSensor.unregisterListener(this.mCarSensorListener);
        }
    }

    public UCarCommon.GearStateInfo getCurrentGearValue() {
        ISensor iSensor = this.mSensor;
        if (iSensor != null) {
            this.info = new UCarCommon.GearStateInfo(UCarCommon.GearState.fromInt(iSensor.getSensorEvent(2097664)), Math.round((float) this.mSensor.getSensorEvent(1048832)));
        }
        return this.info;
    }

    public void uploadGearMode(UCarCommon.GearStateInfo gearStateInfo) {
        CarLinkService carLinkService = (CarLinkService) this.context;
        if (carLinkService != null && carLinkService.isDeviceConnected()) {
            UCarAdapter.getInstance().sendGearStateInfo(gearStateInfo);
        }
    }
}
