package com.geely.carlink.handler.vr;

import android.content.Context;
import android.os.RemoteException;
import android.util.Log;
import com.geely.carlink.constant.Const;
import com.geely.lib.oneosapi.OneOSApiManager;
import com.geely.lib.oneosapi.listener.ServiceConnectionListener;
import com.geely.lib.oneosapi.vr.IVRDialogStatusChangedListener;
import com.geely.lib.oneosapi.vr.VrManager;

public class VrHandler implements IVrHandler {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private Context mContext;
    private OneOSApiManager mOneOSApiManager;
    private IVRDialogStatusChangedListener.Stub mVrListener = new IVRDialogStatusChangedListener.Stub() {
        /* class com.geely.carlink.handler.vr.VrHandler.AnonymousClass1 */

        @Override // com.geely.lib.oneosapi.vr.IVRDialogStatusChangedListener
        public void onVRDialogStatusChanged(int i) throws RemoteException {
            Log.d(VrHandler.this.TAG, "onVRDialogStatusChanged: vr status = " + i);
            VrHandler.this.mVrStatus = i;
        }
    };
    private VrManager mVrManager;
    private int mVrStatus = 2;

    @Override // com.geely.carlink.ext.IHandler
    public String getHandlerName() {
        return getClass().getSimpleName();
    }

    @Override // com.geely.carlink.ext.IHandler
    public void init(Context context) {
        Log.d(this.TAG, "init: ");
        this.mContext = context;
        initVrManager(context);
    }

    @Override // com.geely.carlink.ext.IHandler
    public void deInit() {
        if (this.mVrManager != null) {
            Log.d(this.TAG, "deInit: ");
            this.mVrManager.unregisterVRDialogStatusChangedListener(this.mVrListener);
        }
    }

    private void initVrManager(Context context) {
        OneOSApiManager instance = OneOSApiManager.getInstance(context);
        this.mOneOSApiManager = instance;
        instance.registerServiceConnectionListener(new ServiceConnectionListener() {
            /* class com.geely.carlink.handler.vr.VrHandler.AnonymousClass2 */

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceConnectionChanged(boolean z) {
                Log.d(VrHandler.this.TAG, "onServiceConnectionChanged() connectionState = " + z);
                if (z) {
                    VrHandler vrHandler = VrHandler.this;
                    vrHandler.mVrManager = vrHandler.mOneOSApiManager.getVrManager();
                    VrHandler.this.registerVrListener();
                }
            }

            @Override // com.geely.lib.oneosapi.listener.ServiceConnectionListener
            public void onServiceBinderUpdated(int i) {
                if (i == 2) {
                    VrHandler vrHandler = VrHandler.this;
                    vrHandler.mVrManager = vrHandler.mOneOSApiManager.getVrManager();
                    VrHandler.this.registerVrListener();
                }
            }
        });
        this.mOneOSApiManager.init();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerVrListener() {
        VrManager vrManager = this.mVrManager;
        if (vrManager != null) {
            vrManager.registerVRDialogStatusChangedListener(this.mVrListener);
        } else {
            Log.e(this.TAG, "onServiceConnectionChanged: vr manager is null");
        }
    }

    public void stopNativeVr() {
        if (this.mVrStatus == 1) {
            Log.d(this.TAG, "stopNativeVr: stop native vr");
            this.mVrManager.toggleDialogue();
            return;
        }
        Log.d(this.TAG, "stopNativeVr: native vr is not started");
    }
}
