package com.geely.carlink.service;

import android.bluetooth.BluetoothA2dpSink;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothHeadsetClient;
import android.bluetooth.BluetoothPbapClient;
import android.bluetooth.BluetoothProfile;
import android.content.Context;
import android.content.IntentFilter;
import android.util.Log;
import com.geely.carlink.broadcast.BluetoothConnectionReceiver;
import com.geely.carlink.constant.Const;
import com.geely.carlink.utils.CarLinkConfigUtils;
import com.geely.carlink.utils.SharedPreferencesUtils;
import java.util.Arrays;
import java.util.List;
import java.util.Set;

public class BluetoothDelegateImpl implements BluetoothDelegate {
    int PRIORITY_OFF = 0;
    int PRIORITY_ON = 100;
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private BluetoothA2dpSink bluetoothA2dp;
    private BluetoothHeadsetClient bluetoothHeadset;
    private BluetoothPbapClient bluetoothPbapClient;
    private final Context context;
    private final BluetoothAdapter mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
    private final BluetoothConnectionReceiver mBluetoothConnectionReceiver = new BluetoothConnectionReceiver();

    public BluetoothDelegateImpl(Context context2) {
        this.context = context2;
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void init() {
        this.mBluetoothAdapter.getProfileProxy(this.context, new BluetoothProfile.ServiceListener() {
            /* class com.geely.carlink.service.BluetoothDelegateImpl.AnonymousClass1 */

            public void onServiceConnected(int i, BluetoothProfile bluetoothProfile) {
                BluetoothDelegateImpl.this.bluetoothHeadset = (BluetoothHeadsetClient) bluetoothProfile;
                Log.e(BluetoothDelegateImpl.this.TAG, "mBluetoothHeadset:onServiceConnected");
                String addressParam = SharedPreferencesUtils.getAddressParam(BluetoothDelegateImpl.this.context);
                Log.e(BluetoothDelegateImpl.this.TAG, "address = " + addressParam);
                if (!addressParam.equals("")) {
                    for (String str : Arrays.asList(addressParam.split(","))) {
                        Log.d(BluetoothDelegateImpl.this.TAG, "getTrustDeviceMacAddress: address = " + str);
                        BluetoothDevice remoteDevice = BluetoothDelegateImpl.this.mBluetoothAdapter.getRemoteDevice(str);
                        int priority = BluetoothDelegateImpl.this.bluetoothHeadset.getPriority(remoteDevice);
                        Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceStateChanged:  hfp pro = " + priority);
                        if (priority == BluetoothDelegateImpl.this.PRIORITY_OFF) {
                            Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceStateChanged: hfp setPriority on");
                            BluetoothDelegateImpl.this.bluetoothHeadset.setPriority(remoteDevice, BluetoothDelegateImpl.this.PRIORITY_ON);
                        }
                    }
                }
            }

            public void onServiceDisconnected(int i) {
                BluetoothDelegateImpl.this.bluetoothHeadset = null;
                Log.e(BluetoothDelegateImpl.this.TAG, "mBluetoothHeadset:onServiceDisconnected");
            }
        }, 16);
        this.mBluetoothAdapter.getProfileProxy(this.context, new BluetoothProfile.ServiceListener() {
            /* class com.geely.carlink.service.BluetoothDelegateImpl.AnonymousClass2 */

            public void onServiceConnected(int i, BluetoothProfile bluetoothProfile) {
                BluetoothDelegateImpl.this.bluetoothA2dp = (BluetoothA2dpSink) bluetoothProfile;
                Log.e(BluetoothDelegateImpl.this.TAG, "mBluetoothA2DP:onServiceConnected");
                String addressParam = SharedPreferencesUtils.getAddressParam(BluetoothDelegateImpl.this.context);
                Log.e(BluetoothDelegateImpl.this.TAG, "address = " + addressParam);
                if (!addressParam.equals("")) {
                    for (String str : Arrays.asList(addressParam.split(","))) {
                        Log.d(BluetoothDelegateImpl.this.TAG, "getTrustDeviceMacAddress: address = " + str);
                        BluetoothDevice remoteDevice = BluetoothDelegateImpl.this.mBluetoothAdapter.getRemoteDevice(str);
                        int priority = BluetoothDelegateImpl.this.bluetoothA2dp.getPriority(remoteDevice);
                        Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceStateChanged: a2dp pro = " + priority);
                        if (priority == BluetoothDelegateImpl.this.PRIORITY_OFF) {
                            Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceStateChanged: a2pd setPriority on");
                            BluetoothDelegateImpl.this.bluetoothA2dp.setPriority(remoteDevice, BluetoothDelegateImpl.this.PRIORITY_ON);
                        }
                    }
                }
            }

            public void onServiceDisconnected(int i) {
                BluetoothDelegateImpl.this.bluetoothA2dp = null;
                Log.e(BluetoothDelegateImpl.this.TAG, "mBluetoothA2DP:onServiceDisconnected");
            }
        }, 11);
        this.mBluetoothAdapter.getProfileProxy(this.context, new BluetoothProfile.ServiceListener() {
            /* class com.geely.carlink.service.BluetoothDelegateImpl.AnonymousClass3 */

            public void onServiceConnected(int i, BluetoothProfile bluetoothProfile) {
                BluetoothDelegateImpl.this.bluetoothPbapClient = (BluetoothPbapClient) bluetoothProfile;
                Log.d(BluetoothDelegateImpl.this.TAG, "BluetoothPbapClient onServiceConnected: ");
            }

            public void onServiceDisconnected(int i) {
                BluetoothDelegateImpl.this.bluetoothPbapClient = null;
                Log.d(BluetoothDelegateImpl.this.TAG, "BluetoothPbapClient onServiceDisconnected: ");
            }
        }, 17);
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void registerBR(final CarLinkService carLinkService) {
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.bluetooth.device.action.ACL_CONNECTED");
        intentFilter.addAction("android.bluetooth.device.action.ACL_DISCONNECTED");
        intentFilter.addAction("android.bluetooth.headset.profile.action.CONNECTION_STATE_CHANGED");
        intentFilter.addAction("android.bluetooth.headsetclient.profile.action.CONNECTION_STATE_CHANGED");
        intentFilter.addAction("android.bluetooth.a2dp-sink.profile.action.CONNECTION_STATE_CHANGED");
        intentFilter.addAction("android.bluetooth.a2dp.profile.action.CONNECTION_STATE_CHANGED");
        intentFilter.addAction("android.bluetooth.adapter.action.STATE_CHANGED");
        this.context.registerReceiver(this.mBluetoothConnectionReceiver, intentFilter);
        this.mBluetoothConnectionReceiver.setCallBack(new BluetoothConnectionReceiver.CallBack() {
            /* class com.geely.carlink.service.BluetoothDelegateImpl.AnonymousClass4 */

            @Override // com.geely.carlink.broadcast.BluetoothConnectionReceiver.CallBack
            public void onBlueDeviceA2dp(BluetoothDevice bluetoothDevice) {
                String address = bluetoothDevice.getAddress();
                Log.i(BluetoothDelegateImpl.this.TAG, "onBlueDeviceA2dp macAddress:" + address);
                Log.e(BluetoothDelegateImpl.this.TAG, " reconnect before current device state is " + (carLinkService.isDeviceConnected() ? "connect" : "disconnect"));
                if (carLinkService.isDeviceConnected()) {
                    BluetoothDelegateImpl.this.disconnectCurrentBluetoothA2dp(bluetoothDevice);
                } else {
                    Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceA2dp: may be startWirelessReconnect==>" + address);
                }
            }

            @Override // com.geely.carlink.broadcast.BluetoothConnectionReceiver.CallBack
            public void onBlueDeviceHfp(BluetoothDevice bluetoothDevice) {
                Log.i(BluetoothDelegateImpl.this.TAG, "onBlueDeviceHfp macAddress:" + bluetoothDevice.getAddress());
                String address = bluetoothDevice.getAddress();
                Log.e(BluetoothDelegateImpl.this.TAG, "reconnect before current device state is " + (carLinkService.isDeviceConnected() ? "connect" : "disconnect"));
                if (carLinkService.isDeviceConnected()) {
                    BluetoothDelegateImpl.this.disconnectCurrentBluetoothHfp(bluetoothDevice);
                } else {
                    Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceHfp: may be startWirelessReconnect==>" + address);
                }
            }

            @Override // com.geely.carlink.broadcast.BluetoothConnectionReceiver.CallBack
            public BluetoothDevice getCurrentBluetooth() {
                BluetoothDevice a2dpBluetoothDevice = BluetoothDelegateImpl.this.getA2dpBluetoothDevice();
                Log.d(BluetoothDelegateImpl.this.TAG, "getCurrentBluetooth: " + a2dpBluetoothDevice);
                return a2dpBluetoothDevice;
            }

            @Override // com.geely.carlink.broadcast.BluetoothConnectionReceiver.CallBack
            public void disConnectBluetoothDevice(BluetoothDevice bluetoothDevice) {
                Log.d("BluetoothConnectionReceiver", "disConnectBluetoothDevice: " + bluetoothDevice);
                BluetoothDelegateImpl.this.disconnectCurrentBluetoothA2dp(bluetoothDevice);
                BluetoothDelegateImpl.this.disconnectCurrentBluetoothHfp(bluetoothDevice);
                BluetoothDelegateImpl.this.disconnectCurrentBluetoothPbap(bluetoothDevice);
            }

            @Override // com.geely.carlink.broadcast.BluetoothConnectionReceiver.CallBack
            public void onBlueDeviceStateChanged(boolean z) {
                Log.d(BluetoothDelegateImpl.this.TAG, "onBlueDeviceStateChanged: " + z);
            }
        });
    }

    public String getBluetoothMacAddress() {
        BluetoothAdapter bluetoothAdapter = this.mBluetoothAdapter;
        if (bluetoothAdapter == null) {
            Log.e(this.TAG, "bluetoothAdapter is null, use fake bt mac address, wireless connection can not work normally");
            return CarLinkConfigUtils.FAKE_BLUETOOTH_MAC;
        }
        String address = bluetoothAdapter.getAddress();
        if (address != null && !address.isEmpty()) {
            return address;
        }
        Log.e(this.TAG, "Can not get address from fwk, use fake bt mac address, wireless connection can not work normally");
        return CarLinkConfigUtils.FAKE_BLUETOOTH_MAC;
    }

    public void disconnectA2dp(String str) {
        BluetoothDevice remoteDevice = this.mBluetoothAdapter.getRemoteDevice(str);
        Log.i(this.TAG, "disconnectA2dp() BluetoothDevice:" + remoteDevice);
        BluetoothA2dpSink bluetoothA2dpSink = this.bluetoothA2dp;
        if (bluetoothA2dpSink != null && remoteDevice != null) {
            try {
                bluetoothA2dpSink.disconnect(remoteDevice);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void disconnectHfp(String str) {
        BluetoothDevice remoteDevice = this.mBluetoothAdapter.getRemoteDevice(str);
        Log.i(this.TAG, "disconnectHfp() BluetoothDevice:" + remoteDevice);
        BluetoothHeadsetClient bluetoothHeadsetClient = this.bluetoothHeadset;
        if (bluetoothHeadsetClient != null && remoteDevice != null) {
            try {
                bluetoothHeadsetClient.disconnect(remoteDevice);
            } catch (Exception e) {
                e.printStackTrace();
                Log.d(this.TAG, "disconnectHfp: " + e.getMessage());
            }
        }
    }

    public void disconnectBluetoothHfp(BluetoothDevice bluetoothDevice) {
        Log.i(this.TAG, "disconnectCurrentBluetoothHfp() BluetoothDevice:" + bluetoothDevice);
        BluetoothHeadsetClient bluetoothHeadsetClient = this.bluetoothHeadset;
        if (bluetoothHeadsetClient != null && bluetoothDevice != null) {
            try {
                bluetoothHeadsetClient.disconnect(bluetoothDevice);
            } catch (Exception e) {
                e.printStackTrace();
                Log.d(this.TAG, "disconnectBluetoothHfp: " + e.getMessage());
            }
        }
    }

    public void disconnectBluetootha2dp(BluetoothDevice bluetoothDevice) {
        Log.i(this.TAG, "disconnectCurrentBluetoothHfp() BluetoothDevice:" + bluetoothDevice);
        BluetoothA2dpSink bluetoothA2dpSink = this.bluetoothA2dp;
        if (bluetoothA2dpSink != null && bluetoothDevice != null) {
            try {
                bluetoothA2dpSink.disconnect(bluetoothDevice);
            } catch (Exception e) {
                e.printStackTrace();
                Log.d(this.TAG, "disconnectBluetootha2dp: " + e.getMessage());
            }
        }
    }

    public String geta2dpConnectedDeviceMac() {
        List connectedDevices;
        BluetoothDevice bluetoothDevice;
        BluetoothA2dpSink bluetoothA2dpSink = this.bluetoothA2dp;
        String address = (bluetoothA2dpSink == null || (connectedDevices = bluetoothA2dpSink.getConnectedDevices()) == null || connectedDevices.size() <= 0 || (bluetoothDevice = (BluetoothDevice) connectedDevices.get(0)) == null) ? "" : bluetoothDevice.getAddress();
        Log.i(this.TAG, "geta2dpConnectedDeviceMac=" + address);
        return address;
    }

    public String getHfpConnectedDeviceMac() {
        List connectedDevices;
        BluetoothDevice bluetoothDevice;
        BluetoothHeadsetClient bluetoothHeadsetClient = this.bluetoothHeadset;
        String address = (bluetoothHeadsetClient == null || (connectedDevices = bluetoothHeadsetClient.getConnectedDevices()) == null || connectedDevices.size() <= 0 || (bluetoothDevice = (BluetoothDevice) connectedDevices.get(0)) == null) ? "" : bluetoothDevice.getAddress();
        Log.i(this.TAG, "getHfpConnectedDeviceMac=" + address);
        return address;
    }

    public BluetoothDevice getCurrentBluetoothDevice(BluetoothProfile bluetoothProfile) {
        List<BluetoothDevice> connectedDevices;
        if (bluetoothProfile == null || (connectedDevices = bluetoothProfile.getConnectedDevices()) == null || connectedDevices.size() <= 0) {
            return null;
        }
        return connectedDevices.get(0);
    }

    public BluetoothDevice getHeadSetBluetoothDevice() {
        return getCurrentBluetoothDevice(this.bluetoothHeadset);
    }

    public BluetoothDevice getA2dpBluetoothDevice() {
        return getCurrentBluetoothDevice(this.bluetoothA2dp);
    }

    public void connectA2dp(String str) {
        BluetoothDevice remoteDevice = this.mBluetoothAdapter.getRemoteDevice(str);
        Log.i(this.TAG, "connectA2dp() BluetoothDevice:" + remoteDevice);
        BluetoothA2dpSink bluetoothA2dpSink = this.bluetoothA2dp;
        if (bluetoothA2dpSink != null && remoteDevice != null) {
            try {
                bluetoothA2dpSink.connect(remoteDevice);
            } catch (Exception e) {
                e.printStackTrace();
                Log.d(this.TAG, "connectA2dp: " + e.getMessage());
            }
        }
    }

    public void connectHfp(String str) {
        BluetoothDevice remoteDevice = this.mBluetoothAdapter.getRemoteDevice(str);
        Log.i(this.TAG, "connectHfp() BluetoothDevice:" + remoteDevice);
        BluetoothHeadsetClient bluetoothHeadsetClient = this.bluetoothHeadset;
        if (bluetoothHeadsetClient != null && remoteDevice != null) {
            try {
                bluetoothHeadsetClient.connect(remoteDevice);
            } catch (Exception e) {
                e.printStackTrace();
                Log.d(this.TAG, "connectHfp: " + e.getMessage());
            }
        }
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void connectBluetooth(String str) {
        connectA2dp(str);
        connectHfp(str);
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void disconnectBluetooth(String str) {
        disconnectA2dp(str);
        disconnectHfp(str);
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void disconnectCurrentBluetoothHfp(BluetoothDevice bluetoothDevice) {
        if (this.bluetoothHeadset != null) {
            disconnectBluetoothHfp(bluetoothDevice);
        }
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void disconnectCurrentBluetoothA2dp(BluetoothDevice bluetoothDevice) {
        if (this.bluetoothA2dp != null) {
            disconnectBluetootha2dp(bluetoothDevice);
        }
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void disconnectCurrentBluetoothPbap(BluetoothDevice bluetoothDevice) {
        BluetoothPbapClient bluetoothPbapClient2 = this.bluetoothPbapClient;
        if (bluetoothPbapClient2 != null && bluetoothDevice != null) {
            try {
                bluetoothPbapClient2.disconnect(bluetoothDevice);
            } catch (Exception e) {
                e.printStackTrace();
                Log.d(this.TAG, "disconnect pbap: " + e.getMessage());
            }
        }
    }

    @Override // com.geely.carlink.service.BluetoothDelegate
    public void deInit() {
        this.context.unregisterReceiver(this.mBluetoothConnectionReceiver);
        if (this.mBluetoothAdapter != null) {
            if (this.bluetoothHeadset != null) {
                Log.i(this.TAG, "deInit: closeProfileProxy hfp");
                this.mBluetoothAdapter.closeProfileProxy(16, this.bluetoothHeadset);
            }
            if (this.bluetoothA2dp != null) {
                Log.i(this.TAG, "deInit: closeProfileProxy a2dp");
                this.mBluetoothAdapter.closeProfileProxy(11, this.bluetoothA2dp);
            }
            if (this.bluetoothPbapClient != null) {
                Log.i(this.TAG, "deInit: closeProfileProxy pbap");
                this.mBluetoothAdapter.closeProfileProxy(17, this.bluetoothPbapClient);
                return;
            }
            return;
        }
        Log.e(this.TAG, "deInit: mBluetoothAdapter is null");
    }

    public void onConnectCarLinkResolved() {
        Log.d(this.TAG, "onConnectcarLinkResolved: ");
        Set<BluetoothDevice> bondedDevices = BluetoothAdapter.getDefaultAdapter().getBondedDevices();
        StringBuffer stringBuffer = new StringBuffer();
        for (BluetoothDevice bluetoothDevice : bondedDevices) {
            boolean priority = this.bluetoothA2dp.setPriority(bluetoothDevice, this.PRIORITY_OFF);
            boolean priority2 = this.bluetoothHeadset.setPriority(bluetoothDevice, this.PRIORITY_OFF);
            boolean priority3 = this.bluetoothPbapClient.setPriority(bluetoothDevice, this.PRIORITY_OFF);
            Log.d(this.TAG, "setPriority(" + bluetoothDevice + ", " + this.PRIORITY_OFF + ")isA2dp=" + priority);
            Log.d(this.TAG, "setPriority(" + bluetoothDevice + ", " + this.PRIORITY_OFF + ")isHeadset=" + priority2);
            Log.d(this.TAG, "setPriority(" + bluetoothDevice + ", " + this.PRIORITY_OFF + ")isPbapClient=" + priority3);
            this.bluetoothHeadset.disconnect(bluetoothDevice);
            this.bluetoothA2dp.disconnect(bluetoothDevice);
            this.bluetoothPbapClient.disconnect(bluetoothDevice);
            stringBuffer.append(bluetoothDevice.getAddress() + ",");
        }
        Log.d(this.TAG, "macaddress = " + stringBuffer.toString());
        SharedPreferencesUtils.setAddressParam(this.context, stringBuffer.toString());
    }

    public void onDisConnectCarLinkResolved() {
        Log.d(this.TAG, "onDisConnectcarLinkResolved");
        for (BluetoothDevice bluetoothDevice : BluetoothAdapter.getDefaultAdapter().getBondedDevices()) {
            this.bluetoothA2dp.setPriority(bluetoothDevice, this.PRIORITY_ON);
            this.bluetoothHeadset.setPriority(bluetoothDevice, this.PRIORITY_ON);
            this.bluetoothPbapClient.setPriority(bluetoothDevice, this.PRIORITY_ON);
            SharedPreferencesUtils.clear(this.context);
        }
    }
}
