package com.geely.carlink.service;

import a.b.a.c;
import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.Service;
import android.bluetooth.BluetoothManager;
import android.car.Car;
import android.car.CarNotConnectedException;
import android.car.media.CarAudioManager;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.SharedPreferences;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbManager;
import android.media.AudioAttributes;
import android.os.Binder;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.KeyEvent;
import android.view.WindowManager;
import com.geely.carlink.BuildConfig;
import com.geely.carlink.MainActivity;
import com.geely.carlink.R;
import com.geely.carlink.app.HmiApp;
import com.geely.carlink.broadcast.BroadCastProxy;
import com.geely.carlink.broadcast.LocalVoiceAwakeBroadcastReceiver;
import com.geely.carlink.broadcast.SimulationBroadcastReceiver;
import com.geely.carlink.constant.Const;
import com.geely.carlink.ext.HandlerManager;
import com.geely.carlink.listener.ServiceListener;
import com.ucar.vehiclesdk.ICameraInfoListener;
import com.ucar.vehiclesdk.ICarConnectListener;
import com.ucar.vehiclesdk.ICarInitCallback;
import com.ucar.vehiclesdk.IPhoneDataListener;
import com.ucar.vehiclesdk.UCarAdapter;
import com.ucar.vehiclesdk.UCarCommon;
import com.ucar.vehiclesdk.UCarConfig;
import com.ucar.vehiclesdk.camera.AbstractCamera;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Base64;
import java.util.Iterator;
import java.util.Random;

public class CarLinkService extends Service {
    private static final int ALIGNMENT = 16;
    private static final String CAMERA_ID = "1";
    private static final String CAMERA_NAME = "Car_Camera_1";
    private static final String CAR_ID_KEY = "car_id_key";
    private static final String CAR_ID_PREFS = "car_id_prefs";
    private static final int CAR_ID_SIZE = 6;
    public static final int DISPLAY_DENSITY_DPI = 320;
    public static final int DISPLAY_FPS = 30;
    public static final int MSG_ON_CONNECT_STATE_CHANGED = 101;
    public static final int MSG_SHOW_PIN_CODE = 106;
    public static final int MSG_SHOW_PROGRESS = 104;
    public static final int MSG_START_ADVERTISE_SCAN_DEVICE = 102;
    public static final int MSG_STOP_ADVERTISE_SCAN_DEVICE = 103;
    private static final int PROCESS_0 = 0;
    private static final int PROCESS_COMPLETE = 100;
    public static final int START_CAST_DELAY = 100;
    private static boolean sIsServiceInitialized = false;
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    public BluetoothDelegateImpl bluetoothDelegate;
    private BroadCastProxy broadCastProxy;
    private boolean isCarLinkPhoneCalling = false;
    private boolean isMusicPlaying = false;
    private final LocalVoiceAwakeBroadcastReceiver localVoiceAwakeBroadcastReceiver = new LocalVoiceAwakeBroadcastReceiver();
    private final IBinder mBind = new MyBind();
    private ICameraInfoListener mCameraInfoCallback;
    private Car mCar;
    private CarAudioManager mCarAudioManager;
    private ICarConnectListener mConnectCallback;
    private String mDeviceId;
    private int mDisplayDensityDpi;
    private int mExpectedDisplayHeight;
    private int mExpectedDisplayWidth;
    private int mFullDisplayHeight;
    private int mFullDisplayWidth;
    private final Handler mHandler = new Handler(Looper.getMainLooper()) {
        /* class com.geely.carlink.service.CarLinkService.AnonymousClass5 */

        public void handleMessage(Message message) {
            super.handleMessage(message);
            int i = message.what;
            if (i == 101) {
                CarLinkService.this.handleConnectStateChangedMessage(message);
            } else if (i == 106) {
                Log.i(CarLinkService.this.TAG, "MSG_SHOW_PIN_CODE");
                if (CarLinkService.this.mListener != null) {
                    CarLinkService.this.mListener.onPinCodeRefresh(message);
                }
            } else if (i == 103) {
                UCarAdapter.getInstance().stopAdvertise();
                CarLinkService.this.mIsAdvertising = false;
            } else if (i == 104 && CarLinkService.this.mListener != null) {
                CarLinkService.this.mListener.onProgress(message);
            }
        }
    };
    private boolean mIsAdvertising = false;
    private boolean mIsCarVoiceWakeUp = false;
    private boolean mIsCastSucceed = false;
    private boolean mIsDeviceConnected = false;
    private boolean mIsPendingCheckExitProcess = false;
    public ServiceListener mListener;
    private IPhoneDataListener mPhoneDataCallback;
    private UCarCommon.PhoneStateInfo mPhoneStateInfo = new UCarCommon.PhoneStateInfo();
    private final SimulationBroadcastReceiver mSimulationReceiver = new SimulationBroadcastReceiver();
    private int mTryConnectType = 0;
    private UCarConfig mUCarConfig;
    public UsbDelegateImpl mUsbDelegate;
    private UsbManager mUsbManager;
    private UCarCommon.ModemCallState modemCallState = UCarCommon.ModemCallState.UNKNOWN_STATE;

    public class MyBind extends Binder {
        public MyBind() {
        }

        public CarLinkService getService() {
            return CarLinkService.this;
        }
    }

    public IBinder onBind(Intent intent) {
        Log.e(this.TAG, "onBind()");
        return this.mBind;
    }

    public boolean onUnbind(Intent intent) {
        return super.onUnbind(intent);
    }

    public void onCreate() {
        super.onCreate();
        Log.e(this.TAG, "onCreate()");
        SimulationBroadcastReceiver simulationBroadcastReceiver = this.mSimulationReceiver;
        registerReceiver(simulationBroadcastReceiver, simulationBroadcastReceiver.createIntentFilter());
        setForegroundNotification();
        this.broadCastProxy = new BroadCastProxy(this);
        BluetoothDelegateImpl bluetoothDelegateImpl = new BluetoothDelegateImpl(this);
        this.bluetoothDelegate = bluetoothDelegateImpl;
        bluetoothDelegateImpl.init();
        this.bluetoothDelegate.registerBR(this);
        UsbDelegateImpl usbDelegateImpl = new UsbDelegateImpl(this);
        this.mUsbDelegate = usbDelegateImpl;
        usbDelegateImpl.registerBR(this);
        this.localVoiceAwakeBroadcastReceiver.setCallBack(new LocalVoiceAwakeBroadcastReceiver.CallBack() {
            /* class com.geely.carlink.service.$$Lambda$CukjujoW3S6n3e2Jr4Tpnqkwk */

            @Override // com.geely.carlink.broadcast.LocalVoiceAwakeBroadcastReceiver.CallBack
            public final void onLocalVRAwake() {
                CarLinkService.this.handleWakeUpShortPressKeyEvent();
            }
        });
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(LocalVoiceAwakeBroadcastReceiver.ACTION_KEY_VOICE_EVENT_ACTION);
        registerReceiver(this.localVoiceAwakeBroadcastReceiver, intentFilter);
        this.mUsbManager = (UsbManager) getSystemService(c.m);
        Car createCar = Car.createCar(this);
        this.mCar = createCar;
        this.mCarAudioManager = (CarAudioManager) createCar.getCarManager(Car.AUDIO_SERVICE);
        initData();
        initCarLinkCarSDK();
    }

    public void reInitCarLinkCarSDK() {
        UCarAdapter.getInstance().deInit();
        this.broadCastProxy.sendConnectStateByBroadCast(false, this.mDeviceId);
        initCarLinkCarSDK();
    }

    private void setForegroundNotification() {
        NotificationChannel notificationChannel = new NotificationChannel("carlink_channel", "CarLink 服务已启动", 2);
        NotificationManager notificationManager = (NotificationManager) getSystemService("notification");
        if (notificationManager != null) {
            notificationManager.createNotificationChannel(notificationChannel);
        }
        startForeground(1, new Notification.Builder(this, "carlink_channel").setContentTitle("CarLink服务已启动").setSmallIcon(R.mipmap.ic_launcher).build());
    }

    private void initData() {
        HandlerManager.getInstance().init(this);
    }

    public void initCarLinkCarSDK() {
        Log.i(this.TAG, "initCarLinkCarSDK()" + sIsServiceInitialized);
        boolean z = false;
        sIsServiceInitialized = false;
        this.mIsDeviceConnected = false;
        this.mIsCastSucceed = false;
        this.mIsPendingCheckExitProcess = false;
        this.isCarLinkPhoneCalling = false;
        this.isMusicPlaying = false;
        this.mIsAdvertising = false;
        this.mIsCarVoiceWakeUp = false;
        initDisplayMetrics();
        byte[] generateCarId = generateCarId();
        Log.i(this.TAG, "carId = " + Arrays.toString(generateCarId) + this.mFullDisplayWidth + this.mFullDisplayHeight);
        UCarConfig.Builder builder = new UCarConfig.Builder();
        if (BuildConfig.flavorType.intValue() == 4) {
            z = true;
        }
        this.mUCarConfig = builder.setCarBrMac(generateCarId).setDpi(DISPLAY_DENSITY_DPI).setFps(30).setScreenWidth(this.mFullDisplayWidth).setScreenHeight(this.mFullDisplayHeight).setVideoDisplayWidth(this.mExpectedDisplayWidth).setVideoDisplayHeight(this.mExpectedDisplayHeight).setSupportP2P(true).setSupportCamera(true).setSupportSoftAP(z).build();
        UCarAdapter.getInstance().init(getApplicationContext(), this.mUCarConfig, new ICarInitCallback() {
            /* class com.geely.carlink.service.CarLinkService.AnonymousClass1 */

            @Override // com.ucar.vehiclesdk.ICarInitCallback
            public void onInitSuccess() {
                Log.i(CarLinkService.this.TAG, "UCarAdapter init success");
                boolean unused = CarLinkService.sIsServiceInitialized = true;
                CarLinkService.this.registerCarEventListener();
                if (CarLinkService.this.mListener != null) {
                    CarLinkService.this.mListener.onSDKInitSuccess();
                }
            }

            @Override // com.ucar.vehiclesdk.ICarInitCallback
            public void onInitFailed(int i) {
                boolean unused = CarLinkService.sIsServiceInitialized = false;
                Log.e(CarLinkService.this.TAG, "UCarAdapter init failed");
            }
        });
    }

    public boolean isCarLinkSDKInitSuccess() {
        return sIsServiceInitialized;
    }

    private void initDisplayMetrics() {
        Display defaultDisplay = ((WindowManager) getApplicationContext().getSystemService("window")).getDefaultDisplay();
        DisplayMetrics displayMetrics = new DisplayMetrics();
        defaultDisplay.getMetrics(displayMetrics);
        this.mDisplayDensityDpi = displayMetrics.densityDpi;
        this.mFullDisplayWidth = displayMetrics.widthPixels;
        if (BuildConfig.flavorType.intValue() == 0) {
            this.mFullDisplayWidth += 120;
        }
        this.mFullDisplayHeight = displayMetrics.heightPixels;
        if (BuildConfig.flavorType.intValue() == 4 && HmiApp.getInstance().getDisplayId() == 2 && this.mFullDisplayWidth != 2880) {
            this.mFullDisplayWidth = Const.G636_CSD_WIDTH;
            this.mFullDisplayHeight = Const.G636_CSD_HEIGHT;
        }
        Log.i(this.TAG, "mFullDisplayWidth=" + this.mFullDisplayWidth + "mFullDisplayHeight=" + this.mFullDisplayHeight + "mDisplayDensityDpi=" + this.mDisplayDensityDpi);
        this.mExpectedDisplayWidth = this.mFullDisplayWidth;
        this.mExpectedDisplayHeight = this.mFullDisplayHeight;
    }

    public byte[] getBluetoothMac() {
        byte[] bArr = new byte[6];
        String address = ((BluetoothManager) getSystemService("bluetooth")).getAdapter().getAddress();
        Log.i(this.TAG, "car mac:" + address + ", is connected before:" + UCarAdapter.existedCarBluetoothMac(address, getApplicationContext()));
        if (address != null) {
            String[] split = address.split(":");
            for (int i = 0; i < split.length; i++) {
                bArr[i] = (byte) Integer.parseInt(split[i], 16);
            }
        } else {
            Log.e(this.TAG, "Temporarily use random numbers as IDs, only for testing");
            new Random().nextBytes(bArr);
        }
        return bArr;
    }

    private byte[] generateCarId() {
        SharedPreferences sharedPreferences = getSharedPreferences(CAR_ID_PREFS, 0);
        String string = sharedPreferences.getString(CAR_ID_KEY, "");
        if (TextUtils.isEmpty(string)) {
            byte[] bluetoothMac = getBluetoothMac();
            String encodeToString = Base64.getEncoder().encodeToString(bluetoothMac);
            sharedPreferences.edit().putString(CAR_ID_KEY, encodeToString).apply();
            Log.d(this.TAG, "raw id = " + Arrays.toString(bluetoothMac));
            string = encodeToString;
        }
        Log.d(this.TAG, "id = " + string);
        return Base64.getDecoder().decode(string);
    }

    public void systemModeDeInit() {
        Log.e(this.TAG, "systemModeDeInit");
        unRegisterSDK();
    }

    public void systemModeInit() {
        Log.e(this.TAG, "systemModeInit");
        registerSDK();
    }

    private void registerSDK() {
        Log.e(this.TAG, "registerSDK");
        initCarLinkCarSDK();
    }

    public void unRegisterSDK() {
        Log.e(this.TAG, "unRegisterSDK: isDeviceConnected()====>" + isDeviceConnected());
        if (isDeviceConnected()) {
            Log.d(this.TAG, "unRegisterSDK: disconnect");
            disconnect();
            UCarAdapter.getInstance().stopAdvertise();
        }
        ServiceListener serviceListener = this.mListener;
        if (serviceListener != null) {
            serviceListener.onHeadUnitDeactivate();
        }
    }

    public void handleWakeUpShortPressKeyEvent() {
        Log.i(this.TAG, "handleWakeUpShortPressKeyEvent()");
        if (isDeviceConnected() && this.mIsCarVoiceWakeUp) {
            UCarAdapter.getInstance().sendVRCMD(UCarCommon.VRCmdType.VR_CMD_VR_STOP, "关闭语音助手");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerCarEventListener() {
        Log.i(this.TAG, "registerCarEventListener");
        this.mConnectCallback = new ICarConnectListener() {
            /* class com.geely.carlink.service.CarLinkService.AnonymousClass2 */

            @Override // com.ucar.vehiclesdk.ICarConnectListener
            public void onPinCode(String str, String str2) {
                Log.i(CarLinkService.this.TAG, "onPinCode, pin code: " + str + ", device name: " + str2);
                Message obtain = Message.obtain();
                obtain.what = 106;
                Bundle bundle = new Bundle();
                bundle.putString("PIN_CODE", str);
                bundle.putString("DEVICE_NAME", str2);
                obtain.obj = bundle;
                CarLinkService.this.mHandler.sendMessage(obtain);
            }

            @Override // com.ucar.vehiclesdk.ICarConnectListener
            public void onConnectingProgress(String str, String str2, int i) {
                Log.i(CarLinkService.this.TAG, "onConnectingProgress: " + i);
                Bundle bundle = new Bundle();
                bundle.putString("ID", str);
                bundle.putString("NAME", str2);
                bundle.putInt("PROGRESS", i);
                Message obtain = Message.obtain();
                obtain.what = 104;
                obtain.obj = bundle;
                CarLinkService.this.mHandler.sendMessage(obtain);
            }

            @Override // com.ucar.vehiclesdk.ICarConnectListener
            public void onConnectStateChanged(String str, int i, int i2) {
                Bundle bundle = new Bundle();
                bundle.putString("ID", str);
                bundle.putInt("STATE", i);
                bundle.putInt("PARAMETER", i2);
                Message obtain = Message.obtain();
                obtain.what = 101;
                obtain.obj = bundle;
                CarLinkService.this.mHandler.sendMessage(obtain);
            }
        };
        UCarAdapter.getInstance().registerCarConnectListener(this.mConnectCallback);
        this.mPhoneDataCallback = new IPhoneDataListener() {
            /* class com.geely.carlink.service.CarLinkService.AnonymousClass3 */

            @Override // com.ucar.vehiclesdk.IPhoneDataListener
            public void onPhoneStateInfoReceived(String str, UCarCommon.PhoneStateInfo phoneStateInfo) {
                CarLinkService.this.handlePhoneStateInfoReceived(phoneStateInfo);
            }

            @Override // com.ucar.vehiclesdk.IPhoneDataListener
            public AudioAttributes getAudioAttributesByType(UCarCommon.AudioType audioType) {
                int i = 2;
                int i2 = 4;
                switch (AnonymousClass6.$SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[audioType.ordinal()]) {
                    case 1:
                        i = 12;
                        Log.i(CarLinkService.this.TAG, "STREAM_TTS");
                        i2 = 1;
                        break;
                    case 2:
                    case 3:
                        Log.i(CarLinkService.this.TAG, "TREAM_IP_CALL/STREAM_MODEM_CALL");
                        CarLinkService.this.setEcnrConfigurationForCall();
                        i2 = 1;
                        break;
                    case 4:
                        i = 16;
                        Log.i(CarLinkService.this.TAG, "STREAM_AI_ASSISTANT");
                        i2 = 1;
                        break;
                    case 5:
                        i = 6;
                        Log.i(CarLinkService.this.TAG, "STREAM_RING");
                        break;
                    case 6:
                        i = 10;
                        Log.i(CarLinkService.this.TAG, "STREAM_NOTIFICATION");
                        break;
                    case 7:
                        Log.i(CarLinkService.this.TAG, "STREAM_TTS/STREAM_SYSTEM");
                        i = 1;
                        break;
                    default:
                        Log.i(CarLinkService.this.TAG, "STREAM_CAST_MUSIC");
                        i2 = 2;
                        i = 1;
                        break;
                }
                return new AudioAttributes.Builder().setUsage(i).setContentType(i2).build();
            }

            @Override // com.ucar.vehiclesdk.IPhoneDataListener
            public void onMusicInfoReceived(String str, UCarCommon.MusicInfo musicInfo) {
                if (musicInfo.isPlaying()) {
                    if (!CarLinkService.this.isMusicPlaying) {
                        UCarAdapter.getInstance().allowGainAudioFocus();
                    }
                    CarLinkService.this.isMusicPlaying = true;
                    HandlerManager.getInstance().getExpandHandler().updatePlayState(3);
                    Log.i(CarLinkService.this.TAG, "ucar music is playing");
                    return;
                }
                HandlerManager.getInstance().getExpandHandler().updatePlayState(2);
                CarLinkService.this.isMusicPlaying = false;
                Log.i(CarLinkService.this.TAG, "ucar music is idle");
            }

            @Override // com.ucar.vehiclesdk.IPhoneDataListener
            public void onNavigationInfoReceived(String str, UCarCommon.NavigationInfo navigationInfo) {
                if (navigationInfo.isNavigating()) {
                    HandlerManager.getInstance().getExpandHandler().cancelLocalNavi();
                    if (CarLinkService.this.mListener != null) {
                        CarLinkService.this.mListener.setTopApp();
                    }
                    Log.i(CarLinkService.this.TAG, "ucar navigation is active");
                    return;
                }
                Log.i(CarLinkService.this.TAG, "ucar navigation is idle");
            }
        };
        UCarAdapter.getInstance().registerPhoneDataListener(this.mPhoneDataCallback);
        if (this.mUCarConfig.isSupportCamera()) {
            this.mCameraInfoCallback = new ICameraInfoListener() {
                /* class com.geely.carlink.service.CarLinkService.AnonymousClass4 */

                @Override // com.ucar.vehiclesdk.ICameraInfoListener
                public ArrayList<AbstractCamera> getNativeCamera() {
                    return null;
                }

                @Override // com.ucar.vehiclesdk.ICameraInfoListener
                public ArrayList<UCarCommon.CameraInfo> getAndroidCameraInfo() {
                    ArrayList<UCarCommon.CameraInfo> arrayList = new ArrayList<>();
                    arrayList.add(new UCarCommon.CameraInfo("1", CarLinkService.CAMERA_NAME, UCarCommon.LensFacing.LENS_FACING_BACK));
                    return arrayList;
                }
            };
            UCarAdapter.getInstance().registerCameraInfoListener(this.mCameraInfoCallback);
        }
    }

    /* renamed from: com.geely.carlink.service.CarLinkService$6  reason: invalid class name */
    static /* synthetic */ class AnonymousClass6 {
        static final /* synthetic */ int[] $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType;

        /* JADX WARNING: Can't wrap try/catch for region: R(18:0|1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|18) */
        /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x003e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0049 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x0054 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0028 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0033 */
        static {
            int[] iArr = new int[UCarCommon.AudioType.values().length];
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType = iArr;
            iArr[UCarCommon.AudioType.STREAM_TTS.ordinal()] = 1;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_IP_CALL.ordinal()] = 2;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_MODEM_CALL.ordinal()] = 3;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_AI_ASSISTANT.ordinal()] = 4;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_RING.ordinal()] = 5;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_NOTIFICATION.ordinal()] = 6;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_SYSTEM.ordinal()] = 7;
            $SwitchMap$com$ucar$vehiclesdk$UCarCommon$AudioType[UCarCommon.AudioType.STREAM_CAST_MUSIC.ordinal()] = 8;
        }
    }

    private void unregisterCarEventListener() {
        UCarAdapter.getInstance().unregisterCarConnectListener(this.mConnectCallback);
        UCarAdapter.getInstance().unregisterPhoneDataListener(this.mPhoneDataCallback);
        UCarAdapter.getInstance().unregisterCameraInfoListener(this.mCameraInfoCallback);
    }

    public void sendDisConnectBroadCast() {
        if (this.mIsCastSucceed) {
            Log.i(this.TAG, "sendDisConnectBroadCast()");
            this.broadCastProxy.sendConnectStateByBroadCast(false, this.mDeviceId);
        }
    }

    public void onDestroy() {
        super.onDestroy();
        Log.i(this.TAG, "onDestroy");
        unregisterCarEventListener();
        UCarAdapter.getInstance().deInit();
        unregisterReceiver(this.mSimulationReceiver);
        unregisterReceiver(this.localVoiceAwakeBroadcastReceiver);
        this.mUsbDelegate.deInit();
        this.bluetoothDelegate.deInit();
        HandlerManager.getInstance().deInit();
        this.mHandler.removeCallbacksAndMessages(null);
        Log.d(this.TAG, "exit process");
        System.exit(0);
    }

    public void registerServiceListener(ServiceListener serviceListener) {
        this.mListener = serviceListener;
    }

    public void unregisterServiceListener() {
        this.mListener = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleConnectStateChangedMessage(Message message) {
        Bundle bundle = (Bundle) message.obj;
        String string = bundle.getString("ID");
        this.mDeviceId = string;
        int connectType = UCarAdapter.getInstance().getConnectType(string);
        int i = bundle.getInt("STATE");
        int i2 = bundle.getInt("PARAMETER");
        boolean z = i2 == 11;
        switch (i) {
            case 1:
                if (this.mIsDeviceConnected) {
                    Log.i(this.TAG, "ucar device disconnected, is disconnect by user : " + z + " type = " + connectType);
                    this.mIsDeviceConnected = false;
                    this.mIsCastSucceed = false;
                    this.broadCastProxy.sendConnectStateByBroadCast(false, string);
                    unsetEcnrConfigurationForCall();
                    ServiceListener serviceListener = this.mListener;
                    if (serviceListener != null) {
                        serviceListener.onDisconnected(message);
                    }
                    BluetoothDelegateImpl bluetoothDelegateImpl = this.bluetoothDelegate;
                    if (bluetoothDelegateImpl != null) {
                        bluetoothDelegateImpl.onDisConnectCarLinkResolved();
                        return;
                    }
                    return;
                }
                return;
            case 2:
                Log.i(this.TAG, "ucar device connected");
                this.mIsDeviceConnected = true;
                ServiceListener serviceListener2 = this.mListener;
                if (serviceListener2 != null) {
                    serviceListener2.onConnectSuccess();
                }
                BluetoothDelegateImpl bluetoothDelegateImpl2 = this.bluetoothDelegate;
                if (bluetoothDelegateImpl2 != null) {
                    bluetoothDelegateImpl2.onConnectCarLinkResolved();
                }
                this.broadCastProxy.sendConnectStateByBroadCast(true, string);
                return;
            case 3:
                Log.i(this.TAG, "ucar device connect failed" + string + "/" + i2 + "/" + i);
                ServiceListener serviceListener3 = this.mListener;
                if (serviceListener3 != null) {
                    serviceListener3.onConnectFail(i2);
                    return;
                }
                return;
            case 4:
                Log.i(this.TAG, "cast connected");
                this.mIsCastSucceed = true;
                this.mIsPendingCheckExitProcess = true;
                startMainActivity();
                ServiceListener serviceListener4 = this.mListener;
                if (serviceListener4 != null) {
                    serviceListener4.onCastConnected();
                }
                this.broadCastProxy.sendConnectStateByBroadCast(true, string);
                return;
            case 5:
                Log.i(this.TAG, "cast disconnected type = " + connectType + "isDisconnectByUser =" + z);
                this.mIsCastSucceed = false;
                if (this.mListener != null && z) {
                    Log.i(this.TAG, "mListener.onCastDisConnected()");
                    this.broadCastProxy.sendConnectStateByBroadCast(false, string);
                    BluetoothDelegateImpl bluetoothDelegateImpl3 = this.bluetoothDelegate;
                    if (bluetoothDelegateImpl3 != null) {
                        bluetoothDelegateImpl3.onDisConnectCarLinkResolved();
                    }
                    this.mListener.onCastDisConnected();
                    return;
                }
                return;
            case 6:
                ServiceListener serviceListener5 = this.mListener;
                if (serviceListener5 != null) {
                    serviceListener5.goToHome();
                    return;
                }
                return;
            default:
                return;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handlePhoneStateInfoReceived(UCarCommon.PhoneStateInfo phoneStateInfo) {
        this.mHandler.post(new Runnable(phoneStateInfo) {
            /* class com.geely.carlink.service.$$Lambda$CarLinkService$GxQEIgI55vEeZaUTVo5eqkAmXc */
            public final /* synthetic */ UCarCommon.PhoneStateInfo f$1;

            {
                this.f$1 = r2;
            }

            public final void run() {
                CarLinkService.this.lambda$handlePhoneStateInfoReceived$0$CarLinkService(this.f$1);
            }
        });
    }

    public /* synthetic */ void lambda$handlePhoneStateInfoReceived$0$CarLinkService(UCarCommon.PhoneStateInfo phoneStateInfo) {
        int i;
        boolean isUseMicrophone = phoneStateInfo.isUseMicrophone();
        if (isUseMicrophone != this.mPhoneStateInfo.isUseMicrophone()) {
            if (phoneStateInfo.isUseMicrophone()) {
                Log.i(this.TAG, "ucar request use mic");
                HandlerManager.getInstance().getExpandHandler().stopNativeVr();
            } else {
                Log.i(this.TAG, "ucar has released mic");
                unsetEcnrConfigurationForCall();
            }
            this.mPhoneStateInfo.setUseMicrophone(isUseMicrophone);
        }
        boolean isVoiceAssistantActive = phoneStateInfo.isVoiceAssistantActive();
        if (isVoiceAssistantActive != this.mPhoneStateInfo.isVoiceAssistantActive()) {
            if (isVoiceAssistantActive) {
                Log.i(this.TAG, "voice assistant state is active");
                try {
                    this.mIsCarVoiceWakeUp = true;
                    Log.i(this.TAG, "ecnr start vr");
                    if (UCarAdapter.getInstance().getConnectType(this.mDeviceId) == 2) {
                        i = 27;
                        Log.i(this.TAG, "ecnr vr type usb");
                    } else {
                        i = 28;
                        Log.i(this.TAG, "ecnr vr type wifi");
                    }
                    this.mCarAudioManager.setEcnrConfiguration(4, i);
                    this.mCarAudioManager.setEcnrMode(0);
                } catch (CarNotConnectedException e) {
                    Log.e(this.TAG, "Car is not connected", e);
                } catch (NullPointerException e2) {
                    Log.e(this.TAG, "mCarAudioManager is NULL!", e2);
                }
            } else {
                Log.i(this.TAG, "voice assistant state is idle");
                try {
                    if (this.mIsCarVoiceWakeUp) {
                        this.mIsCarVoiceWakeUp = false;
                        Log.i(this.TAG, "ecnr stop vr");
                        this.mCarAudioManager.setEcnrConfiguration(0, 0);
                        this.mCarAudioManager.setEcnrMode(3);
                    }
                } catch (CarNotConnectedException e3) {
                    Log.e(this.TAG, "Car is not connected", e3);
                } catch (NullPointerException e4) {
                    Log.e(this.TAG, "mCarAudioManager is NULL!", e4);
                }
            }
            this.mPhoneStateInfo.setVoiceAssistantActive(isVoiceAssistantActive);
        }
        this.modemCallState = phoneStateInfo.getModemCallState();
        Log.i(this.TAG, "receiveDataFromPhone: dataType:DATA_TYPE_CALL_STATE_FOCUS, callState:" + this.modemCallState);
        if (this.modemCallState != this.mPhoneStateInfo.getModemCallState()) {
            if (this.modemCallState == UCarCommon.ModemCallState.RINGING) {
                this.broadCastProxy.sendPhoneStateByBroadCast(1);
                HandlerManager.getInstance().getExpandHandler().stopNativeVr();
                this.isCarLinkPhoneCalling = true;
                ServiceListener serviceListener = this.mListener;
                if (serviceListener != null) {
                    serviceListener.setTopApp();
                    this.mListener.onCallStateRinging();
                }
                this.broadCastProxy.sendQuitFullScreenView();
                Log.i(this.TAG, "modem call state changed : " + this.modemCallState);
            } else if (this.modemCallState == UCarCommon.ModemCallState.OFFHOOK) {
                this.isCarLinkPhoneCalling = true;
                Log.i(this.TAG, "UCarCommon.ModemCallState.OFFHOOK");
                this.broadCastProxy.sendPhoneStateByBroadCast(2);
                HandlerManager.getInstance().getExpandHandler().stopNativeVr();
                ServiceListener serviceListener2 = this.mListener;
                if (serviceListener2 != null) {
                    serviceListener2.setTopApp();
                    this.mListener.onCallStateOffhook();
                }
            } else if (this.modemCallState == UCarCommon.ModemCallState.IDLE) {
                Log.i(this.TAG, "UCarCommon.ModemCallState.IDLE");
                if (this.isCarLinkPhoneCalling) {
                    this.isCarLinkPhoneCalling = false;
                }
                ServiceListener serviceListener3 = this.mListener;
                if (serviceListener3 != null) {
                    serviceListener3.onCallStateIdle();
                }
            }
            this.mPhoneStateInfo.setModemCallState(this.modemCallState);
        }
        boolean isVoipCall = phoneStateInfo.isVoipCall();
        if (isVoipCall != this.mPhoneStateInfo.isVoipCall()) {
            if (isVoipCall) {
                ServiceListener serviceListener4 = this.mListener;
                if (serviceListener4 != null) {
                    serviceListener4.setTopApp();
                }
                Log.i(this.TAG, "voip call state is active");
            } else {
                Log.i(this.TAG, "voip call state is idle");
            }
            this.mPhoneStateInfo.setVoipCall(isVoipCall);
        }
    }

    public boolean isCalling() {
        return this.isCarLinkPhoneCalling;
    }

    public UCarCommon.ModemCallState getCallState() {
        return this.modemCallState;
    }

    public boolean isMusicPlaying() {
        return this.isMusicPlaying;
    }

    public boolean isDeviceConnected() {
        return this.mIsDeviceConnected;
    }

    public boolean isAdvertising() {
        return this.mIsAdvertising;
    }

    public boolean isCastSucceed() {
        return this.mIsCastSucceed;
    }

    public void tryConnect(int i) {
        this.mTryConnectType = i;
        HandlerManager.getInstance().getExpandHandler().tryConnect(i);
    }

    public void onPermitted() {
        int i = this.mTryConnectType;
        if (i == 1) {
            Log.d(this.TAG, "onPermitted: prepare connect usb");
            connectUsbDevice();
        } else if (i != 2) {
            Log.e(this.TAG, "onPermitted: type error");
        } else if (this.mListener != null) {
            Log.d(this.TAG, "onPermitted: prepare connect wifi");
            this.mListener.onPermitted();
        } else {
            Log.e(this.TAG, "onPreConnect: listener null");
        }
    }

    public void onDenied() {
        if (this.mListener == null) {
            Log.e(this.TAG, "onDenied: listener null");
            return;
        }
        Log.d(this.TAG, "onDenied: ");
        this.mListener.onDenied();
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x002f A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:3:0x001b  */
    public void connectUsbDevice() {
        boolean z;
        Log.d(this.TAG, "connectUsbDevice: ");
        Iterator<UsbDevice> it = this.mUsbManager.getDeviceList().values().iterator();
        while (true) {
            if (!it.hasNext()) {
                int vendorId = it.next().getVendorId();
                if (vendorId == 4817 || vendorId == 13211) {
                    z = true;
                }
                if (!it.hasNext()) {
                    z = false;
                    break;
                }
            }
        }
        z = true;
        if (z) {
            Log.e(this.TAG, "connectUsbDevice: carlink devices");
        } else {
            Log.d(this.TAG, "connectUsbDevice: reset support usb for usb connecting");
        }
    }

    public void disconnect() {
        if (isDeviceConnected()) {
            Log.i(this.TAG, "主动断开连接+" + UCarAdapter.getInstance().disconnect());
        }
    }

    public void startAvd() {
        Log.i(this.TAG, "开始扫描。。。。。。");
        UCarAdapter.getInstance().startAdvertise();
        this.mIsAdvertising = true;
    }

    public void stopAdv() {
        Log.i(this.TAG, "stopAdv()");
        if (UCarAdapter.getInstance().stopAdvertise()) {
            Log.i(this.TAG, "stopAdv: stop adv success");
            this.mIsAdvertising = false;
        }
    }

    public void stopCarLinkNav() {
        UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_DOWN, UCarCommon.KeyCodeType.KEY_CODE_NAVI_QUIT, 0);
        UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_UP, UCarCommon.KeyCodeType.KEY_CODE_NAVI_QUIT, 0);
    }

    public void sendKeyEventInternal(KeyEvent keyEvent) {
        Log.d(this.TAG, "sendKeyEventInternal: " + keyEvent.getKeyCode());
        sendKeyEvent(keyEvent);
    }

    public void sendKeyEventInternal(int i) {
        Log.d(this.TAG, "sendKeyEventInternal: " + i);
        UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_DOWN, UCarCommon.KeyCodeType.fromInt(i), 0);
        UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_UP, UCarCommon.KeyCodeType.fromInt(i), 0);
    }

    public void sendKeyEvent(KeyEvent keyEvent) {
        UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_DOWN, UCarCommon.KeyCodeType.fromInt(keyEvent.getKeyCode()), keyEvent.getMetaState());
        UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_UP, UCarCommon.KeyCodeType.fromInt(keyEvent.getKeyCode()), keyEvent.getMetaState());
    }

    public void handleWakeUpLongPressKeyEvent() {
        boolean sendKeyEvent = UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_DOWN, UCarCommon.KeyCodeType.KEY_CODE_VR_START, 0);
        Log.d(this.TAG, "handleWakeUpLongPressKeyEvent" + sendKeyEvent + UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_UP, UCarCommon.KeyCodeType.KEY_CODE_VR_START, 0));
    }

    public void startMainActivity() {
        if (this.mListener == null) {
            Intent intent = new Intent(this, MainActivity.class);
            intent.addFlags(268435456);
            startActivity(intent);
            Log.d(this.TAG, "startMainActivity success");
            return;
        }
        Log.d(this.TAG, "mListener != null");
    }

    public void tryReconnect() {
        tryReconnectWirelessCarLink();
        tryReconnectWiredCarLink();
    }

    private void tryReconnectWirelessCarLink() {
        Log.d(this.TAG, "tryReconnectWirelessCarLink: ");
        tryConnect(2);
    }

    private void tryReconnectWiredCarLink() {
        Log.d(this.TAG, "tryReconnect: connect usb device");
        UCarAdapter.getInstance().enableUsbDeviceDetection(true);
    }

    public void disableUsbDeviceDetection() {
        Log.d(this.TAG, "disableUsbDeviceDetection");
        int connectType = UCarAdapter.getInstance().getConnectType(this.mDeviceId);
        if (!isDeviceConnected() || connectType != 2) {
            UCarAdapter.getInstance().enableUsbDeviceDetection(false);
        } else {
            Log.i(this.TAG, "disableUsbDeviceDetection: usb connect");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setEcnrConfigurationForCall() {
        int i;
        if (isDeviceConnected()) {
            try {
                Log.i(this.TAG, "ecnr start call");
                if (UCarAdapter.getInstance().getConnectType(this.mDeviceId) == 2) {
                    i = 29;
                    Log.i(this.TAG, "ecnr call type usb");
                } else {
                    i = 30;
                    Log.i(this.TAG, "ecnr call type wifi");
                }
                CarAudioManager carAudioManager = this.mCarAudioManager;
                if (carAudioManager != null) {
                    carAudioManager.setEcnrConfiguration(5, i);
                    this.mCarAudioManager.setEcnrMode(0);
                }
            } catch (CarNotConnectedException e) {
                Log.e(this.TAG, "Car is not connected", e);
            } catch (NullPointerException e2) {
                Log.e(this.TAG, "mCarAudioManager is NULL!", e2);
            }
        }
    }

    private void unsetEcnrConfigurationForCall() {
        try {
            if (this.mCarAudioManager != null) {
                Log.i(this.TAG, "ecnr stop call");
                this.mCarAudioManager.setEcnrConfiguration(0, 0);
                this.mCarAudioManager.setEcnrMode(3);
            }
        } catch (CarNotConnectedException e) {
            Log.e(this.TAG, "Car is not connected", e);
        } catch (NullPointerException e2) {
            Log.e(this.TAG, "mCarAudioManager is NULL!", e2);
        }
    }
}
