package com.geely.carlink.service;

import a.b.a.c;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbManager;
import android.util.Log;
import com.geely.carlink.broadcast.UsbBroadcastReceiver;
import com.geely.carlink.constant.Const;

public class UsbDelegateImpl implements UsbDelegate {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private boolean isUsbConnect = false;
    private final UsbBroadcastReceiver.CallBack mCallback = new UsbBroadcastReceiver.CallBack() {
        /* class com.geely.carlink.service.UsbDelegateImpl.AnonymousClass1 */

        @Override // com.geely.carlink.broadcast.UsbBroadcastReceiver.CallBack
        public void onUsbDeviceAttached(Intent intent) {
            Log.d(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: ");
            UsbDevice usbDevice = (UsbDevice) intent.getParcelableExtra("device");
            if (usbDevice == null) {
                Log.e(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: device null");
                return;
            }
            Log.d(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: device : " + usbDevice);
            if (!UsbDelegateImpl.this.isUsbDeviceSupportHiCar(usbDevice)) {
                if (usbDevice.getDeviceClass() != 0) {
                    Log.d(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: after usb enum");
                } else if (!(UsbDelegateImpl.this.mContext instanceof CarLinkService)) {
                    Log.e(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: context type error");
                } else if (UsbDelegateImpl.this.isUsbConnect) {
                    Log.e(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: usb already connect");
                } else {
                    CarLinkService carLinkService = (CarLinkService) UsbDelegateImpl.this.mContext;
                    if (carLinkService.isDeviceConnected()) {
                        Log.d(UsbDelegateImpl.this.TAG, "isDeviceConnected = true");
                        return;
                    }
                    Log.d(UsbDelegateImpl.this.TAG, "onUsbDeviceAttached: call try connect (usb)");
                    UsbDelegateImpl.this.isUsbConnect = true;
                    carLinkService.tryConnect(1);
                }
            }
        }

        @Override // com.geely.carlink.broadcast.UsbBroadcastReceiver.CallBack
        public void onUsbDeviceDetached(Intent intent) {
            Log.d(UsbDelegateImpl.this.TAG, "onUsbDeviceDetached: ");
            UsbDelegateImpl.this.isUsbConnect = false;
        }
    };
    private final Context mContext;
    private final UsbBroadcastReceiver mUsbBroadcastReceiver = new UsbBroadcastReceiver();
    private UsbManager mUsbManager;

    public UsbDelegateImpl(Context context) {
        this.mContext = context;
        init();
    }

    @Override // com.geely.carlink.service.UsbDelegate
    public void init() {
        this.mUsbManager = (UsbManager) this.mContext.getSystemService(c.m);
        if (this.mUsbBroadcastReceiver == null) {
            Log.e(this.TAG, "init: mUsbBroadcastReceiver null");
            return;
        }
        Log.d(this.TAG, "init: setCallBack");
        this.mUsbBroadcastReceiver.setCallBack(this.mCallback);
    }

    @Override // com.geely.carlink.service.UsbDelegate
    public void registerBR(CarLinkService carLinkService) {
        Log.d(this.TAG, "registerBR: ");
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.hardware.usb.action.USB_DEVICE_ATTACHED");
        intentFilter.addAction("android.hardware.usb.action.USB_DEVICE_DETACHED");
        this.mContext.registerReceiver(this.mUsbBroadcastReceiver, intentFilter);
    }

    @Override // com.geely.carlink.service.UsbDelegate
    public void deInit() {
        Log.d(this.TAG, "deInit: ");
        this.mContext.unregisterReceiver(this.mUsbBroadcastReceiver);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isUsbDeviceSupportHiCar(UsbDevice usbDevice) {
        if (usbDevice == null) {
            Log.e(this.TAG, "isUsbDeviceSupportHiCar: device null");
            return false;
        }
        int vendorId = usbDevice.getVendorId();
        if (vendorId == 4817 || vendorId == 13211) {
            Log.d(this.TAG, "onUsbDeviceAttached: support hicar " + vendorId);
            return true;
        }
        Log.d(this.TAG, "onUsbDeviceAttached: not support hicar " + vendorId);
        return false;
    }
}
