package com.geely.carlink.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.text.Editable;
import android.text.TextPaint;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.AttributeSet;
import android.view.View;
import androidx.appcompat.widget.AppCompatTextView;
import com.geely.carlink.BuildConfig;
import com.geely.carlink.R;
import com.geely.carlink.app.HmiApp;

public class UCarAutoScaleTextView extends AppCompatTextView {
    private static final String CALCULATION_STRING = "正";
    private CharSequence mLastText;
    private int mLengthByChar;
    private final TextWatcher mTextWatcher;
    private int mWidthCalcBySize;
    private float mWidthPercent;

    public UCarAutoScaleTextView(Context context) {
        this(context, null);
    }

    public UCarAutoScaleTextView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public UCarAutoScaleTextView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        float f;
        this.mTextWatcher = new TextWatcher() {
            /* class com.geely.carlink.widget.UCarAutoScaleTextView.AnonymousClass1 */

            public void beforeTextChanged(CharSequence charSequence, int i, int i2, int i3) {
            }

            public void onTextChanged(CharSequence charSequence, int i, int i2, int i3) {
            }

            public void afterTextChanged(Editable editable) {
                UCarAutoScaleTextView.this.calcTextSize();
            }
        };
        int i2 = 0;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.UCarAutoScaleTextView, i, 0);
        if (obtainStyledAttributes != null) {
            try {
                f = obtainStyledAttributes.getFloat(1, 1.0f);
                i2 = obtainStyledAttributes.getInt(0, 0);
            } finally {
                obtainStyledAttributes.recycle();
            }
        } else {
            f = 1.0f;
        }
        if (BuildConfig.flavorType.intValue() == 4 && HmiApp.getInstance().getDisplayId() == 2) {
            f /= 2.0f;
        }
        this.mLengthByChar = i2;
        this.mWidthPercent = Math.min(f, 1.0f);
        this.mWidthCalcBySize = getResources().getDisplayMetrics().widthPixels;
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        calcTextSize();
        addTextChangedListener(this.mTextWatcher);
    }

    /* access modifiers changed from: protected */
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        removeTextChangedListener(this.mTextWatcher);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.widget.AppCompatTextView
    public void onMeasure(int i, int i2) {
        if (View.MeasureSpec.getMode(i) != 1073741824) {
            i = View.MeasureSpec.makeMeasureSpec((int) ((((float) this.mWidthCalcBySize) * this.mWidthPercent) + ((float) getPaddingLeft()) + ((float) getPaddingRight())), 1073741824);
        }
        super.onMeasure(i, i2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calcTextSize() {
        float f;
        float f2;
        CharSequence text = getText();
        if (!(text == null || TextUtils.isEmpty(text) || TextUtils.equals(this.mLastText, text))) {
            this.mLastText = text;
            int i = (int) (((float) this.mWidthCalcBySize) * this.mWidthPercent);
            int i2 = this.mLengthByChar;
            TextPaint paint = getPaint();
            String[] split = text.toString().split("\n");
            int i3 = 0;
            for (String str : split) {
                i3 = Math.max(i3, str.length());
            }
            if (i2 > i3) {
                f = measureText(paint, i2);
            } else {
                f = measureText(paint, split);
            }
            float f3 = (float) i;
            paint.setTextSize((f3 / f) * paint.getTextSize());
            if (i2 > i3) {
                f2 = measureText(paint, i2);
            } else {
                f2 = measureText(paint, split);
            }
            while (f2 > f3) {
                paint.setTextSize(paint.getTextSize() - 1.0f);
                if (i2 > i3) {
                    f2 = measureText(paint, i2);
                } else {
                    f2 = measureText(paint, split);
                }
            }
        }
    }

    private float measureText(TextPaint textPaint, String[] strArr) {
        float f = 0.0f;
        for (String str : strArr) {
            float measureText = textPaint.measureText(str);
            if (measureText > f) {
                f = measureText;
            }
        }
        return f;
    }

    private float measureText(TextPaint textPaint, int i) {
        return textPaint.measureText(CALCULATION_STRING) * ((float) i);
    }
}
