package com.geely.carlink.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Outline;
import android.graphics.Rect;
import android.text.TextPaint;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewOutlineProvider;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.geely.carlink.BuildConfig;
import com.geely.carlink.R;
import com.geely.carlink.app.HmiApp;
import com.geely.carlink.constant.Const;
import com.geely.lib.oneosapi.user.bean.LoginType;

public class UCarPinCodeView extends LinearLayout {
    private static final int CODE_LENGTH = 6;
    private static final float DEFAULT_PERCENT = 0.5f;
    private final String TAG;
    private String mPinCode;
    private int mSize;
    private final TextView[] mTextViews;
    private int mWidth;
    private float mWidthPercent;
    private int margin;

    public UCarPinCodeView(Context context) {
        this(context, null);
    }

    public UCarPinCodeView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public UCarPinCodeView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.mTextViews = new TextView[6];
        this.margin = 5;
        String str = Const.GLOBAL_TAG + getClass().getSimpleName();
        this.TAG = str;
        setOrientation(0);
        int i2 = getResources().getDisplayMetrics().widthPixels;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.UCarPinCodeView, i, 0);
        float f = DEFAULT_PERCENT;
        if (obtainStyledAttributes != null) {
            try {
                f = obtainStyledAttributes.getFloat(0, DEFAULT_PERCENT);
            } finally {
                obtainStyledAttributes.recycle();
            }
        }
        Log.i(str, "displayWidth = " + i2);
        if (BuildConfig.flavorType.intValue() == 4) {
            Log.i(str, "HmiApp.getInstance().getDisplayId() = " + HmiApp.getInstance().getDisplayId());
            if (HmiApp.getInstance().getDisplayId() == 2) {
                f = 0.325f;
                Log.i(str, "widthPercent = 0.43f;");
            } else if (HmiApp.getInstance().getDisplayId() == 0) {
                f = 0.65f;
                Log.i(str, "widthPercent = 0.65f");
            }
        }
        float min = Math.min(f, 1.0f);
        this.mWidthPercent = min;
        this.mWidth = (int) (((float) i2) * min);
        Log.i(str, "mWidth" + this.mWidth);
        this.mSize = (int) (((float) this.mWidth) / 8.0f);
        Rect rect = new Rect();
        int i3 = -1;
        for (int i4 = 0; i4 < 6; i4++) {
            TextView textView = new TextView(context, null, 0, R.style.UCarPinCode_Style);
            if (i3 == -1) {
                TextPaint paint = textView.getPaint();
                paint.getTextBounds(LoginType.PASSWORD, 0, 1, rect);
                i3 = (int) ((((float) this.mSize) / (((float) rect.height()) * 2.0f)) * paint.getTextSize());
            }
            textView.setTextSize(0, (float) i3);
            textView.setGravity(17);
            int i5 = this.mSize;
            ViewGroup.MarginLayoutParams marginLayoutParams = new ViewGroup.MarginLayoutParams(i5, i5);
            if (i4 == 0) {
                marginLayoutParams.rightMargin = (((this.mSize * 2) / 5) / 2) + this.margin;
            } else if (i4 == 5) {
                marginLayoutParams.leftMargin = (((this.mSize * 2) / 5) / 2) + this.margin;
            } else {
                marginLayoutParams.leftMargin = (((this.mSize * 2) / 5) / 2) + this.margin;
                marginLayoutParams.rightMargin = (((this.mSize * 2) / 5) / 2) + this.margin;
            }
            textView.setClipToOutline(true);
            textView.setOutlineProvider(new ViewOutlineProvider() {
                /* class com.geely.carlink.widget.UCarPinCodeView.AnonymousClass1 */

                public void getOutline(View view, Outline outline) {
                    outline.setRoundRect(0, 0, view.getWidth(), view.getHeight(), 20.0f);
                }
            });
            addView(textView, marginLayoutParams);
            this.mTextViews[i4] = textView;
        }
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i, int i2) {
        if (getChildCount() == 6) {
            super.onMeasure(View.MeasureSpec.makeMeasureSpec(this.mWidth + (this.margin * 2 * 5), 1073741824), View.MeasureSpec.makeMeasureSpec(this.mSize, 1073741824));
            return;
        }
        throw new RuntimeException("pin code must be length 6");
    }

    public void setPinCode(String str) {
        if (str.length() == 6) {
            this.mPinCode = str;
            int i = 0;
            while (i < 6) {
                int i2 = i + 1;
                this.mTextViews[i].setText(str.substring(i, i2));
                i = i2;
            }
            return;
        }
        throw new IllegalArgumentException("pin code must be length 6");
    }

    public String getPinCode() {
        return this.mPinCode;
    }
}
