package com.geely.lib.oneosapi.gesture;

import android.content.Context;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.gesture.IGestureEventNotifyCallback;
import com.geely.lib.oneosapi.gesture.IGestureManager;
import java.lang.ref.WeakReference;

public class GestureManager implements ServiceBaseManager {
    private static final int MSG_GESTURE_FUN_NOTIFY = 101;
    private static final String TAG = "GestureManager";
    private IGestureEventNotifyCallback gestureEventNotifyCallback = new IGestureEventNotifyCallback.Stub() {
        /* class com.geely.lib.oneosapi.gesture.GestureManager.AnonymousClass1 */

        @Override // com.geely.lib.oneosapi.gesture.IGestureEventNotifyCallback
        public String getUID() throws RemoteException {
            return "";
        }

        @Override // com.geely.lib.oneosapi.gesture.IGestureEventNotifyCallback
        public void onGestureNotify(GestureModel gestureModel) throws RemoteException {
            Message message = new Message();
            message.what = 101;
            message.obj = gestureModel;
            GestureManager.this.mHandler.sendMessage(message);
        }
    };
    private IGestureNotifyListener gestureNotifyListener;
    private final Context mContext;
    private SyncHandler mHandler;
    private IGestureManager mService;

    public static class SyncHandler extends Handler {
        public WeakReference<GestureManager> weakReference;

        public void handleMessage(Message message) {
            super.handleMessage(message);
            GestureManager gestureManager = this.weakReference.get();
            if (message.what == 101 && gestureManager.gestureNotifyListener != null) {
                GestureModel gestureModel = (GestureModel) message.obj;
                Log.d(GestureManager.TAG, "onGestureNotify: " + gestureModel.toString());
                gestureManager.gestureNotifyListener.onGestureNotify(gestureModel);
            }
        }

        private SyncHandler(GestureManager gestureManager, Looper looper) {
            super(looper);
            this.weakReference = new WeakReference<>(gestureManager);
        }
    }

    public GestureManager(Context context, IBinder iBinder) {
        this.mContext = context;
        this.mService = IGestureManager.Stub.asInterface(iBinder);
        this.mHandler = new SyncHandler(context.getMainLooper());
        Log.d(TAG, "GestureManager: mService=" + this.mService);
    }

    public boolean addGestureDetectEventNotify(IGestureNotifyListener iGestureNotifyListener) {
        try {
            IGestureManager iGestureManager = this.mService;
            if (iGestureManager == null) {
                return false;
            }
            this.gestureNotifyListener = iGestureNotifyListener;
            return iGestureManager.addGestureDetectEventNotify(this.gestureEventNotifyCallback);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean removeGestureDetectEventNotify() {
        try {
            IGestureManager iGestureManager = this.mService;
            if (iGestureManager == null) {
                return false;
            }
            this.gestureNotifyListener = null;
            return iGestureManager.removeGestureDetectEventNotify(this.gestureEventNotifyCallback);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = IGestureManager.Stub.asInterface(iBinder);
        Log.d(TAG, "setService: mService=" + this.mService);
    }
}
