package com.geely.lib.oneosapi.launcher;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.launcher.ILauncherService;
import com.geely.lib.oneosapi.launcher.listener.IEnterOrExitHomePageChangeListener;
import com.geely.lib.oneosapi.launcher.listener.ILauncherPageSwitchListener;
import com.geely.lib.oneosapi.launcher.listener.IMapWidgetChangeListener;
import com.geely.lib.oneosapi.launcher.listener.IWeatherWidgetChangeListener;
import com.geely.lib.oneosapi.launcher.listener.IWidgetListDisplayChangeListener;

public class LauncherManager implements ServiceBaseManager {
    private static final String TAG = "ShortcutManager";
    private ILauncherService mService;

    public LauncherManager(Context context, IBinder iBinder) {
        this.mService = ILauncherService.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        ILauncherService iLauncherService = this.mService;
        return iLauncherService != null && iLauncherService.asBinder().isBinderAlive();
    }

    public void closeApplets(String str) {
        if (isServiceAlive()) {
            try {
                this.mService.closeApplets(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "closeApplets: service is not alive");
        }
    }

    public void hvacMassageDisplay(boolean z, boolean z2) {
        if (isServiceAlive()) {
            try {
                this.mService.hvacMassageDisplay(z, z2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "hvacMassageDisplay: service is not alive");
        }
    }

    public void mediaSourceListDisplay(boolean z, boolean z2) {
        if (isServiceAlive()) {
            try {
                this.mService.mediaSourceListDisplay(z, z2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "mediaSourceListDisplay: service is not alive");
        }
    }

    public void openApplets(String str) {
        if (isServiceAlive()) {
            try {
                this.mService.openApplets(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "openApplets: service is not alive");
        }
    }

    public void registerEnterOrExitHomePageChangeListener(IEnterOrExitHomePageChangeListener iEnterOrExitHomePageChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.registerEnterOrExitHomePageChangeListener(iEnterOrExitHomePageChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "unRegisterWeatherWidgetListener: service is not alive");
        }
    }

    public void registerLauncherPageSwitchListener(ILauncherPageSwitchListener iLauncherPageSwitchListener) {
        if (isServiceAlive()) {
            try {
                this.mService.registerLauncherPageSwitchListener(iLauncherPageSwitchListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "registerLauncherPageSwitchListener: service is not alive");
        }
    }

    public void registerMapWidgetListener(IMapWidgetChangeListener iMapWidgetChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.registerMapWidgetListener(iMapWidgetChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "registerMapWidgetListener: service is not alive");
        }
    }

    public void registerWeatherWidgetListener(IWeatherWidgetChangeListener iWeatherWidgetChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.registerWeatherWidgetListener(iWeatherWidgetChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "registerWeatherWidgetListener: service is not alive");
        }
    }

    public void registerWidgetListDisplayChangeListener(IWidgetListDisplayChangeListener iWidgetListDisplayChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.registerWidgetListDisplayChangeListener(iWidgetListDisplayChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "registerWidgetListDisplayChangeListener: service is not alive");
        }
    }

    public void selectWidgetMap(String str) {
        if (isServiceAlive()) {
            try {
                this.mService.selectWidgetMap(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "selectWidgetMap: service is not alive");
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = ILauncherService.Stub.asInterface(iBinder);
    }

    public void showPsdMediaControlWidget(boolean z) {
        if (isServiceAlive()) {
            try {
                this.mService.showPsdMediaControlWidget(z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "showPsdMediaControlWidget: service is not alive");
        }
    }

    public void startGlobalSearch(String str) {
        if (isServiceAlive()) {
            try {
                this.mService.startGlobalSearch(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "startGlobalSearch: service is not alive");
        }
    }

    public void togglePsdWidget() {
        if (isServiceAlive()) {
            try {
                this.mService.togglePsdWidget();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "togglePsdWidget: service is not alive");
        }
    }

    public void toggleWidget() {
        if (isServiceAlive()) {
            try {
                this.mService.toggleWidget();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "toggleWidget: service is not alive");
        }
    }

    public void unRegisterEnterOrExitHomePageChangeListener(IEnterOrExitHomePageChangeListener iEnterOrExitHomePageChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.unRegisterEnterOrExitHomePageChangeListener(iEnterOrExitHomePageChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "unRegisterWeatherWidgetListener: service is not alive");
        }
    }

    public void unRegisterLauncherPageSwitchListener(ILauncherPageSwitchListener iLauncherPageSwitchListener) {
        if (isServiceAlive()) {
            try {
                this.mService.unRegisterLauncherPageSwitchListener(iLauncherPageSwitchListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "unRegisterLauncherPageSwitchListener: service is not alive");
        }
    }

    public void unRegisterMapWidgetListener(IMapWidgetChangeListener iMapWidgetChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.unRegisterMapWidgetListener(iMapWidgetChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "unRegisterMapWidgetListener: service is not alive");
        }
    }

    public void unRegisterWeatherWidgetListener(IWeatherWidgetChangeListener iWeatherWidgetChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.unRegisterWeatherWidgetListener(iWeatherWidgetChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "unRegisterWeatherWidgetListener: service is not alive");
        }
    }

    public void unRegisterWidgetListDisplayChangeListener(IWidgetListDisplayChangeListener iWidgetListDisplayChangeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.unRegisterWidgetListDisplayChangeListener(iWidgetListDisplayChangeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "unRegisterWidgetListDisplayChangeListener: service is not alive");
        }
    }
}
