package com.geely.lib.oneosapi.linkmanager;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.linkmanager.ILinkListener;
import com.geely.lib.oneosapi.linkmanager.ILinkManager;
import com.geely.lib.oneosapi.linkmanager.IModemCallStateListener;
import com.geely.lib.oneosapi.linkmanager.IMusicStateListener;
import com.geely.lib.oneosapi.linkmanager.ITryConnectCallback;

public class LinkManager implements ServiceBaseManager {
    private static final String TAG = "LinkManager";
    private final Context mContext;
    private ILinkManager mService;

    public static abstract class BaseLinkListener extends ILinkListener.Stub {
        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onConnectStatusChange(int i, int i2, int i3) {
            Log.d(LinkManager.TAG, "onConnectStatusChange connect = " + i + " brand = " + i2 + " type = " + i3);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onDisconnectRequest(int i, int i2) {
            Log.d(LinkManager.TAG, "onDisconnectRequest brand = " + i + " type = " + i2);
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onFastBackward() throws RemoteException {
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onFastForward() throws RemoteException {
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onNext() throws RemoteException {
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onPlay() throws RemoteException {
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onPrevious() throws RemoteException {
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onSourceActivated(boolean z) throws RemoteException {
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ILinkListener
        public void onStop() throws RemoteException {
        }
    }

    public static abstract class BaseTryConnectCallback extends ITryConnectCallback.Stub {
        @Override // com.geely.lib.oneosapi.linkmanager.ITryConnectCallback
        public void denied() {
            Log.d(LinkManager.TAG, "denied: ");
        }

        @Override // com.geely.lib.oneosapi.linkmanager.ITryConnectCallback
        public void permitted() {
            Log.d(LinkManager.TAG, "permitted: ");
        }
    }

    public static abstract class ModemCallStateListener extends IModemCallStateListener.Stub {
        @Override // com.geely.lib.oneosapi.linkmanager.IModemCallStateListener
        public void onModemCallStateChange(int i) throws RemoteException {
            Log.d(LinkManager.TAG, "onModemCallStateChange = " + i);
        }
    }

    public static abstract class MusicStateListener extends IMusicStateListener.Stub {
        @Override // com.geely.lib.oneosapi.linkmanager.IMusicStateListener
        public void onMusicStatusChange(String str, String str2, String str3, String str4, long j, String str5, String str6, String str7, String str8, int i, boolean z, boolean z2) throws RemoteException {
            Log.d(LinkManager.TAG, "onMusicStatusChange = " + str);
        }
    }

    public LinkManager(Context context, IBinder iBinder) {
        this.mContext = context;
        this.mService = ILinkManager.Stub.asInterface(iBinder);
    }

    public void fastBackward() {
        Log.d(TAG, "fastBackward: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.fastBackward();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void fastForward() {
        Log.d(TAG, "fastForward: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.fastForward();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public int getConnectedSessionBrand() {
        Log.i(TAG, "getConnectedSessionBrand");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                return this.mService.getConnectedSessionBrand();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return 0;
    }

    public int getConnectedSessionType() {
        Log.i(TAG, "getConnectedSessionType");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                return this.mService.getConnectedSessionType();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return 0;
    }

    public boolean isSessionConnected() {
        Log.i(TAG, "isSessionConnected");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                return this.mService.isSessionConnected();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return false;
    }

    public boolean isSourceActivated() {
        Log.d(TAG, "isSourceActivated: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                Log.d(TAG, "isSourceActivated: " + this.mService.isSourceActivated());
                return this.mService.isSourceActivated();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return false;
    }

    public void next() {
        Log.d(TAG, "next: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.next();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void play() {
        Log.d(TAG, "play: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.play();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void previous() {
        Log.d(TAG, "previous: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.previous();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void registerListener(BaseLinkListener baseLinkListener, String str) {
        Log.i(TAG, "registerListener " + str);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager == null || !iLinkManager.asBinder().isBinderAlive()) {
            Log.e(TAG, "registerListener: service null");
            return;
        }
        try {
            this.mService.registerListener(baseLinkListener, str);
        } catch (RemoteException e) {
            e.printStackTrace();
        }
    }

    public void registerModemCallStateListener(ModemCallStateListener modemCallStateListener, String str) {
        Log.i(TAG, "registerListener " + str);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager == null || !iLinkManager.asBinder().isBinderAlive()) {
            Log.e(TAG, "registerListener: service null");
            return;
        }
        try {
            this.mService.registerModemCallStateListener(modemCallStateListener, str);
        } catch (RemoteException e) {
            e.printStackTrace();
        }
    }

    public void registerMusicStateListener(MusicStateListener musicStateListener, String str) {
        Log.i(TAG, "registerListener " + str);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager == null || !iLinkManager.asBinder().isBinderAlive()) {
            Log.e(TAG, "registerListener: service null");
            return;
        }
        try {
            this.mService.registerMusicStateListener(musicStateListener, str);
        } catch (RemoteException e) {
            e.printStackTrace();
        }
    }

    public void sessionConnected(int i, int i2) {
        Log.i(TAG, "sessionConnected");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.sessionConnected(i, i2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void sessionDisconnected(int i, int i2) {
        Log.i(TAG, "sessionDisconnected");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.sessionDisconnected(i, i2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void setModemCallState(int i) {
        Log.i(TAG, "setMusicInfo");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.setModemCallState(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void setMusicInfo(String str, String str2, String str3, String str4, long j, String str5, String str6, String str7, String str8, int i, boolean z, boolean z2) {
        Log.i(TAG, "setMusicInfo");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.setMusicInfo(str, str2, str3, str4, j, str5, str6, str7, str8, i, z, z2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        if (iBinder != null) {
            this.mService = ILinkManager.Stub.asInterface(iBinder);
        }
    }

    public void stop() {
        Log.d(TAG, "stop: ");
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.stop();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void tryConnect(int i, int i2, ITryConnectCallback iTryConnectCallback) {
        Log.i(TAG, "tryConnect brand = " + i + " type = " + i2);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.tryConnect(i, i2, iTryConnectCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void unregisterListener(BaseLinkListener baseLinkListener, String str) {
        Log.i(TAG, "unregisterListener " + str);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.unregisterListener(baseLinkListener, str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void unregisterModemCallStateListener(ModemCallStateListener modemCallStateListener, String str) {
        Log.i(TAG, "unregisterListener " + str);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.unregisterModemCallStateListener(modemCallStateListener, str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void unregisterMusicStateListener(MusicStateListener musicStateListener, String str) {
        Log.i(TAG, "unregisterListener " + str);
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.unregisterMusicStateListener(musicStateListener, str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void updatePlayState(int i, int i2) {
        Log.d(TAG, "updatePlayState brand  " + (i2 == 1 ? "HiCar" : "CarLink") + " state = " + (i == 1 ? "play" : "stop"));
        ILinkManager iLinkManager = this.mService;
        if (iLinkManager != null && iLinkManager.asBinder().isBinderAlive()) {
            try {
                this.mService.updatePlayState(i, i2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }
}
