package com.geely.lib.oneosapi.mediacenter;

import android.content.Context;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Parcel;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.mediacenter.IHeartbeatPacket;
import com.geely.lib.oneosapi.mediacenter.IMediaCenter;
import com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager;
import com.geely.lib.oneosapi.mediacenter.constant.MediaCenterConstant;
import com.geely.lib.oneosapi.mediacenter.listener.ISourceStateListener;
import com.geely.lib.oneosapi.mediacenter.listener.SourceStateListener;
import com.geely.lib.oneosapi.mediacenter.manager.BtMusicManager;
import com.geely.lib.oneosapi.mediacenter.manager.CarManager;
import com.geely.lib.oneosapi.mediacenter.manager.MusicAdapterManager;
import com.geely.lib.oneosapi.mediacenter.manager.OnlineMusicManager;
import com.geely.lib.oneosapi.mediacenter.manager.RadioManager;
import com.geely.lib.oneosapi.mediacenter.manager.UsbMusicManager;
import com.geely.lib.oneosapi.mediacenter.manager.YunTingManager;
import com.geely.lib.oneosapi.mediacenter.vr.VrAdapterManager;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

public class MediaCenterManager implements ServiceBaseManager {
    private static final String TAG = "MediaCenterManager";
    private final BtMusicManager mBtMusicManager;
    private final CarManager mCarManager;
    private Context mContext;
    private final Handler mHandler;
    private final MusicAdapterManager mMusicAdapterManager;
    private final Map<MediaCenterConstant.AudioSource, BaseMusicManager> mMusicManagerMap;
    private final OnlineMusicManager mOnlineMusicManager;
    private MediaCenterManager mPsdMediaCenterManager;
    private boolean mPsdMode;
    private final SourceStateListenerImpl mPsdSourceStateListenerImpl = new SourceStateListenerImpl(true);
    private final RadioManager mRadioManager;
    private IMediaCenter mService;
    private final SourceStateListenerImpl mSourceStateListenerImpl = new SourceStateListenerImpl(this);
    private final CopyOnWriteArrayList<SourceStateListener> mSourceStateListeners = new CopyOnWriteArrayList<>();
    private final UsbMusicManager mUsbMusicManager;
    private final VrAdapterManager mVrAdapterManager;
    private final YunTingManager mYunTingManager;

    public class SourceStateListenerImpl extends ISourceStateListener.Stub {
        private final boolean isPsdCallback;

        public SourceStateListenerImpl(MediaCenterManager mediaCenterManager) {
            this(false);
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.ISourceStateListener
        public void onPsdBtStateChanged(final boolean z) throws RemoteException {
            if (this.isPsdCallback == MediaCenterManager.this.isPsdMode()) {
                MediaCenterManager.this.mHandler.post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.MediaCenterManager.SourceStateListenerImpl.AnonymousClass2 */

                    public void run() {
                        Iterator it = MediaCenterManager.this.mSourceStateListeners.iterator();
                        while (it.hasNext()) {
                            ((SourceStateListener) it.next()).onPsdBtStateChanged(z);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.ISourceStateListener
        public void onSourceChanged(final int i, final int i2) throws RemoteException {
            if (this.isPsdCallback == MediaCenterManager.this.isPsdMode()) {
                MediaCenterManager.this.mHandler.post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.MediaCenterManager.SourceStateListenerImpl.AnonymousClass1 */

                    public void run() {
                        Iterator it = MediaCenterManager.this.mSourceStateListeners.iterator();
                        while (it.hasNext()) {
                            ((SourceStateListener) it.next()).onSourceChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2));
                        }
                    }
                });
            }
        }

        @Override // android.os.Binder, com.geely.lib.oneosapi.mediacenter.listener.ISourceStateListener.Stub
        public boolean onTransact(int i, Parcel parcel, Parcel parcel2, int i2) throws RemoteException {
            try {
                return super.onTransact(i, parcel, parcel2, i2);
            } catch (RuntimeException e) {
                Log.e(MediaCenterManager.TAG, "onTransact: ", e);
                return false;
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.ISourceStateListener
        public void onWeCarFlowTabChanged(final int i, final int i2) throws RemoteException {
            if (this.isPsdCallback == MediaCenterManager.this.isPsdMode()) {
                MediaCenterManager.this.mHandler.post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.MediaCenterManager.SourceStateListenerImpl.AnonymousClass3 */

                    public void run() {
                        Iterator it = MediaCenterManager.this.mSourceStateListeners.iterator();
                        while (it.hasNext()) {
                            ((SourceStateListener) it.next()).onWeCarFlowTabChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2));
                        }
                    }
                });
            }
        }

        public SourceStateListenerImpl(boolean z) {
            this.isPsdCallback = z;
        }
    }

    public MediaCenterManager(Context context, IBinder iBinder) {
        Map<MediaCenterConstant.AudioSource, BaseMusicManager> synchronizedMap = Collections.synchronizedMap(new HashMap());
        this.mMusicManagerMap = synchronizedMap;
        this.mHandler = new Handler(Looper.getMainLooper());
        this.mContext = context;
        BtMusicManager btMusicManager = new BtMusicManager(context, null, this);
        this.mBtMusicManager = btMusicManager;
        synchronizedMap.put(MediaCenterConstant.AudioSource.AUDIO_SOURCE_BT, btMusicManager);
        UsbMusicManager usbMusicManager = new UsbMusicManager(this.mContext, null, this);
        this.mUsbMusicManager = usbMusicManager;
        synchronizedMap.put(MediaCenterConstant.AudioSource.AUDIO_SOURCE_USB, usbMusicManager);
        OnlineMusicManager onlineMusicManager = new OnlineMusicManager(this.mContext, null, this);
        this.mOnlineMusicManager = onlineMusicManager;
        synchronizedMap.put(MediaCenterConstant.AudioSource.AUDIO_SOURCE_ONLINE, onlineMusicManager);
        YunTingManager yunTingManager = new YunTingManager(this.mContext, null, this);
        this.mYunTingManager = yunTingManager;
        synchronizedMap.put(MediaCenterConstant.AudioSource.AUDIO_SOURCE_YUNTING, yunTingManager);
        this.mRadioManager = new RadioManager(this.mContext, null, this);
        this.mCarManager = new CarManager(this.mContext, null, this);
        initMediaCenterManger(iBinder);
        this.mVrAdapterManager = new VrAdapterManager(context, this);
        this.mMusicAdapterManager = new MusicAdapterManager(context, this);
    }

    private void initCarManager() {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                this.mCarManager.setService(iMediaCenter.getCarManager());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    private void initMediaCenterManger(IBinder iBinder) {
        if (iBinder != null) {
            this.mService = IMediaCenter.Stub.asInterface(iBinder);
            initMusicManager();
            initRadioManager();
            initCarManager();
            try {
                this.mService.addSourceStateListener(this.mSourceStateListenerImpl);
                this.mService.addPsdSourceStateListener(this.mPsdSourceStateListenerImpl);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            notifyMediaCenterDied();
        }
    }

    private void initMusicManager() {
        Log.d(TAG, "initMusicManager() called " + this.mService);
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                IMusicManager musicManager = iMediaCenter.getMusicManager();
                this.mOnlineMusicManager.setService(musicManager);
                this.mUsbMusicManager.setService(musicManager);
                this.mBtMusicManager.setService(musicManager);
                this.mYunTingManager.setService(musicManager);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    private void initRadioManager() {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                this.mRadioManager.setService(iMediaCenter.getRadioManager());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    private void notifyMediaCenterDied() {
        this.mService = null;
        BtMusicManager btMusicManager = this.mBtMusicManager;
        if (btMusicManager != null) {
            btMusicManager.setService(null);
        }
        UsbMusicManager usbMusicManager = this.mUsbMusicManager;
        if (usbMusicManager != null) {
            usbMusicManager.setService(null);
        }
        OnlineMusicManager onlineMusicManager = this.mOnlineMusicManager;
        if (onlineMusicManager != null) {
            onlineMusicManager.setService(null);
        }
        RadioManager radioManager = this.mRadioManager;
        if (radioManager != null) {
            radioManager.setService(null);
        }
    }

    public void addSourceStateListener(SourceStateListener sourceStateListener) {
        if (sourceStateListener != null && !this.mSourceStateListeners.contains(sourceStateListener)) {
            this.mSourceStateListeners.add(sourceStateListener);
        }
    }

    public String getAppPackageName(MediaCenterConstant.AudioSource audioSource, MediaCenterConstant.AppSource appSource) {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter == null) {
            return null;
        }
        try {
            return iMediaCenter.getAppPackageName(audioSource.ordinal(), appSource.ordinal());
        } catch (RemoteException e) {
            e.printStackTrace();
            return null;
        }
    }

    public BtMusicManager getBtMusicManager() {
        return this.mBtMusicManager;
    }

    public CarManager getCarManager() {
        return this.mCarManager;
    }

    public MediaCenterConstant.AppSource getCurrentAppSource() {
        int i;
        if (this.mService != null) {
            try {
                if (isPsdMode()) {
                    i = this.mService.getCurrentPsdAppSource();
                } else {
                    i = this.mService.getCurrentAppSource();
                }
                return MediaCenterConstant.getAppSourceEnum(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return MediaCenterConstant.AppSource.UNKNOWN;
    }

    public MediaCenterConstant.AudioSource getCurrentAudioSource() {
        int i;
        if (this.mService != null) {
            try {
                if (isPsdMode()) {
                    i = this.mService.getCurrentPsdAudioSource();
                } else {
                    i = this.mService.getCurrentAudioSource();
                }
                return MediaCenterConstant.getAudioSourceEnum(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return MediaCenterConstant.AudioSource.AUDIO_SOURCE_UNKNOWN;
    }

    public MediaCenterConstant.AppSource getFocusedAppSource() {
        int i;
        if (this.mService != null) {
            try {
                if (isPsdMode()) {
                    i = this.mService.getPsdFocusedAppSource();
                } else {
                    i = this.mService.getFocusedAppSource();
                }
                return MediaCenterConstant.getAppSourceEnum(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return MediaCenterConstant.AppSource.UNKNOWN;
    }

    public MediaCenterConstant.AudioSource getFocusedAudioSource() {
        int i;
        if (this.mService != null) {
            try {
                if (isPsdMode()) {
                    i = this.mService.getPsdFocusedAudioSource();
                } else {
                    i = this.mService.getFocusedAudioSource();
                }
                return MediaCenterConstant.getAudioSourceEnum(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return MediaCenterConstant.AudioSource.AUDIO_SOURCE_UNKNOWN;
    }

    public MusicAdapterManager getMusicAdapterManager() {
        return this.mMusicAdapterManager;
    }

    public Map<MediaCenterConstant.AudioSource, BaseMusicManager> getMusicManagerMap() {
        return this.mMusicManagerMap;
    }

    public OnlineMusicManager getOnlineMusicManager() {
        return this.mOnlineMusicManager;
    }

    public MediaCenterManager getPsdMediaCenter() {
        if (this.mPsdMediaCenterManager == null) {
            this.mPsdMediaCenterManager = new MediaCenterManager(this.mContext, this.mService.asBinder());
        }
        this.mPsdMediaCenterManager.setPsdMode(true);
        return this.mPsdMediaCenterManager;
    }

    public RadioManager getRadioManager() {
        return this.mRadioManager;
    }

    public UsbMusicManager getUsbMusicManager() {
        return this.mUsbMusicManager;
    }

    public VrAdapterManager getVrAdapterManager() {
        return this.mVrAdapterManager;
    }

    public YunTingManager getYunTingManager() {
        return this.mYunTingManager;
    }

    public boolean isAlive() {
        IMediaCenter iMediaCenter = this.mService;
        return iMediaCenter != null && iMediaCenter.asBinder().isBinderAlive();
    }

    public boolean isPsdBtAudioSource(MediaCenterConstant.AudioSource audioSource, MediaCenterConstant.AppSource appSource) {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter == null) {
            return false;
        }
        try {
            return iMediaCenter.isPsdBtAudioSource(audioSource.ordinal(), appSource.ordinal());
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean isPsdBtDeviceConnected() {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter == null) {
            return false;
        }
        try {
            return iMediaCenter.isPsdBtDeviceConnected();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean isPsdMode() {
        return this.mPsdMode;
    }

    public void removeSourceStateListener(SourceStateListener sourceStateListener) {
        if (sourceStateListener != null) {
            this.mSourceStateListeners.remove(sourceStateListener);
        }
    }

    public void requestAudioSource(MediaCenterConstant.AudioSource audioSource, MediaCenterConstant.AppSource appSource) {
        Log.d(TAG, "requestAudioSource() called with: source = [" + audioSource + "], app = [" + appSource + "] by " + this.mContext.getPackageName());
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                iMediaCenter.requestAudioSource(audioSource.ordinal(), appSource.ordinal());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(TAG, "requestMediaSource: mService is null");
        }
    }

    public void runHeartbeatPacket() {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                iMediaCenter.setHeartbeatPacket(new IHeartbeatPacket.Stub() {
                    /* class com.geely.lib.oneosapi.mediacenter.MediaCenterManager.AnonymousClass1 */

                    @Override // com.geely.lib.oneosapi.mediacenter.IHeartbeatPacket
                    public String getPackageName() throws RemoteException {
                        return MediaCenterManager.this.mContext.getPackageName();
                    }
                });
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void setPsdBtAudioSource(MediaCenterConstant.AudioSource audioSource, MediaCenterConstant.AppSource appSource, boolean z) {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                iMediaCenter.setPsdBtAudioSource(audioSource.ordinal(), appSource.ordinal(), z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void setPsdBtChannel(MediaCenterConstant.AppSource appSource, boolean z) {
        IMediaCenter iMediaCenter = this.mService;
        if (iMediaCenter != null) {
            try {
                iMediaCenter.setPsdBtChannel(appSource.ordinal(), z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void setPsdMode(boolean z) {
        this.mPsdMode = z;
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        MediaCenterManager mediaCenterManager = this.mPsdMediaCenterManager;
        if (mediaCenterManager != null) {
            mediaCenterManager.setService(iBinder);
        }
        initMediaCenterManger(iBinder);
    }

    public boolean isPsdBtAudioSource(MediaCenterConstant.AudioSource audioSource) {
        return isPsdBtAudioSource(audioSource, MediaCenterConstant.AppSource.UNKNOWN);
    }

    public void setPsdBtAudioSource(MediaCenterConstant.AudioSource audioSource, boolean z) {
        setPsdBtAudioSource(audioSource, MediaCenterConstant.AppSource.UNKNOWN, z);
    }

    public void requestAudioSource(MediaCenterConstant.AudioSource audioSource) {
        requestAudioSource(audioSource, MediaCenterConstant.AppSource.UNKNOWN);
    }
}
