package com.geely.lib.oneosapi.mediacenter.base;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.RemoteException;
import android.os.ResultReceiver;
import android.util.Log;
import com.geely.lib.oneosapi.mediacenter.IMusicManager;
import com.geely.lib.oneosapi.mediacenter.MediaCenterManager;
import com.geely.lib.oneosapi.mediacenter.bean.DeviceInfo;
import com.geely.lib.oneosapi.mediacenter.bean.MediaData;
import com.geely.lib.oneosapi.mediacenter.bean.MusicFileData;
import com.geely.lib.oneosapi.mediacenter.bean.OnlineUserInfo;
import com.geely.lib.oneosapi.mediacenter.bean.SearchResult;
import com.geely.lib.oneosapi.mediacenter.callback.IMusicListCallback;
import com.geely.lib.oneosapi.mediacenter.callback.MusicListCallback;
import com.geely.lib.oneosapi.mediacenter.constant.MediaCenterConstant;
import com.geely.lib.oneosapi.mediacenter.listener.DeviceStateListener;
import com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener;
import com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener;
import com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener;
import com.geely.lib.oneosapi.mediacenter.listener.MediaStateListener;
import com.geely.lib.oneosapi.mediacenter.listener.MusicStateListener;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

public abstract class BaseMusicManager {
    public Context mContext;
    private final DeviceStateListenerImpl mDeviceStateListenerImpl = new DeviceStateListenerImpl();
    public final CopyOnWriteArrayList<DeviceStateListener> mDeviceStateListeners = new CopyOnWriteArrayList<>();
    private final Handler mHandler = new Handler(Looper.getMainLooper());
    public final MediaCenterManager mMediaCenterManager;
    private final MediaStateListenerImpl mMediaStateListenerImpl = new MediaStateListenerImpl(this);
    public final CopyOnWriteArrayList<MediaStateListener> mMediaStateListeners = new CopyOnWriteArrayList<>();
    private final MusicStateListenerImpl mMusicStateListenerImpl = new MusicStateListenerImpl(this);
    public final CopyOnWriteArrayList<MusicStateListener> mMusicStateListeners = new CopyOnWriteArrayList<>();
    private final MediaStateListenerImpl mPsdMediaStateListenerImpl = new MediaStateListenerImpl(true);
    private final MusicStateListenerImpl mPsdMusicStateListenerImpl = new MusicStateListenerImpl(true);
    public IMusicManager mService;
    private final String mTag = getClass().getSimpleName();

    public class DeviceStateListenerImpl extends IDeviceStateListener.Stub {
        public DeviceStateListenerImpl() {
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onAppDied(final int i) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass8 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onAppDied(MediaCenterConstant.getAppSourceEnum(i));
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onAppExistStateChanged(final int i, final int i2, final boolean z) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass7 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onAppExistStateChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), z);
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onBluetoothDeviceChange(final int i, final List<DeviceInfo> list) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass6 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onBluetoothDeviceChange(MediaCenterConstant.getAudioSourceEnum(i), list);
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onDeviceError(final int i, final int i2, final String str) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass2 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onDeviceError(MediaCenterConstant.getAudioSourceEnum(i), i2, str);
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onDeviceStateChanged(final int i, final int i2, final DeviceInfo deviceInfo) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass1 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onDeviceStateChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getDeviceStateEnum(i2), deviceInfo);
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onScanPathFinish(final int i, final List<MusicFileData> list) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass3 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onScanPathFinish(MediaCenterConstant.getAudioSourceEnum(i), list);
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onSearchSongResult(final int i, final int i2, final List<SearchResult> list) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass5 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onSearchSongResult(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), list);
                    }
                }
            });
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IDeviceStateListener
        public void onUserInfoResult(final int i, final int i2, final OnlineUserInfo onlineUserInfo) throws RemoteException {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.DeviceStateListenerImpl.AnonymousClass4 */

                public void run() {
                    Iterator<DeviceStateListener> it = BaseMusicManager.this.mDeviceStateListeners.iterator();
                    while (it.hasNext()) {
                        it.next().onUserInfoResult(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), onlineUserInfo);
                    }
                }
            });
        }
    }

    public class MediaStateListenerImpl extends IMediaStateListener.Stub {
        private final boolean isPsdCallback;

        public MediaStateListenerImpl(BaseMusicManager baseMusicManager) {
            this(false);
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onFavorStateChanged(final int i, final int i2, final MediaData mediaData) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass5 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onFavorStateChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), mediaData);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onLrcLoad(final int i, final int i2, final String str, final long j) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass6 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onLrcLoad(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), str, j);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onMediaDataChanged(final int i, final int i2, final MediaData mediaData) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass1 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onMediaDataChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), mediaData);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onPlayListChanged(final int i, final int i2, final List<MediaData> list) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass4 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayListChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), list);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onPlayModeChange(final int i, final int i2, final int i3) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                BaseMusicManager.this.mHandler.post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass7 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayModeChange(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), MediaCenterConstant.getPlayModeEnum(i3));
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onPlayPositionChanged(final int i, final int i2, final long j, final long j2) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass2 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayPositionChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), j, j2);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMediaStateListener
        public void onPlayStateChanged(final int i, final int i2, final int i3) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MediaStateListenerImpl.AnonymousClass3 */

                    public void run() {
                        Iterator<MediaStateListener> it = BaseMusicManager.this.mMediaStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayStateChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getAppSourceEnum(i2), MediaCenterConstant.getPlayStateEnum(i3));
                        }
                    }
                });
            }
        }

        public MediaStateListenerImpl(boolean z) {
            this.isPsdCallback = z;
        }
    }

    @Deprecated
    public class MusicStateListenerImpl extends IMusicStateListener.Stub {
        private final boolean isPsdCallback;

        public MusicStateListenerImpl(BaseMusicManager baseMusicManager) {
            this(false);
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onFavorStateChanged(final int i, final MediaData mediaData) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass5 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onFavorStateChanged(MediaCenterConstant.getAudioSourceEnum(i), mediaData);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onLrcLoad(final int i, final String str, final long j) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass6 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onLrcLoad(MediaCenterConstant.getAudioSourceEnum(i), str, j);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onMediaDataChanged(final int i, final MediaData mediaData) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass1 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onMediaDataChanged(MediaCenterConstant.getAudioSourceEnum(i), mediaData);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onPlayListChanged(final int i, final List<MediaData> list) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass4 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayListChanged(MediaCenterConstant.getAudioSourceEnum(i), list);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onPlayModeChange(final int i, final int i2) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                BaseMusicManager.this.mHandler.post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass7 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayModeChange(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getPlayModeEnum(i2));
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onPlayPositionChanged(final int i, final long j, final long j2) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass2 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayPositionChanged(MediaCenterConstant.getAudioSourceEnum(i), j, j2);
                        }
                    }
                });
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IMusicStateListener
        public void onPlayStateChanged(final int i, final int i2) throws RemoteException {
            if (this.isPsdCallback == BaseMusicManager.this.mMediaCenterManager.isPsdMode()) {
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager.MusicStateListenerImpl.AnonymousClass3 */

                    public void run() {
                        Iterator<MusicStateListener> it = BaseMusicManager.this.mMusicStateListeners.iterator();
                        while (it.hasNext()) {
                            it.next().onPlayStateChanged(MediaCenterConstant.getAudioSourceEnum(i), MediaCenterConstant.getPlayStateEnum(i2));
                        }
                    }
                });
            }
        }

        public MusicStateListenerImpl(boolean z) {
            this.isPsdCallback = z;
        }
    }

    public BaseMusicManager(Context context, IMusicManager iMusicManager, MediaCenterManager mediaCenterManager) {
        this.mContext = context;
        initService(iMusicManager);
        this.mMediaCenterManager = mediaCenterManager;
    }

    public void addDeviceStateListener(DeviceStateListener deviceStateListener) {
        if (deviceStateListener != null && !this.mDeviceStateListeners.contains(deviceStateListener)) {
            this.mDeviceStateListeners.add(deviceStateListener);
        }
    }

    public void addFavor(MediaData mediaData) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.addFavor(getAudioSource(), mediaData);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "addFavor: mService is null");
        }
    }

    public void addMediaStateListener(MediaStateListener mediaStateListener) {
        if (mediaStateListener != null && !this.mMediaStateListeners.contains(mediaStateListener)) {
            this.mMediaStateListeners.add(mediaStateListener);
        }
    }

    @Deprecated
    public void addMusicStateListener(MusicStateListener musicStateListener) {
        if (musicStateListener != null && !this.mMusicStateListeners.contains(musicStateListener)) {
            this.mMusicStateListeners.add(musicStateListener);
        }
    }

    public void cancelFavor(MediaData mediaData) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.cancelFavor(getAudioSource(), mediaData);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "cancelFavor: mService is null");
        }
    }

    public void fastForward(long j) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.fastForward(getAudioSource(), j);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "fastForward: mService is null");
        }
    }

    public void fastRewind(long j) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.fastRewind(getAudioSource(), j);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "fastRewind: mService is null");
        }
    }

    public abstract int getAudioSource();

    public MediaCenterConstant.AppSource getCurrentAppSource() {
        return this.mMediaCenterManager.getCurrentAppSource();
    }

    public MediaCenterConstant.AudioSource getCurrentAudioSource() {
        return this.mMediaCenterManager.getCurrentAudioSource();
    }

    public Bundle getCurrentMediaBundle(MediaCenterConstant.AppSource appSource, String str, Bundle bundle, ResultReceiver resultReceiver) {
        if (appSource == null) {
            appSource = MediaCenterConstant.AppSource.UNKNOWN;
        }
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return iMusicManager.getCurrentMediaBundle(getAudioSource(), appSource.ordinal(), str, bundle, resultReceiver);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "getCurrentMediaBundle: mService is null");
            return Bundle.EMPTY;
        }
    }

    public MediaData getCurrentMediaData() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return iMusicManager.getCurrentMediaData(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
                return null;
            }
        } else {
            Log.w(this.mTag, "getCurrentMediaData: mService is null");
            return null;
        }
    }

    public MediaCenterConstant.PlayState getCurrentPlayState() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return MediaCenterConstant.getPlayStateEnum(iMusicManager.getCurrentPlayState(getAudioSource()));
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "getCurrentPlayState: mService is null");
            return MediaCenterConstant.PlayState.MUSIC_STATE_STOP;
        }
    }

    public long getCurrentPosition() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return iMusicManager.getCurrentPosition(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
                return 0;
            }
        } else {
            Log.w(this.mTag, "getCurrentPosition: mService is null");
            return 0;
        }
    }

    public List<DeviceInfo> getDevicesInfo() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return iMusicManager.getDevicesInfo(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
                return null;
            }
        } else {
            Log.w(this.mTag, "getDevicesInfo: mService is null");
            return null;
        }
    }

    public List<MediaData> getFavorList() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return iMusicManager.getFavorList(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
                return null;
            }
        } else {
            Log.w(this.mTag, "getFavorList: mService is null");
            return null;
        }
    }

    @Deprecated
    public List<MediaData> getPlayList() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return iMusicManager.getPlayList(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
                return null;
            }
        } else {
            Log.w(this.mTag, "getPlayList: mService is null");
            return null;
        }
    }

    public void getPlayListAsync(MusicListCallback musicListCallback) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.getPlayListAsync(getAudioSource(), (IMusicListCallback) musicListCallback.getCallbackImpl());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "getPlayListAsync: mService is null");
        }
    }

    public MediaCenterConstant.PlayMode getPlayMode() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                return MediaCenterConstant.getPlayModeEnum(iMusicManager.getPlayMode(getAudioSource()));
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "getPlayMode: mService is null");
            return MediaCenterConstant.PlayMode.PLAY_MODE_QUEUE;
        }
    }

    public void initService(IMusicManager iMusicManager) {
        this.mService = iMusicManager;
        if (iMusicManager != null) {
            try {
                iMusicManager.addDeviceStateListener(getAudioSource(), this.mDeviceStateListenerImpl);
                this.mService.addMusicStateListener(getAudioSource(), this.mMusicStateListenerImpl);
                this.mService.addPsdMusicStateListener(getAudioSource(), this.mPsdMusicStateListenerImpl);
                this.mService.addMediaStateListener(getAudioSource(), this.mMediaStateListenerImpl);
                this.mService.addPsdMediaStateListener(getAudioSource(), this.mPsdMediaStateListenerImpl);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public boolean isAlive() {
        IMusicManager iMusicManager = this.mService;
        return iMusicManager != null && iMusicManager.asBinder().isBinderAlive();
    }

    public void next() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.next(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "next: mService is null");
        }
    }

    public void pause() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.pause(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "pause: mService is null");
        }
    }

    public void play() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.play(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "play: mService is null");
        }
    }

    public void playItem(MediaData mediaData) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.playItem(getAudioSource(), mediaData);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "playItem: mService is null");
        }
    }

    @Deprecated
    public void pre() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.prev(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "prev: mService is null");
        }
    }

    public void prev() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.prev(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "prev: mService is null");
        }
    }

    public void removeDeviceStateListener(DeviceStateListener deviceStateListener) {
        if (deviceStateListener != null) {
            this.mDeviceStateListeners.remove(deviceStateListener);
        }
    }

    public void removeMediaStateListener(MediaStateListener mediaStateListener) {
        if (mediaStateListener != null) {
            this.mMediaStateListeners.remove(mediaStateListener);
        }
    }

    @Deprecated
    public void removeMusicStateListener(MusicStateListener musicStateListener) {
        if (musicStateListener != null) {
            this.mMusicStateListeners.remove(musicStateListener);
        }
    }

    public void seekTo(long j) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.seekTo(getAudioSource(), j);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "seekTo: mService is null");
        }
    }

    public void sendCommand(String str, Bundle bundle, ResultReceiver resultReceiver) {
        sendCommand(MediaCenterConstant.AppSource.UNKNOWN, str, bundle, resultReceiver);
    }

    public void setPlayMode(MediaCenterConstant.PlayMode playMode) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.setPlayMode(getAudioSource(), playMode.ordinal());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "setPlayMode: mService is null");
        }
    }

    public void setService(IMusicManager iMusicManager) {
        initService(iMusicManager);
    }

    public void startApp() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.startApp(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "startApp: mService is null");
        }
    }

    public void sendCommand(MediaCenterConstant.AppSource appSource, String str, Bundle bundle, ResultReceiver resultReceiver) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.sendCommand(getAudioSource(), appSource.ordinal(), str, bundle, resultReceiver);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.w(this.mTag, "sendCommand: mService is null");
        }
    }

    public Bundle getCurrentMediaBundle(String str, Bundle bundle, ResultReceiver resultReceiver) {
        return getCurrentMediaBundle(MediaCenterConstant.AppSource.UNKNOWN, str, bundle, resultReceiver);
    }

    public Bundle getCurrentMediaBundle(String str, ResultReceiver resultReceiver) {
        return getCurrentMediaBundle(MediaCenterConstant.AppSource.UNKNOWN, str, null, resultReceiver);
    }
}
