package com.geely.lib.oneosapi.mediacenter.base;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.os.Parcel;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.mediacenter.IRadioManager;
import com.geely.lib.oneosapi.mediacenter.MediaCenterManager;
import com.geely.lib.oneosapi.mediacenter.bean.Frequency;
import com.geely.lib.oneosapi.mediacenter.constant.MediaCenterConstant;
import com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener;
import java.util.ArrayList;
import java.util.List;

public abstract class BaseRadioManager {
    private final Context mContext;
    private Handler mHandler = new Handler(Looper.getMainLooper());
    public final MediaCenterManager mMediaCenterManager;
    public final RadioStateListenerImpl mPsdRadioStateListenerImpl = new RadioStateListenerImpl(true);
    public final RadioStateListenerImpl mRadioStateListenerImpl = new RadioStateListenerImpl(this);
    public final List<IRadioStateListener> mRadioStateListeners = new ArrayList();
    private IRadioManager mService;

    public class RadioStateListenerImpl extends IRadioStateListener.Stub {
        private final boolean isPsdCallback;

        public RadioStateListenerImpl(BaseRadioManager baseRadioManager) {
            this(false);
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCarouselPlayStart(boolean z) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCarouselPlayStart(z);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCarouserPlayStop(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCarouserPlayStop(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCarouserWaiting(int i, long j) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCarouserWaiting(i, j);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCollectionStationListChanged(List<Frequency> list) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCollectionStationListChanged(list);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCollectionStationListReachesMax() throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCollectionStationListReachesMax();
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCurrentBand(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCurrentBand(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onCurrentFrequency(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onCurrentFrequency(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onOpenRadioResult(boolean z) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onOpenRadioResult(z);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onRadioClosed(boolean z) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onRadioClosed(z);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onRadioError(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onRadioError(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onRadioMuteState(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onRadioMuteState(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onRadioNameListChanged(List<Frequency> list) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onRadioNameListChanged(list);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onRadioStatusChanged(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onRadioStatusChanged(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onScanStarted(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onScanStarted(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onScanStationListChanged(List<Frequency> list) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onScanStationListChanged(list);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onScanStopped(boolean z) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onScanStopped(z);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onSeekStarted(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onSeekStarted(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onSeekStopped(boolean z) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onSeekStopped(z);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onSignalQualityChanged(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onSignalQualityChanged(i);
                    }
                }
            }
        }

        @Override // com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener
        public void onStationFrequency(int i) throws RemoteException {
            if (this.isPsdCallback == BaseRadioManager.this.mMediaCenterManager.isPsdMode()) {
                synchronized (BaseRadioManager.this.mRadioStateListeners) {
                    for (IRadioStateListener iRadioStateListener : BaseRadioManager.this.mRadioStateListeners) {
                        iRadioStateListener.onStationFrequency(i);
                    }
                }
            }
        }

        @Override // android.os.Binder, com.geely.lib.oneosapi.mediacenter.listener.IRadioStateListener.Stub
        public boolean onTransact(int i, Parcel parcel, Parcel parcel2, int i2) throws RemoteException {
            try {
                return super.onTransact(i, parcel, parcel2, i2);
            } catch (RuntimeException e) {
                Log.e("BaseRadioManager", "onTransact: ", e);
                return false;
            }
        }

        public RadioStateListenerImpl(boolean z) {
            this.isPsdCallback = z;
        }
    }

    public BaseRadioManager(Context context, IRadioManager iRadioManager, MediaCenterManager mediaCenterManager) {
        this.mContext = context;
        initService(iRadioManager);
        this.mMediaCenterManager = mediaCenterManager;
    }

    public boolean addCollectionStation(int i, boolean z) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.addCollectionStation(i, z);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean closeRadio(IRadioStateListener iRadioStateListener) {
        return this.mRadioStateListeners.remove(iRadioStateListener);
    }

    public int getBand() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return 0;
        }
        try {
            return iRadioManager.getBand();
        } catch (RemoteException e) {
            e.printStackTrace();
            return 0;
        }
    }

    public List<Frequency> getCollectionStationsList() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return null;
        }
        try {
            return iRadioManager.getCollectionStationsList();
        } catch (RemoteException e) {
            e.printStackTrace();
            return null;
        }
    }

    public MediaCenterConstant.AudioSource getCurrentAudioSource() {
        return this.mMediaCenterManager.getCurrentAudioSource();
    }

    public int getFrequency() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return 0;
        }
        try {
            return iRadioManager.getFrequency();
        } catch (RemoteException e) {
            e.printStackTrace();
            return 0;
        }
    }

    public List<Frequency> getRadioStationsNameList() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return null;
        }
        try {
            return iRadioManager.getRadioStationsNameList();
        } catch (RemoteException e) {
            e.printStackTrace();
            return null;
        }
    }

    public int getRadioStatus() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return 0;
        }
        try {
            return iRadioManager.getRadioStatus();
        } catch (RemoteException e) {
            e.printStackTrace();
            return 0;
        }
    }

    public List<Frequency> getScanStationsList() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return null;
        }
        try {
            return iRadioManager.getScanStationsList();
        } catch (RemoteException e) {
            e.printStackTrace();
            return null;
        }
    }

    public void initService(IRadioManager iRadioManager) {
        this.mService = iRadioManager;
        if (iRadioManager != null) {
            try {
                iRadioManager.openRadioAsync(this.mRadioStateListenerImpl);
                this.mService.openPsdRadioAsync(this.mPsdRadioStateListenerImpl);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public boolean isAlive() {
        return this.mService != null;
    }

    public boolean isFirstUseRadio() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.isFirstUseRadio();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean openRadioAsync(IRadioStateListener iRadioStateListener) {
        return this.mRadioStateListeners.add(iRadioStateListener);
    }

    public boolean pause() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.pause();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean play() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.play();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public int playRadioFavor() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return 0;
        }
        try {
            return iRadioManager.playRadioFavor();
        } catch (RemoteException e) {
            e.printStackTrace();
            return 0;
        }
    }

    public boolean scanAsync() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.scanAsync();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean seekAsync(int i) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.seekAsync(i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean setBandAsync(int i) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.setBandAsync(i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean setFrequency(int i) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.setFrequency(i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public void setService(IRadioManager iRadioManager) {
        initService(iRadioManager);
    }

    public boolean startCarouselPlay(int i) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.startCarouselPlay(i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean stopCarouselPlay() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.stopCarouselPlay();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean stopSeekOrScanAsync() {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.stopSeekOrScanAsync();
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean toNextStation(int i) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.toNextStation(i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean tuneAsync(int i) {
        IRadioManager iRadioManager = this.mService;
        if (iRadioManager == null) {
            return false;
        }
        try {
            return iRadioManager.tuneAsync(i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }
}
