package com.geely.lib.oneosapi.mediacenter.manager;

import android.content.Context;
import android.os.Bundle;
import android.os.RemoteException;
import com.geely.lib.oneosapi.mediacenter.IMusicManager;
import com.geely.lib.oneosapi.mediacenter.MediaCenterManager;
import com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager;
import com.geely.lib.oneosapi.mediacenter.bean.MediaData;
import com.geely.lib.oneosapi.mediacenter.bean.SearchBean;
import com.geely.lib.oneosapi.mediacenter.callback.ContentCallback;
import com.geely.lib.oneosapi.mediacenter.callback.IContentCallback;
import com.geely.lib.oneosapi.mediacenter.callback.IMusicQueryCallback;
import com.geely.lib.oneosapi.mediacenter.callback.ISearchSongCallback;
import com.geely.lib.oneosapi.mediacenter.callback.IUserInfoCallback;
import com.geely.lib.oneosapi.mediacenter.callback.MusicQueryCallback;
import com.geely.lib.oneosapi.mediacenter.callback.SearchSongCallback;
import com.geely.lib.oneosapi.mediacenter.callback.UserInfoCallback;
import com.geely.lib.oneosapi.mediacenter.constant.MediaCenterConstant;
import com.geely.lib.oneosapi.mediacenter.listener.OnlineDeviceStateListener;
import com.google.gson.GsonBuilder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.function.Consumer;

public class OnlineMusicManager extends BaseMusicManager {
    public static final String CHANNEL_BOOK = "channel_book";
    public static final String CHANNEL_BROADCAST = "channel_broadcast";
    public static final String CHANNEL_MUSIC = "channel_music";
    public static final String CHANNEL_NEWS = "channel_news";
    public static final String CHANNEL_RADIO = "channel_radio";
    private final int mAudioSource = MediaCenterConstant.AudioSource.AUDIO_SOURCE_ONLINE.ordinal();

    public OnlineMusicManager(Context context, IMusicManager iMusicManager, MediaCenterManager mediaCenterManager) {
        super(context, iMusicManager, mediaCenterManager);
    }

    private List<SearchBean.Text> getValueList(List<String> list) {
        ArrayList arrayList = new ArrayList();
        for (String str : list) {
            SearchBean.Text text = new SearchBean.Text();
            text.text = str;
            arrayList.add(text);
        }
        return arrayList;
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public void addFavor(MediaData mediaData) {
        addFavor(mediaData, MediaCenterConstant.AppSource.UNKNOWN);
    }

    public void addOnlineDeviceStateListener(OnlineDeviceStateListener onlineDeviceStateListener) {
        addDeviceStateListener(onlineDeviceStateListener);
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public void cancelFavor(MediaData mediaData) {
        cancelFavor(mediaData, MediaCenterConstant.AppSource.UNKNOWN);
    }

    public void closeFavor() {
        sendCommand(MediaCenterConstant.Command.CLOSE_FAVOR, null, null);
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public int getAudioSource() {
        return this.mAudioSource;
    }

    public void getContent(String str, ContentCallback contentCallback) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.getContent(getAudioSource(), str, (IContentCallback) contentCallback.getCallbackImpl());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public MediaData getCurrentMediaData() {
        return getCurrentMediaData(MediaCenterConstant.AppSource.UNKNOWN);
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public MediaCenterConstant.PlayState getCurrentPlayState() {
        return getCurrentPlayState(MediaCenterConstant.AppSource.UNKNOWN);
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public long getCurrentPosition() {
        return getCurrentPosition(MediaCenterConstant.AppSource.UNKNOWN);
    }

    @Deprecated
    public void getOnlineUserInfoAsync(MediaCenterConstant.AppSource appSource) {
    }

    public void getOnlineUserInfoAsync(MediaCenterConstant.AppSource appSource, UserInfoCallback userInfoCallback) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.getOnlineUserInfoAsync(getAudioSource(), appSource.ordinal(), (IUserInfoCallback) userInfoCallback.getCallbackImpl());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public List<MediaCenterConstant.AppSource> getRecentlyAppSource() {
        ArrayList arrayList = new ArrayList();
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                List<String> recentlyAppSource = iMusicManager.getRecentlyAppSource(getAudioSource());
                if (recentlyAppSource != null) {
                    recentlyAppSource.forEach(new Consumer(arrayList) {
                        /* class com.geely.lib.oneosapi.mediacenter.manager.$$Lambda$OnlineMusicManager$sDfmt7tM0GtUR_Ec0CcpSEkvO_Y */
                        public final /* synthetic */ List f$0;

                        {
                            this.f$0 = r1;
                        }

                        @Override // java.util.function.Consumer
                        public final void accept(Object obj) {
                            this.f$0.add(MediaCenterConstant.AppSource.valueOf((String) obj));
                        }
                    });
                }
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        return arrayList;
    }

    public boolean isAgreedUserProtocol() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager == null) {
            return false;
        }
        try {
            return iMusicManager.isAgreedUserProtocol(getAudioSource());
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public boolean isMusicQualitySwitch(int i) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager == null) {
            return false;
        }
        try {
            return iMusicManager.isMusicQualitySwitch(getAudioSource(), i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    public int isSupportChangeMode(MediaCenterConstant.PlayMode playMode) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager == null) {
            return 0;
        }
        try {
            return iMusicManager.isSupportChangeMode(getAudioSource(), playMode.ordinal());
        } catch (RemoteException e) {
            e.printStackTrace();
            return 0;
        }
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public void next() {
        next(MediaCenterConstant.AppSource.UNKNOWN);
    }

    public int notifyVrStatusNotifierStatus(int i) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager == null) {
            return 0;
        }
        try {
            return iMusicManager.notifyVrStatusNotifierStatus(getAudioSource(), i);
        } catch (RemoteException e) {
            e.printStackTrace();
            return 0;
        }
    }

    public int onUIWordingTriggered(String str) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager == null) {
            return -1;
        }
        try {
            return iMusicManager.onUIWordingTriggered(getAudioSource(), str);
        } catch (RemoteException e) {
            e.printStackTrace();
            return -1;
        }
    }

    public void openFavor() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.openFavor(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void openHistory() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.openHistory(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void openHistoryList(int i, boolean z) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_AUTO_PLAY, z);
        bundle.putInt(MediaCenterConstant.CommandArgsKey.CLASSIC_TYPE, i);
        sendCommand(MediaCenterConstant.Command.OPEN_HISTORY_LIST, bundle, null);
    }

    public void openLoginPage() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.openLoginPage(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void openLrcPage() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.openLrcPage(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void openPlayList() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.openPlayList(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public void pause() {
        pause(MediaCenterConstant.AppSource.UNKNOWN);
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public void play() {
        play(MediaCenterConstant.AppSource.UNKNOWN);
    }

    public void playContent(int i, String str, int i2, boolean z) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.playContent(getAudioSource(), i, str, i2, z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void playFavor() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.playFavor(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void playSearchSongByNameItem(String str, int i) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.playSearchSongByNameItem(getAudioSource(), str, i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    @Override // com.geely.lib.oneosapi.mediacenter.base.BaseMusicManager
    public void prev() {
        prev(MediaCenterConstant.AppSource.UNKNOWN);
    }

    public void replay() {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.replay(getAudioSource());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void requestAudioSource() {
        this.mMediaCenterManager.requestAudioSource(MediaCenterConstant.AudioSource.AUDIO_SOURCE_ONLINE);
    }

    public void searchMediaForVR(String str) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.searchMediaForVR(getAudioSource(), str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    @Deprecated
    public void searchSongByName(String str) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.searchSongByName(getAudioSource(), str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void searchSongByNameAsync(String str, SearchSongCallback searchSongCallback) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.searchSongByNameAsync(getAudioSource(), str, (ISearchSongCallback) searchSongCallback.getCallbackImpl());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    @Deprecated
    public void semanticSearch(String str, String str2, String str3, String str4) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.semanticSearch(getAudioSource(), str, str2, str3, str4);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void startAppTab(String str) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.startAppTab(getAudioSource(), str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    public void switchSourceQuality(int i) {
        Bundle bundle = new Bundle();
        bundle.putInt(MediaCenterConstant.CommandArgsKey.QUALITY, i);
        sendCommand(MediaCenterConstant.Command.SWITCH_SOURCE_QUALITY, bundle, null);
    }

    public void addFavor(MediaData mediaData, MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        sendCommand(MediaCenterConstant.Command.ADD_FAVOR, bundle, null);
    }

    public void cancelFavor(MediaData mediaData, MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        sendCommand(MediaCenterConstant.Command.CANCEL_FAVOR, bundle, null);
    }

    public MediaData getCurrentMediaData(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        Bundle currentMediaBundle = getCurrentMediaBundle(MediaCenterConstant.MediaBoundKey.MEDIA_DATA, bundle, null);
        currentMediaBundle.setClassLoader(MediaData.class.getClassLoader());
        return (MediaData) currentMediaBundle.getParcelable(MediaCenterConstant.MediaBoundKey.MEDIA_DATA);
    }

    public MediaCenterConstant.PlayState getCurrentPlayState(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        return MediaCenterConstant.getPlayStateEnum(getCurrentMediaBundle(MediaCenterConstant.MediaBoundKey.PLAY_STATE, bundle, null).getInt(MediaCenterConstant.MediaBoundKey.PLAY_STATE, -1));
    }

    public long getCurrentPosition(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        return getCurrentMediaBundle(MediaCenterConstant.MediaBoundKey.PLAY_POSITION, bundle, null).getLong(MediaCenterConstant.MediaBoundKey.PLAY_POSITION, 0);
    }

    public void next(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        sendCommand(MediaCenterConstant.Command.NEXT, bundle, null);
    }

    public void pause(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        sendCommand(MediaCenterConstant.Command.PAUSE, bundle, null);
    }

    public void play(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        sendCommand("play", bundle, null);
    }

    public void prev(MediaCenterConstant.AppSource appSource) {
        Bundle bundle = new Bundle();
        bundle.putBoolean(MediaCenterConstant.CommandArgsKey.IS_PSD_MODE, this.mMediaCenterManager.isPsdMode());
        bundle.putInt(MediaCenterConstant.CommandArgsKey.APP_SOURCE, appSource.ordinal());
        sendCommand(MediaCenterConstant.Command.PREV, bundle, null);
    }

    public void requestAudioSource(MediaCenterConstant.AppSource appSource) {
        this.mMediaCenterManager.requestAudioSource(MediaCenterConstant.AudioSource.AUDIO_SOURCE_ONLINE, appSource);
    }

    @Deprecated
    public void semanticSearch(String str, HashMap<String, List<String>> hashMap, MusicQueryCallback musicQueryCallback) {
        if (this.mService != null) {
            SearchBean searchBean = new SearchBean();
            searchBean.semantic.domain = str;
            if (str.equals("fm")) {
                searchBean.semantic.query = SearchBean.QUERY_VALUE_FM;
            } else {
                searchBean.semantic.query = SearchBean.QUERY_VALUE_MUSIC;
            }
            if (!hashMap.isEmpty()) {
                ArrayList arrayList = new ArrayList();
                for (String str2 : hashMap.keySet()) {
                    List<String> list = hashMap.get(str2);
                    if (list != null && !list.isEmpty()) {
                        SearchBean.Slot slot = new SearchBean.Slot();
                        slot.type = str2;
                        slot.values = getValueList(list);
                        arrayList.add(slot);
                    }
                }
                searchBean.semantic.slots = arrayList;
            }
            String str3 = null;
            try {
                str3 = new GsonBuilder().disableHtmlEscaping().create().toJson(searchBean, SearchBean.class);
            } catch (Exception e) {
                e.printStackTrace();
            }
            try {
                this.mService.semanticSearchAsync(getAudioSource(), str3, (IMusicQueryCallback) musicQueryCallback.getCallbackImpl());
            } catch (RemoteException e2) {
                e2.printStackTrace();
            }
        }
    }

    public void semanticSearch(String str, List<String> list, String str2, boolean z, boolean z2, String str3, MusicQueryCallback musicQueryCallback) {
        IMusicManager iMusicManager = this.mService;
        if (iMusicManager != null) {
            try {
                iMusicManager.semanticSearchAndPlay(getAudioSource(), str, list, str2, z, z2, str3, (IMusicQueryCallback) musicQueryCallback.getCallbackImpl());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }
}
