package com.geely.lib.oneosapi.navi;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import android.os.RemoteException;
import android.util.Log;
import android.view.MotionEvent;
import android.view.Surface;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.navi.INaviEventNotify;
import com.geely.lib.oneosapi.navi.INaviObserver;
import com.geely.lib.oneosapi.navi.IServerCallback;
import com.geely.lib.oneosapi.navi.IServiceBinder;
import com.geely.lib.oneosapi.navi.entitys.MapStatusTypes;
import com.geely.lib.oneosapi.navi.ipc.TransferModel;
import com.geely.lib.oneosapi.navi.model.base.NaviBaseModel;
import com.geely.lib.oneosapi.navi.model.base.NaviErrorModel;
import com.geely.lib.oneosapi.navi.model.base.NaviProtocolID;
import com.geely.lib.oneosapi.navi.model.base.NaviResultCode;
import com.geely.lib.oneosapi.navi.model.base.PoiInfo;
import com.geely.lib.oneosapi.navi.model.client.NaviRoutePlan;
import com.geely.lib.oneosapi.navi.model.client.SearchByKeyword;
import com.geely.lib.oneosapi.navi.model.client.UserGetFavoritePois;
import com.geely.lib.oneosapi.navi.model.client.UserIdBindModel;
import com.geely.lib.oneosapi.navi.model.client.UserLogoutModel;
import com.geely.lib.oneosapi.navi.model.service.RspFavoritePois;
import com.geely.lib.oneosapi.navi.model.service.RspLaunchMap;
import com.geely.lib.oneosapi.navi.model.service.RspMapStatus;
import com.geely.lib.oneosapi.navi.model.service.RspPoiSearchResult;
import com.geely.lib.oneosapi.navi.utils.Contents;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

public class NaviManager extends NaviAPI implements ServiceBaseManager {
    private static final int MSG_FUN_LISTENER = 100;
    private static final int MSG_FUN_NOTIFY = 101;
    private static final int MSG_NAVI_ERROR_CALLBACK = 105;
    private static final int MSG_NAVI_INIT_RETRY = 104;
    private static final int MSG_NAVI_SUCCESS_CALLBACK = 106;
    private static final String TAG = "NaviManager";
    private int errorCode = -1;
    private IServiceBinder initService;
    private final INaviEventNotify inviEventNotify = new INaviEventNotify.Stub() {
        /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass2 */

        @Override // com.geely.lib.oneosapi.navi.INaviEventNotify
        public String getUID() throws RemoteException {
            return null;
        }

        @Override // com.geely.lib.oneosapi.navi.INaviEventNotify
        public void onNaviNotify(TransferModel transferModel) throws RemoteException {
            Message obtain = Message.obtain();
            obtain.what = 101;
            obtain.obj = transferModel;
            NaviManager.this.mHandler.sendMessage(obtain);
        }
    };
    private final ConcurrentHashMap<Integer, INaviAPICallback> mAPICallbacks = new ConcurrentHashMap<>();
    private final Context mContext;
    private SyncHandler mHandler;
    private INaviEventListener mNaviEventListener;
    private final Object mNaviLock = new Object();
    private final INaviObserver mNaviObserver = new INaviObserver.Stub() {
        /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass1 */
        private String uuid = UUID.randomUUID().toString();

        @Override // com.geely.lib.oneosapi.navi.INaviObserver
        public String getUID() throws RemoteException {
            return this.uuid;
        }

        @Override // com.geely.lib.oneosapi.navi.INaviObserver
        public void onNaviAPICallback(TransferModel transferModel) throws RemoteException {
            Message obtain = Message.obtain();
            obtain.what = 100;
            obtain.obj = transferModel;
            NaviManager.this.mHandler.sendMessage(obtain);
        }
    };
    private int mSearchNum = 0;
    private int mapVendor = 10;
    private INaviServer naviService;
    private List<PoiInfo> viaList;

    public static class SyncHandler extends Handler {
        public WeakReference<NaviManager> weakReference;

        public void handleMessage(Message message) {
            super.handleMessage(message);
            NaviManager naviManager = this.weakReference.get();
            switch (message.what) {
                case 100:
                    NaviBaseModel naviBaseModel = ((TransferModel) message.obj).getNaviBaseModel();
                    INaviAPICallback iNaviAPICallback = (INaviAPICallback) naviManager.mAPICallbacks.remove(Integer.valueOf(naviBaseModel.getCallbackId()));
                    if (iNaviAPICallback == null) {
                        naviManager.log.d(NaviManager.TAG, "mAPICallbacks not find callbackId,current result callbackId is " + naviBaseModel.getCallbackId());
                        return;
                    } else if (naviBaseModel instanceof NaviErrorModel) {
                        NaviErrorModel naviErrorModel = (NaviErrorModel) naviBaseModel;
                        iNaviAPICallback.onFail(naviErrorModel);
                        naviManager.log.d(NaviManager.TAG, "---出参：" + naviErrorModel.toString());
                        return;
                    } else {
                        iNaviAPICallback.onSuccess(naviBaseModel);
                        naviManager.log.d(NaviManager.TAG, "---出参：" + naviBaseModel.toString());
                        return;
                    }
                case 101:
                    if (naviManager.mNaviEventListener != null) {
                        naviManager.mNaviEventListener.onNaviEvent(((TransferModel) message.obj).getNaviBaseModel());
                        return;
                    }
                    return;
                case 102:
                case 103:
                default:
                    return;
                case 104:
                    naviManager.connectNaviServer(naviManager.mapVendor, false, (INaviAPICallback) message.obj);
                    return;
                case 105:
                    naviManager.errorCallback(message.arg1, (INaviAPICallback) message.obj);
                    return;
                case 106:
                    RspLaunchMap rspLaunchMap = new RspLaunchMap();
                    rspLaunchMap.setMapLaunchedType(0);
                    ((INaviAPICallback) message.obj).onSuccess(rspLaunchMap);
                    return;
            }
        }

        private SyncHandler(NaviManager naviManager, Looper looper) {
            super(looper);
            this.weakReference = new WeakReference<>(naviManager);
        }
    }

    public NaviManager(Context context, IBinder iBinder) {
        this.log.d(TAG, "NaviManager()");
        this.mContext = context;
        this.mHandler = new SyncHandler(context.getMainLooper());
        if (iBinder != null) {
            this.log.d(TAG, "NaviManager()-->binder != null");
            this.initService = IServiceBinder.Stub.asInterface(iBinder);
            connectNaviServer(this.mapVendor, false, null);
        }
    }

    public static /* synthetic */ int access$1908(NaviManager naviManager) {
        int i = naviManager.mSearchNum;
        naviManager.mSearchNum = i + 1;
        return i;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void connectNaviServer(int i, boolean z, final INaviAPICallback iNaviAPICallback) {
        synchronized (this.mNaviLock) {
            this.mapVendor = i;
            this.errorCode = -1;
            this.naviService = null;
            if (this.initService == null) {
                this.log.d(TAG, "connectNaviServer()---->initService == null");
                return;
            }
            try {
                this.log.d(TAG, this.mContext.getPackageName() + " be going to get NaviServer");
                this.initService.getNaviServer(i, z, new IServerCallback.Stub() {
                    /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass3 */

                    @Override // com.geely.lib.oneosapi.navi.IServerCallback
                    public String getKey() throws RemoteException {
                        return NaviManager.this.mContext.getPackageName();
                    }

                    @Override // com.geely.lib.oneosapi.navi.IServerCallback
                    public void initFailed(int i, String str) throws RemoteException {
                        NaviManager.this.log.d(NaviManager.TAG, "connectNaviServer---->initFailed(),errorCode=" + i + ",errorMessage=" + str + " packageName= " + getKey());
                        synchronized (NaviManager.this.mNaviLock) {
                            NaviManager.this.naviService = null;
                            if (i != 100002) {
                                if (i != 100003) {
                                    if (i == 1001) {
                                        Message obtain = Message.obtain();
                                        obtain.what = 105;
                                        obtain.arg1 = 1001;
                                        obtain.obj = iNaviAPICallback;
                                        NaviManager.this.mHandler.sendMessage(obtain);
                                    }
                                }
                            }
                            RspMapStatus rspMapStatus = new RspMapStatus(new NaviBaseModel());
                            rspMapStatus.setProtocolID(1001);
                            rspMapStatus.setMapStatus(MapStatusTypes.APP_FINISH.getCode());
                            TransferModel transferModel = new TransferModel();
                            transferModel.setNaviBaseModel(rspMapStatus);
                            Message obtain2 = Message.obtain();
                            obtain2.what = 101;
                            obtain2.obj = transferModel;
                            NaviManager.this.mHandler.sendMessage(obtain2);
                        }
                    }

                    @Override // com.geely.lib.oneosapi.navi.IServerCallback
                    public void initSuccess(INaviServer iNaviServer) throws RemoteException {
                        NaviManager.this.log.d(NaviManager.TAG, "connectNaviServer---->initSuccess() : " + getKey());
                        synchronized (NaviManager.this.mNaviLock) {
                            NaviManager.this.errorCode = 0;
                            NaviManager.this.naviService = iNaviServer;
                            NaviManager.this.registerNaviNotifyObserver();
                            NaviManager.this.mHandler.removeMessages(104);
                            if (iNaviAPICallback != null) {
                                Message obtain = Message.obtain();
                                obtain.what = 106;
                                obtain.obj = iNaviAPICallback;
                                NaviManager.this.mHandler.sendMessage(obtain);
                            }
                        }
                    }
                });
            } catch (RemoteException e) {
                e.printStackTrace();
                this.log.d(TAG, "connectNaviServer---->printStackTrace:" + this.mContext.getPackageName());
                synchronized (this.mNaviLock) {
                    this.naviService = null;
                    Message obtain = Message.obtain();
                    obtain.what = 104;
                    obtain.obj = iNaviAPICallback;
                    this.mHandler.sendMessage(obtain);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void cycleSearchKeyword(final List<String> list, final int i, final int i2, final INaviAPICallback iNaviAPICallback) {
        UserGetFavoritePois userGetFavoritePois;
        if ("HOME".equals(list.get(this.mSearchNum)) || "COMPANY".equals(list.get(this.mSearchNum))) {
            if ("HOME".equals(list.get(this.mSearchNum))) {
                userGetFavoritePois = new UserGetFavoritePois(1);
            } else {
                userGetFavoritePois = new UserGetFavoritePois(2);
            }
            getFavoritePois(userGetFavoritePois, new INaviAPICallback() {
                /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass7 */

                @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
                public void onFail(NaviErrorModel naviErrorModel) {
                    NaviManager.this.log.d(NaviManager.TAG, "multiDestNavi---getFavoritePois---onFail：" + naviErrorModel.toString());
                    NaviManager.this.mSearchNum = 0;
                    NaviManager.this.viaList = null;
                    iNaviAPICallback.onFail(naviErrorModel);
                }

                @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
                public void onSuccess(NaviBaseModel naviBaseModel) {
                    NaviManager.this.log.d(NaviManager.TAG, "multiDestNavi---getFavoritePois---onSuccess：" + naviBaseModel.toString());
                    NaviManager.access$1908(NaviManager.this);
                    if (NaviManager.this.mSearchNum != list.size()) {
                        RspFavoritePois rspFavoritePois = (RspFavoritePois) naviBaseModel;
                        PoiInfo poiInfo = new PoiInfo();
                        poiInfo.setLatLng(rspFavoritePois.getFavoritePoiInfoList().get(0).getPoiInfo().getLatLng());
                        poiInfo.setName(rspFavoritePois.getFavoritePoiInfoList().get(0).getPoiInfo().getName());
                        NaviManager.this.viaList.add(poiInfo);
                        NaviManager.this.cycleSearchKeyword(list, i, i2, iNaviAPICallback);
                        return;
                    }
                    NaviRoutePlan naviRoutePlan = new NaviRoutePlan(null, ((RspFavoritePois) naviBaseModel).getFavoritePoiInfoList().get(0).getPoiInfo());
                    naviRoutePlan.setViaPoiInfos(NaviManager.this.viaList);
                    naviRoutePlan.setStrategy(i);
                    naviRoutePlan.setAction(i2);
                    NaviManager.this.invokeAPIAsync(naviRoutePlan, iNaviAPICallback);
                    NaviManager.this.mSearchNum = 0;
                    NaviManager.this.viaList = null;
                }
            });
            return;
        }
        SearchByKeyword searchByKeyword = new SearchByKeyword(0, list.get(this.mSearchNum), "");
        searchByKeyword.setAction(0);
        searchByKeyword.setSortRule(0);
        searchByKeyword(searchByKeyword, new INaviAPICallback() {
            /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass6 */

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onFail(NaviErrorModel naviErrorModel) {
                NaviManager.this.log.d(NaviManager.TAG, "multiDestNavi---searchByKeyword---onFail：" + naviErrorModel.toString());
                NaviManager.this.mSearchNum = 0;
                NaviManager.this.viaList = null;
                iNaviAPICallback.onFail(naviErrorModel);
            }

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onSuccess(NaviBaseModel naviBaseModel) {
                NaviManager.this.log.d(NaviManager.TAG, "multiDestNavi---searchByKeyword---onSuccess：" + naviBaseModel.toString());
                NaviManager.access$1908(NaviManager.this);
                if (NaviManager.this.mSearchNum != list.size()) {
                    RspPoiSearchResult rspPoiSearchResult = (RspPoiSearchResult) naviBaseModel;
                    PoiInfo poiInfo = new PoiInfo();
                    poiInfo.setLatLng(rspPoiSearchResult.getPOIList().get(0).getLatLng());
                    poiInfo.setName(rspPoiSearchResult.getPOIList().get(0).getName());
                    NaviManager.this.viaList.add(poiInfo);
                    NaviManager.this.cycleSearchKeyword(list, i, i2, iNaviAPICallback);
                    return;
                }
                NaviRoutePlan naviRoutePlan = new NaviRoutePlan(null, ((RspPoiSearchResult) naviBaseModel).getPOIList().get(0));
                naviRoutePlan.setViaPoiInfos(NaviManager.this.viaList);
                naviRoutePlan.setStrategy(i);
                naviRoutePlan.setAction(i2);
                NaviManager.this.invokeAPIAsync(naviRoutePlan, iNaviAPICallback);
                NaviManager.this.mSearchNum = 0;
                NaviManager.this.viaList = null;
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void errorCallback(int i, INaviAPICallback iNaviAPICallback) {
        if (iNaviAPICallback != null) {
            NaviErrorModel naviErrorModel = new NaviErrorModel((NaviBaseModel) null);
            naviErrorModel.setErrorCode(i);
            naviErrorModel.setErrorString(NaviResultCode.getErrorMsg(i));
            this.log.d(TAG, "errorCallback---出参:" + naviErrorModel.toString());
            iNaviAPICallback.onFail(naviErrorModel);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int registerNaviNotifyObserver() {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer == null) {
                return -1;
            }
            try {
                if (iNaviServer.addNaviEventNotify(this.inviEventNotify)) {
                    return 0;
                }
                return -2;
            } catch (RemoteException e) {
                e.printStackTrace();
                return -2;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void removeHandlerCallbacks() {
        this.mHandler.removeCallbacksAndMessages(null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void switchMapServerForBindAMap(final UserIdBindModel userIdBindModel, final INaviAPICallback iNaviAPICallback) {
        connectNaviServer(0, false, new INaviAPICallback() {
            /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass10 */

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onFail(NaviErrorModel naviErrorModel) {
                NaviManager.this.log.d(NaviManager.TAG, "switch map failed");
            }

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onSuccess(NaviBaseModel naviBaseModel) {
                NaviManager.this.log.d(NaviManager.TAG, "switch map success");
                NaviManager.super.bindUserIdToAMap(userIdBindModel, iNaviAPICallback);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void switchMapServerForLogoutAMap(final UserLogoutModel userLogoutModel, final INaviAPICallback iNaviAPICallback) {
        connectNaviServer(0, false, new INaviAPICallback() {
            /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass11 */

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onFail(NaviErrorModel naviErrorModel) {
                NaviManager.this.log.d(NaviManager.TAG, "switch map failed");
            }

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onSuccess(NaviBaseModel naviBaseModel) {
                NaviManager.this.log.d(NaviManager.TAG, "switch map success");
                NaviManager.super.logoutUserIdToAMap(userLogoutModel, iNaviAPICallback);
            }
        });
    }

    private void unregisterNaviNotifyObserver() {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    iNaviServer.removeNaviEventNotify(this.inviEventNotify);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public boolean addSurface(Surface surface, int i, int i2, int i3) {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    return iNaviServer.addSurface(surface, i, i2, i3);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            return false;
        }
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public int bindUserIdToAMap(final UserIdBindModel userIdBindModel, final INaviAPICallback iNaviAPICallback) {
        String currectConnectMap = getCurrectConnectMap();
        if (currectConnectMap.isEmpty()) {
            return -1;
        }
        if (Contents.AMAP_PACKAGE.equals(currectConnectMap)) {
            return super.bindUserIdToAMap(userIdBindModel, iNaviAPICallback);
        }
        cancelNavi(new INaviAPICallback() {
            /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass8 */

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onFail(NaviErrorModel naviErrorModel) {
                Log.d(NaviManager.TAG, "当前不在导航:" + naviErrorModel.toString());
                NaviManager.this.switchMapServerForBindAMap(userIdBindModel, iNaviAPICallback);
            }

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onSuccess(NaviBaseModel naviBaseModel) {
                Log.d(NaviManager.TAG, "结束导航成功:" + naviBaseModel.toString());
                NaviManager.this.switchMapServerForBindAMap(userIdBindModel, iNaviAPICallback);
            }
        });
        return 0;
    }

    public void dispatchTouchEvent(MotionEvent motionEvent) {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    iNaviServer.dispatchTouchEvent(motionEvent);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public String getCurrectConnectMap() {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    return iNaviServer.getPackageName();
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            return "";
        }
    }

    public int getDefaultMap() {
        synchronized (this.mNaviLock) {
            IServiceBinder iServiceBinder = this.initService;
            if (iServiceBinder == null) {
                return -1;
            }
            try {
                int defaultMap = iServiceBinder.getDefaultMap();
                if (defaultMap == -100) {
                    return 1001;
                }
                return defaultMap;
            } catch (RemoteException e) {
                e.printStackTrace();
                return -2;
            }
        }
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public int invokeAPIAsync(NaviBaseModel naviBaseModel, INaviAPICallback iNaviAPICallback) {
        synchronized (this.mNaviLock) {
            if (this.naviService == null) {
                errorCallback(this.errorCode, iNaviAPICallback);
                connectNaviServer(this.mapVendor, false, null);
                return -1;
            }
            try {
                naviBaseModel.setPackageName(this.mContext.getPackageName());
                TransferModel transferModel = new TransferModel();
                transferModel.setNaviBaseModel(naviBaseModel);
                if (iNaviAPICallback != null) {
                    this.mAPICallbacks.put(Integer.valueOf(naviBaseModel.getCallbackId()), iNaviAPICallback);
                }
                this.log.d(TAG, "---入参:" + naviBaseModel.toString() + "mNaviObserver:" + this.mNaviObserver.toString());
                return this.naviService.invokeNaviAPIAsync(transferModel, this.mNaviObserver);
            } catch (Exception e) {
                e.printStackTrace();
                errorCallback(-2, iNaviAPICallback);
                return -2;
            }
        }
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public NaviBaseModel invokeAPISync(NaviBaseModel naviBaseModel) {
        synchronized (this.mNaviLock) {
            if (this.naviService == null) {
                return null;
            }
            try {
                naviBaseModel.setPackageName(this.mContext.getPackageName());
                TransferModel transferModel = new TransferModel();
                transferModel.setNaviBaseModel(naviBaseModel);
                this.log.d(TAG, "---入参:" + naviBaseModel.toString());
                return this.naviService.invokeNaviAPI(transferModel).getNaviBaseModel();
            } catch (Exception unused) {
                return null;
            }
        }
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public boolean isConnected() {
        boolean z;
        synchronized (this.mNaviLock) {
            z = this.naviService != null;
        }
        return z;
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public int launchMap(int i, INaviAPICallback iNaviAPICallback) {
        if (i == 1) {
            this.log.d(TAG, "打开百度，通过Intent方式");
            Intent intent = new Intent("android.intent.action.MAIN");
            intent.setComponent(new ComponentName(Contents.BAIDU_PACKAGE, "com.baidu.naviauto.SlashActivity"));
            intent.addFlags(268566528);
            this.mContext.startActivity(intent);
        } else if (i == 0) {
            this.log.d(TAG, "打开高德，通过Intent方式");
            Intent intent2 = new Intent("android.intent.action.MAIN");
            intent2.setComponent(new ComponentName(Contents.AMAP_PACKAGE, "com.autonavi.auto.remote.fill.UsbFillActivity"));
            intent2.addFlags(268566528);
            this.mContext.startActivity(intent2);
        } else if (i == 10) {
            return launchMap(getDefaultMap(), iNaviAPICallback);
        }
        connectNaviServer(i, true, iNaviAPICallback);
        setDefaultMap(i);
        return 0;
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public int logoutUserIdToAMap(final UserLogoutModel userLogoutModel, final INaviAPICallback iNaviAPICallback) {
        String currectConnectMap = getCurrectConnectMap();
        if (currectConnectMap.isEmpty()) {
            return -1;
        }
        if (Contents.AMAP_PACKAGE.equals(currectConnectMap)) {
            return super.logoutUserIdToAMap(userLogoutModel, iNaviAPICallback);
        }
        cancelNavi(new INaviAPICallback() {
            /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass9 */

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onFail(NaviErrorModel naviErrorModel) {
                Log.d(NaviManager.TAG, "当前不在导航:" + naviErrorModel.toString());
                NaviManager.this.switchMapServerForLogoutAMap(userLogoutModel, iNaviAPICallback);
            }

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onSuccess(NaviBaseModel naviBaseModel) {
                Log.d(NaviManager.TAG, "结束导航成功:" + naviBaseModel.toString());
                NaviManager.this.switchMapServerForLogoutAMap(userLogoutModel, iNaviAPICallback);
            }
        });
        return 0;
    }

    public void multiDestNavi(List<String> list, int i, int i2, INaviAPICallback iNaviAPICallback) {
        synchronized (this.mNaviLock) {
            if (list != null) {
                if (list.size() > 0) {
                    this.viaList = new ArrayList();
                    cycleSearchKeyword(list, i, i2, iNaviAPICallback);
                }
            }
            this.log.d(TAG, "目的地为null：");
        }
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public void release() {
        synchronized (this.mNaviLock) {
            this.naviService = null;
            this.mAPICallbacks.clear();
            this.mNaviEventListener = null;
            this.mHandler.postDelayed(new Runnable() {
                /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass4 */

                public void run() {
                    NaviManager.this.removeHandlerCallbacks();
                }
            }, 1000);
        }
    }

    public boolean removedSurface(Surface surface, int i) {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    return iNaviServer.removedSurface(surface, i);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            return false;
        }
    }

    public int setDefaultMap(int i) {
        synchronized (this.mNaviLock) {
            IServiceBinder iServiceBinder = this.initService;
            if (iServiceBinder == null) {
                return -1;
            }
            try {
                return iServiceBinder.setDefaultMap(i);
            } catch (RemoteException e) {
                e.printStackTrace();
                return -2;
            }
        }
    }

    @Override // com.geely.lib.oneosapi.navi.NaviAPI
    public void setNaviEventListener(INaviEventListener iNaviEventListener) {
        this.mNaviEventListener = iNaviEventListener;
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.log.d(TAG, "setService()");
        if (iBinder != null) {
            this.log.d(TAG, "setService()-->binder != null");
            this.initService = IServiceBinder.Stub.asInterface(iBinder);
            connectNaviServer(this.mapVendor, false, null);
        }
    }

    public boolean addSurface(Surface surface, int i, int i2, int i3, int i4, int i5) {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    return iNaviServer.addSurfaceWithRoadView(surface, i, i2, i3, i4, i5);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            return false;
        }
    }

    public boolean addSurface(Surface surface, int i, int i2, int i3, int i4, int i5, int i6, int i7) {
        synchronized (this.mNaviLock) {
            INaviServer iNaviServer = this.naviService;
            if (iNaviServer != null) {
                try {
                    return iNaviServer.addSurfaceWithRoadViewAndOffset(surface, i, i2, i3, i4, i5, i6, i7);
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            return false;
        }
    }

    public int launchMap(int i, Bundle bundle, INaviAPICallback iNaviAPICallback) {
        if (i == 1) {
            this.log.d(TAG, "打开百度，通过Intent方式");
            Intent intent = new Intent("android.intent.action.MAIN");
            intent.setComponent(new ComponentName(Contents.BAIDU_PACKAGE, "com.baidu.naviauto.SlashActivity"));
            intent.addFlags(268566528);
            this.mContext.startActivity(intent, bundle);
        } else if (i == 0) {
            this.log.d(TAG, "打开高德，通过Intent方式");
            Intent intent2 = new Intent("android.intent.action.MAIN");
            intent2.setComponent(new ComponentName(Contents.AMAP_PACKAGE, "com.autonavi.auto.remote.fill.UsbFillActivity"));
            intent2.addFlags(268566528);
            this.mContext.startActivity(intent2, bundle);
        } else if (i == 10) {
            return launchMap(getDefaultMap(), iNaviAPICallback);
        }
        connectNaviServer(i, true, iNaviAPICallback);
        setDefaultMap(i);
        return 0;
    }

    @Deprecated
    public int launchMap() {
        NaviBaseModel naviBaseModel = new NaviBaseModel();
        naviBaseModel.setProtocolID(NaviProtocolID.APP_LAUNCH_MAP);
        return invokeAPIAsync(naviBaseModel, new INaviAPICallback() {
            /* class com.geely.lib.oneosapi.navi.NaviManager.AnonymousClass5 */

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onFail(NaviErrorModel naviErrorModel) {
            }

            @Override // com.geely.lib.oneosapi.navi.INaviAPICallback
            public void onSuccess(NaviBaseModel naviBaseModel) {
            }
        });
    }
}
