package com.geely.lib.oneosapi.ota;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.ota.IOtaService;

public class OtaManager implements ServiceBaseManager {
    private static final String SDK_VERSION = "==20230130==";
    private static final String TAG = "OtaManager==20230130==";
    private Context mContext;
    private String mPackageName;
    private IOtaService mService;

    public OtaManager(Context context, IBinder iBinder) {
        this.mPackageName = context.getPackageName();
        Log.d(TAG, "OtaManager(" + context + "," + iBinder + ")" + this.mPackageName);
        this.mContext = context;
        initOtaManger(iBinder);
    }

    private void initOtaManger(IBinder iBinder) {
        if (iBinder != null) {
            this.mService = IOtaService.Stub.asInterface(iBinder);
        }
    }

    private void serviceIsNull() {
        Log.d(TAG, "OtaServiceIsNull" + this.mPackageName);
    }

    public String getCurrentCarVersionName() {
        String str;
        Log.d(TAG, "getCurrentCarVersionName");
        IOtaService iOtaService = this.mService;
        if (iOtaService != null) {
            try {
                str = iOtaService.getCurrentCarVersionName();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            str = null;
        }
        Log.d(TAG, "getCurrentCarVersionName:result = " + str + this.mPackageName);
        return str;
    }

    public String getUpgradeVersionName() {
        String str;
        Log.d(TAG, "getUpgradeVersionName");
        IOtaService iOtaService = this.mService;
        if (iOtaService != null) {
            try {
                str = iOtaService.getUpgradeVersionName();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            str = null;
        }
        Log.d(TAG, "getUpgradeVersionName:result = " + str + this.mPackageName);
        return str;
    }

    public boolean isAlive() {
        Log.d(TAG, "isAlive()" + this.mPackageName);
        if (this.mService == null) {
            serviceIsNull();
        }
        IOtaService iOtaService = this.mService;
        boolean z = iOtaService != null && iOtaService.asBinder().isBinderAlive();
        Log.d(TAG, "isAlive：result = " + z);
        return z;
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        Log.d(TAG, "setService(" + iBinder + ")" + this.mPackageName);
        initOtaManger(iBinder);
    }
}
