package com.geely.lib.oneosapi.payment;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.payment.IPaymentCallback;
import com.geely.lib.oneosapi.payment.IPaymentService;

public class PaymentManager implements ServiceBaseManager {
    private static final String TAG = "PaymentManager";
    private Context mContetx;
    private IPaymentService mService;

    public static abstract class BasePaymentCallback extends IPaymentCallback.Stub {
        @Override // com.geely.lib.oneosapi.payment.IPaymentCallback
        public void isPaySuccessCallback(int i, String str) {
            Log.d(PaymentManager.TAG, "BasePaymentCallback() called with: code = [" + i + "], message = [" + str + "]");
        }
    }

    public PaymentManager(Context context, IBinder iBinder) {
        this.mContetx = context;
        this.mService = IPaymentService.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        IPaymentService iPaymentService = this.mService;
        return iPaymentService != null && iPaymentService.asBinder().isBinderAlive();
    }

    public void isPaySuccessCallback(int i, String str) {
        if (isServiceAlive()) {
            try {
                this.mService.isPaySuccessCallback(i, str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "startPayment: service is not alive");
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = IPaymentService.Stub.asInterface(iBinder);
    }

    public void startPayment(OrderRenderParam orderRenderParam, BasePaymentCallback basePaymentCallback) {
        if (isServiceAlive()) {
            try {
                this.mService.startPayment(orderRenderParam, basePaymentCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "startPayment: service is not alive");
        }
    }
}
