package com.geely.lib.oneosapi.scenemode;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.scenemode.ISceneModeService;

public class SceneModeManager implements ServiceBaseManager {
    public static final int EXECUTE_CANT_OPEN = 3;
    public static final int EXECUTE_FAIL = 2;
    public static final int EXECUTE_NOT_SUPPORT = 4;
    public static final int EXECUTE_SUCCESS = 1;
    private static final String TAG = "SceneModeManager";
    private ISceneModeService mService;

    public SceneModeManager(Context context, IBinder iBinder) {
        this.mService = ISceneModeService.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        ISceneModeService iSceneModeService = this.mService;
        return iSceneModeService != null && iSceneModeService.asBinder().isBinderAlive();
    }

    public void enterIntoModeById(String str) {
        Log.d(TAG, "enterIntoModeById() called with: sceneId = [" + str + "]");
        if (isServiceAlive()) {
            try {
                this.mService.enterIntoModeById(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "enterIntoModeById(): service is not alive");
        }
    }

    public void executeModeById(String str, boolean z) {
        Log.d(TAG, "executeModeById() called with: sceneId = [" + str + "], isOpen = [" + z + "]");
        if (isServiceAlive()) {
            try {
                this.mService.executeModeById(str, z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "executeModeById(): service is not alive");
        }
    }

    public int executeSceneModeById(String str, boolean z) {
        Log.d(TAG, "executeModeById() called with: sceneId = [" + str + "], isOpen = [" + z + "]");
        if (isServiceAlive()) {
            try {
                return this.mService.executeSceneModeById(str, z);
            } catch (RemoteException e) {
                e.printStackTrace();
                return 2;
            }
        } else {
            Log.d(TAG, "executeModeById(): service is not alive");
            return 2;
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = ISceneModeService.Stub.asInterface(iBinder);
    }
}
