package com.geely.lib.oneosapi.schedule;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.schedule.CPCallbackInterface;
import com.geely.lib.oneosapi.schedule.ICalendarInfoAPI;
import com.geely.lib.oneosapi.schedule.bean.CPAddScheduleBean;
import com.geely.lib.oneosapi.schedule.bean.CPHolidayInfo;
import com.geely.lib.oneosapi.schedule.bean.CPScheduleInfo;
import java.util.List;

public class ScheduleManager implements ServiceBaseManager {
    private static final String TAG = "ScheduleManager";
    private Context mContext;
    private ICalendarInfoAPI mService;

    public static abstract class BaseCPCallbackInterface extends CPCallbackInterface.Stub {
        @Override // com.geely.lib.oneosapi.schedule.CPCallbackInterface
        public void callbackCalendarEventInfo(List<CPScheduleInfo> list) {
            Log.d(ScheduleManager.TAG, "callbackScheduleInfo() called with: list = [" + list + "]");
        }

        @Override // com.geely.lib.oneosapi.schedule.CPCallbackInterface
        public void callbackCalendarImportInfo(List<CPHolidayInfo> list) {
            Log.d(ScheduleManager.TAG, "callbackHolidayInfo() called with: list = [" + list + "]");
        }
    }

    public ScheduleManager(Context context, IBinder iBinder) {
        this.mContext = context;
        this.mService = ICalendarInfoAPI.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        ICalendarInfoAPI iCalendarInfoAPI = this.mService;
        return iCalendarInfoAPI != null && iCalendarInfoAPI.asBinder().isBinderAlive();
    }

    public void getCalendarEvents(BaseCPCallbackInterface baseCPCallbackInterface) {
        if (isServiceAlive()) {
            try {
                this.mService.getCalendarEvents(baseCPCallbackInterface);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "getScheduleInfo: service is not alive");
        }
    }

    public void getCalendarImportEvents(BaseCPCallbackInterface baseCPCallbackInterface) {
        if (isServiceAlive()) {
            try {
                this.mService.getCalendarImportEvents(baseCPCallbackInterface);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "getHolidayInfo: service is not alive");
        }
    }

    public void launchAddImportSchedule() throws RemoteException {
        if (isServiceAlive()) {
            this.mService.launchAddImportSchedule();
        } else {
            Log.d(TAG, "launchAddImportSchedule: service is not alive");
        }
    }

    public void launchAddImportScheduleParameter(long j) throws RemoteException {
        if (isServiceAlive()) {
            this.mService.launchAddImportScheduleParameter(j);
        } else {
            Log.d(TAG, "launchAddImportSchedule: service is not alive");
        }
    }

    public void launchAddSchedule() throws RemoteException {
        if (isServiceAlive()) {
            this.mService.launchAddSchedule();
        } else {
            Log.d(TAG, "launchScheduleHome: service is not alive");
        }
    }

    public void launchAddScheduleParameter(long j) throws RemoteException {
        if (isServiceAlive()) {
            this.mService.launchAddScheduleParameter(j);
        } else {
            Log.d(TAG, "launchScheduleHome: service is not alive");
        }
    }

    public void launchScheduleHome() throws RemoteException {
        if (isServiceAlive()) {
            this.mService.launchScheduleHome();
        } else {
            Log.d(TAG, "launchScheduleHome: service is not alive");
        }
    }

    public int setAddCalendarEvent(CPAddScheduleBean cPAddScheduleBean) throws RemoteException {
        if (isServiceAlive()) {
            return this.mService.setAddCalendarEvent(cPAddScheduleBean);
        }
        Log.d(TAG, "setAddCalendarEvent: service is not alive");
        return -1;
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = ICalendarInfoAPI.Stub.asInterface(iBinder);
    }
}
