package com.geely.lib.oneosapi.smart;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.smart.IResultCallback;
import com.geely.lib.oneosapi.smart.ISmartApi;

public class SmartHomeManager implements ServiceBaseManager {
    private static final String TAG = "SmartHomeManager";
    private Context mContext;
    private ISmartApi mService;

    public static abstract class BaseSmartHomeAPICallback extends IResultCallback.Stub {
        @Override // com.geely.lib.oneosapi.smart.IResultCallback
        public void callback(int i, String str) {
            Log.d(SmartHomeManager.TAG, "BaseSmartHomeAPICallback: code=" + i + "/message=" + str);
        }
    }

    public SmartHomeManager(Context context, IBinder iBinder) {
        this.mContext = context;
        this.mService = ISmartApi.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        ISmartApi iSmartApi = this.mService;
        return iSmartApi != null && iSmartApi.asBinder().isBinderAlive();
    }

    public void controlACTemp(String str, String str2, int i, int i2, BaseSmartHomeAPICallback baseSmartHomeAPICallback) {
        if (isServiceAlive()) {
            try {
                this.mService.controlACTemp(str, str2, i, i2, baseSmartHomeAPICallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "controlACTemp: service is not alive");
        }
    }

    public void controlDeviceMode(String str, int i, int i2, BaseSmartHomeAPICallback baseSmartHomeAPICallback) {
        if (isServiceAlive()) {
            try {
                this.mService.controlDeviceMode(str, i, i2, baseSmartHomeAPICallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "controlDeviceMode: service is not alive");
        }
    }

    public void controlDeviceSpeed(String str, int i, int i2, BaseSmartHomeAPICallback baseSmartHomeAPICallback) {
        if (isServiceAlive()) {
            try {
                this.mService.controlDeviceSpeed(str, i, i2, baseSmartHomeAPICallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "controlDeviceSpeed: service is not alive");
        }
    }

    public void controlDeviceSwitch(String str, int i, boolean z, BaseSmartHomeAPICallback baseSmartHomeAPICallback) {
        if (isServiceAlive()) {
            try {
                this.mService.controlDeviceSwitch(str, i, z, baseSmartHomeAPICallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "controlDeviceSwitch: service is not alive");
        }
    }

    public void controlSceneMode(boolean z, String str, BaseSmartHomeAPICallback baseSmartHomeAPICallback) {
        if (isServiceAlive()) {
            try {
                this.mService.controlSceneMode(z, str, baseSmartHomeAPICallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "controlSceneMode: service is not alive");
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        if (iBinder != null) {
            this.mService = ISmartApi.Stub.asInterface(iBinder);
        }
    }
}
