package com.geely.lib.oneosapi.systemui;

import android.content.Context;
import android.os.IBinder;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.systemui.IDockBarService;

public class DockBarManager implements ServiceBaseManager {
    public static final int DOCK_HIDE = 3;
    public static final int DOCK_HIDE_NO_ANIM = 5;
    public static final int DOCK_SHOW_ALL = 1;
    public static final int DOCK_SHOW_LINE = 2;
    public static final int DOCK_SHOW_NO_ANIM = 4;
    private static final String TAG = "DockBarManager";
    private IDockBarService mService;

    public DockBarManager(Context context, IBinder iBinder) {
        this.mService = IDockBarService.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        IDockBarService iDockBarService = this.mService;
        return iDockBarService != null && iDockBarService.asBinder().isBinderAlive();
    }

    public void canSlide(boolean z) {
        Log.d(TAG, "canSlide." + z);
        if (isServiceAlive()) {
            try {
                this.mService.canSlide(z);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "canSlide: service is not alive");
        }
    }

    public int getDockStatus() {
        Log.d(TAG, "getDockStatus.");
        if (isServiceAlive()) {
            try {
                return this.mService.getDockStatus();
            } catch (Exception e) {
                e.printStackTrace();
                return -1;
            }
        } else {
            Log.d(TAG, "getDockStatus: service is not alive");
            return -1;
        }
    }

    public void playAnimSub(boolean z) {
        Log.d(TAG, "playAnimSub." + z);
        if (isServiceAlive()) {
            try {
                this.mService.playAnimSub(z);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "playAnimSub: service is not alive");
        }
    }

    public void playAnimSubPsd(boolean z) {
        Log.d(TAG, "playAnimSub." + z);
        if (isServiceAlive()) {
            try {
                this.mService.playAnimSubPsd(z);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "playAnimSub: service is not alive");
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = IDockBarService.Stub.asInterface(iBinder);
    }

    public void showDock(int i) {
        Log.d(TAG, "showDock." + i);
        if (isServiceAlive()) {
            try {
                this.mService.showDock(i);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "showDock: service is not alive");
        }
    }

    public void showDockNoAnim(int i) {
        Log.d(TAG, "showDockNoAnim." + i);
        if (isServiceAlive()) {
            try {
                this.mService.showDockNoAnim(i);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "showDockNoAnim: service is not alive");
        }
    }
}
