package com.geely.lib.oneosapi.systemui;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.systemui.IStatusBarService;

public class StatusBarPublicManager implements ServiceBaseManager {
    private static final String TAG = "StatusBarPublicManager";
    private IStatusBarService mService;

    public StatusBarPublicManager(Context context, IBinder iBinder) {
        this.mService = IStatusBarService.Stub.asInterface(iBinder);
    }

    private void closeDialogByName(String str) {
        Log.d(TAG, "closeDialogByName--dialogName." + str);
        if (isServiceAlive()) {
            try {
                this.mService.closeDialogByName(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "closeDialogByName: service is not alive");
        }
    }

    private boolean isServiceAlive() {
        IStatusBarService iStatusBarService = this.mService;
        return iStatusBarService != null && iStatusBarService.asBinder().isBinderAlive();
    }

    private void setLeftTempStateVisibility(String str, int i) {
        Log.d(TAG, "setLeftTempStateMediaVisibility leftTempStateContents : " + str + " visibility :" + i);
        if (isServiceAlive()) {
            try {
                this.mService.setLeftTempStateVisibility(str, i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "setPsdStatusVisibility: service is not alive");
        }
    }

    private void showDialogByName(String str) {
        Log.d(TAG, "dialogName." + str);
        if (isServiceAlive()) {
            try {
                this.mService.showDialogByName(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "showDialogByName: service is not alive");
        }
    }

    public void closeAccessPointDialog() {
        closeDialogByName("AccessPoint");
    }

    public void closeBluetoothDialog() {
        closeDialogByName("Bluetooth");
    }

    public void closeWifiDialog() {
        closeDialogByName("Wifi");
    }

    public int getPsdStatusBarVisibility() {
        Log.d(TAG, "getPsdStatusBarVisibility");
        if (isServiceAlive()) {
            try {
                return this.mService.getPsdStatusBarVisibility();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "getPsdStatusBarVisibility: service is not alive");
            return 0;
        }
    }

    public void setCsdActivity(IBinder iBinder) {
        Log.d(TAG, "setCsdActivity csdActitvity" + iBinder);
        if (isServiceAlive()) {
            try {
                this.mService.setCsdActivity(iBinder);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "setCsdActivity: service is not alive");
        }
    }

    public void setLeftTempStateMediaVisibility(int i) {
        setLeftTempStateVisibility("music", i);
    }

    public void setPsdActivity(IBinder iBinder) {
        Log.d(TAG, "setPsdActivity psdAcitvity" + iBinder);
        if (isServiceAlive()) {
            try {
                this.mService.setPsdActivity(iBinder);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "setPsdActivity: service is not alive");
        }
    }

    public void setPsdStatusVisibility(int i) {
        Log.d(TAG, "setPsdStatusVisibility visibility" + i);
        if (isServiceAlive()) {
            try {
                this.mService.setPsdStatusVisibility(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "setPsdStatusVisibility: service is not alive");
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = IStatusBarService.Stub.asInterface(iBinder);
    }

    public void showAccessPointDialog() {
        showDialogByName("AccessPoint");
    }

    public void showBluetoothDialog() {
        showDialogByName("Bluetooth");
    }

    public void showCsdBluetoothDialogInPsd() {
        showDialogByName("CsdBluetoothInPsd");
    }

    public void showPsdBluetoothDialog() {
        showDialogByName("PsdBluetooth");
    }

    public void showWifiDialog() {
        showDialogByName("Wifi");
    }
}
