package com.geely.lib.oneosapi.theme;

import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.theme.IApplyByLauncherCallback;
import com.geely.lib.oneosapi.theme.IGetOwnerStaticWallpaperCallback;
import com.geely.lib.oneosapi.theme.IGetOwnerVideoWallpaperCallback;
import com.geely.lib.oneosapi.theme.IThemeService;

public class ThemeManager implements ServiceBaseManager {
    private static final String TAG = "ThemeManager";
    private Context mContetx;
    private IThemeService mService;

    public static abstract class BaseApplyByLauncherCallback extends IApplyByLauncherCallback.Stub {
        @Override // com.geely.lib.oneosapi.theme.IApplyByLauncherCallback
        public void applyByLauncherCallback(int i) throws RemoteException {
            Log.d(ThemeManager.TAG, "BaseApplyByLauncherCallback() called with: code = [" + i + "]");
        }
    }

    public static abstract class BaseGetOwnerStaticWallpaperCallback extends IGetOwnerStaticWallpaperCallback.Stub {
        @Override // com.geely.lib.oneosapi.theme.IGetOwnerStaticWallpaperCallback
        public void getOwnerStaticWallpaperCallback(int i, String str) throws RemoteException {
            Log.d(ThemeManager.TAG, "BaseGetOwnerStaticWallpaperCallback() called with: code = [" + i + "], message = [" + str + "]");
        }
    }

    public static abstract class BaseGetOwnerVideoWallpaperCallback extends IGetOwnerVideoWallpaperCallback.Stub {
        @Override // com.geely.lib.oneosapi.theme.IGetOwnerVideoWallpaperCallback
        public void getOwnerVideoWallpaperCallback(int i, String str) throws RemoteException {
            Log.d(ThemeManager.TAG, "BaseGetOwnerVideoWallpaperCallback() called with: code = [" + i + "], message = [" + str + "]");
        }
    }

    public ThemeManager(Context context, IBinder iBinder) {
        this.mContetx = context;
        this.mService = IThemeService.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        IThemeService iThemeService = this.mService;
        return iThemeService != null && iThemeService.asBinder().isBinderAlive();
    }

    public void applyDress(String str, String str2, IDressApplyCallback iDressApplyCallback) {
        if (isServiceAlive()) {
            try {
                this.mService.applyDress(str, str2, iDressApplyCallback);
            } catch (RemoteException e) {
                Log.e(TAG, "applyDress: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "applyDress: service is not alive");
        }
    }

    public void applyLiveWallpaper() {
        if (isServiceAlive()) {
            try {
                this.mService.applyLiveWallpaper();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "applyLiveWallpaper: service is not alive");
        }
    }

    public void applyStaticWallpaper() {
        if (isServiceAlive()) {
            try {
                this.mService.applyStaticWallpaper();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "applyStaticWallpaper: service is not alive");
        }
    }

    public void applyWallpaperByLauncher(String str, IApplyByLauncherCallback iApplyByLauncherCallback) {
        if (isServiceAlive()) {
            try {
                this.mService.applyWallpaperByLauncher(str, iApplyByLauncherCallback);
            } catch (RemoteException e) {
                Log.e(TAG, "applyWallpaperByLauncher: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "applyWallpaperByLauncher: service is not alive");
        }
    }

    public void delDressFile(String str, String str2, IDressDelCallback iDressDelCallback) {
        if (isServiceAlive()) {
            try {
                this.mService.delDressFile(str, str2, iDressDelCallback);
            } catch (RemoteException e) {
                Log.e(TAG, "delDressFile: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "delDressFile: service is not alive");
        }
    }

    public void downloadDress(String str, String str2, boolean z, IDressDlCallback iDressDlCallback) {
        if (isServiceAlive()) {
            try {
                this.mService.downloadDress(str, str2, iDressDlCallback);
            } catch (RemoteException e) {
                Log.e(TAG, "downloadDress: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "downloadDress: service is not alive");
        }
    }

    public int getCurrentWallpaperType() {
        int i;
        if (isServiceAlive()) {
            try {
                i = this.mService.getCurrentWallpaperType();
            } catch (RemoteException e) {
                Log.e(TAG, "getCurrentWallpaperType: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "getCurrentWallpaperType: service is not alive");
            i = -1;
        }
        Log.d(TAG, "getCurrentWallpaperType: retType" + i);
        return i;
    }

    public void getOwnerStaticWallpaperData(IGetOwnerStaticWallpaperCallback iGetOwnerStaticWallpaperCallback) {
        if (isServiceAlive()) {
            try {
                Log.d(TAG, "getOwnerStaticWallpaperCallback is :" + iGetOwnerStaticWallpaperCallback);
                this.mService.getOwnerStaticWallpaperData(iGetOwnerStaticWallpaperCallback);
            } catch (RemoteException e) {
                Log.e(TAG, "getOwnerStaticWallpaperData: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "getOwnerStaticWallpaperData: service is not alive");
        }
    }

    public void getOwnerVideoWallpaperData(IGetOwnerVideoWallpaperCallback iGetOwnerVideoWallpaperCallback) {
        if (isServiceAlive()) {
            try {
                this.mService.getOwnerVideoWallpaperData(iGetOwnerVideoWallpaperCallback);
            } catch (RemoteException e) {
                Log.e(TAG, "getOwnerVideoWallpaperData: RemoteException:" + e.getMessage());
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "getOwnerVideoWallpaperData: service is not alive");
        }
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        this.mService = IThemeService.Stub.asInterface(iBinder);
    }
}
