package com.geely.lib.oneosapi.user;

import android.content.Context;
import android.os.Binder;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.user.IAuthorizeCallback;
import com.geely.lib.oneosapi.user.IAutoAccountInfo;
import com.geely.lib.oneosapi.user.IFeedbackListener;
import com.geely.lib.oneosapi.user.ILaunchLoginResultCallback;
import com.geely.lib.oneosapi.user.ILoginCallback;
import com.geely.lib.oneosapi.user.IScanQRCodeListener;
import com.geely.lib.oneosapi.user.IThirdAppAuthCallback;
import com.geely.lib.oneosapi.user.IUserService;
import com.geely.lib.oneosapi.user.bean.AccountInfo;
import com.geely.lib.oneosapi.user.bean.SourceAccountInfo;
import com.geely.lib.oneosapi.user.bean.UserInfo;
import java.util.List;

public class UserManager implements ServiceBaseManager {
    private static final String TAG = "UserManager";
    private Context mContext;
    private IUserService mService;

    public static abstract class AuthorizeCallback extends IAuthorizeCallback.Stub {
        @Override // com.geely.lib.oneosapi.user.IAuthorizeCallback
        public void getAuthorizationStatus(boolean z) {
            Log.d(UserManager.TAG, "getAuthorizationStatus() called with: hasAuthorized = [" + z + "]");
        }
    }

    public static abstract class AutoAccountInfo extends IAutoAccountInfo.Stub {
    }

    public static abstract class BaseLoginCallBack extends ILoginCallback.Stub {
        @Override // com.geely.lib.oneosapi.user.ILoginCallback
        public void onLogin() {
            Log.d(UserManager.TAG, "onLogin: ");
        }

        @Override // com.geely.lib.oneosapi.user.ILoginCallback
        public void onLogout() {
            Log.d(UserManager.TAG, "onLogout: ");
        }

        @Override // com.geely.lib.oneosapi.user.ILoginCallback
        public void onTokenChanged(String str) {
            Log.d(UserManager.TAG, "onTokenChanged() called with: token = [" + str + "]");
        }

        @Override // com.geely.lib.oneosapi.user.ILoginCallback
        public void onTokenRefresh(String str) {
            Log.d(UserManager.TAG, "onTokenRefresh() called with: token = [" + str + "]");
        }

        @Override // com.geely.lib.oneosapi.user.ILoginCallback
        public void onUserInfoChanged(UserInfo userInfo) {
            Log.d(UserManager.TAG, "onUserInfoChanged() called with: userInfo = [" + userInfo + "]");
        }
    }

    public static abstract class FeedbackListener extends IFeedbackListener.Stub {
    }

    public static abstract class LaunchLoginResultCallback extends ILaunchLoginResultCallback.Stub {
        @Override // com.geely.lib.oneosapi.user.ILaunchLoginResultCallback
        public void onLoginResult(int i, int i2) {
            Log.d(UserManager.TAG, "onLoginResult() called requestCode " + i + " resultCode " + i2);
        }
    }

    public static abstract class ScanQRCodeListener extends IScanQRCodeListener.Stub {
        @Override // com.geely.lib.oneosapi.user.IScanQRCodeListener
        public void getQrCodeStatus(String str, String str2) {
            Log.d(UserManager.TAG, "getQrCodeStatus() called with: status = [" + str + "], info = [" + str2 + "]");
        }

        @Override // com.geely.lib.oneosapi.user.IScanQRCodeListener
        public void scanQrCodeStatus(String str, String str2) {
            Log.d(UserManager.TAG, "scanQrCodeStatus() called with: status = [" + str + "], info = [" + str2 + "]");
        }
    }

    public static abstract class ThirdAppAuthCallback extends IThirdAppAuthCallback.Stub {
        @Override // com.geely.lib.oneosapi.user.IThirdAppAuthCallback
        public void isThirdAppAuthorized(String str) {
            Log.d(UserManager.TAG, "isThirdAppAuthorized() called with: completeMobile = [" + str + "]");
        }
    }

    public UserManager(Context context, IBinder iBinder) {
        this.mContext = context;
        this.mService = IUserService.Stub.asInterface(iBinder);
    }

    private boolean isServiceAlive() {
        IUserService iUserService = this.mService;
        return iUserService != null && iUserService.asBinder().isBinderAlive();
    }

    public boolean fastLogin(UserInfo userInfo) {
        if (isServiceAlive()) {
            try {
                return this.mService.fastLogin(userInfo);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "fastLogin: service is not alive");
        return false;
    }

    public String getAccessToken() {
        if (isServiceAlive()) {
            try {
                return this.mService.getAccessToken();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getAccessToken: service is not alive");
        return null;
    }

    public AccountInfo getAccountInfo() {
        if (isServiceAlive()) {
            try {
                return this.mService.getAccountInfo();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getAccountInfo: service is not alive");
        return null;
    }

    public String getCommonData(int i) {
        if (isServiceAlive()) {
            try {
                return this.mService.getCommonData(i);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getCommonData: service is not alive");
        return null;
    }

    public String getCurrentUserProfile() {
        if (isServiceAlive()) {
            try {
                return this.mService.getCurrentUserProfile();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getCurrentUserProfile: service is not alive");
        return "M1";
    }

    public String getEmergencyMobile() {
        if (isServiceAlive()) {
            try {
                return this.mService.getEmergencyMobile();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "setEmergencyMobile: service is not alive");
        return null;
    }

    public List<UserInfo> getHistoricalAccountInfo() {
        if (isServiceAlive()) {
            try {
                return this.mService.getHistoricalAccountInfo();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getHistoricalAccountInfo: service is not alive");
        return null;
    }

    public void getLoginQrcode(String str, ScanQRCodeListener scanQRCodeListener) {
        if (isServiceAlive()) {
            try {
                this.mService.getLoginQrcode(str, scanQRCodeListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getLoginQrcode: service is not alive");
    }

    public UserInfo getLoginUser() {
        if (isServiceAlive()) {
            try {
                return this.mService.getLoginUser();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getLoginUser: service is not alive");
        return null;
    }

    public String getPolicyContent(String str, String str2) {
        if (isServiceAlive()) {
            try {
                return this.mService.getPolicyContent(str, str2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getPolicyContent: service is not alive");
        return null;
    }

    public SourceAccountInfo getSourceAccountInfo() {
        if (isServiceAlive()) {
            try {
                return this.mService.getSourceAccountInfo();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getSourceAccountInfo: service is not alive");
        return null;
    }

    public String getToken() {
        if (isServiceAlive()) {
            try {
                return this.mService.getToken();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getToken: ");
        return null;
    }

    public boolean getUserAuthorizationStatus(String str, AuthorizeCallback authorizeCallback) {
        if (isServiceAlive()) {
            try {
                return this.mService.getUserAuthorizationStatus(str, authorizeCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getUserAuthorizationStatus: service is not alive");
        return false;
    }

    public String getUserProfileName() {
        if (isServiceAlive()) {
            try {
                return this.mService.getUserProfileName();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "getUserProfileName: service is not alive");
        return "";
    }

    public boolean hasLogin() {
        if (isServiceAlive()) {
            try {
                return this.mService.hasLogin();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "hasLogin: service is not alive");
        return false;
    }

    public boolean hideBackView() {
        if (isServiceAlive()) {
            try {
                return this.mService.hideBackView();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "hideBackView: service is not alive");
        return false;
    }

    public boolean isAutoAccountAuthorized(AuthorizeCallback authorizeCallback) {
        if (isServiceAlive()) {
            try {
                return this.mService.isAutoAccountAuthorized(authorizeCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "isAutoAccountAuthorized: service is not alive");
        return false;
    }

    public boolean isBackShow() {
        if (isServiceAlive()) {
            try {
                return this.mService.isBackShow();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "isBackShow: service is not alive");
        return false;
    }

    public boolean isConnectService() {
        return isServiceAlive();
    }

    public boolean isThirdAppAuthorized(String str, ThirdAppAuthCallback thirdAppAuthCallback) {
        if (isServiceAlive()) {
            try {
                return this.mService.isThirdAppAuthorized(str, thirdAppAuthCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "isThirdAppAuthorized: service is not alive");
        return false;
    }

    public boolean launchLogin() {
        if (isServiceAlive()) {
            try {
                return this.mService.launchLogin();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "launchLogin: service is not alive");
        return false;
    }

    public boolean launchLoginForResult(String str, int i, LaunchLoginResultCallback launchLoginResultCallback) {
        if (isServiceAlive()) {
            try {
                return this.mService.launchLoginForResult(str, i, launchLoginResultCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "launchLoginForResult: service is not alive");
        return false;
    }

    public boolean launchLoginWithParam(String str, String str2, boolean z) {
        try {
            return this.mService.launchLoginWithParam(str, str2, z);
        } catch (RemoteException e) {
            e.printStackTrace();
            Log.e(TAG, "launchLoginWithParam: service is not alive");
            return false;
        }
    }

    public boolean launchToFeedbackContent(boolean z) {
        if (isServiceAlive()) {
            try {
                return this.mService.launchToFeedbackContent(z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "launchToUserFeedback: service is not alive");
        return false;
    }

    public boolean launchToLogin(boolean z) {
        if (isServiceAlive()) {
            try {
                return this.mService.launchToLogin(z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "launchToLogin: service is not alive");
        return false;
    }

    public boolean launchToUserFeedback(boolean z) {
        if (isServiceAlive()) {
            try {
                return this.mService.launchToUserFeedback(z);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "launchToUserFeedback: service is not alive");
        return false;
    }

    public String login(String str) {
        if (isServiceAlive()) {
            try {
                return this.mService.login(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "login: service is not alive");
        return null;
    }

    public boolean logout() {
        if (isServiceAlive()) {
            try {
                return this.mService.logout();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "logout: service is not alive");
        return false;
    }

    public boolean notifyTokenExpired() {
        if (isServiceAlive()) {
            try {
                return this.mService.notifyTokenExpired();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "notifyTokenExpired: service is not alive");
        return false;
    }

    public String refreshToken() {
        if (isServiceAlive()) {
            try {
                return this.mService.refreshToken();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "refreshToken: service is not alive");
        return null;
    }

    public UserInfo refreshUserInfo() {
        if (isServiceAlive()) {
            try {
                return this.mService.refreshUserInfo();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "refreshUserInfo: service is not alive");
        return null;
    }

    public void restartRecognition() {
        if (isServiceAlive()) {
            try {
                this.mService.restartRecognition();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "restartRecognition: service is not alive");
        }
    }

    public boolean saveUserProfile(String str) {
        if (isServiceAlive()) {
            try {
                return this.mService.saveUserProfile(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "userProfile: service is not alive");
        return false;
    }

    public void sendAutoAccountInfo(AutoAccountInfo autoAccountInfo) {
        if (isServiceAlive()) {
            try {
                this.mService.sendAutoAccountInfo(autoAccountInfo);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "sendAutoAccountInfo: service is not alive");
    }

    public void setCommonData(String str, int i) {
        if (isServiceAlive()) {
            try {
                this.mService.setCommonData(str, i);
                return;
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "setCommonData: service is not alive");
    }

    public boolean setCurrentUserProfile(String str) {
        if (isServiceAlive()) {
            try {
                return this.mService.setCurrentUserProfile(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "setCurrentUserProfile: service is not alive");
        return false;
    }

    public void setEmergencyMobile(String str) {
        if (isServiceAlive()) {
            try {
                this.mService.setEmergencyMobile(str);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "setEmergencyMobile: service is not alive");
    }

    public boolean setLoginCallback(BaseLoginCallBack baseLoginCallBack) {
        Log.e(TAG, "setLoginCallback getCallingPid：" + Binder.getCallingPid());
        if (isServiceAlive()) {
            try {
                return this.mService.setLoginCallback(baseLoginCallBack);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "setLoginCallback: service is not alive");
        return false;
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        if (iBinder != null) {
            this.mService = IUserService.Stub.asInterface(iBinder);
        }
    }

    public boolean showBackView() {
        if (isServiceAlive()) {
            try {
                return this.mService.showBackView();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "showBackView: service is not alive");
        return false;
    }

    public void startRecognition() {
        if (isServiceAlive()) {
            try {
                this.mService.startRecognition();
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "startRecognition: service is not alive");
        }
    }

    public void submitFeedback(FeedbackListener feedbackListener) {
        if (isServiceAlive()) {
            try {
                this.mService.submitFeedback(feedbackListener);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "submitFeedback: service is not alive");
        }
    }

    public boolean unregisterLoginCallback(BaseLoginCallBack baseLoginCallBack) {
        if (isServiceAlive()) {
            try {
                return this.mService.unregisterLoginCallback(baseLoginCallBack);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
        Log.e(TAG, "unregisterLoginCallback: service is not alive");
        return false;
    }
}
