package com.geely.lib.oneosapi.vr;

import android.content.Context;
import android.content.pm.PackageManager;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import com.geely.carlink.BuildConfig;
import com.geely.lib.oneosapi.common.ServiceBaseManager;
import com.geely.lib.oneosapi.vr.ISpeechRecognitionCallback;
import com.geely.lib.oneosapi.vr.ITtsCallback;
import com.geely.lib.oneosapi.vr.IVRDialogStatusChangedListener;
import com.geely.lib.oneosapi.vr.IVrService;
import java.util.ArrayList;
import java.util.List;
import org.json.JSONObject;

public class VrManager implements ServiceBaseManager {
    private static final String SDK_VERSION = "==20221020==";
    private static final String TAG = "VrManager==20221020==";
    private Context mContext;
    private String mPackageName;
    private List<IVRDialogStatusChangedListener.Stub> mRegisterListListener = new ArrayList();
    private IVrService mService;
    private List<String> mTogglePermissionList = new ArrayList();
    private List<IVRDialogStatusChangedListener.Stub> mUnregisterListListener = new ArrayList();

    public static class DialogType {
        public static int TYPE_INPUT_TEXT = 1;
    }

    public VrManager(Context context, IBinder iBinder) {
        this.mPackageName = context.getPackageName();
        Log.d(TAG, "VrManager(" + context + "," + iBinder + ")" + this.mPackageName);
        this.mContext = context;
        this.mTogglePermissionList.add("com.geely.hicar");
        this.mTogglePermissionList.add(BuildConfig.APPLICATION_ID);
        initVrManger(iBinder);
    }

    private String getAppName() {
        Context context = this.mContext;
        if (context == null) {
            return "";
        }
        try {
            PackageManager packageManager = context.getPackageManager();
            return packageManager.getApplicationInfo(this.mContext.getPackageName(), 128).loadLabel(packageManager).toString();
        } catch (Throwable th) {
            Log.i(TAG, "getAppName:" + th.getMessage());
            return "";
        }
    }

    private String getAppVersionName() {
        Context context = this.mContext;
        if (context == null) {
            return "";
        }
        try {
            return context.getPackageManager().getPackageInfo(this.mContext.getPackageName(), 0).versionName;
        } catch (Exception e) {
            Log.i(TAG, "getAppVersionName:" + e.getMessage());
            return "1.0.0";
        }
    }

    private String getProcessName() {
        Context context = this.mContext;
        if (context == null) {
            return "";
        }
        try {
            return context.getApplicationInfo().processName;
        } catch (Exception e) {
            Log.i(TAG, "getProcessName:" + e.getMessage());
            return "";
        }
    }

    private void initVrManger(IBinder iBinder) {
        if (iBinder != null) {
            this.mService = IVrService.Stub.asInterface(iBinder);
            if (isAlive()) {
                Log.d(TAG, "mRegisterListListener.size = " + this.mRegisterListListener.size());
                if (this.mRegisterListListener.size() > 0) {
                    for (IVRDialogStatusChangedListener.Stub stub : this.mRegisterListListener) {
                        registerVRDialogStatusChangedListener(stub);
                    }
                    this.mRegisterListListener.clear();
                }
                Log.d(TAG, "mUnregisterListListener.size = " + this.mUnregisterListListener.size());
                if (this.mUnregisterListListener.size() > 0) {
                    for (IVRDialogStatusChangedListener.Stub stub2 : this.mUnregisterListListener) {
                        unregisterVRDialogStatusChangedListener(stub2);
                    }
                    this.mUnregisterListListener.clear();
                }
            }
        }
    }

    private void serviceIsNull() {
        Log.d(TAG, "VrServiceIsNull" + this.mPackageName);
    }

    public void closeDialogue(String str) {
        Log.d(TAG, "closeDialogue(" + str + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.closeDialogue(str, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public void disableVR() {
        Log.d(TAG, "disableVR()" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.disableVR(this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public void enableVR() {
        Log.d(TAG, "enableVR()" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.enableVR(this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public boolean isAlive() {
        Log.d(TAG, "isAlive()" + this.mPackageName);
        if (this.mService == null) {
            serviceIsNull();
        }
        IVrService iVrService = this.mService;
        boolean z = iVrService != null && iVrService.asBinder().isBinderAlive();
        Log.d(TAG, "isAlive：result = " + z);
        return z;
    }

    public void onPageChange(String str, String str2) {
        if (isAlive()) {
            try {
                this.mService.onPageChange(str, str2);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.d(TAG, "VrServiceIsNull" + str);
        }
    }

    public void registerVRDialogStatusChangedListener(IVRDialogStatusChangedListener.Stub stub) {
        Log.d(TAG, "registerVRDialogStatusChangedListener(" + stub + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.registerVRDialogStatusChangedListener(stub, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            if (!this.mRegisterListListener.contains(stub)) {
                this.mRegisterListListener.add(stub);
            }
        }
        Log.d(TAG, "registerVRDialogStatusChangedListener：result = " + ((String) null));
    }

    @Override // com.geely.lib.oneosapi.common.ServiceBaseManager
    public void setService(IBinder iBinder) {
        Log.d(TAG, "setService(" + iBinder + ")" + this.mPackageName);
        initVrManger(iBinder);
    }

    public void speak(String str, boolean z, int i) {
        Log.d(TAG, "speak(" + str + "," + z + "," + i + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.speak(str, z, i, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public void speakIncomingCall(String str) {
        Log.d(TAG, "speakIncomingCall(" + str + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.speakIncomingCall(str, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public String startDialogue(String str) {
        String str2;
        Log.d(TAG, "startDialogue(" + str + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                str2 = this.mService.startDialogue(str, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            str2 = null;
        }
        Log.d(TAG, "startDialogue:result = " + str2 + this.mPackageName);
        return str2;
    }

    public String startDialogueByType(int i) {
        String str;
        Log.d(TAG, "startDialogueByType(" + i + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                str = this.mService.startDialogueByType(i, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            str = null;
        }
        Log.d(TAG, "startDialogueByType:result = " + str + this.mPackageName);
        return str;
    }

    public boolean startSpeechRecognition(long j, long j2, ISpeechRecognitionCallback.Stub stub) {
        boolean z;
        Log.d(TAG, "startSpeechRecognition(" + j + "," + j2 + stub + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                z = this.mService.startSpeechRecognition(this.mPackageName, j, j2, stub);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            z = false;
        }
        Log.d(TAG, "startSpeechRecognition:result=" + z + this.mPackageName);
        return z;
    }

    @Deprecated
    public void stopSpeechRecognition() {
        Log.d(TAG, "stopSpeechRecognition()" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.stopSpeechRecognition(this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public void stopSpeechRecognitionByTime(long j) {
        Log.d(TAG, "stopSpeechRecognitionByTime(" + j + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.stopSpeechRecognitionByTime(this.mPackageName, j);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
        }
    }

    public String toggleDialogue() {
        String str;
        Log.d(TAG, "toggleDialogue()" + this.mPackageName);
        if (!this.mTogglePermissionList.contains(this.mPackageName)) {
            Log.d(TAG, "无权调用 toggleDialogue()" + this.mPackageName);
        } else if (isAlive()) {
            try {
                str = this.mService.toggleDialogue(this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
            Log.d(TAG, "toggleDialogue：result = " + str);
            return str;
        } else {
            serviceIsNull();
        }
        str = null;
        Log.d(TAG, "toggleDialogue：result = " + str);
        return str;
    }

    public void trackData(String str, JSONObject jSONObject) throws IllegalStateException {
        if (!isAlive()) {
            serviceIsNull();
        } else if (jSONObject != null) {
            try {
                this.mService.trackData(getAppName(), getAppVersionName(), getProcessName(), str, jSONObject.toString());
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            Log.e(TAG, "trackData>>jsonObject is null");
            throw new IllegalStateException("jsonObject is null");
        }
    }

    public void unregisterVRDialogStatusChangedListener(IVRDialogStatusChangedListener.Stub stub) {
        Log.d(TAG, "unregisterVRDialogStatusChangedListener(" + stub + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                this.mService.unregisterVRDialogStatusChangedListener(stub, this.mPackageName);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            if (!this.mUnregisterListListener.contains(stub)) {
                this.mUnregisterListListener.add(stub);
            }
        }
        Log.d(TAG, "unregisterVRDialogStatusChangedListener：result = " + ((String) null));
    }

    public String startDialogue(String str, ITtsCallback.Stub stub) {
        String str2;
        Log.d(TAG, "startDialogue(" + str + "," + stub + ")" + this.mPackageName);
        if (isAlive()) {
            try {
                str2 = this.mService.startDialogWithCallback(this.mPackageName, str, stub);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        } else {
            serviceIsNull();
            str2 = null;
        }
        Log.d(TAG, "startDialogue:result = " + str2);
        return str2;
    }
}
