package com.geely.toolchain.hmi.blur;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.SystemProperties;
import android.util.AttributeSet;
import android.util.Log;
import android.view.SurfaceView;
import android.view.View;
import android.widget.FrameLayout;
import com.geely.toolchain.hmi.R;
import java.lang.reflect.Method;

public class LayerBlurView extends FrameLayout {
    private static final int SURFACE_VIEW_OVERLAY_LAYER = -1;
    private static final String TAG = "LayerBlurView";
    private static boolean sInit = false;
    private static Method sSetBackgroundLayerZOrdered;
    private static Method sSetBlurAttrsMethod;
    private static Method sSetBlurBehindMethod;
    private final float CORNER_RADIUS;
    private final String blurTag;
    private SurfaceView mBlurView;
    private float mCornerRadius;

    private static int argb(float f, float f2, float f3, float f4) {
        return (((int) ((f * 255.0f) + 0.5f)) << 24) | (((int) ((f2 * 255.0f) + 0.5f)) << 16) | (((int) ((f3 * 255.0f) + 0.5f)) << 8) | ((int) ((f4 * 255.0f) + 0.5f));
    }

    public LayerBlurView(Context context) {
        this(context, null);
    }

    public LayerBlurView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public LayerBlurView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.mCornerRadius = 0.0f;
        this.CORNER_RADIUS = 0.0f;
        this.blurTag = "LayerBlurView_TAG";
        init(context);
        Log.i(TAG, "LayerBlurView() called isBlurSupported = [" + isBlurSupported() + "]");
        if (isBlurSupported()) {
            SurfaceView surfaceView = new SurfaceView(context);
            this.mBlurView = surfaceView;
            surfaceView.setTag("LayerBlurView_TAG");
            enableBlurBehind(this.mBlurView);
            addView(this.mBlurView);
        }
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.LayerBlurView);
        float f = obtainStyledAttributes.getFloat(R.styleable.LayerBlurView_blurRadius, 160.0f);
        float f2 = obtainStyledAttributes.getFloat(R.styleable.LayerBlurView_blurLuminance, 1.0f);
        float f3 = obtainStyledAttributes.getFloat(R.styleable.LayerBlurView_blurAlpha, 1.0f);
        float dimension = obtainStyledAttributes.getDimension(R.styleable.LayerBlurView_blurCornerRadiusDP, 0.0f);
        dimension = dimension == 0.0f ? obtainStyledAttributes.getFloat(R.styleable.LayerBlurView_blurCornerRadius, 0.0f) : dimension;
        setForegroundColor(obtainStyledAttributes.getColor(R.styleable.LayerBlurView_blurForegroundColor, 0));
        int i2 = obtainStyledAttributes.getInt(R.styleable.LayerBlurView_blurZOrder, -1);
        obtainStyledAttributes.recycle();
        setBlurAttrs(f, f2, f3, dimension);
        setBackgroundLayerZOrdered(i2);
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i, int i2) {
        super.onMeasure(i, i2);
        int mode = View.MeasureSpec.getMode(i);
        int mode2 = View.MeasureSpec.getMode(i2);
        int size = View.MeasureSpec.getSize(i);
        int size2 = View.MeasureSpec.getSize(i2);
        int i3 = 0;
        if (getLayoutParams().width == -2 || getLayoutParams().height == -2) {
            int i4 = -1;
            size2 = 0;
            for (int i5 = 0; i5 < getChildCount(); i5++) {
                View childAt = getChildAt(i5);
                if ("LayerBlurView_TAG".equals(childAt.getTag())) {
                    i4 = i5;
                } else if (childAt.getVisibility() != 8) {
                    measureChild(childAt, i, i2);
                    size2 = Math.max(size2, childAt.getMeasuredHeight());
                    i3 = Math.max(i3, childAt.getMeasuredWidth());
                }
            }
            if (mode == Integer.MIN_VALUE) {
                i = View.MeasureSpec.makeMeasureSpec(i3, 1073741824);
            }
            if (mode2 == Integer.MIN_VALUE) {
                i2 = View.MeasureSpec.makeMeasureSpec(size2, 1073741824);
            }
            if (i4 != -1) {
                measureChild(getChildAt(i4), i, i2);
            }
            Log.d(TAG, "wrapcontentMeasure: widthSize" + i3 + ", heightSize:" + size2);
            size = i3;
        }
        setMeasuredDimension(size, size2);
        Log.d(TAG, "onMeasure: widthSize" + size + ", heightSize:" + size2);
    }

    public void setBlurAttrs(float f, float f2, float f3, float f4) {
        this.mCornerRadius = f4;
        boolean z = SystemProperties.getBoolean("persist.sys.layerblur.enable", true);
        Log.i(TAG, "supportBlur." + z);
        if (!z || !isBlurSupported()) {
            Log.e(TAG, "system is not support layer blur");
            RoundedDrawable roundedDrawable = new RoundedDrawable();
            roundedDrawable.setDrawable(new ColorDrawable(argb(1.0f - f2, 0.0f, 0.0f, 0.0f)));
            roundedDrawable.setRadius((int) f4);
            setBackground(roundedDrawable);
        } else {
            setBlurAttrs(this.mBlurView, f, f2, f3, (1.1f * f4) + 0.8f);
        }
        Drawable foreground = getForeground();
        if (foreground instanceof RoundedDrawable) {
            ((RoundedDrawable) foreground).setRadius((int) f4);
        }
    }

    public void setForeground(Drawable drawable) {
        if (drawable != null) {
            RoundedDrawable roundedDrawable = new RoundedDrawable();
            roundedDrawable.setRadius((int) this.mCornerRadius);
            roundedDrawable.setDrawable(drawable);
            super.setForeground(roundedDrawable);
            return;
        }
        super.setForeground(drawable);
    }

    public SurfaceView getBlurView() {
        return this.mBlurView;
    }

    /* access modifiers changed from: protected */
    public void onVisibilityChanged(View view, int i) {
        super.onVisibilityChanged(view, i);
        SurfaceView surfaceView = this.mBlurView;
        if (surfaceView != null) {
            surfaceView.setVisibility(i);
        }
    }

    public void setForegroundColor(int i) {
        setForeground(new ColorDrawable(i));
    }

    public void setBackgroundLayerZOrdered(int i) {
        setBackgroundLayerZOrdered(this.mBlurView, i);
    }

    private static void init(Context context) {
        if (!sInit) {
            sInit = true;
            ReflectUtils.bypassHiddenApi(context);
            try {
                sSetBlurBehindMethod = ReflectUtils.from((Class<?>) SurfaceView.class).method("setBlurBehind", Boolean.TYPE).method();
                sSetBlurAttrsMethod = ReflectUtils.from((Class<?>) SurfaceView.class).method("setBlurAttrs", Float.TYPE, Float.TYPE, Float.TYPE, Float.TYPE).method();
            } catch (Exception e) {
                Log.e(TAG, "system is not support layer blur", e);
            }
            try {
                sSetBackgroundLayerZOrdered = ReflectUtils.from((Class<?>) SurfaceView.class).method("setBackgroundLayerZOrdered", Integer.TYPE).method();
            } catch (Exception e2) {
                Log.e(TAG, "system is not support setBackgroundLayerZOrdered", e2);
            }
        }
    }

    private static boolean isBlurSupported() {
        return (sSetBlurBehindMethod == null || sSetBlurAttrsMethod == null) ? false : true;
    }

    private static void enableBlurBehind(SurfaceView surfaceView) {
        Method method;
        if (surfaceView != null && (method = sSetBlurBehindMethod) != null) {
            try {
                method.invoke(surfaceView, true);
            } catch (Exception e) {
                Log.e(TAG, "setBlurBehind failed", e);
            }
        }
    }

    private static void setBlurAttrs(SurfaceView surfaceView, float f, float f2, float f3, float f4) {
        Method method;
        if (surfaceView != null && (method = sSetBlurAttrsMethod) != null) {
            try {
                method.invoke(surfaceView, Float.valueOf(f), Float.valueOf(f2), Float.valueOf(f3), Float.valueOf(Math.max(1.0f, f4)));
            } catch (Exception e) {
                Log.e(TAG, "setBlurBehind failed", e);
            }
        }
    }

    private static void setBackgroundLayerZOrdered(SurfaceView surfaceView, int i) {
        if (surfaceView != null) {
            Method method = sSetBackgroundLayerZOrdered;
            if (method == null) {
                Log.e(TAG, "system is not support setBackgroundLayerZOrdered");
                return;
            }
            try {
                method.invoke(surfaceView, Integer.valueOf(i));
            } catch (Exception e) {
                Log.e(TAG, "setBackgroundLayerZOrdered failed", e);
            }
        }
    }
}
