package com.geely.toolchain.hmi.blur;

import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.drawable.Drawable;
import java.util.Objects;

public class RoundedDrawable extends Drawable {
    final Paint mBackgroundPaint;
    private Drawable mDrawable;
    private boolean mIsClipEnabled = true;
    final Paint mPaint;
    private int mRadius;
    private final Rect mTmpBounds = new Rect();
    private final RectF mTmpBoundsF = new RectF();

    public int getOpacity() {
        return -3;
    }

    public RoundedDrawable() {
        Paint paint = new Paint();
        this.mPaint = paint;
        paint.setAntiAlias(true);
        Paint paint2 = new Paint();
        this.mBackgroundPaint = paint2;
        paint2.setAntiAlias(true);
        paint2.setColor(0);
    }

    public void setDrawable(Drawable drawable) {
        if (!Objects.equals(this.mDrawable, drawable)) {
            this.mDrawable = drawable;
            this.mPaint.setShader(null);
            invalidateSelf();
        }
    }

    public Drawable getDrawable() {
        return this.mDrawable;
    }

    public void setBackgroundColor(int i) {
        this.mBackgroundPaint.setColor(i);
        invalidateSelf();
    }

    public int getBackgroundColor() {
        return this.mBackgroundPaint.getColor();
    }

    public void setClipEnabled(boolean z) {
        this.mIsClipEnabled = z;
        if (!z) {
            this.mPaint.setShader(null);
        }
        invalidateSelf();
    }

    public boolean isClipEnabled() {
        return this.mIsClipEnabled;
    }

    /* access modifiers changed from: protected */
    public void onBoundsChange(Rect rect) {
        this.mTmpBounds.right = rect.width();
        this.mTmpBounds.bottom = rect.height();
        this.mTmpBoundsF.right = (float) rect.width();
        this.mTmpBoundsF.bottom = (float) rect.height();
        this.mPaint.setShader(null);
    }

    public void draw(Canvas canvas) {
        Rect bounds = getBounds();
        if (this.mDrawable != null && !bounds.isEmpty()) {
            canvas.save();
            canvas.translate((float) bounds.left, (float) bounds.top);
            RectF rectF = this.mTmpBoundsF;
            int i = this.mRadius;
            canvas.drawRoundRect(rectF, (float) i, (float) i, this.mBackgroundPaint);
            if (this.mIsClipEnabled) {
                if (this.mPaint.getShader() == null) {
                    updateBitmapShader();
                }
                RectF rectF2 = this.mTmpBoundsF;
                int i2 = this.mRadius;
                canvas.drawRoundRect(rectF2, (float) i2, (float) i2, this.mPaint);
            } else {
                int ceil = (int) Math.ceil((double) (((float) Math.min(this.mRadius, Math.min(bounds.width(), bounds.height()) / 2)) * (1.0f - (1.0f / ((float) Math.sqrt(2.0d))))));
                this.mTmpBounds.inset(ceil, ceil);
                this.mDrawable.setBounds(this.mTmpBounds);
                this.mDrawable.draw(canvas);
                int i3 = -ceil;
                this.mTmpBounds.inset(i3, i3);
            }
            canvas.restore();
        }
    }

    public void setAlpha(int i) {
        this.mPaint.setAlpha(i);
        this.mBackgroundPaint.setAlpha(i);
    }

    public int getAlpha() {
        return this.mPaint.getAlpha();
    }

    public void setColorFilter(ColorFilter colorFilter) {
        this.mPaint.setColorFilter(colorFilter);
    }

    public void setRadius(int i) {
        this.mRadius = i;
    }

    public int getRadius() {
        return this.mRadius;
    }

    private void updateBitmapShader() {
        if (this.mDrawable != null) {
            Rect bounds = getBounds();
            if (!bounds.isEmpty()) {
                this.mPaint.setShader(new BitmapShader(drawableToBitmap(this.mDrawable, bounds.width(), bounds.height()), Shader.TileMode.CLAMP, Shader.TileMode.CLAMP));
            }
        }
    }

    private Bitmap drawableToBitmap(Drawable drawable, int i, int i2) {
        Bitmap createBitmap = Bitmap.createBitmap(i, i2, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        drawable.setBounds(0, 0, i, i2);
        drawable.draw(canvas);
        return createBitmap;
    }
}
