package com.geely.toolchain.hmi.blur2;

import android.app.Activity;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Outline;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewOutlineProvider;
import android.widget.FrameLayout;
import com.geely.toolchain.hmi.R;

public class BlurView extends FrameLayout {
    private static final String TAG = "BlurView";
    private float blur2CornerRadius;
    BlurController blurController = new NoOpController();

    public BlurView(Context context) {
        super(context);
        init(null, 0);
    }

    public BlurView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init(attributeSet, 0);
    }

    public BlurView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init(attributeSet, i);
    }

    private void init(AttributeSet attributeSet, int i) {
        TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R.styleable.BlurView, i, 0);
        setOverlayColor(obtainStyledAttributes.getColor(R.styleable.BlurView_blurOverlayColor, 0));
        setBlurRadius(obtainStyledAttributes.getFloat(R.styleable.BlurView_blur2Radius, 16.0f));
        this.blur2CornerRadius = obtainStyledAttributes.getFloat(R.styleable.BlurView_blur2CornerRadius, 0.0f);
        obtainStyledAttributes.recycle();
    }

    public void draw(Canvas canvas) {
        if (this.blurController.draw(canvas)) {
            super.draw(canvas);
        }
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        this.blurController.updateBlurViewSize();
    }

    /* access modifiers changed from: protected */
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        this.blurController.setBlurAutoUpdate(false);
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        if (!isHardwareAccelerated()) {
            Log.e(TAG, "BlurView can't be used in not hardware-accelerated window!");
        } else {
            this.blurController.setBlurAutoUpdate(true);
        }
    }

    public void setRoot(ViewGroup viewGroup) {
        Drawable background = viewGroup.getBackground();
        if (getContext() != null && (getContext() instanceof Activity)) {
            background = ((Activity) getContext()).getWindow().getDecorView().getBackground();
        }
        setupWith(viewGroup).setFrameClearDrawable(background);
        setOutlineProvider(new ViewOutlineProvider() {
            /* class com.geely.toolchain.hmi.blur2.BlurView.AnonymousClass1 */

            public void getOutline(View view, Outline outline) {
                outline.setRoundRect(0, 0, view.getWidth(), view.getHeight(), BlurView.this.blur2CornerRadius);
            }
        });
        setClipToOutline(true);
    }

    public BlurViewFacade setupWith(ViewGroup viewGroup) {
        this.blurController.destroy();
        PreDrawBlurController preDrawBlurController = new PreDrawBlurController(this, viewGroup, new RenderScriptBlur(viewGroup.getContext(), this.blur2CornerRadius));
        this.blurController = preDrawBlurController;
        return preDrawBlurController;
    }

    public BlurViewFacade setBlurRadius(float f) {
        return this.blurController.setBlurRadius(f);
    }

    public BlurViewFacade setOverlayColor(int i) {
        return this.blurController.setOverlayColor(i);
    }

    public BlurViewFacade setBlurAutoUpdate(boolean z) {
        return this.blurController.setBlurAutoUpdate(z);
    }

    public BlurViewFacade setBlurEnabled(boolean z) {
        return this.blurController.setBlurEnabled(z);
    }
}
