package com.geely.toolchain.hmi.dialog;

import android.app.Dialog;
import android.content.res.Configuration;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;
import androidx.fragment.app.DialogFragment;
import androidx.fragment.app.FragmentManager;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.util.UiUtil;
import java.util.Objects;

public abstract class BaseHmiDialogFragment extends DialogFragment {
    protected final String TAG = (getClass().getSimpleName() + " - " + hashCode());

    /* access modifiers changed from: protected */
    public abstract int setLayoutId();

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        Log.i(this.TAG, this.TAG + " : onCreate");
    }

    @Override // androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater layoutInflater, ViewGroup viewGroup, Bundle bundle) {
        ((Dialog) Objects.requireNonNull(getDialog())).getWindow().setBackgroundDrawable(new ColorDrawable(0));
        return layoutInflater.inflate(setLayoutId(), viewGroup, false);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        Log.d(this.TAG, this.TAG + " : onViewCreated");
        super.onViewCreated(view, bundle);
        if (getContext() != null) {
            if (UiUtil.getHmiCurrentModelIsDark(getContext())) {
                Log.d(this.TAG, "current mode is dark");
            } else {
                Log.d(this.TAG, "current mode is light");
            }
        }
    }

    @Override // androidx.fragment.app.DialogFragment
    public Dialog onCreateDialog(Bundle bundle) {
        AnonymousClass1 r3 = new Dialog(requireContext(), R.style.hmi_dialog_style) {
            /* class com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment.AnonymousClass1 */

            public void dismiss() {
                InputMethodManager inputMethodManager;
                super.dismiss();
                View currentFocus = getCurrentFocus();
                if ((currentFocus instanceof TextView) && (inputMethodManager = (InputMethodManager) BaseHmiDialogFragment.this.requireContext().getSystemService("input_method")) != null && inputMethodManager.isActive()) {
                    inputMethodManager.hideSoftInputFromWindow(currentFocus.getWindowToken(), 0);
                }
            }
        };
        r3.setCancelable(true);
        r3.setCanceledOnTouchOutside(true);
        return r3;
    }

    @Override // androidx.fragment.app.Fragment
    public void onResume() {
        Log.d(this.TAG, this.TAG + " : onResume");
        super.onResume();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onStart() {
        Log.d(this.TAG, this.TAG + " : onStart");
        super.onStart();
    }

    @Override // androidx.fragment.app.Fragment
    public void onPause() {
        Log.d(this.TAG, this.TAG + " : onPause");
        super.onPause();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onStop() {
        Log.d(this.TAG, this.TAG + " : onStop");
        super.onStop();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onDestroyView() {
        Log.d(this.TAG, this.TAG + " : onDestroyView");
        super.onDestroyView();
    }

    @Override // androidx.fragment.app.Fragment
    public void onDestroy() {
        Log.d(this.TAG, this.TAG + " : onDestroy");
        super.onDestroy();
    }

    @Override // androidx.fragment.app.Fragment
    public void onConfigurationChanged(Configuration configuration) {
        Log.d(this.TAG, this.TAG + " : onConfigurationChanged " + configuration);
        super.onConfigurationChanged(configuration);
    }

    @Override // androidx.fragment.app.Fragment
    public void onMultiWindowModeChanged(boolean z) {
        Log.d(this.TAG, this.TAG + " : onMultiWindowModeChanged " + z);
        super.onMultiWindowModeChanged(z);
    }

    @Override // androidx.fragment.app.DialogFragment
    public void show(FragmentManager fragmentManager, String str) {
        Log.d(this.TAG, this.TAG + " : show  " + str);
        super.show(fragmentManager, str);
    }

    @Override // androidx.fragment.app.DialogFragment
    public void dismiss() {
        Log.d(this.TAG, this.TAG + " : dismiss");
        super.dismiss();
    }
}
