package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiStateButton;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiAddCustomViewTipDialog extends BaseHmiDialogFragment {
    private String hmiContent;
    private String hmiLeftBtnText;
    private String hmiRightBtnText;
    private String hmiTitle;
    private View hmiView;
    private HmiTextView mContent;
    private LinearLayout mCustomView;
    private HmiSelectListener mHmiSelectListener;
    private HmiStateButton mLeftBtn;
    private HmiStateButton mRightBtn;
    private FrameLayout mRootView;
    private HmiTextView mTitle;

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment
    public int setLayoutId() {
        return R.layout.hmi_add_custom_view_tip_dialog;
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        super.onViewCreated(view, bundle);
        if (bundle != null) {
            this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
            this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
            this.hmiLeftBtnText = bundle.getString("hmiLeftBtnText", this.hmiLeftBtnText);
            this.hmiRightBtnText = bundle.getString("hmiRightBtnText", this.hmiRightBtnText);
        }
        initView(view);
        initData();
    }

    private void initView(View view) {
        this.mTitle = (HmiTextView) view.findViewById(R.id.title);
        this.mContent = (HmiTextView) view.findViewById(R.id.content);
        this.mLeftBtn = (HmiStateButton) view.findViewById(R.id.leftBtn);
        this.mRightBtn = (HmiStateButton) view.findViewById(R.id.rightBtn);
        this.mRootView = (FrameLayout) view.findViewById(R.id.rootView);
        this.mCustomView = (LinearLayout) view.findViewById(R.id.customView);
        this.mLeftBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddCustomViewTipDialog$Gg8xTbSg3aB4STah7Lg3a8AnGTw */

            public final void onClick(View view) {
                HmiAddCustomViewTipDialog.this.lambda$initView$0$HmiAddCustomViewTipDialog(view);
            }
        });
        this.mRightBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddCustomViewTipDialog$Z0WDczIOLq_krClojyPVg5MsX1c */

            public final void onClick(View view) {
                HmiAddCustomViewTipDialog.this.lambda$initView$1$HmiAddCustomViewTipDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiAddCustomViewTipDialog(View view) {
        HmiSelectListener hmiSelectListener = this.mHmiSelectListener;
        if (hmiSelectListener != null) {
            hmiSelectListener.leftAction(this);
        } else {
            Log.i(this.TAG, "leftAction mHmiSelectListener is null");
        }
    }

    public /* synthetic */ void lambda$initView$1$HmiAddCustomViewTipDialog(View view) {
        HmiSelectListener hmiSelectListener = this.mHmiSelectListener;
        if (hmiSelectListener != null) {
            hmiSelectListener.rightAction(this);
        } else {
            Log.i(this.TAG, "rightAction mHmiSelectListener is null");
        }
    }

    private void initData() {
        this.mTitle.setText(this.hmiTitle);
        this.mContent.setText(this.hmiContent);
        this.mLeftBtn.setText(this.hmiLeftBtnText);
        this.mRightBtn.setText(this.hmiRightBtnText);
        View view = this.hmiView;
        if (view != null) {
            this.mCustomView.addView(view);
        } else {
            Log.e(this.TAG, "initData: hmiView  is null");
        }
    }

    private void hmiConfigChange() {
        Context context = getContext();
        if (context != null) {
            Log.i(this.TAG, "hmiConfigChange: ");
            this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
            this.mTitle.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_title_color));
            this.mContent.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_content_color));
            this.mLeftBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_color_click_default), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mRightBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_dialog_un_select_btn_bg_color), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mLeftBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_select_btn_text_color));
            this.mRightBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_unselect_btn_text_color));
        }
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        Log.i("测试1", "onConfigurationChanged: ");
        hmiConfigChange();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        Log.i(this.TAG, this.TAG + " onSaveInstanceState");
        bundle.putString("hmiTitle", this.hmiTitle);
        bundle.putString("hmiContent", this.hmiContent);
        bundle.putString("hmiLeftBtnText", this.hmiLeftBtnText);
        bundle.putString("hmiRightBtnText", this.hmiRightBtnText);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewStateRestored(Bundle bundle) {
        super.onViewStateRestored(bundle);
        if (bundle == null) {
            Log.i(this.TAG, "onViewStateRestored: savedInstanceState is null");
            return;
        }
        this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
        this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
        this.hmiLeftBtnText = bundle.getString("hmiLeftBtnText", this.hmiLeftBtnText);
        this.hmiRightBtnText = bundle.getString("hmiRightBtnText", this.hmiRightBtnText);
    }

    public HmiAddCustomViewTipDialog setHmiTitle(String str) {
        this.hmiTitle = str;
        return this;
    }

    public HmiAddCustomViewTipDialog setHmiAddView(View view) {
        this.hmiView = view;
        return this;
    }

    public HmiAddCustomViewTipDialog setHmiContent(String str) {
        this.hmiContent = str;
        return this;
    }

    public HmiAddCustomViewTipDialog setHmiLeftBtnText(String str) {
        this.hmiLeftBtnText = str;
        return this;
    }

    public HmiAddCustomViewTipDialog setHmiRightBtnText(String str) {
        this.hmiRightBtnText = str;
        return this;
    }

    public HmiAddCustomViewTipDialog setHmiSelectListener(HmiSelectListener hmiSelectListener) {
        this.mHmiSelectListener = hmiSelectListener;
        return this;
    }
}
