package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.constraintlayout.widget.Group;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.util.UiUtil;
import com.geely.toolchain.hmi.view.HmiButton;
import com.geely.toolchain.hmi.view.HmiEditText;
import com.geely.toolchain.hmi.view.HmiImageView;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiAddWlanDialog extends BaseDialog {
    private static final String TAG = BaseDialog.class.getSimpleName();
    private HmiButton mCancel;
    private String mCancelText = "取消";
    private HmiImageView mClearPassword;
    private HmiImageView mCloseIcon;
    private HmiButton mConnection;
    private String mConnectionText = "连接";
    private HmiEditText mEditPassword;
    private boolean mEnable;
    private Group mGroupId;
    private HmiTextView mHint;
    private String mHintText = "密码长度不低于8位";
    private HmiConnectionListener mHmiConnectionListener;
    private HmiSeePasswordListener mHmiSeePasswordListener;
    private HmiTextChangedListener mHmiTextChangedListener;
    private boolean mInitCheckPwdIcon;
    private int mInputType;
    private HmiTextView mKeyOne;
    private HmiTextView mKeyTwo;
    private HmiImageView mLockIcon;
    private ConstraintLayout mPasswordCl;
    private int mPwdMinLength = 8;
    private ConstraintLayout mRootView;
    private HmiTextView mSafeLevel;
    private String mSafeLevelText;
    private HmiImageView mSeePassword;
    private HmiTextView mSignal;
    private String mSignalText;
    private int mStyle = 1;
    private TextWatcher mTextWatcher;
    private HmiTextView mTitle;
    private String mTitleText;

    public interface HmiConnectionListener {
        void cancel(HmiEditText hmiEditText, HmiAddWlanDialog hmiAddWlanDialog);

        void connection(HmiEditText hmiEditText, HmiAddWlanDialog hmiAddWlanDialog);
    }

    public interface HmiSeePasswordListener {
        void isShowPassword(HmiAddWlanDialog hmiAddWlanDialog, HmiEditText hmiEditText, boolean z);
    }

    public interface HmiTextChangedListener {
        void afterTextChanged(HmiAddWlanDialog hmiAddWlanDialog, HmiEditText hmiEditText, Editable editable);

        void beforeTextChanged(HmiAddWlanDialog hmiAddWlanDialog, HmiEditText hmiEditText, CharSequence charSequence, int i, int i2, int i3);

        void onTextChanged(HmiAddWlanDialog hmiAddWlanDialog, HmiEditText hmiEditText, CharSequence charSequence, int i, int i2, int i3);
    }

    public HmiAddWlanDialog(Context context) {
        super(context);
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        initView(getWindow());
        initData();
    }

    public void hmiConfigChange(Context context) {
        int i = context.getResources().getConfiguration().uiMode;
        String str = TAG;
        Log.d(str, "uiMode ====" + i);
        Log.i(str, "hmiConfigChange: context = " + context);
        boolean hmiCurrentModelIsDark = UiUtil.getHmiCurrentModelIsDark(context);
        Window window = getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        if (hmiCurrentModelIsDark) {
            attributes.dimAmount = 0.8f;
        } else {
            attributes.dimAmount = 0.4f;
        }
        window.setAttributes(attributes);
        this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
        this.mTitle.setTextColor(context.getColor(R.color.oneoshmi_dialog_not_title_content_color));
        if (this.mStyle == 1) {
            this.mCloseIcon.setImageResource(R.drawable.oneoshmi_return_pop_big);
        } else {
            this.mCloseIcon.setImageResource(R.drawable.oneoshmi_close_pop_big);
        }
        this.mKeyOne.setTextColor(context.getColor(R.color.oneoshmi_dialog_title_color));
        this.mKeyTwo.setTextColor(context.getColor(R.color.oneoshmi_dialog_title_color));
        this.mSignal.setTextColor(context.getColor(R.color.oneoshmi_dialog_title_color));
        this.mSafeLevel.setTextColor(context.getColor(R.color.oneoshmi_dialog_title_color));
        this.mPasswordCl.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_input_password_bg));
        this.mLockIcon.setImageResource(R.drawable.oneoshmi_lock_press);
        this.mEditPassword.setTextColor(context.getColor(R.color.oneoshmi_dialog_title_color));
        this.mEditPassword.setHintTextColor(context.getColor(R.color.oneoshmi_dialog_password_text_hint_color));
        setSeePasswordIcon(this.mInitCheckPwdIcon);
        this.mClearPassword.setImageResource(R.drawable.oneoshmi_close);
        this.mHint.setTextColor(context.getColor(R.color.oneoshmi_dialog_content_color));
        setConnectionBtnIsEnableClick(this.mEnable, context);
        this.mCancel.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_button_unselect_bg));
        this.mCancel.setTextColor(context.getColor(R.color.oneoshmi_dialog_unselect_btn_text_color));
    }

    private void initView(Window window) {
        this.mRootView = (ConstraintLayout) window.findViewById(R.id.rootView);
        this.mTitle = (HmiTextView) window.findViewById(R.id.title);
        this.mSignal = (HmiTextView) window.findViewById(R.id.keyOneValue);
        this.mSafeLevel = (HmiTextView) window.findViewById(R.id.keyTwoValue);
        this.mKeyOne = (HmiTextView) window.findViewById(R.id.keyOne);
        this.mKeyTwo = (HmiTextView) window.findViewById(R.id.keyTwo);
        this.mEditPassword = (HmiEditText) window.findViewById(R.id.password);
        this.mClearPassword = (HmiImageView) window.findViewById(R.id.clearPassword);
        this.mSeePassword = (HmiImageView) window.findViewById(R.id.seePassword);
        this.mConnection = (HmiButton) window.findViewById(R.id.connection);
        this.mCancel = (HmiButton) window.findViewById(R.id.cancel);
        this.mGroupId = (Group) window.findViewById(R.id.groupId);
        this.mHint = (HmiTextView) window.findViewById(R.id.hint);
        this.mCloseIcon = (HmiImageView) window.findViewById(R.id.closeIcon);
        this.mPasswordCl = (ConstraintLayout) window.findViewById(R.id.passwordCl);
        this.mLockIcon = (HmiImageView) window.findViewById(R.id.lockIcon);
        if (this.mStyle == 1) {
            this.mGroupId.setVisibility(8);
            this.mCloseIcon.setImageResource(R.drawable.oneoshmi_return_pop_big);
            ((ConstraintLayout.LayoutParams) this.mPasswordCl.getLayoutParams()).topMargin = UiUtil.dp2px(getContext(), getContext().getResources().getDimension(R.dimen.oneoshmi_dialog_psssword_cl_top));
        } else {
            this.mCloseIcon.setImageResource(R.drawable.oneoshmi_close_pop_big);
            this.mGroupId.setVisibility(0);
        }
        setHmiListener();
    }

    private void setHmiListener() {
        this.mCloseIcon.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddWlanDialog$uwMYdzbX0kLBK8Qz40iSonn9s0c */

            public final void onClick(View view) {
                HmiAddWlanDialog.this.lambda$setHmiListener$0$HmiAddWlanDialog(view);
            }
        });
        this.mSeePassword.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddWlanDialog$erDRtj0tVEyW6_Uilzpmau0dRWc */

            public final void onClick(View view) {
                HmiAddWlanDialog.this.lambda$setHmiListener$1$HmiAddWlanDialog(view);
            }
        });
        this.mClearPassword.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddWlanDialog$nAgsZGsKu1ykoKdgpYgIscQrDs */

            public final void onClick(View view) {
                HmiAddWlanDialog.this.lambda$setHmiListener$2$HmiAddWlanDialog(view);
            }
        });
        TextWatcher textWatcher = this.mTextWatcher;
        if (textWatcher != null) {
            this.mEditPassword.addTextChangedListener(textWatcher);
        } else {
            this.mEditPassword.addTextChangedListener(new TextWatcher() {
                /* class com.geely.toolchain.hmi.dialog.HmiAddWlanDialog.AnonymousClass1 */

                public void beforeTextChanged(CharSequence charSequence, int i, int i2, int i3) {
                    if (HmiAddWlanDialog.this.mHmiTextChangedListener != null) {
                        HmiTextChangedListener hmiTextChangedListener = HmiAddWlanDialog.this.mHmiTextChangedListener;
                        HmiAddWlanDialog hmiAddWlanDialog = HmiAddWlanDialog.this;
                        hmiTextChangedListener.beforeTextChanged(hmiAddWlanDialog, hmiAddWlanDialog.mEditPassword, charSequence, i, i2, i3);
                        return;
                    }
                    Log.e(HmiAddWlanDialog.TAG, "mHmiTextChangedListener is null");
                }

                public void onTextChanged(CharSequence charSequence, int i, int i2, int i3) {
                    if (HmiAddWlanDialog.this.mHmiTextChangedListener != null) {
                        HmiTextChangedListener hmiTextChangedListener = HmiAddWlanDialog.this.mHmiTextChangedListener;
                        HmiAddWlanDialog hmiAddWlanDialog = HmiAddWlanDialog.this;
                        hmiTextChangedListener.onTextChanged(hmiAddWlanDialog, hmiAddWlanDialog.mEditPassword, charSequence, i, i2, i3);
                        return;
                    }
                    Log.e(HmiAddWlanDialog.TAG, "mHmiTextChangedListener is null");
                }

                public void afterTextChanged(Editable editable) {
                    if (HmiAddWlanDialog.this.mHmiTextChangedListener != null) {
                        HmiTextChangedListener hmiTextChangedListener = HmiAddWlanDialog.this.mHmiTextChangedListener;
                        HmiAddWlanDialog hmiAddWlanDialog = HmiAddWlanDialog.this;
                        hmiTextChangedListener.afterTextChanged(hmiAddWlanDialog, hmiAddWlanDialog.mEditPassword, editable);
                        return;
                    }
                    Log.e(HmiAddWlanDialog.TAG, "mHmiTextChangedListener is null");
                }
            });
        }
        this.mConnection.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddWlanDialog$RDGaGeBhqdqyczfsbxPuck10kc */

            public final void onClick(View view) {
                HmiAddWlanDialog.this.lambda$setHmiListener$3$HmiAddWlanDialog(view);
            }
        });
        this.mCancel.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiAddWlanDialog$9csV_yn2jaLD583tf0oWJJBwmvE */

            public final void onClick(View view) {
                HmiAddWlanDialog.this.lambda$setHmiListener$4$HmiAddWlanDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$setHmiListener$0$HmiAddWlanDialog(View view) {
        dismiss();
    }

    public /* synthetic */ void lambda$setHmiListener$1$HmiAddWlanDialog(View view) {
        boolean z = !this.mInitCheckPwdIcon;
        this.mInitCheckPwdIcon = z;
        HmiSeePasswordListener hmiSeePasswordListener = this.mHmiSeePasswordListener;
        if (hmiSeePasswordListener != null) {
            hmiSeePasswordListener.isShowPassword(this, this.mEditPassword, z);
        }
    }

    public /* synthetic */ void lambda$setHmiListener$2$HmiAddWlanDialog(View view) {
        this.mEditPassword.setText("");
        Log.i(TAG, "password is clear");
    }

    public /* synthetic */ void lambda$setHmiListener$3$HmiAddWlanDialog(View view) {
        HmiConnectionListener hmiConnectionListener = this.mHmiConnectionListener;
        if (hmiConnectionListener != null) {
            hmiConnectionListener.connection(this.mEditPassword, this);
        } else {
            Log.e(TAG, "please set ConnectionListener");
        }
    }

    public /* synthetic */ void lambda$setHmiListener$4$HmiAddWlanDialog(View view) {
        HmiConnectionListener hmiConnectionListener = this.mHmiConnectionListener;
        if (hmiConnectionListener != null) {
            hmiConnectionListener.cancel(this.mEditPassword, this);
        } else {
            Log.e(TAG, "please set ConnectionListener");
        }
    }

    private void initData() {
        this.mTitle.setText(this.mTitleText);
        this.mSignal.setText(this.mSignalText);
        this.mSafeLevel.setText(this.mSafeLevelText);
        this.mConnection.setText(this.mConnectionText);
        this.mCancel.setText(this.mCancelText);
        this.mEditPassword.setMaxHeight(this.mPwdMinLength);
        this.mEditPassword.setInputType(this.mInputType);
        setSeePasswordIcon(this.mInitCheckPwdIcon);
        this.mHint.setText(this.mHintText);
    }

    public void dismiss() {
        this.mEditPassword.setText("");
        super.dismiss();
    }

    public HmiAddWlanDialog setStyle(int i) {
        this.mStyle = i;
        return this;
    }

    public HmiAddWlanDialog setHintText(String str) {
        this.mHintText = str;
        return this;
    }

    public HmiEditText getEditPassword() {
        return this.mEditPassword;
    }

    public HmiAddWlanDialog setInputType(int i) {
        this.mInputType = i;
        return this;
    }

    public HmiAddWlanDialog setInitCheckPwdIcon(boolean z) {
        this.mInitCheckPwdIcon = z;
        return this;
    }

    public HmiAddWlanDialog setSeePasswordIcon(boolean z) {
        Log.i(TAG, "is show password icon -> " + z);
        this.mInitCheckPwdIcon = z;
        if (z) {
            this.mSeePassword.setImageResource(R.drawable.oneoshmi_show_password_press);
        } else {
            this.mSeePassword.setImageResource(R.drawable.oneoshmi_hide_password_press);
        }
        return this;
    }

    public HmiAddWlanDialog setClearPwdIconVisibility(int i) {
        Log.i(TAG, "ClearPwdIconVisibility is " + i);
        this.mClearPassword.setVisibility(i);
        return this;
    }

    public HmiAddWlanDialog setSeePwdIconVisibility(int i) {
        Log.i(TAG, "SeePwdIconVisibility is " + i);
        this.mSeePassword.setVisibility(i);
        return this;
    }

    public HmiAddWlanDialog setTitle(String str) {
        this.mTitleText = str;
        Log.i(TAG, "title text is" + str);
        return this;
    }

    public HmiAddWlanDialog setPwdMinLength(int i) {
        Log.i(TAG, "PasswordLength is " + i);
        this.mPwdMinLength = i;
        return this;
    }

    public int getPwdMinLength() {
        return this.mPwdMinLength;
    }

    public HmiAddWlanDialog setSignalText(String str) {
        this.mSignalText = str;
        Log.i(TAG, "signalText text is" + str);
        return this;
    }

    public HmiAddWlanDialog setSafeLevelText(String str) {
        this.mSafeLevelText = str;
        Log.i(TAG, "safeLevelText text is" + str);
        return this;
    }

    public HmiAddWlanDialog setConnectionText(String str) {
        this.mConnectionText = str;
        Log.i(TAG, "connectionText text is" + str);
        return this;
    }

    public HmiAddWlanDialog setCancelText(String str) {
        this.mCancelText = str;
        Log.i(TAG, "cancelText text is" + str);
        return this;
    }

    @Deprecated
    public HmiAddWlanDialog setConnectionBtnIsEnableClick(boolean z) {
        this.mEnable = z;
        if (z) {
            this.mConnection.setBackground(ContextCompat.getDrawable(getContext(), R.drawable.oneoshmi_dialog_button_select_bg));
            this.mConnection.setTextColor(getContext().getColor(R.color.oneoshmi_dialog_select_btn_text_color));
            this.mConnection.setEnabled(true);
        } else {
            this.mConnection.setBackground(ContextCompat.getDrawable(getContext(), R.drawable.oneoshmi_dialog_button_select_unclick_bg));
            this.mConnection.setTextColor(getContext().getColor(R.color.oneoshmi_dialog_select_btn_un_click_text_color));
            this.mConnection.setEnabled(false);
        }
        return this;
    }

    public HmiAddWlanDialog setConnectionBtnIsEnableClick(boolean z, Context context) {
        this.mEnable = z;
        if (z) {
            this.mConnection.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_button_select_bg));
            this.mConnection.setTextColor(context.getColor(R.color.oneoshmi_dialog_select_btn_text_color));
            this.mConnection.setEnabled(true);
        } else {
            this.mConnection.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_button_select_unclick_bg));
            this.mConnection.setTextColor(context.getColor(R.color.oneoshmi_dialog_select_btn_un_click_text_color));
            this.mConnection.setEnabled(false);
        }
        return this;
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public int setLayoutId() {
        return R.layout.hmi_add_wlan_dialog;
    }

    public HmiAddWlanDialog setConnectionListener(HmiConnectionListener hmiConnectionListener) {
        this.mHmiConnectionListener = hmiConnectionListener;
        return this;
    }

    public HmiAddWlanDialog setHmiSeePasswordListener(HmiSeePasswordListener hmiSeePasswordListener) {
        this.mHmiSeePasswordListener = hmiSeePasswordListener;
        return this;
    }

    @Deprecated
    public HmiAddWlanDialog setHmiTextChangedListener(HmiTextChangedListener hmiTextChangedListener) {
        this.mHmiTextChangedListener = hmiTextChangedListener;
        return this;
    }

    public HmiAddWlanDialog setTextWatcher(TextWatcher textWatcher) {
        this.mTextWatcher = textWatcher;
        return this;
    }
}
