package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.util.UiUtil;
import com.geely.toolchain.hmi.view.HmiButton;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiDoubleButtonNoTitleDialog extends BaseDialog {
    private static final String TAG = "HmiDoubleButtonNoTitleDialog";
    private HmiTextView mContent;
    private String mContentText;
    private HmiButton mLeftButton;
    private String mLeftButtonText;
    private HmiButton mRightButton;
    private String mRightButtonText;
    private ConstraintLayout mRootView;
    private SelectListener mSelectListener;
    private SelectListener2 mSelectListener2;

    public interface SelectListener {
        void leftAction();

        void rightAction();
    }

    public interface SelectListener2 {
        void leftAction(HmiDoubleButtonNoTitleDialog hmiDoubleButtonNoTitleDialog);

        void rightAction(HmiDoubleButtonNoTitleDialog hmiDoubleButtonNoTitleDialog);
    }

    public HmiDoubleButtonNoTitleDialog(Context context) {
        super(context);
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public int setLayoutId() {
        return R.layout.hmi_double_button_no_title_dialog;
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        initView(getWindow());
        initData();
    }

    public void hmiConfigChange(Context context) {
        int i = context.getResources().getConfiguration().uiMode;
        String str = TAG;
        Log.d(str, "uiMode ====" + i);
        Log.i(str, "hmiConfigChange: context = " + context);
        boolean hmiCurrentModelIsDark = UiUtil.getHmiCurrentModelIsDark(context);
        Window window = getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        if (hmiCurrentModelIsDark) {
            attributes.dimAmount = 0.8f;
        } else {
            attributes.dimAmount = 0.4f;
        }
        window.setAttributes(attributes);
        this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
        this.mContent.setTextColor(context.getColor(R.color.oneoshmi_dialog_not_title_content_color));
        this.mLeftButton.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_button_select_bg));
        this.mLeftButton.setTextColor(context.getColor(R.color.oneoshmi_dialog_select_btn_text_color));
        this.mRightButton.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_button_unselect_bg));
        this.mRightButton.setTextColor(context.getColor(R.color.oneoshmi_dialog_unselect_btn_text_color));
    }

    private void initView(Window window) {
        this.mRootView = (ConstraintLayout) window.findViewById(R.id.rootView);
        this.mContent = (HmiTextView) window.findViewById(R.id.content);
        this.mLeftButton = (HmiButton) window.findViewById(R.id.leftButton);
        this.mRightButton = (HmiButton) window.findViewById(R.id.rightButton);
        this.mLeftButton.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiDoubleButtonNoTitleDialog$LOF2pP1J07agKKL_MYzTbwYngE */

            public final void onClick(View view) {
                HmiDoubleButtonNoTitleDialog.this.lambda$initView$0$HmiDoubleButtonNoTitleDialog(view);
            }
        });
        this.mRightButton.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiDoubleButtonNoTitleDialog$JN9ha82sLhk1yDMrDXGtmw2RvZo */

            public final void onClick(View view) {
                HmiDoubleButtonNoTitleDialog.this.lambda$initView$1$HmiDoubleButtonNoTitleDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiDoubleButtonNoTitleDialog(View view) {
        SelectListener selectListener = this.mSelectListener;
        if (selectListener != null) {
            selectListener.leftAction();
            dismiss();
            return;
        }
        String str = TAG;
        Log.i(str, "mSelectListener is null");
        SelectListener2 selectListener2 = this.mSelectListener2;
        if (selectListener2 != null) {
            selectListener2.leftAction(this);
        } else {
            Log.i(str, "mSelectListener2 is null");
        }
    }

    public /* synthetic */ void lambda$initView$1$HmiDoubleButtonNoTitleDialog(View view) {
        SelectListener selectListener = this.mSelectListener;
        if (selectListener != null) {
            selectListener.rightAction();
            dismiss();
            return;
        }
        String str = TAG;
        Log.i(str, "mSelectListener is null");
        SelectListener2 selectListener2 = this.mSelectListener2;
        if (selectListener2 != null) {
            selectListener2.rightAction(this);
        } else {
            Log.i(str, "mSelectListener2 is null");
        }
    }

    private void initData() {
        this.mContent.setText(this.mContentText);
        this.mLeftButton.setText(this.mLeftButtonText);
        this.mRightButton.setText(this.mRightButtonText);
    }

    public HmiDoubleButtonNoTitleDialog setContent(String str) {
        this.mContentText = str;
        Log.i(TAG, "content text is " + str);
        return this;
    }

    public HmiDoubleButtonNoTitleDialog setLeftButtonText(String str) {
        this.mLeftButtonText = str;
        Log.i(TAG, "left button text is" + str);
        return this;
    }

    public HmiDoubleButtonNoTitleDialog setRightButtonText(String str) {
        this.mRightButtonText = str;
        Log.i(TAG, "right button text is" + str);
        return this;
    }

    @Deprecated
    public HmiDoubleButtonNoTitleDialog setSelectListener(SelectListener selectListener) {
        this.mSelectListener = selectListener;
        Log.i(TAG, "HmiDoubleButtonNoTitleDialog SelectListener is not null");
        return this;
    }

    public HmiDoubleButtonNoTitleDialog setSelectListener2(SelectListener2 selectListener2) {
        this.mSelectListener2 = selectListener2;
        Log.i(TAG, "HmiDoubleButtonNoTitleDialog SelectListener2 is not null");
        return this;
    }
}
