package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiStateButton;
import com.geely.toolchain.hmi.view.HmiStateCheckBox;
import com.geely.toolchain.hmi.view.HmiTextView;
import java.io.Serializable;

public class HmiHasCheckBoxSingleButtonDialog extends BaseHmiDialogFragment {
    private String hmiBtnText;
    private String hmiContent;
    private String hmiDesc;
    private String hmiTitle;
    private HmiStateCheckBox mBox;
    private HmiStateButton mBtn;
    private HmiTextView mContent;
    private HmiTextView mDesc;
    private LinearLayout mDescLinearLayout;
    private HmiBtnListener mHmiBtnListener;
    private FrameLayout mRootView;
    private HmiTextView mTitle;

    public interface HmiBtnListener extends Serializable {
        void action(HmiHasCheckBoxSingleButtonDialog hmiHasCheckBoxSingleButtonDialog, boolean z);
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment
    public int setLayoutId() {
        return R.layout.hmi_has_check_box_single_button_dialog;
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        super.onViewCreated(view, bundle);
        if (bundle != null) {
            this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
            this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
            this.hmiDesc = bundle.getString("hmiDesc", this.hmiDesc);
            this.hmiBtnText = bundle.getString("hmiBtnText", this.hmiBtnText);
            this.mHmiBtnListener = (HmiBtnListener) bundle.getSerializable("mHmiBtnListener");
        }
        initView(view);
        initData();
    }

    private void initView(View view) {
        this.mTitle = (HmiTextView) view.findViewById(R.id.title);
        this.mContent = (HmiTextView) view.findViewById(R.id.content);
        this.mDesc = (HmiTextView) view.findViewById(R.id.desc);
        this.mBtn = (HmiStateButton) view.findViewById(R.id.btn);
        this.mBox = (HmiStateCheckBox) view.findViewById(R.id.box);
        this.mRootView = (FrameLayout) view.findViewById(R.id.rootView);
        this.mDescLinearLayout = (LinearLayout) view.findViewById(R.id.ll);
        this.mBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiHasCheckBoxSingleButtonDialog$6riILfe05EfcmEEzJ14HAjUceMI */

            public final void onClick(View view) {
                HmiHasCheckBoxSingleButtonDialog.this.lambda$initView$0$HmiHasCheckBoxSingleButtonDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiHasCheckBoxSingleButtonDialog(View view) {
        HmiBtnListener hmiBtnListener = this.mHmiBtnListener;
        if (hmiBtnListener != null) {
            hmiBtnListener.action(this, this.mBox.isChecked());
        } else {
            Log.i(this.TAG, "action mHmiBtnListener is null");
        }
    }

    private void initData() {
        this.mTitle.setText(this.hmiTitle);
        this.mContent.setText(this.hmiContent);
        this.mContent.getViewTreeObserver().addOnPreDrawListener(new ViewTreeObserver.OnPreDrawListener() {
            /* class com.geely.toolchain.hmi.dialog.HmiHasCheckBoxSingleButtonDialog.AnonymousClass1 */

            public boolean onPreDraw() {
                if (HmiHasCheckBoxSingleButtonDialog.this.mContent.getLineCount() > 1) {
                    HmiHasCheckBoxSingleButtonDialog.this.mDescLinearLayout.setGravity(8388627);
                }
                HmiHasCheckBoxSingleButtonDialog.this.mContent.getViewTreeObserver().removeOnPreDrawListener(this);
                return false;
            }
        });
        this.mDesc.setText(this.hmiDesc);
        this.mBtn.setText(this.hmiBtnText);
    }

    private void hmiConfigChange() {
        Context context = getContext();
        if (context != null) {
            this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
            this.mTitle.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_title_color));
            this.mContent.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_content_color));
            this.mDesc.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_desc_color));
            this.mBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_color_click_default), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_select_btn_text_color));
        }
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        hmiConfigChange();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        Log.i(this.TAG, this.TAG + " onSaveInstanceState");
        bundle.putString("hmiTitle", this.hmiTitle);
        bundle.putString("hmiContent", this.hmiContent);
        bundle.putString("hmiDesc", this.hmiDesc);
        bundle.putString("hmiBtnText", this.hmiBtnText);
        bundle.putSerializable("mHmiBtnListener", this.mHmiBtnListener);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewStateRestored(Bundle bundle) {
        super.onViewStateRestored(bundle);
        if (bundle == null) {
            Log.i(this.TAG, "onViewStateRestored: savedInstanceState is null");
            return;
        }
        this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
        this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
        this.hmiDesc = bundle.getString("hmiDesc", this.hmiDesc);
        this.hmiBtnText = bundle.getString("hmiBtnText", this.hmiBtnText);
        this.mHmiBtnListener = (HmiBtnListener) bundle.getSerializable("mHmiBtnListener");
    }

    public HmiHasCheckBoxSingleButtonDialog setHmiTitle(String str) {
        this.hmiTitle = str;
        return this;
    }

    public HmiHasCheckBoxSingleButtonDialog setHmiDesc(String str) {
        this.hmiDesc = str;
        return this;
    }

    public HmiHasCheckBoxSingleButtonDialog setHmiContent(String str) {
        this.hmiContent = str;
        return this;
    }

    public HmiHasCheckBoxSingleButtonDialog setHmiBtnText(String str) {
        this.hmiBtnText = str;
        return this;
    }

    public HmiHasCheckBoxSingleButtonDialog setHmiBtnListener(HmiBtnListener hmiBtnListener) {
        this.mHmiBtnListener = hmiBtnListener;
        return this;
    }
}
