package com.geely.toolchain.hmi.dialog;

import android.app.Dialog;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ProgressBar;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiImageView;
import com.geely.toolchain.hmi.view.HmiTextView;
import java.util.Objects;

public class HmiHasIconTipDialog extends BaseHmiDialogFragment {
    private String hmiContent;
    private int hmiIconId;
    private HmiTextView mContent;
    private HmiImageView mIcon;
    private ProgressBar mProgressBar;

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment
    public int setLayoutId() {
        return R.layout.hmi_has_icon_tip_dialog;
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        Bundle arguments = getArguments();
        if (arguments == null) {
            Log.i(this.TAG, "onCreate: arguments is null");
            return;
        }
        this.hmiIconId = arguments.getInt("hmiIcon");
        this.hmiContent = arguments.getString("hmiContent");
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        super.onViewCreated(view, bundle);
        ((Dialog) Objects.requireNonNull(getDialog())).getWindow().setDimAmount(0.0f);
        if (bundle != null) {
            this.hmiIconId = bundle.getInt("hmiIcon", this.hmiIconId);
            this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
        }
        initView(view);
        initData();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        Log.i(this.TAG, this.TAG + " onSaveInstanceState");
        bundle.putInt("hmiIcon", this.hmiIconId);
        bundle.putString("hmiContent", this.hmiContent);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewStateRestored(Bundle bundle) {
        super.onViewStateRestored(bundle);
        if (bundle == null) {
            Log.i(this.TAG, "onViewStateRestored: savedInstanceState is null");
            return;
        }
        this.hmiIconId = bundle.getInt("hmiIcon", this.hmiIconId);
        this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
    }

    private void initView(View view) {
        this.mIcon = (HmiImageView) view.findViewById(R.id.icon);
        this.mContent = (HmiTextView) view.findViewById(R.id.content);
        this.mProgressBar = (ProgressBar) view.findViewById(R.id.progressBar);
    }

    private void initData() {
        if (this.hmiIconId == 0) {
            this.mIcon.setVisibility(4);
            this.mProgressBar.setVisibility(0);
        } else {
            this.mIcon.setVisibility(0);
            this.mProgressBar.setVisibility(4);
        }
        this.mIcon.setImageResource(this.hmiIconId);
        this.mContent.setText(this.hmiContent);
    }

    public void setHmiIconId(int i) {
        this.hmiIconId = i;
    }

    public void setHmiContent(String str) {
        this.hmiContent = str;
    }
}
