package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.content.res.Configuration;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiImageView;
import com.geely.toolchain.hmi.view.HmiStateButton;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiHasImageDoubleButtonDialog extends BaseHmiDialogFragment {
    private Bitmap hmiBitmap;
    private String hmiContent;
    private int hmiImageResource;
    private String hmiLeftBtnText;
    private String hmiRightBtnText;
    private String hmiTitle;
    private HmiTextView mContent;
    private HmiSelectListener mHmiSelectListener;
    private HmiImageView mImage;
    private HmiStateButton mLeftBtn;
    private HmiStateButton mRightBtn;
    private FrameLayout mRootView;
    private HmiTextView mTitle;

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment
    public int setLayoutId() {
        return R.layout.hmi_has_image_double_button_dialog;
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        super.onViewCreated(view, bundle);
        if (bundle != null) {
            this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
            this.hmiImageResource = bundle.getInt("hmiImageResource", this.hmiImageResource);
            this.hmiBitmap = (Bitmap) bundle.getParcelable("hmiBitmap");
            this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
            this.hmiLeftBtnText = bundle.getString("hmiLeftBtnText", this.hmiLeftBtnText);
            this.hmiRightBtnText = bundle.getString("hmiRightBtnText", this.hmiRightBtnText);
        }
        initView(view);
        initData();
    }

    private void initView(View view) {
        this.mTitle = (HmiTextView) view.findViewById(R.id.title);
        this.mImage = (HmiImageView) view.findViewById(R.id.img);
        this.mContent = (HmiTextView) view.findViewById(R.id.content);
        this.mLeftBtn = (HmiStateButton) view.findViewById(R.id.leftBtn);
        this.mRightBtn = (HmiStateButton) view.findViewById(R.id.rightBtn);
        this.mRootView = (FrameLayout) view.findViewById(R.id.rootView);
        this.mLeftBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiHasImageDoubleButtonDialog$_cU6BzmkxSGp4IXSt1rU2EbP53s */

            public final void onClick(View view) {
                HmiHasImageDoubleButtonDialog.this.lambda$initView$0$HmiHasImageDoubleButtonDialog(view);
            }
        });
        this.mRightBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiHasImageDoubleButtonDialog$MbT5lSV5yKVgLVnaMX9HP8RHsDE */

            public final void onClick(View view) {
                HmiHasImageDoubleButtonDialog.this.lambda$initView$1$HmiHasImageDoubleButtonDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiHasImageDoubleButtonDialog(View view) {
        HmiSelectListener hmiSelectListener = this.mHmiSelectListener;
        if (hmiSelectListener != null) {
            hmiSelectListener.leftAction(this);
        } else {
            Log.i(this.TAG, "leftAction mHmiSelectListener is null");
        }
    }

    public /* synthetic */ void lambda$initView$1$HmiHasImageDoubleButtonDialog(View view) {
        HmiSelectListener hmiSelectListener = this.mHmiSelectListener;
        if (hmiSelectListener != null) {
            hmiSelectListener.rightAction(this);
        } else {
            Log.i(this.TAG, "rightAction mHmiSelectListener is null");
        }
    }

    private void initData() {
        this.mTitle.setText(this.hmiTitle);
        this.mContent.setText(this.hmiContent);
        this.mLeftBtn.setText(this.hmiLeftBtnText);
        this.mRightBtn.setText(this.hmiRightBtnText);
        this.mImage.setImageResource(this.hmiImageResource);
        Bitmap bitmap = this.hmiBitmap;
        if (bitmap != null) {
            this.mImage.setImageBitmap(bitmap);
        }
    }

    private void hmiConfigChange() {
        Context context = getContext();
        if (context != null) {
            this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
            this.mTitle.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_title_color));
            this.mContent.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_content_color));
            this.mLeftBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_color_click_default), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mRightBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_dialog_un_select_btn_bg_color), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mLeftBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_select_btn_text_color));
            this.mRightBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_unselect_btn_text_color));
        }
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        hmiConfigChange();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        Log.i(this.TAG, this.TAG + " onSaveInstanceState");
        bundle.putString("hmiTitle", this.hmiTitle);
        bundle.putInt("hmiImageResource", this.hmiImageResource);
        bundle.putParcelable("hmiBitmap", this.hmiBitmap);
        bundle.putString("hmiContent", this.hmiContent);
        bundle.putString("hmiLeftBtnText", this.hmiLeftBtnText);
        bundle.putString("hmiRightBtnText", this.hmiRightBtnText);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewStateRestored(Bundle bundle) {
        super.onViewStateRestored(bundle);
        if (bundle == null) {
            Log.i(this.TAG, "onViewStateRestored: savedInstanceState is null");
            return;
        }
        this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
        this.hmiImageResource = bundle.getInt("hmiImageResource", this.hmiImageResource);
        this.hmiBitmap = (Bitmap) bundle.getParcelable("hmiBitmap");
        this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
        this.hmiLeftBtnText = bundle.getString("hmiLeftBtnText", this.hmiLeftBtnText);
        this.hmiRightBtnText = bundle.getString("hmiRightBtnText", this.hmiRightBtnText);
    }

    public HmiHasImageDoubleButtonDialog setHmiTitle(String str) {
        this.hmiTitle = str;
        return this;
    }

    public HmiHasImageDoubleButtonDialog setHmiImageResource(int i) {
        this.hmiImageResource = i;
        return this;
    }

    public HmiHasImageDoubleButtonDialog setHmiBitmap(Bitmap bitmap) {
        this.hmiBitmap = bitmap;
        return this;
    }

    public HmiHasImageDoubleButtonDialog setHmiContent(String str) {
        this.hmiContent = str;
        return this;
    }

    public HmiHasImageDoubleButtonDialog setHmiLeftBtnText(String str) {
        this.hmiLeftBtnText = str;
        return this;
    }

    public HmiHasImageDoubleButtonDialog setHmiRightBtnText(String str) {
        this.hmiRightBtnText = str;
        return this;
    }

    public HmiHasImageDoubleButtonDialog setHmiSelectListener(HmiSelectListener hmiSelectListener) {
        this.mHmiSelectListener = hmiSelectListener;
        return this;
    }
}
