package com.geely.toolchain.hmi.dialog;

import android.app.Dialog;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.listener.HmiOnClickListener;
import com.geely.toolchain.hmi.util.UiUtil;
import com.geely.toolchain.hmi.view.HmiButton;
import com.geely.toolchain.hmi.view.HmiImageView;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiMessageDialog extends Dialog {
    private static final String TAG = "HmiMessageDialog";
    private Bitmap bitmap;
    private String contentValue;
    private HmiButton mCancel;
    private OnClickMessageListener mClickMessageListener;
    private ConstraintLayout mConstraintLayout;
    private HmiTextView mContent;
    private int mDrawableId = -1;
    private HmiOnClickListener mHmiOnClickListener;
    private HmiImageView mImage;
    private HmiButton mLook;
    private HmiTextView mTitle;
    private String titleValue;
    private String tvCancel;
    private String tvLook;

    public interface OnClickMessageListener {
        void lookAction();
    }

    public HmiMessageDialog(Context context) {
        super(context, R.style.onesHmiMessageDialogStyle);
        Window window = getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        attributes.y = UiUtil.dp2px(context, context.getResources().getDimension(R.dimen.oneoshmi_dialog_meaage_top_magin));
        window.setAttributes(attributes);
        window.setGravity(48);
    }

    /* access modifiers changed from: protected */
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        setContentView(R.layout.hmi_message_dialog);
        Window window = getWindow();
        window.clearFlags(2);
        initView(window);
    }

    private void initView(Window window) {
        this.mLook = (HmiButton) window.findViewById(R.id.msg_bton_look);
        this.mCancel = (HmiButton) window.findViewById(R.id.msg_bton_cancel);
        this.mImage = (HmiImageView) window.findViewById(R.id.img_icon);
        this.mTitle = (HmiTextView) window.findViewById(R.id.tv_title);
        this.mContent = (HmiTextView) window.findViewById(R.id.tv_content);
        this.mConstraintLayout = (ConstraintLayout) window.findViewById(R.id.constraintlayout);
        this.mLook.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiMessageDialog$MPGaVJTMDJ218OiaG6LpZE_TE4 */

            public final void onClick(View view) {
                HmiMessageDialog.m11lambda$MPGaVJTMDJ218OiaG6LpZE_TE4(HmiMessageDialog.this, view);
            }
        });
        this.mCancel.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiMessageDialog$ddym8mlkBGpmT6RTFoFyWPkXfX0 */

            public final void onClick(View view) {
                HmiMessageDialog.this.lambda$initView$0$HmiMessageDialog(view);
            }
        });
        this.mTitle.setText(this.titleValue);
        this.mContent.setText(this.contentValue);
        this.mLook.setText(this.tvLook);
        this.mCancel.setText(this.tvCancel);
        this.mImage.setImageBitmap(this.bitmap);
    }

    public /* synthetic */ void lambda$initView$0$HmiMessageDialog(View view) {
        HmiOnClickListener hmiOnClickListener = this.mHmiOnClickListener;
        if (hmiOnClickListener != null) {
            hmiOnClickListener.cancelAction();
            return;
        }
        Log.i(TAG, "messageCancelListener is null");
        dismiss();
    }

    public HmiMessageDialog setLeftButtonText(String str) {
        this.tvLook = str;
        return this;
    }

    public HmiMessageDialog setRightButtonText(String str) {
        this.tvCancel = str;
        return this;
    }

    public HmiMessageDialog setTitlevalue(String str) {
        this.titleValue = str;
        return this;
    }

    public HmiMessageDialog setContent(String str) {
        this.contentValue = str;
        return this;
    }

    public HmiMessageDialog setImageById(int i) {
        this.mDrawableId = i;
        this.mImage.setImageResource(i);
        return this;
    }

    public HmiMessageDialog setImageByDrawable(Drawable drawable) {
        this.mImage.setImageDrawable(drawable);
        return this;
    }

    public HmiMessageDialog setImageBitmap(Bitmap bitmap2) {
        this.bitmap = bitmap2;
        return this;
    }

    public void hmiConfigChange() {
        this.mConstraintLayout.setBackground(ContextCompat.getDrawable(getContext(), R.drawable.oneoshmi_dialog_message_bg));
        this.mCancel.setBackground(ContextCompat.getDrawable(getContext(), R.drawable.oneoshmi_dialog_message_bt_bg));
        this.mCancel.setTextColor(ContextCompat.getColor(getContext(), R.color.oneoshmi_dialog_bg_message_canceltext_color));
        this.mLook.setBackground(ContextCompat.getDrawable(getContext(), R.drawable.oneoshmi_dialog_message_bt_bg));
        this.mLook.setTextColor(ContextCompat.getColor(getContext(), R.color.oneoshmi_main_theme_color));
        this.mTitle.setTextColor(ContextCompat.getColor(getContext(), R.color.oneoshmi_dialog_bg_message_title_color));
        this.mContent.setTextColor(ContextCompat.getColor(getContext(), R.color.oneoshmi_dialog_bg_message_content_color));
        Bitmap bitmap2 = this.bitmap;
        if (bitmap2 != null) {
            this.mImage.setImageBitmap(bitmap2);
        } else {
            Log.i(TAG, "bitmap == null");
        }
        int i = this.mDrawableId;
        if (i != -1) {
            this.mImage.setImageResource(i);
        } else {
            Log.i(TAG, "mDrawable == null");
        }
    }

    @Deprecated
    public HmiMessageDialog setOnClickMessageListener(Context context, OnClickMessageListener onClickMessageListener) {
        this.mClickMessageListener = onClickMessageListener;
        return this;
    }

    public HmiMessageDialog setOnClickMessageListener(HmiOnClickListener hmiOnClickListener) {
        this.mHmiOnClickListener = hmiOnClickListener;
        return this;
    }

    /* access modifiers changed from: private */
    public void onClick(View view) {
        OnClickMessageListener onClickMessageListener = this.mClickMessageListener;
        if (onClickMessageListener != null) {
            onClickMessageListener.lookAction();
            return;
        }
        HmiOnClickListener hmiOnClickListener = this.mHmiOnClickListener;
        if (hmiOnClickListener != null) {
            hmiOnClickListener.lookAction();
        } else {
            Log.e(TAG, "mClickMessageListener or mHmiOnClickListener  is null");
        }
    }
}
