package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.util.UiUtil;
import com.geely.toolchain.hmi.view.HmiImageView;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiResultDialog extends BaseDialog {
    private HmiImageView mCancel;
    private HmiImageView mResultIcon;
    private int mResultIconId;
    private String mResultText;
    private HmiTextView mResultTv;
    private ConstraintLayout mRootView;

    public HmiResultDialog(Context context) {
        super(context);
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public int setLayoutId() {
        return R.layout.hmi_result_dialog;
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        initView(getWindow());
        initData();
    }

    public void hmiConfigChange(Context context) {
        Log.d(TAG, "uiMode ====" + context.getResources().getConfiguration().uiMode);
        Log.i(TAG, "hmiConfigChange: context = " + context);
        boolean hmiCurrentModelIsDark = UiUtil.getHmiCurrentModelIsDark(context);
        Window window = getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        if (hmiCurrentModelIsDark) {
            attributes.dimAmount = 0.8f;
        } else {
            attributes.dimAmount = 0.4f;
        }
        window.setAttributes(attributes);
        this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
        this.mCancel.setImageResource(R.drawable.oneoshmi_close_pop_big);
        this.mResultTv.setTextColor(context.getColor(R.color.oneoshmi_dialog_title_color));
        this.mResultIcon.setImageResource(this.mResultIconId);
    }

    private void initView(Window window) {
        this.mCancel = (HmiImageView) window.findViewById(R.id.cancel);
        this.mResultTv = (HmiTextView) window.findViewById(R.id.result);
        this.mResultIcon = (HmiImageView) window.findViewById(R.id.resultIcon);
        this.mRootView = (ConstraintLayout) window.findViewById(R.id.rootView);
        this.mCancel.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiResultDialog$zIDJ9t3elf6bRY1ny3W0C8_XWRA */

            public final void onClick(View view) {
                HmiResultDialog.this.lambda$initView$0$HmiResultDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiResultDialog(View view) {
        dismiss();
    }

    private void initData() {
        this.mResultTv.setText(this.mResultText);
        this.mResultIcon.setImageResource(this.mResultIconId);
    }

    public HmiResultDialog setResultText(String str) {
        this.mResultText = str;
        return this;
    }

    public HmiResultDialog setResultIcon(int i) {
        this.mResultIconId = i;
        return this;
    }
}
