package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.RecyclerView;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiTextView;
import java.util.List;

public class HmiTabAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {
    private static final String TAG = "HmiTabAdapter";
    private final Context context;
    private int index = 0;
    private List<String> lists;
    private int maxSize = 5;
    private SelectionListener selectionListener;

    public interface SelectionListener {
        void selectTab(int i);
    }

    public HmiTabAdapter(Context context2) {
        this.context = context2;
    }

    public void setData(List<String> list) {
        this.lists = list;
    }

    public void setMaxSize(int i) {
        this.maxSize = i;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        return new HmiViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.hmi_tab_item, viewGroup, false));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i) {
        HmiViewHolder hmiViewHolder = (HmiViewHolder) viewHolder;
        hmiViewHolder.textView.setText(this.lists.get(i));
        hmiViewHolder.textView.setTextColor(this.context.getColor(R.color.oneoshmi_dialog_content_color));
        viewHolder.itemView.setOnClickListener(new View.OnClickListener(i) {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiTabAdapter$v47m6QG3PmRNlqjg7yuLda0gH1c */
            public final /* synthetic */ int f$1;

            {
                this.f$1 = r2;
            }

            public final void onClick(View view) {
                HmiTabAdapter.this.lambda$onBindViewHolder$0$HmiTabAdapter(this.f$1, view);
            }
        });
        if (this.index == i) {
            hmiViewHolder.view.setVisibility(0);
            hmiViewHolder.view.setBackground(ContextCompat.getDrawable(this.context, R.drawable.oneoshmi_tab_item_indicator_shape));
            hmiViewHolder.textView.setTextColor(this.context.getColor(R.color.oneoshmi_main_theme_color));
            hmiViewHolder.textView.setTextSize(2, 36.0f);
            SelectionListener selectionListener2 = this.selectionListener;
            if (selectionListener2 != null) {
                selectionListener2.selectTab(i);
            } else {
                Log.e(TAG, "selectionListener is null");
            }
        } else {
            hmiViewHolder.view.setVisibility(8);
            hmiViewHolder.view.setBackground(ContextCompat.getDrawable(this.context, R.drawable.oneoshmi_tab_item_indicator_shape));
            hmiViewHolder.textView.setTextColor(this.context.getColor(R.color.oneoshmi_dialog_content_color));
            hmiViewHolder.textView.setTextSize(2, 32.0f);
        }
    }

    public /* synthetic */ void lambda$onBindViewHolder$0$HmiTabAdapter(int i, View view) {
        this.index = i;
        notifyDataSetChanged();
        SelectionListener selectionListener2 = this.selectionListener;
        if (selectionListener2 != null) {
            selectionListener2.selectTab(i);
        } else {
            Log.e(TAG, "selectionListener is null");
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        return Math.min(this.lists.size(), this.maxSize);
    }

    public void setSelectionListener(SelectionListener selectionListener2) {
        this.selectionListener = selectionListener2;
    }

    private static class HmiViewHolder extends RecyclerView.ViewHolder {
        public HmiTextView textView;
        public View view;

        public HmiViewHolder(View view2) {
            super(view2);
            this.textView = (HmiTextView) view2.findViewById(R.id.tabItemText);
            this.view = view2.findViewById(R.id.tabItemIndicator);
        }
    }
}
