package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.RecyclerView;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.dialog.HmiTabAdapter;
import com.geely.toolchain.hmi.util.UiUtil;
import com.geely.toolchain.hmi.view.HmiDialogDampScrollView;
import com.geely.toolchain.hmi.view.HmiImageView;
import com.geely.toolchain.hmi.view.HmiTextView;
import java.util.List;
import java.util.Objects;

public class HmiTabDialog extends BaseDialog {
    private static final String TAG = "HmiTabDialog";
    private int indexTag = -1;
    private HmiImageView mClose;
    private ConstraintLayout mRootView;
    private HmiDialogDampScrollView mScrollView;
    private RecyclerView mTabRecyclerView;
    private HmiTextView mTitle;
    private String mTitleText = "";
    private int maxSize = 5;
    private SelectionListener selectionListener;
    private List<String> tabs;

    public interface SelectionListener {
        void selectTab(int i, HmiDialogDampScrollView hmiDialogDampScrollView);
    }

    public HmiTabDialog(Context context) {
        super(context);
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public int setLayoutId() {
        return R.layout.hmi_tab_dialog;
    }

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseDialog
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        initView(getWindow());
        initData();
    }

    public void hmiConfigChange(Context context) {
        Log.d(TAG, "uiMode ====" + context.getResources().getConfiguration().uiMode);
        Log.i(TAG, "hmiConfigChange: context = " + context);
        boolean hmiCurrentModelIsDark = UiUtil.getHmiCurrentModelIsDark(context);
        Window window = getWindow();
        WindowManager.LayoutParams attributes = window.getAttributes();
        if (hmiCurrentModelIsDark) {
            attributes.dimAmount = 0.8f;
        } else {
            attributes.dimAmount = 0.4f;
        }
        window.setAttributes(attributes);
        this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
        this.mTitle.setTextColor(context.getColor(R.color.oneoshmi_dialog_not_title_content_color));
        this.mClose.setImageResource(R.drawable.oneoshmi_close_pop_big);
        if (this.mTitleText.isEmpty()) {
            ((RecyclerView.Adapter) Objects.requireNonNull(this.mTabRecyclerView.getAdapter())).notifyDataSetChanged();
        }
    }

    private void initView(Window window) {
        this.mTabRecyclerView = (RecyclerView) window.findViewById(R.id.tabRecyclerView);
        this.mClose = (HmiImageView) window.findViewById(R.id.close);
        this.mScrollView = (HmiDialogDampScrollView) window.findViewById(R.id.scrollView);
        this.mTitle = (HmiTextView) window.findViewById(R.id.title);
        this.mRootView = (ConstraintLayout) window.findViewById(R.id.rootView);
        this.mClose.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiTabDialog$sQCStFTQaxuS8tprXBmdJyHyq4c */

            public final void onClick(View view) {
                HmiTabDialog.this.lambda$initView$0$HmiTabDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiTabDialog(View view) {
        dismiss();
    }

    private void initData() {
        if (this.mTitleText.isEmpty()) {
            this.mTitle.setVisibility(8);
            this.mScrollView.setVisibility(0);
            HmiTabAdapter hmiTabAdapter = new HmiTabAdapter(getContext());
            hmiTabAdapter.setMaxSize(this.maxSize);
            hmiTabAdapter.setData(this.tabs);
            this.mTabRecyclerView.setAdapter(hmiTabAdapter);
            hmiTabAdapter.setSelectionListener(new HmiTabAdapter.SelectionListener() {
                /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiTabDialog$_NVC7SG8l2FV5iSPFjvicOFO0ew */

                @Override // com.geely.toolchain.hmi.dialog.HmiTabAdapter.SelectionListener
                public final void selectTab(int i) {
                    HmiTabDialog.this.lambda$initData$1$HmiTabDialog(i);
                }
            });
            return;
        }
        this.mScrollView.setVisibility(8);
        this.mTitle.setVisibility(0);
        this.mTitle.setText(this.mTitleText);
    }

    public /* synthetic */ void lambda$initData$1$HmiTabDialog(int i) {
        if (this.indexTag != i) {
            SelectionListener selectionListener2 = this.selectionListener;
            if (selectionListener2 != null) {
                this.indexTag = i;
                selectionListener2.selectTab(i, this.mScrollView);
                return;
            }
            Log.e(TAG, "selectionListener is null");
        }
    }

    public HmiTabDialog setHmiTabs(List<String> list) {
        this.tabs = list;
        return this;
    }

    public HmiTabDialog setTitle(String str) {
        this.mTitleText = str;
        return this;
    }

    public HmiTabDialog setSelectionListener(SelectionListener selectionListener2) {
        this.selectionListener = selectionListener2;
        return this;
    }
}
