package com.geely.toolchain.hmi.dialog;

import android.content.Context;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;
import androidx.core.content.ContextCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiStateButton;
import com.geely.toolchain.hmi.view.HmiTextView;

public class HmiWarnDialog extends BaseHmiDialogFragment {
    private String hmiContent;
    private String hmiLeftBtnText;
    private String hmiRightBtnText;
    private String hmiTitle;
    private HmiTextView mContent;
    private HmiSelectListener mHmiSelectListener;
    private HmiStateButton mLeftBtn;
    private HmiStateButton mRightBtn;
    private FrameLayout mRootView;
    private HmiTextView mTitle;

    /* access modifiers changed from: protected */
    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment
    public int setLayoutId() {
        return R.layout.hmi_warn_dialog;
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        super.onViewCreated(view, bundle);
        if (bundle != null) {
            this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
            this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
            this.hmiLeftBtnText = bundle.getString("hmiLeftBtnText", this.hmiLeftBtnText);
            this.hmiRightBtnText = bundle.getString("hmiRightBtnText", this.hmiRightBtnText);
        }
        initView(view);
        initData();
    }

    private void initView(View view) {
        this.mTitle = (HmiTextView) view.findViewById(R.id.title);
        this.mContent = (HmiTextView) view.findViewById(R.id.content);
        this.mLeftBtn = (HmiStateButton) view.findViewById(R.id.leftBtn);
        this.mRightBtn = (HmiStateButton) view.findViewById(R.id.rightBtn);
        this.mRootView = (FrameLayout) view.findViewById(R.id.rootView);
        this.mLeftBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiWarnDialog$qcuqshgSxDzZMLCOl9ag6IGzBOA */

            public final void onClick(View view) {
                HmiWarnDialog.this.lambda$initView$0$HmiWarnDialog(view);
            }
        });
        this.mRightBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.dialog.$$Lambda$HmiWarnDialog$v_10rAZ4m4n4MMWlXFwdrBVHv5s */

            public final void onClick(View view) {
                HmiWarnDialog.this.lambda$initView$1$HmiWarnDialog(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$HmiWarnDialog(View view) {
        HmiSelectListener hmiSelectListener = this.mHmiSelectListener;
        if (hmiSelectListener != null) {
            hmiSelectListener.leftAction(this);
        } else {
            Log.i(this.TAG, "leftAction mHmiSelectListener is null");
        }
    }

    public /* synthetic */ void lambda$initView$1$HmiWarnDialog(View view) {
        HmiSelectListener hmiSelectListener = this.mHmiSelectListener;
        if (hmiSelectListener != null) {
            hmiSelectListener.rightAction(this);
        } else {
            Log.i(this.TAG, "rightAction mHmiSelectListener is null");
        }
    }

    private void initData() {
        this.mTitle.setText(this.hmiTitle);
        this.mContent.setText(this.hmiContent);
        this.mLeftBtn.setText(this.hmiLeftBtnText);
        this.mRightBtn.setText(this.hmiRightBtnText);
    }

    private void hmiConfigChange() {
        Context context = getContext();
        if (context != null) {
            this.mRootView.setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_dialog_bg));
            this.mTitle.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_title_color));
            this.mContent.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_content_color));
            this.mLeftBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_warning_btn_default), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mRightBtn.setBtnColorAndRadius(ContextCompat.getColor(context, R.color.oneoshmi_dialog_un_select_btn_bg_color), context.getResources().getDimension(R.dimen.oneoshmi_common_radius_small));
            this.mLeftBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_select_btn_text_color));
            this.mRightBtn.setTextColor(ContextCompat.getColor(context, R.color.oneoshmi_dialog_unselect_btn_text_color));
        }
    }

    @Override // com.geely.toolchain.hmi.dialog.BaseHmiDialogFragment, androidx.fragment.app.Fragment
    public void onConfigurationChanged(Configuration configuration) {
        super.onConfigurationChanged(configuration);
        hmiConfigChange();
    }

    @Override // androidx.fragment.app.Fragment, androidx.fragment.app.DialogFragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        Log.i(this.TAG, this.TAG + " onSaveInstanceState");
        bundle.putString("hmiTitle", this.hmiTitle);
        bundle.putString("hmiContent", this.hmiContent);
        bundle.putString("hmiLeftBtnText", this.hmiLeftBtnText);
        bundle.putString("hmiRightBtnText", this.hmiRightBtnText);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewStateRestored(Bundle bundle) {
        super.onViewStateRestored(bundle);
        if (bundle == null) {
            Log.i(this.TAG, "onViewStateRestored: savedInstanceState is null");
            return;
        }
        this.hmiTitle = bundle.getString("hmiTitle", this.hmiTitle);
        this.hmiContent = bundle.getString("hmiContent", this.hmiContent);
        this.hmiLeftBtnText = bundle.getString("hmiLeftBtnText", this.hmiLeftBtnText);
        this.hmiRightBtnText = bundle.getString("hmiRightBtnText", this.hmiRightBtnText);
    }

    public HmiWarnDialog setHmiTitle(String str) {
        this.hmiTitle = str;
        return this;
    }

    public HmiWarnDialog setHmiContent(String str) {
        this.hmiContent = str;
        return this;
    }

    public HmiWarnDialog setHmiLeftBtnText(String str) {
        this.hmiLeftBtnText = str;
        return this;
    }

    public HmiWarnDialog setHmiRightBtnText(String str) {
        this.hmiRightBtnText = str;
        return this;
    }

    public HmiWarnDialog setHmiSelectListener(HmiSelectListener hmiSelectListener) {
        this.mHmiSelectListener = hmiSelectListener;
        return this;
    }
}
