package com.geely.toolchain.hmi.search;

import android.content.Context;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Parcel;
import android.os.Parcelable;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.AttributeSet;
import android.util.Log;
import android.view.AbsSavedState;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.inputmethod.InputMethodManager;
import android.widget.ImageButton;
import android.widget.TextView;
import androidx.appcompat.widget.TintTypedArray;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.core.content.ContextCompat;
import androidx.core.view.ViewCompat;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiImageView;

public class HmiSearchView extends ConstraintLayout {
    private static final int SDK_INT = 29;
    private static final String TAG = "HmiSearchView";
    private final FocusEditText mFocusEditText;
    private OnFocusChangeListener mFocusListener;
    private CharSequence mOldQueryText;
    private OnQueryTextListener mQueryListener;
    private final ImageButton mSearchViewClearButton;
    private CharSequence mUserQuery;
    private final HmiImageView mVoiceImageView;

    public interface OnFocusChangeListener {
        void onFocusChange(boolean z);
    }

    public interface OnQueryTextListener {
        void onQueryTextChange(CharSequence charSequence);

        void onQueryTextSubmit(CharSequence charSequence);
    }

    public void addView(View view) {
    }

    public HmiSearchView(Context context) {
        this(context, null);
    }

    public HmiSearchView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public HmiSearchView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.mFocusListener = null;
        this.mQueryListener = null;
        TintTypedArray obtainStyledAttributes = TintTypedArray.obtainStyledAttributes(context, attributeSet, R.styleable.HMISearchView, i, 0);
        ViewCompat.saveAttributeDataForStyleable(this, context, R.styleable.HMISearchView, attributeSet, obtainStyledAttributes.getWrappedTypeArray(), i, 0);
        LayoutInflater.from(context).inflate(obtainStyledAttributes.getResourceId(R.styleable.HMISearchView_layout, R.layout.hmi_search_view), (ViewGroup) this, true);
        HmiImageView hmiImageView = (HmiImageView) findViewById(R.id.search_iv_icon);
        HmiImageView hmiImageView2 = (HmiImageView) findViewById(R.id.voice_iv_icon);
        this.mVoiceImageView = hmiImageView2;
        FocusEditText focusEditText = (FocusEditText) findViewById(R.id.search_view_edit_text);
        this.mFocusEditText = focusEditText;
        focusEditText.addTextChangedListener(new TextWatcher() {
            /* class com.geely.toolchain.hmi.search.HmiSearchView.AnonymousClass1 */

            public void afterTextChanged(Editable editable) {
            }

            public void beforeTextChanged(CharSequence charSequence, int i, int i2, int i3) {
            }

            public void onTextChanged(CharSequence charSequence, int i, int i2, int i3) {
                HmiSearchView.this.onTextChanged(charSequence);
            }
        });
        focusEditText.setOnEditorActionListener(new TextView.OnEditorActionListener() {
            /* class com.geely.toolchain.hmi.search.HmiSearchView.AnonymousClass2 */

            public boolean onEditorAction(TextView textView, int i, KeyEvent keyEvent) {
                if (i != 3) {
                    return false;
                }
                HmiSearchView.this.onSubmitQuery();
                return true;
            }
        });
        focusEditText.setOnFocusChangeListener(new View.OnFocusChangeListener() {
            /* class com.geely.toolchain.hmi.search.HmiSearchView.AnonymousClass3 */

            public void onFocusChange(View view, boolean z) {
                if (HmiSearchView.this.mFocusListener != null) {
                    HmiSearchView.this.mFocusListener.onFocusChange(z);
                } else {
                    Log.i(HmiSearchView.TAG, "mFocusListener is null");
                }
            }
        });
        focusEditText.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.search.HmiSearchView.AnonymousClass4 */

            public void onClick(View view) {
                HmiSearchView.this.setFocusMode(true);
                HmiSearchView.this.showKeyboard();
            }
        });
        ImageButton imageButton = (ImageButton) findViewById(R.id.search_view_clear_button);
        this.mSearchViewClearButton = imageButton;
        imageButton.setOnClickListener(new View.OnClickListener() {
            /* class com.geely.toolchain.hmi.search.HmiSearchView.AnonymousClass5 */

            public void onClick(View view) {
                HmiSearchView.this.setTextClearOnClearFocus(true);
                HmiSearchView.this.mFocusEditText.clearFocus();
            }
        });
        if (obtainStyledAttributes.hasValue(R.styleable.HMISearchView_search_clearIcon)) {
            setClearIcon(ContextCompat.getDrawable(context, R.drawable.oneoshmi_search_close_icon));
        }
        imageButton.setVisibility(8);
        if (obtainStyledAttributes.hasValue(R.styleable.HMISearchView_android_hint)) {
            setHint(obtainStyledAttributes.getString(R.styleable.HMISearchView_android_hint));
        }
        int i2 = obtainStyledAttributes.getInt(R.styleable.HMISearchView_android_imeOptions, -1);
        if (i2 != -1) {
            setImeOptions(i2);
        }
        int i3 = obtainStyledAttributes.getInt(R.styleable.HMISearchView_android_inputType, -1);
        if (i3 != -1) {
            setInputType(i3);
        }
        if (obtainStyledAttributes.getBoolean(R.styleable.HMISearchView_backgroundDefault, false)) {
            setBackground(ContextCompat.getDrawable(context, R.drawable.oneoshmi_search_bg));
        }
        if (obtainStyledAttributes.hasValue(R.styleable.HMISearchView_searchIcon)) {
            hmiImageView.setImageDrawable(ContextCompat.getDrawable(context, obtainStyledAttributes.getResourceId(R.styleable.HMISearchView_searchIcon, 0)));
        }
        if (obtainStyledAttributes.getBoolean(R.styleable.HMISearchView_voiceIconGone, false)) {
            hmiImageView2.setVisibility(8);
        }
        obtainStyledAttributes.recycle();
    }

    public HmiImageView getVoiceImageView() {
        return this.mVoiceImageView;
    }

    public void setBackgroundColor(int i) {
        this.mFocusEditText.setBackgroundColor(i);
    }

    public boolean requestFocus(int i, Rect rect) {
        return this.mFocusEditText.requestFocus(i, rect);
    }

    public void clearFocus() {
        this.mFocusEditText.clearFocus();
    }

    public void setFocusMode(boolean z) {
        this.mFocusEditText.setFocusable(z);
        this.mFocusEditText.setFocusableInTouchMode(z);
        this.mFocusEditText.requestFocus();
    }

    public void setClearIcon(Drawable drawable) {
        this.mSearchViewClearButton.setImageDrawable(drawable);
    }

    public void setImeOptions(int i) {
        this.mFocusEditText.setImeOptions(i);
    }

    public void setInputType(int i) {
        this.mFocusEditText.setInputType(i);
    }

    public void setTextClearOnBackPressed(boolean z) {
        this.mFocusEditText.setTextClearOnBackPressed(z);
    }

    public void setTextClearOnClearFocus(boolean z) {
        this.mFocusEditText.setTextClearOnClearFocus(z);
    }

    public CharSequence getTextQuery() {
        return this.mFocusEditText.getText();
    }

    public void setTextQuery(CharSequence charSequence, boolean z) {
        this.mFocusEditText.setText(charSequence);
        if (charSequence != null) {
            FocusEditText focusEditText = this.mFocusEditText;
            focusEditText.setSelection(focusEditText.length());
            this.mUserQuery = charSequence;
        }
        if (z && !TextUtils.isEmpty(charSequence)) {
            onSubmitQuery();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onSubmitQuery() {
        Editable text = this.mFocusEditText.getText();
        if (this.mQueryListener == null) {
            Log.i(TAG, "mQueryListener is null!");
        } else if (text == null || TextUtils.getTrimmedLength(text) <= 0) {
            Log.i(TAG, "query is null! or query lenth < 0");
        } else {
            this.mQueryListener.onQueryTextSubmit(text.toString());
            setFocusMode(false);
            hideKeyboard();
            this.mFocusEditText.getText().clear();
        }
    }

    public void setTextTypeface(Typeface typeface) {
        this.mFocusEditText.setTypeface(typeface);
    }

    public void setHint(CharSequence charSequence) {
        this.mFocusEditText.setHint(charSequence);
    }

    public void setTextHintColor(int i) {
        this.mFocusEditText.setHintTextColor(i);
    }

    public void setTextColor(int i) {
        this.mFocusEditText.setTextColor(i);
    }

    public void setOnFocusChangeListener(OnFocusChangeListener onFocusChangeListener) {
        this.mFocusListener = onFocusChangeListener;
    }

    public void setOnQueryTextListener(OnQueryTextListener onQueryTextListener) {
        this.mQueryListener = onQueryTextListener;
    }

    public void showKeyboard() {
        if (!isInEditMode()) {
            ((InputMethodManager) getContext().getSystemService("input_method")).showSoftInput(this.mFocusEditText, 0);
        }
    }

    public void hideKeyboard() {
        if (!isInEditMode()) {
            ((InputMethodManager) getContext().getSystemService("input_method")).hideSoftInputFromWindow(this.mFocusEditText.getWindowToken(), 0);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onTextChanged(CharSequence charSequence) {
        if (!TextUtils.isEmpty(charSequence)) {
            this.mSearchViewClearButton.setVisibility(0);
        } else {
            this.mSearchViewClearButton.setVisibility(8);
        }
        this.mUserQuery = this.mFocusEditText.getText();
        if (this.mQueryListener != null && !TextUtils.equals(charSequence, this.mOldQueryText)) {
            this.mQueryListener.onQueryTextChange(charSequence.toString());
        }
        this.mOldQueryText = charSequence.toString();
    }

    /* access modifiers changed from: protected */
    public Parcelable onSaveInstanceState() {
        Parcelable onSaveInstanceState = super.onSaveInstanceState();
        if (onSaveInstanceState == null) {
            return super.onSaveInstanceState();
        }
        SavedState savedState = new SavedState(onSaveInstanceState);
        savedState.text = getTextQuery().toString();
        savedState.focus = this.mFocusEditText.hasFocus();
        return savedState;
    }

    /* access modifiers changed from: protected */
    public void onRestoreInstanceState(Parcelable parcelable) {
        if (parcelable instanceof SavedState) {
            SavedState savedState = (SavedState) parcelable;
            super.onRestoreInstanceState(savedState.getSuperState());
            setTextQuery(savedState.text, false);
            if (savedState.focus) {
                this.mFocusEditText.requestFocus();
                return;
            }
            return;
        }
        super.onRestoreInstanceState(parcelable);
    }

    /* access modifiers changed from: private */
    public static class SavedState extends AbsSavedState {
        private Parcelable.ClassLoaderCreator<SavedState> cReator;
        Parcelable.ClassLoaderCreator<SavedState> creator;
        boolean focus;
        String text;

        protected SavedState(Parcelable parcelable) {
            super(parcelable);
            this.focus = false;
            this.cReator = new Parcelable.ClassLoaderCreator<SavedState>() {
                /* class com.geely.toolchain.hmi.search.HmiSearchView.SavedState.AnonymousClass1 */

                @Override // android.os.Parcelable.ClassLoaderCreator
                public SavedState createFromParcel(Parcel parcel, ClassLoader classLoader) {
                    return new SavedState(parcel, classLoader);
                }

                @Override // android.os.Parcelable.Creator
                public SavedState createFromParcel(Parcel parcel) {
                    return new SavedState(parcel, null);
                }

                @Override // android.os.Parcelable.Creator
                public SavedState[] newArray(int i) {
                    return new SavedState[i];
                }
            };
        }

        protected SavedState(Parcel parcel, ClassLoader classLoader) {
            super(parcel, classLoader);
            boolean z = false;
            this.focus = false;
            AnonymousClass1 r0 = new Parcelable.ClassLoaderCreator<SavedState>() {
                /* class com.geely.toolchain.hmi.search.HmiSearchView.SavedState.AnonymousClass1 */

                @Override // android.os.Parcelable.ClassLoaderCreator
                public SavedState createFromParcel(Parcel parcel, ClassLoader classLoader) {
                    return new SavedState(parcel, classLoader);
                }

                @Override // android.os.Parcelable.Creator
                public SavedState createFromParcel(Parcel parcel) {
                    return new SavedState(parcel, null);
                }

                @Override // android.os.Parcelable.Creator
                public SavedState[] newArray(int i) {
                    return new SavedState[i];
                }
            };
            this.cReator = r0;
            this.creator = r0;
            this.text = parcel.readString();
            if (Build.VERSION.SDK_INT >= 29) {
                this.focus = parcel.readBoolean();
            } else {
                this.focus = parcel.readInt() == 1 ? true : z;
            }
        }

        public void writeToParcel(Parcel parcel, int i) {
            super.writeToParcel(parcel, i);
            parcel.writeString(this.text);
            if (Build.VERSION.SDK_INT >= 29) {
                parcel.writeBoolean(this.focus);
            } else {
                parcel.writeInt(this.focus ? 1 : 0);
            }
        }
    }
}
