package com.geely.toolchain.hmi.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import com.geely.toolchain.hmi.R;

public class HmiDialogDampScrollView extends HmiDampScrollView {
    private static final String TAG = "HmiDialogDampScrollView";
    private boolean isScrolledToBottom;
    private boolean isScrolledToTop;
    private int mMaxHeight;
    private ISmartScrollChangedListener mSmartScrollChangedListener;
    public ScrollViewListener scrollViewListener;

    public interface ISmartScrollChangedListener {
        void onBottom();

        void onMiddle();

        void onTop();
    }

    public interface ScrollViewListener {
        void onScrollChanged(HmiDialogDampScrollView hmiDialogDampScrollView, int i, int i2, int i3, int i4);
    }

    public HmiDialogDampScrollView(Context context) {
        this(context, null);
    }

    public HmiDialogDampScrollView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.isScrolledToTop = true;
        this.isScrolledToBottom = false;
        this.scrollViewListener = null;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.HmiDialogDampScrollView);
        this.mMaxHeight = (int) obtainStyledAttributes.getDimension(R.styleable.HmiDialogDampScrollView_hmiMaxHeight, 0.0f);
        obtainStyledAttributes.recycle();
    }

    public void setScanScrollChangedListener(ISmartScrollChangedListener iSmartScrollChangedListener) {
        this.mSmartScrollChangedListener = iSmartScrollChangedListener;
    }

    /* access modifiers changed from: protected */
    @Override // androidx.core.widget.NestedScrollView
    public void onOverScrolled(int i, int i2, boolean z, boolean z2) {
        super.onOverScrolled(i, i2, z, z2);
        if (i2 == 0) {
            this.isScrolledToTop = z2;
            this.isScrolledToBottom = false;
            Log.i(TAG, "onOverScrolled isScrolledToTop:" + this.isScrolledToTop);
        } else {
            this.isScrolledToTop = false;
            this.isScrolledToBottom = z2;
            Log.i(TAG, "onOverScrolled isScrolledToBottom:" + this.isScrolledToBottom);
        }
        notifyScrollChangedListeners();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.core.widget.NestedScrollView
    public void onScrollChanged(int i, int i2, int i3, int i4) {
        super.onScrollChanged(i, i2, i3, i4);
        ScrollViewListener scrollViewListener2 = this.scrollViewListener;
        if (scrollViewListener2 != null) {
            scrollViewListener2.onScrollChanged(this, i, i2, i3, i4);
        }
        if (Build.VERSION.SDK_INT < 9) {
            if (getScrollY() == 0) {
                this.isScrolledToTop = true;
                this.isScrolledToBottom = false;
                Log.i(TAG, "onScrollChanged isScrolledToTop:" + this.isScrolledToTop);
            } else if (((getScrollY() + getHeight()) - getPaddingTop()) - getPaddingBottom() == getChildAt(0).getHeight()) {
                this.isScrolledToBottom = true;
                this.isScrolledToTop = false;
                Log.i(TAG, "onScrollChanged isScrolledToBottom:" + this.isScrolledToBottom);
            } else {
                this.isScrolledToTop = false;
                this.isScrolledToBottom = false;
            }
            notifyScrollChangedListeners();
        }
    }

    private void notifyScrollChangedListeners() {
        if (this.isScrolledToTop) {
            ISmartScrollChangedListener iSmartScrollChangedListener = this.mSmartScrollChangedListener;
            if (iSmartScrollChangedListener != null) {
                iSmartScrollChangedListener.onTop();
            }
        } else if (this.isScrolledToBottom) {
            ISmartScrollChangedListener iSmartScrollChangedListener2 = this.mSmartScrollChangedListener;
            if (iSmartScrollChangedListener2 != null) {
                iSmartScrollChangedListener2.onBottom();
            }
        } else {
            ISmartScrollChangedListener iSmartScrollChangedListener3 = this.mSmartScrollChangedListener;
            if (iSmartScrollChangedListener3 != null) {
                iSmartScrollChangedListener3.onMiddle();
            }
        }
    }

    public boolean isScrolledToTop() {
        return this.isScrolledToTop;
    }

    public boolean isScrolledToBottom() {
        return this.isScrolledToBottom;
    }

    /* access modifiers changed from: protected */
    @Override // androidx.core.widget.NestedScrollView
    public void onMeasure(int i, int i2) {
        super.onMeasure(i, View.MeasureSpec.makeMeasureSpec(this.mMaxHeight, Integer.MIN_VALUE));
    }

    public void setHmiMaxHeight(int i) {
        this.mMaxHeight = i;
    }

    public int getHmiMaxHeight() {
        return this.mMaxHeight;
    }

    public void setScrollViewListener(ScrollViewListener scrollViewListener2) {
        this.scrollViewListener = scrollViewListener2;
    }
}
