package com.geely.toolchain.hmi.view;

import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.RectF;
import android.graphics.Shader;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.View;
import androidx.appcompat.widget.AppCompatTextView;
import com.geely.toolchain.hmi.R;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Iterator;

public class HmiDownloadProgressButton extends AppCompatTextView {
    public static final float SCALE = 1.0f;
    public static final int STATE_DOWNLOADING = 1;
    public static final int STATE_FINISH = 3;
    public static final int STATE_NORMAL = 0;
    public static final int STATE_PAUSE = 2;
    public static final int STYLE_BALL_JUMP = 2;
    public static final int STYLE_BALL_PULSE = 1;
    private ArrayList<ValueAnimator> mAnimators;
    private RectF mBackgroundBounds;
    private int mBackgroundColor;
    private Paint mBackgroundPaint;
    private int mBackgroundSecondColor;
    private final float mBallRadius;
    private final float mBallSpacing;
    private int mBallStyle;
    private float mBorderWidth;
    private float mButtonRadius;
    private CharSequence mCurrentText;
    private int mMaxProgress;
    private int mMinProgress;
    private float mProgress;
    private ValueAnimator mProgressAnimation;
    private float mProgressPercent;
    private int mState;
    private float mTextBottomBorder;
    private int mTextColor;
    private int mTextCoverColor;
    private volatile Paint mTextPaint;
    private float mTextRightBorder;
    private float mToProgress;
    private final float[] scaleFloats;
    private boolean showBorder;
    private final float[] translateYFloats;

    public HmiDownloadProgressButton(Context context) {
        this(context, null);
    }

    public HmiDownloadProgressButton(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public HmiDownloadProgressButton(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.mBallStyle = 2;
        this.mProgress = -1.0f;
        this.mBallSpacing = 4.0f;
        this.mBallRadius = 6.0f;
        this.scaleFloats = new float[]{1.0f, 1.0f, 1.0f};
        this.translateYFloats = new float[3];
        if (!isInEditMode()) {
            initAttrs(context, attributeSet);
            init();
            setupAnimations();
        }
    }

    private void initAttrs(Context context, AttributeSet attributeSet) {
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.HmiDownloadProgressButton);
            try {
                this.mBackgroundColor = obtainStyledAttributes.getColor(R.styleable.HmiDownloadProgressButton_progress_btn_background_color, Color.parseColor("#3385FF"));
                this.mBackgroundSecondColor = obtainStyledAttributes.getColor(R.styleable.HmiDownloadProgressButton_progress_btn_background_second_color, Color.parseColor("#E8E8E8"));
                this.mButtonRadius = obtainStyledAttributes.getDimension(R.styleable.HmiDownloadProgressButton_progress_btn_radius, 0.0f);
                this.mTextColor = obtainStyledAttributes.getColor(R.styleable.HmiDownloadProgressButton_progress_btn_text_color, this.mBackgroundColor);
                this.mTextCoverColor = obtainStyledAttributes.getColor(R.styleable.HmiDownloadProgressButton_progress_btn_text_cover_color, -1);
                this.mBorderWidth = obtainStyledAttributes.getDimension(R.styleable.HmiDownloadProgressButton_progress_btn_border_width, (float) dp2px(2));
                this.mBallStyle = obtainStyledAttributes.getInt(R.styleable.HmiDownloadProgressButton_progress_btn_ball_style, 2);
            } finally {
                obtainStyledAttributes.recycle();
            }
        }
    }

    private void init() {
        this.mMaxProgress = 100;
        this.mMinProgress = 0;
        this.mProgress = 0.0f;
        this.showBorder = true;
        this.mBackgroundBounds = new RectF();
        Paint paint = new Paint();
        this.mBackgroundPaint = paint;
        paint.setAntiAlias(true);
        this.mBackgroundPaint.setStyle(Paint.Style.FILL);
        this.mTextPaint = new Paint();
        this.mTextPaint.setAntiAlias(true);
        this.mTextPaint.setTextSize(50.0f);
        setLayerType(1, this.mTextPaint);
        this.mState = 0;
        invalidate();
    }

    private void setupAnimations() {
        ValueAnimator duration = ValueAnimator.ofFloat(0.0f, 1.0f).setDuration(500L);
        this.mProgressAnimation = duration;
        duration.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.geely.toolchain.hmi.view.HmiDownloadProgressButton.AnonymousClass1 */

            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                HmiDownloadProgressButton hmiDownloadProgressButton = HmiDownloadProgressButton.this;
                hmiDownloadProgressButton.mProgress = ((hmiDownloadProgressButton.mToProgress - HmiDownloadProgressButton.this.mProgress) * floatValue) + HmiDownloadProgressButton.this.mProgress;
                HmiDownloadProgressButton.this.invalidate();
            }
        });
        setBallStyle(this.mBallStyle);
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (!isInEditMode()) {
            drawing(canvas);
        }
    }

    private void drawing(Canvas canvas) {
        drawBackground(canvas);
        drawTextAbove(canvas);
    }

    private void drawBackground(Canvas canvas) {
        this.mBackgroundBounds.left = this.showBorder ? this.mBorderWidth : 0.0f;
        this.mBackgroundBounds.top = this.showBorder ? this.mBorderWidth : 0.0f;
        this.mBackgroundBounds.right = ((float) getMeasuredWidth()) - (this.showBorder ? this.mBorderWidth : 0.0f);
        this.mBackgroundBounds.bottom = ((float) getMeasuredHeight()) - (this.showBorder ? this.mBorderWidth : 0.0f);
        if (this.showBorder) {
            this.mBackgroundPaint.setStyle(Paint.Style.STROKE);
            this.mBackgroundPaint.setColor(this.mBackgroundColor);
            this.mBackgroundPaint.setStrokeWidth(this.mBorderWidth);
            RectF rectF = this.mBackgroundBounds;
            float f = this.mButtonRadius;
            canvas.drawRoundRect(rectF, f, f, this.mBackgroundPaint);
        }
        this.mBackgroundPaint.setStyle(Paint.Style.FILL);
        int i = this.mState;
        if (i == 0) {
            this.mBackgroundPaint.setColor(this.mBackgroundColor);
            RectF rectF2 = this.mBackgroundBounds;
            float f2 = this.mButtonRadius;
            canvas.drawRoundRect(rectF2, f2, f2, this.mBackgroundPaint);
        } else if (i == 1 || i == 2) {
            this.mProgressPercent = this.mProgress / (((float) this.mMaxProgress) + 0.0f);
            this.mBackgroundPaint.setColor(this.mBackgroundSecondColor);
            canvas.save();
            RectF rectF3 = this.mBackgroundBounds;
            float f3 = this.mButtonRadius;
            canvas.drawRoundRect(rectF3, f3, f3, this.mBackgroundPaint);
            PorterDuffXfermode porterDuffXfermode = new PorterDuffXfermode(PorterDuff.Mode.SRC_ATOP);
            this.mBackgroundPaint.setColor(this.mBackgroundColor);
            this.mBackgroundPaint.setXfermode(porterDuffXfermode);
            canvas.drawRect(this.mBackgroundBounds.left, this.mBackgroundBounds.top, this.mBackgroundBounds.right * this.mProgressPercent, this.mBackgroundBounds.bottom, this.mBackgroundPaint);
            canvas.restore();
            this.mBackgroundPaint.setXfermode(null);
        } else if (i == 3) {
            this.mBackgroundPaint.setColor(this.mBackgroundColor);
            RectF rectF4 = this.mBackgroundBounds;
            float f4 = this.mButtonRadius;
            canvas.drawRoundRect(rectF4, f4, f4, this.mBackgroundPaint);
        }
    }

    private void drawTextAbove(Canvas canvas) {
        float height = ((float) (canvas.getHeight() / 2)) - ((this.mTextPaint.descent() / 2.0f) + (this.mTextPaint.ascent() / 2.0f));
        if (this.mCurrentText == null) {
            this.mCurrentText = "";
        }
        float measureText = this.mTextPaint.measureText(this.mCurrentText.toString());
        this.mTextBottomBorder = height;
        this.mTextRightBorder = (((float) getMeasuredWidth()) + measureText) / 2.0f;
        int i = this.mState;
        if (i == 0) {
            this.mTextPaint.setShader(null);
            this.mTextPaint.setColor(this.mTextCoverColor);
            canvas.drawText(this.mCurrentText.toString(), (((float) getMeasuredWidth()) - measureText) / 2.0f, height, this.mTextPaint);
        } else if (i == 1 || i == 2) {
            float measuredWidth = ((float) getMeasuredWidth()) * this.mProgressPercent;
            float f = measureText / 2.0f;
            float measuredWidth2 = ((float) (getMeasuredWidth() / 2)) - f;
            float measuredWidth3 = ((float) (getMeasuredWidth() / 2)) + f;
            float measuredWidth4 = ((f - ((float) (getMeasuredWidth() / 2))) + measuredWidth) / measureText;
            if (measuredWidth <= measuredWidth2) {
                this.mTextPaint.setShader(null);
                this.mTextPaint.setColor(this.mTextColor);
            } else if (measuredWidth <= measuredWidth3) {
                LinearGradient linearGradient = new LinearGradient((((float) getMeasuredWidth()) - measureText) / 2.0f, 0.0f, (((float) getMeasuredWidth()) + measureText) / 2.0f, 0.0f, new int[]{this.mTextCoverColor, this.mTextColor}, new float[]{measuredWidth4, measuredWidth4 + 0.001f}, Shader.TileMode.CLAMP);
                this.mTextPaint.setColor(this.mTextColor);
                this.mTextPaint.setShader(linearGradient);
            } else {
                this.mTextPaint.setShader(null);
                this.mTextPaint.setColor(this.mTextCoverColor);
            }
            canvas.drawText(this.mCurrentText.toString(), (((float) getMeasuredWidth()) - measureText) / 2.0f, height, this.mTextPaint);
        } else if (i == 3) {
            this.mTextPaint.setColor(this.mTextCoverColor);
            canvas.drawText(this.mCurrentText.toString(), (((float) getMeasuredWidth()) - measureText) / 2.0f, height, this.mTextPaint);
            drawLoadingBall(canvas);
        }
    }

    private void drawLoadingBall(Canvas canvas) {
        for (int i = 0; i < 3; i++) {
            canvas.save();
            float f = (float) i;
            canvas.translate(this.mTextRightBorder + 10.0f + (12.0f * f) + (f * 4.0f), this.mTextBottomBorder);
            canvas.drawCircle(0.0f, this.translateYFloats[i], this.scaleFloats[i] * 6.0f, this.mTextPaint);
            canvas.restore();
        }
    }

    private void startAnimators() {
        for (int i = 0; i < this.mAnimators.size(); i++) {
            this.mAnimators.get(i).start();
        }
    }

    private void stopAnimators() {
        ArrayList<ValueAnimator> arrayList = this.mAnimators;
        if (arrayList != null) {
            Iterator<ValueAnimator> it = arrayList.iterator();
            while (it.hasNext()) {
                ValueAnimator next = it.next();
                if (next != null && next.isStarted()) {
                    next.end();
                }
            }
        }
    }

    private ArrayList<ValueAnimator> createBallPulseAnimators() {
        ArrayList<ValueAnimator> arrayList = new ArrayList<>();
        int[] iArr = {120, 240, 360};
        for (final int i = 0; i < 3; i++) {
            ValueAnimator ofFloat = ValueAnimator.ofFloat(1.0f, 0.3f, 1.0f);
            ofFloat.setDuration(750L);
            ofFloat.setRepeatCount(-1);
            ofFloat.setStartDelay((long) iArr[i]);
            ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
                /* class com.geely.toolchain.hmi.view.HmiDownloadProgressButton.AnonymousClass2 */

                public void onAnimationUpdate(ValueAnimator valueAnimator) {
                    HmiDownloadProgressButton.this.scaleFloats[i] = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                    HmiDownloadProgressButton.this.postInvalidate();
                }
            });
            arrayList.add(ofFloat);
        }
        return arrayList;
    }

    private ArrayList<ValueAnimator> createBallJumpAnimators() {
        ArrayList<ValueAnimator> arrayList = new ArrayList<>();
        int[] iArr = {70, 140, 210};
        for (final int i = 0; i < 3; i++) {
            float f = this.mTextBottomBorder;
            ValueAnimator ofFloat = ValueAnimator.ofFloat(f, f - 12.0f, f);
            ofFloat.setDuration(600L);
            ofFloat.setRepeatCount(-1);
            ofFloat.setStartDelay((long) iArr[i]);
            ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
                /* class com.geely.toolchain.hmi.view.HmiDownloadProgressButton.AnonymousClass3 */

                public void onAnimationUpdate(ValueAnimator valueAnimator) {
                    HmiDownloadProgressButton.this.translateYFloats[i] = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                    HmiDownloadProgressButton.this.postInvalidate();
                }
            });
            arrayList.add(ofFloat);
        }
        return arrayList;
    }

    public int getState() {
        return this.mState;
    }

    public void setState(int i) {
        if (this.mState != i) {
            this.mState = i;
            invalidate();
            if (i == 3) {
                startAnimators();
            } else {
                stopAnimators();
            }
        }
    }

    public void setCurrentText(CharSequence charSequence) {
        this.mCurrentText = charSequence;
        invalidate();
    }

    public void setProgressText(String str, float f) {
        int i = this.mMinProgress;
        if (f >= ((float) i) && f <= ((float) this.mMaxProgress)) {
            this.mCurrentText = str + new DecimalFormat("##0.0").format((double) f) + "%";
            this.mToProgress = f;
            if (this.mProgressAnimation.isRunning()) {
                this.mProgressAnimation.resume();
                this.mProgressAnimation.start();
                return;
            }
            this.mProgressAnimation.start();
        } else if (f < ((float) i)) {
            this.mProgress = 0.0f;
        } else if (f > ((float) this.mMaxProgress)) {
            this.mProgress = 100.0f;
            this.mCurrentText = str + f + "%";
            invalidate();
        }
    }

    private void setBallStyle(int i) {
        this.mBallStyle = i;
        if (i == 1) {
            this.mAnimators = createBallPulseAnimators();
        } else {
            this.mAnimators = createBallJumpAnimators();
        }
    }

    public boolean isShowBorder() {
        return this.showBorder;
    }

    public void setShowBorder(boolean z) {
        this.showBorder = z;
    }

    public float getBorderWidth() {
        return this.mBorderWidth;
    }

    public void setBorderWidth(int i) {
        this.mBorderWidth = (float) dp2px(i);
    }

    public float getProgress() {
        return this.mProgress;
    }

    public void setProgress(float f) {
        this.mProgress = f;
    }

    public float getButtonRadius() {
        return this.mButtonRadius;
    }

    public void setButtonRadius(float f) {
        this.mButtonRadius = f;
    }

    public int getTextColor() {
        return this.mTextColor;
    }

    @Override // android.widget.TextView
    public void setTextColor(int i) {
        this.mTextColor = i;
    }

    public int getTextCoverColor() {
        return this.mTextCoverColor;
    }

    public void setTextCoverColor(int i) {
        this.mTextCoverColor = i;
    }

    public int getMinProgress() {
        return this.mMinProgress;
    }

    public void setMinProgress(int i) {
        this.mMinProgress = i;
    }

    public int getMaxProgress() {
        return this.mMaxProgress;
    }

    public void setMaxProgress(int i) {
        this.mMaxProgress = i;
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        SavedState savedState = (SavedState) parcelable;
        super.onRestoreInstanceState(savedState.getSuperState());
        this.mState = savedState.state;
        this.mProgress = (float) savedState.progress;
        this.mCurrentText = savedState.currentText;
    }

    public Parcelable onSaveInstanceState() {
        return new SavedState(super.onSaveInstanceState(), (int) this.mProgress, this.mState, this.mCurrentText.toString());
    }

    public static class SavedState extends View.BaseSavedState {
        public static final Parcelable.Creator<SavedState> CREATOR = new Parcelable.Creator<SavedState>() {
            /* class com.geely.toolchain.hmi.view.HmiDownloadProgressButton.SavedState.AnonymousClass1 */

            @Override // android.os.Parcelable.Creator
            public SavedState createFromParcel(Parcel parcel) {
                return new SavedState(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public SavedState[] newArray(int i) {
                return new SavedState[i];
            }
        };
        private final String currentText;
        private final int progress;
        private final int state;

        public SavedState(Parcelable parcelable, int i, int i2, String str) {
            super(parcelable);
            this.progress = i;
            this.state = i2;
            this.currentText = str;
        }

        private SavedState(Parcel parcel) {
            super(parcel);
            this.progress = parcel.readInt();
            this.state = parcel.readInt();
            this.currentText = parcel.readString();
        }

        public void writeToParcel(Parcel parcel, int i) {
            super.writeToParcel(parcel, i);
            parcel.writeInt(this.progress);
            parcel.writeInt(this.state);
            parcel.writeString(this.currentText);
        }
    }

    private int dp2px(int i) {
        return (int) (((float) i) * getContext().getResources().getDisplayMetrics().density);
    }
}
