package com.geely.toolchain.hmi.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.RectF;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import com.geely.toolchain.hmi.R;

public class HmiRingProgress extends View {
    private static final String TAG = "HmiRingProgress";
    private int max;
    private Paint paint;
    private int progress;
    private int roundColor;
    private int roundProgressColor;
    private float roundWidth;

    public HmiRingProgress(Context context) {
        this(context, null);
    }

    public HmiRingProgress(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public HmiRingProgress(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init(context, attributeSet);
    }

    private void init(Context context, AttributeSet attributeSet) {
        this.paint = new Paint();
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.HmiRingProgress);
        this.roundColor = obtainStyledAttributes.getColor(R.styleable.HmiRingProgress_roundColor, Color.parseColor("#14FFFFFF"));
        this.roundProgressColor = obtainStyledAttributes.getColor(R.styleable.HmiRingProgress_roundProgressColor, Color.parseColor("#1368FB"));
        this.roundWidth = obtainStyledAttributes.getDimension(R.styleable.HmiRingProgress_roundWidth, 6.0f);
        this.max = obtainStyledAttributes.getInteger(R.styleable.HmiRingProgress_max, 100);
        this.progress = obtainStyledAttributes.getInteger(R.styleable.HmiRingProgress_progress, this.progress);
        obtainStyledAttributes.recycle();
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        int width = getWidth() / 2;
        float f = (float) width;
        int i = (int) (f - (this.roundWidth / 2.0f));
        this.paint.setColor(this.roundColor);
        this.paint.setStyle(Paint.Style.STROKE);
        this.paint.setStrokeWidth(this.roundWidth);
        this.paint.setAntiAlias(true);
        canvas.drawCircle(f, f, (float) i, this.paint);
        this.paint.setStrokeWidth(this.roundWidth);
        this.paint.setColor(this.roundProgressColor);
        float f2 = (float) (width - i);
        float f3 = (float) (width + i);
        RectF rectF = new RectF(f2, f2, f3, f3);
        this.paint.setStyle(Paint.Style.STROKE);
        float f4 = (float) ((this.progress * 360) / this.max);
        Log.i(TAG, "onDraw: endAngle = " + f4);
        canvas.drawArc(rectF, -90.0f, f4, false, this.paint);
    }

    public synchronized int getMax() {
        return this.max;
    }

    public synchronized void setMax(int i) {
        if (i <= 0) {
            Log.e(TAG, "max more than 0 ");
        }
        this.max = i;
    }

    public int getProgress() {
        return this.progress;
    }

    public void setProgress(int i) {
        if (i <= 0) {
            Log.e(TAG, "progress not less than 0");
        }
        int i2 = this.max;
        if (i > i2) {
            i = i2;
        }
        this.progress = i;
        Log.i(TAG, "setProgress: progress = " + this.progress);
        postInvalidate();
    }

    public float getRoundWidth() {
        return this.roundWidth;
    }

    public void setRoundWidth(float f) {
        this.roundWidth = f;
    }

    public int getRoundColor() {
        return this.roundColor;
    }

    public int getRoundProgressColor() {
        return this.roundProgressColor;
    }

    public void setRoundColor(int i) {
        this.roundColor = i;
    }

    public void setRoundProgressColor(int i) {
        this.roundProgressColor = i;
    }
}
