package com.geely.toolchain.hmi.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.util.Log;
import android.view.LayoutInflater;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.SeekBar;
import com.geely.toolchain.hmi.R;

public class HmiStateSlider extends FrameLayout {
    public static final int DEFAULT_MAX = 100;
    public static final String TAG = "HmiStateSlider";
    private Drawable iconOffDrawable;
    private Drawable iconOnDrawable;
    private ImageView mIcon;
    private SeekBar mSeekBar;
    private SeekBar.OnSeekBarChangeListener onSeekBarChangeListener;

    public HmiStateSlider(Context context) {
        super(context);
        init(null, 0, 0);
    }

    public HmiStateSlider(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init(attributeSet, 0, 0);
    }

    public HmiStateSlider(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init(attributeSet, i, 0);
    }

    public HmiStateSlider(Context context, AttributeSet attributeSet, int i, int i2) {
        super(context, attributeSet, i, i2);
        init(attributeSet, i, i2);
    }

    private void init(AttributeSet attributeSet, int i, int i2) {
        LayoutInflater.from(getContext()).inflate(R.layout.hmi_layout_state_slider, this);
        this.mSeekBar = (SeekBar) findViewById(R.id.seekBar);
        this.mIcon = (ImageView) findViewById(R.id.iv_icon);
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R.styleable.HmiStateSlider);
            int integer = obtainStyledAttributes.getInteger(R.styleable.HmiStateSlider_slider_progress, 0);
            int integer2 = obtainStyledAttributes.getInteger(R.styleable.HmiStateSlider_slider_max, 100);
            this.iconOnDrawable = obtainStyledAttributes.getDrawable(R.styleable.HmiStateSlider_slider_icon_on);
            this.iconOffDrawable = obtainStyledAttributes.getDrawable(R.styleable.HmiStateSlider_slider_icon_off);
            obtainStyledAttributes.recycle();
            initSeekBar(integer, integer2);
            setIconState(integer);
        }
    }

    private void initSeekBar(int i, int i2) {
        Log.i(TAG, "initSeekBar: ");
        this.mSeekBar.setEnabled(true);
        this.mSeekBar.setProgress(i);
        this.mSeekBar.setMax(i2);
        this.mSeekBar.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
            /* class com.geely.toolchain.hmi.view.HmiStateSlider.AnonymousClass1 */

            public void onProgressChanged(SeekBar seekBar, int i, boolean z) {
                HmiStateSlider.this.setIconState(i);
                if (HmiStateSlider.this.onSeekBarChangeListener != null) {
                    HmiStateSlider.this.onSeekBarChangeListener.onProgressChanged(seekBar, i, z);
                }
            }

            public void onStartTrackingTouch(SeekBar seekBar) {
                if (HmiStateSlider.this.onSeekBarChangeListener != null) {
                    HmiStateSlider.this.onSeekBarChangeListener.onStartTrackingTouch(seekBar);
                }
            }

            public void onStopTrackingTouch(SeekBar seekBar) {
                if (HmiStateSlider.this.onSeekBarChangeListener != null) {
                    HmiStateSlider.this.onSeekBarChangeListener.onStopTrackingTouch(seekBar);
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setIconState(int i) {
        if (i > 0 && this.iconOnDrawable != null) {
            this.mIcon.setVisibility(0);
            this.mIcon.setImageDrawable(this.iconOnDrawable);
        } else if (i > 0 || this.iconOffDrawable == null) {
            this.mIcon.setVisibility(8);
        } else {
            this.mIcon.setVisibility(0);
            this.mIcon.setImageDrawable(this.iconOffDrawable);
        }
    }

    public SeekBar getSeekBar() {
        return this.mSeekBar;
    }

    public ImageView getIcon() {
        return this.mIcon;
    }

    public void setOnSeekBarChangeListener(SeekBar.OnSeekBarChangeListener onSeekBarChangeListener2) {
        this.onSeekBarChangeListener = onSeekBarChangeListener2;
    }
}
