package com.geely.toolchain.hmi.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import com.geely.toolchain.hmi.R;
import com.geely.toolchain.hmi.view.HmiTitleBar;
import java.util.List;

public class HmiTitleBar extends ConstraintLayout {
    private ImageView mIvBack;
    private RecyclerView mRvSub;
    private SubTitleAdapter mSubTitleAdapter;
    private String mTitleText;
    private TextView mTvTitle;
    private OnTitleBarBackListener onTitleBarBackListener;

    public interface OnTitleBarBackListener {
        void onTitleBarBack(View view);
    }

    public interface OnTitleBarSubItemClickListener {
        void onItemClick(View view, int i, SubItem subItem);
    }

    public HmiTitleBar(Context context) {
        this(context, null);
    }

    public HmiTitleBar(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public HmiTitleBar(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init(context, attributeSet);
    }

    private void init(Context context, AttributeSet attributeSet) {
        LayoutInflater.from(context).inflate(R.layout.hmi_layout_title_bar, (ViewGroup) this, true);
        this.mIvBack = (ImageView) findViewById(R.id.iv_back);
        this.mTvTitle = (TextView) findViewById(R.id.tv_title);
        this.mRvSub = (RecyclerView) findViewById(R.id.rv_main);
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.HmiTitleBar);
            String string = obtainStyledAttributes.getString(R.styleable.HmiTitleBar_hmiTitle);
            obtainStyledAttributes.recycle();
            setTitleText(string);
            this.mIvBack.setOnClickListener(new View.OnClickListener() {
                /* class com.geely.toolchain.hmi.view.$$Lambda$HmiTitleBar$_X7NT_OjdVOxz4JnN3xJlEx4r90 */

                public final void onClick(View view) {
                    HmiTitleBar.this.lambda$init$0$HmiTitleBar(view);
                }
            });
            SubTitleAdapter subTitleAdapter = new SubTitleAdapter();
            this.mSubTitleAdapter = subTitleAdapter;
            this.mRvSub.setAdapter(subTitleAdapter);
            LinearLayoutManager linearLayoutManager = new LinearLayoutManager(getContext());
            linearLayoutManager.setOrientation(0);
            this.mRvSub.setLayoutManager(linearLayoutManager);
        }
    }

    public /* synthetic */ void lambda$init$0$HmiTitleBar(View view) {
        OnTitleBarBackListener onTitleBarBackListener2 = this.onTitleBarBackListener;
        if (onTitleBarBackListener2 != null) {
            onTitleBarBackListener2.onTitleBarBack(view);
        }
    }

    public void setTitleText(String str) {
        this.mTitleText = str;
        if (!TextUtils.isEmpty(str)) {
            this.mTvTitle.setText(this.mTitleText);
        }
    }

    public void setOnTitleBarBackListener(OnTitleBarBackListener onTitleBarBackListener2) {
        this.onTitleBarBackListener = onTitleBarBackListener2;
    }

    public void setOnTitleBarSubItemClickListener(OnTitleBarSubItemClickListener onTitleBarSubItemClickListener) {
        this.mSubTitleAdapter.setOnTitleBarSubItemClickListener(onTitleBarSubItemClickListener);
    }

    public void setSubData(List<SubItem> list) {
        this.mSubTitleAdapter.setData(list);
    }

    public static class SubItem {
        private int resId;
        private String text = "";

        public SubItem() {
        }

        public SubItem(int i, String str) {
            this.resId = i;
            this.text = str;
        }

        public int getResId() {
            return this.resId;
        }

        public void setResId(int i) {
            this.resId = i;
        }

        public String getText() {
            return this.text;
        }

        public void setText(String str) {
            this.text = str;
        }
    }

    public static class SubTitleAdapter extends RecyclerView.Adapter<ViewHolder> {
        private List<SubItem> mSubItemList;
        private OnTitleBarSubItemClickListener onTitleBarSubItemClickListener;

        public void setData(List<SubItem> list) {
            this.mSubItemList = list;
            notifyDataSetChanged();
        }

        public void setOnTitleBarSubItemClickListener(OnTitleBarSubItemClickListener onTitleBarSubItemClickListener2) {
            this.onTitleBarSubItemClickListener = onTitleBarSubItemClickListener2;
        }

        @Override // androidx.recyclerview.widget.RecyclerView.Adapter
        public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
            return new ViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.hmi_layout_title_bar_item, viewGroup, false));
        }

        public void onBindViewHolder(ViewHolder viewHolder, int i) {
            SubItem subItem;
            List<SubItem> list = this.mSubItemList;
            if (list != null && (subItem = list.get(i)) != null) {
                viewHolder.ivIcon.setImageResource(subItem.getResId());
                viewHolder.tvContent.setText(subItem.getText());
                viewHolder.itemView.setOnClickListener(new View.OnClickListener(i, subItem) {
                    /* class com.geely.toolchain.hmi.view.$$Lambda$HmiTitleBar$SubTitleAdapter$DhpBWBWIcNrSo68_7XePWtY3kGI */
                    public final /* synthetic */ int f$1;
                    public final /* synthetic */ HmiTitleBar.SubItem f$2;

                    {
                        this.f$1 = r2;
                        this.f$2 = r3;
                    }

                    public final void onClick(View view) {
                        HmiTitleBar.SubTitleAdapter.this.lambda$onBindViewHolder$0$HmiTitleBar$SubTitleAdapter(this.f$1, this.f$2, view);
                    }
                });
            }
        }

        public /* synthetic */ void lambda$onBindViewHolder$0$HmiTitleBar$SubTitleAdapter(int i, SubItem subItem, View view) {
            OnTitleBarSubItemClickListener onTitleBarSubItemClickListener2 = this.onTitleBarSubItemClickListener;
            if (onTitleBarSubItemClickListener2 != null) {
                onTitleBarSubItemClickListener2.onItemClick(view, i, subItem);
            }
        }

        @Override // androidx.recyclerview.widget.RecyclerView.Adapter
        public int getItemCount() {
            return this.mSubItemList.size();
        }
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {
        private final ImageView ivIcon;
        private final TextView tvContent;

        public ViewHolder(View view) {
            super(view);
            this.ivIcon = (ImageView) view.findViewById(R.id.iv_icon);
            this.tvContent = (TextView) view.findViewById(R.id.tv_subTitle);
        }
    }
}
