package com.geely.toolchain.hmi.view;

import android.content.Context;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;
import com.geely.toolchain.hmi.R;
import java.lang.ref.WeakReference;

public class HmiToastUtils {
    private static final String TAG = "HmiToastUtils";
    private static final long TOAST_MIN_TIME = 2000;
    private static long mCurrentTime;
    private static WeakReference<Toast> mToastRef;

    public static void showTopShortTime(Context context, String str) {
        showGravity(context, str, 0, 49, true);
    }

    public static void showTopLongTime(Context context, String str) {
        showGravity(context, str, 1, 49, true);
    }

    public static void showTopShortTime(View view) {
        showView(view, 0, 49, true);
    }

    public static void showTopLongTime(View view) {
        showView(view, 1, 49, true);
    }

    public static void showTopLongTime(Context context, int i) {
        showView(context, i, 1, 49, true);
    }

    public static void showTopShortTime(Context context, int i) {
        showView(context, i, 0, 49, true);
    }

    public static void showBottomShortTime(View view) {
        showView(view, 0, 81, false);
    }

    public static void showBottomLongTime(View view) {
        showView(view, 1, 81, false);
    }

    public static void showBottomShortTime(Context context, int i) {
        showView(context, i, 0, 81, false);
    }

    public static void showBottomLongTime(Context context, int i) {
        showView(context, i, 1, 81, false);
    }

    public static void showBottomShortTime(Context context, String str) {
        showGravity(context, str, 0, 81, false);
    }

    public static void showBottomLongTime(Context context, String str) {
        showGravity(context, str, 1, 81, false);
    }

    private static void showGravity(Context context, String str, int i, int i2, boolean z) {
        float dimension = context.getResources().getDimension(R.dimen.oneoshmi_toast_bottom_elevation);
        float dimension2 = context.getResources().getDimension(R.dimen.oneoshmi_toast_margin_Bottom);
        if (z) {
            dimension2 = context.getResources().getDimension(R.dimen.oneoshmi_toast_margin_Top);
            dimension = context.getResources().getDimension(R.dimen.oneoshmi_toast_elevation);
        }
        showGravityLocation(context, str, i, i2, dimension2, dimension);
    }

    private static void showView(View view, int i, int i2, boolean z) {
        float dimension = view.getContext().getResources().getDimension(R.dimen.oneoshmi_toast_bottom_elevation);
        float dimension2 = view.getContext().getResources().getDimension(R.dimen.oneoshmi_toast_margin_Bottom);
        if (z) {
            dimension2 = view.getContext().getResources().getDimension(R.dimen.oneoshmi_toast_margin_Top);
            dimension = view.getContext().getResources().getDimension(R.dimen.oneoshmi_toast_elevation);
        }
        showGravityLocation(view, i, i2, dimension2, dimension);
    }

    private static void showView(Context context, int i, int i2, int i3, boolean z) {
        float dimension = context.getResources().getDimension(R.dimen.oneoshmi_toast_bottom_elevation);
        float dimension2 = context.getResources().getDimension(R.dimen.oneoshmi_toast_margin_Bottom);
        if (z) {
            dimension2 = context.getResources().getDimension(R.dimen.oneoshmi_toast_margin_Top);
            dimension = context.getResources().getDimension(R.dimen.oneoshmi_toast_elevation);
        }
        try {
            showGravityLocation(LayoutInflater.from(context).inflate(i, (ViewGroup) null, false), i2, i3, dimension2, dimension);
        } catch (Exception e) {
            Log.d(TAG, "notfindResid:" + e.getMessage());
        }
    }

    private static void showGravityLocation(View view, int i, int i2, float f, float f2) {
        Toast toast;
        if (System.currentTimeMillis() - mCurrentTime >= 2000) {
            if (view == null) {
                Log.d(TAG, "view ==null");
                return;
            }
            WeakReference<Toast> weakReference = mToastRef;
            if (!(weakReference == null || (toast = weakReference.get()) == null)) {
                try {
                    toast.cancel();
                } catch (Exception e) {
                    Log.d(TAG, "cancel toast fail");
                    e.printStackTrace();
                }
            }
            View inflate = LayoutInflater.from(view.getContext()).inflate(R.layout.hmi_layout_toast, (ViewGroup) null);
            RelativeLayout relativeLayout = (RelativeLayout) inflate.findViewById(R.id.view_root_fl);
            ((HmiShadowLayerBlurView) inflate.findViewById(R.id.shadowView)).setElevation(f2);
            ((TextView) inflate.findViewById(R.id.toast_tv)).setVisibility(8);
            relativeLayout.setVisibility(0);
            relativeLayout.addView(view);
            Toast toast2 = new Toast(view.getContext());
            mToastRef = new WeakReference<>(toast2);
            toast2.setView(inflate);
            toast2.setGravity(i2, (int) view.getContext().getResources().getDimension(R.dimen.oneoshmi_toast_margin_left), (int) f);
            toast2.setDuration(i);
            toast2.show();
            mCurrentTime = System.currentTimeMillis();
        }
    }

    private static void showGravityLocation(Context context, String str, int i, int i2, float f, float f2) {
        Toast toast;
        if (System.currentTimeMillis() - mCurrentTime >= 2000) {
            if (context == null || TextUtils.isEmpty(str)) {
                Log.d(TAG, "context ==null");
                return;
            }
            WeakReference<Toast> weakReference = mToastRef;
            if (!(weakReference == null || (toast = weakReference.get()) == null)) {
                try {
                    toast.cancel();
                } catch (Exception e) {
                    Log.d(TAG, "cancel toast fail");
                    e.printStackTrace();
                }
            }
            View inflate = LayoutInflater.from(context).inflate(R.layout.hmi_layout_toast, (ViewGroup) null);
            TextView textView = (TextView) inflate.findViewById(R.id.toast_tv);
            ((HmiShadowLayerBlurView) inflate.findViewById(R.id.shadowView)).setElevation(f2);
            textView.setVisibility(0);
            ((RelativeLayout) inflate.findViewById(R.id.view_root_fl)).setVisibility(8);
            textView.setText(str);
            Toast toast2 = new Toast(context);
            mToastRef = new WeakReference<>(toast2);
            toast2.setView(inflate);
            toast2.setGravity(i2, (int) context.getResources().getDimension(R.dimen.oneoshmi_toast_margin_left), (int) f);
            toast2.setDuration(i);
            toast2.show();
            mCurrentTime = System.currentTimeMillis();
        }
    }
}
