package android.car.occupantawareness;

import android.car.Car;
import android.car.CarManagerBase;
import android.car.occupantawareness.IOccupantAwarenessEventCallback;
import android.car.occupantawareness.IOccupantAwarenessManager;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import android.os.RemoteException;
import android.util.Log;
import java.lang.ref.WeakReference;

public class OccupantAwarenessManager extends CarManagerBase {
    private static final boolean DBG = false;
    private static final int MSG_HANDLE_DETECTION_EVENT = 1;
    private static final int MSG_HANDLE_SYSTEM_STATUS_CHANGE = 0;
    private static final String TAG = "OAS.Manager";
    private ChangeCallback mChangeCallback;
    private final EventCallbackHandler mEventCallbackHandler;
    private ChangeListenerToService mListenerToService;
    private final Object mLock = new Object();
    private final IOccupantAwarenessManager mOccupantAwarenessService;

    public static abstract class ChangeCallback {
        public abstract void onDetectionEvent(OccupantAwarenessDetection occupantAwarenessDetection);

        public abstract void onSystemStateChanged(SystemStatusEvent systemStatusEvent);
    }

    public OccupantAwarenessManager(Car car, IBinder iBinder) {
        super(car);
        this.mOccupantAwarenessService = IOccupantAwarenessManager.Stub.asInterface(iBinder);
        this.mEventCallbackHandler = new EventCallbackHandler(this, getEventHandler().getLooper());
    }

    @Override // android.car.CarManagerBase
    public void onCarDisconnected() {
        synchronized (this.mLock) {
            this.mChangeCallback = null;
            this.mListenerToService = null;
        }
    }

    public int getCapabilityForRole(int i) {
        try {
            return this.mOccupantAwarenessService.getCapabilityForRole(i);
        } catch (RemoteException e) {
            return ((Integer) handleRemoteExceptionFromCarService(e, 0)).intValue();
        }
    }

    public void registerChangeCallback(ChangeCallback changeCallback) {
        synchronized (this.mLock) {
            if (this.mChangeCallback == null) {
                this.mChangeCallback = changeCallback;
                try {
                    if (this.mListenerToService == null) {
                        this.mListenerToService = new ChangeListenerToService(this);
                    }
                    this.mOccupantAwarenessService.registerEventListener(this.mListenerToService);
                } catch (RemoteException e) {
                    handleRemoteExceptionFromCarService(e);
                }
            } else {
                throw new IllegalStateException("Attempting to register a new listener when an existing listener has already been registered.");
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0014, code lost:
        r2 = r4.mLock;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0016, code lost:
        monitor-enter(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
        r4.mOccupantAwarenessService.unregisterEventListener(r4.mListenerToService);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0021, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:?, code lost:
        handleRemoteExceptionFromCarService(r0);
     */
    public void unregisterChangeCallback() {
        Object obj;
        synchronized (this.mLock) {
            if (this.mChangeCallback == null) {
                Log.e(TAG, "No listener exists to unregister.");
                return;
            }
            this.mChangeCallback = null;
        }
        this.mListenerToService = null;
    }

    private static class ChangeListenerToService extends IOccupantAwarenessEventCallback.Stub {
        private final WeakReference<OccupantAwarenessManager> mOccupantAwarenessManager;

        ChangeListenerToService(OccupantAwarenessManager occupantAwarenessManager) {
            this.mOccupantAwarenessManager = new WeakReference<>(occupantAwarenessManager);
        }

        @Override // android.car.occupantawareness.IOccupantAwarenessEventCallback
        public void onStatusChanged(SystemStatusEvent systemStatusEvent) {
            OccupantAwarenessManager occupantAwarenessManager = this.mOccupantAwarenessManager.get();
            if (occupantAwarenessManager != null) {
                occupantAwarenessManager.handleSystemStatusChanged(systemStatusEvent);
            }
        }

        @Override // android.car.occupantawareness.IOccupantAwarenessEventCallback
        public void onDetectionEvent(OccupantAwarenessDetection occupantAwarenessDetection) {
            OccupantAwarenessManager occupantAwarenessManager = this.mOccupantAwarenessManager.get();
            if (occupantAwarenessManager != null) {
                occupantAwarenessManager.handleDetectionEvent(occupantAwarenessDetection);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleSystemStatusChanged(SystemStatusEvent systemStatusEvent) {
        EventCallbackHandler eventCallbackHandler = this.mEventCallbackHandler;
        eventCallbackHandler.sendMessage(eventCallbackHandler.obtainMessage(0, systemStatusEvent));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchSystemStatusToClient(SystemStatusEvent systemStatusEvent) {
        if (systemStatusEvent != null) {
            synchronized (this.mLock) {
                ChangeCallback changeCallback = this.mChangeCallback;
                if (changeCallback != null) {
                    changeCallback.onSystemStateChanged(systemStatusEvent);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleDetectionEvent(OccupantAwarenessDetection occupantAwarenessDetection) {
        EventCallbackHandler eventCallbackHandler = this.mEventCallbackHandler;
        eventCallbackHandler.sendMessage(eventCallbackHandler.obtainMessage(1, occupantAwarenessDetection));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchDetectionEventToClient(OccupantAwarenessDetection occupantAwarenessDetection) {
        ChangeCallback changeCallback;
        if (occupantAwarenessDetection != null) {
            synchronized (this.mLock) {
                changeCallback = this.mChangeCallback;
            }
            if (changeCallback != null) {
                changeCallback.onDetectionEvent(occupantAwarenessDetection);
            }
        }
    }

    /* access modifiers changed from: private */
    public static final class EventCallbackHandler extends Handler {
        private final WeakReference<OccupantAwarenessManager> mOccupantAwarenessManager;

        EventCallbackHandler(OccupantAwarenessManager occupantAwarenessManager, Looper looper) {
            super(looper);
            this.mOccupantAwarenessManager = new WeakReference<>(occupantAwarenessManager);
        }

        public void handleMessage(Message message) {
            OccupantAwarenessManager occupantAwarenessManager = this.mOccupantAwarenessManager.get();
            if (occupantAwarenessManager != null) {
                int i = message.what;
                if (i == 0) {
                    occupantAwarenessManager.dispatchSystemStatusToClient((SystemStatusEvent) message.obj);
                } else if (i == 1) {
                    occupantAwarenessManager.dispatchDetectionEventToClient((OccupantAwarenessDetection) message.obj);
                } else {
                    throw new RuntimeException("Unknown message " + message.what);
                }
            }
        }
    }
}
