package com.geely.carlink.broadcast;

import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.util.Log;
import com.geely.carlink.constant.Const;

public class BluetoothConnectionReceiver extends BroadcastReceiver {
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private CallBack callBack;

    public interface CallBack {
        void disConnectBluetoothDevice(BluetoothDevice bluetoothDevice);

        BluetoothDevice getCurrentBluetooth();

        void onBlueDeviceA2dp(BluetoothDevice bluetoothDevice);

        void onBlueDeviceHfp(BluetoothDevice bluetoothDevice);

        void onBlueDeviceStateChanged(boolean z);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public void onReceive(Context context, Intent intent) {
        char c;
        Log.i(this.TAG, "onReceive() Intent:" + intent);
        String action = intent.getAction();
        if (action == null) {
            Log.e(this.TAG, "action is null, return");
            return;
        }
        BluetoothDevice bluetoothDevice = (BluetoothDevice) intent.getParcelableExtra("android.bluetooth.device.extra.DEVICE");
        String address = bluetoothDevice != null ? bluetoothDevice.getAddress() : "";
        action.hashCode();
        boolean z = true;
        switch (action.hashCode()) {
            case -1530327060:
                if (action.equals("android.bluetooth.adapter.action.STATE_CHANGED")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -301431627:
                if (action.equals("android.bluetooth.device.action.ACL_CONNECTED")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 40146574:
                if (action.equals("android.bluetooth.a2dp-sink.profile.action.CONNECTION_STATE_CHANGED")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 448318136:
                if (action.equals("android.bluetooth.headsetclient.profile.action.CONNECTION_STATE_CHANGED")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 545516589:
                if (action.equals("android.bluetooth.headset.profile.action.CONNECTION_STATE_CHANGED")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 1244161670:
                if (action.equals("android.bluetooth.a2dp.profile.action.CONNECTION_STATE_CHANGED")) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 1821585647:
                if (action.equals("android.bluetooth.device.action.ACL_DISCONNECTED")) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                if (this.callBack != null) {
                    int intExtra = intent.getIntExtra("android.bluetooth.adapter.extra.STATE", 0);
                    Log.i(this.TAG, "BluetoothState: " + intExtra);
                    CallBack callBack2 = this.callBack;
                    if (intExtra != 12) {
                        z = false;
                    }
                    callBack2.onBlueDeviceStateChanged(z);
                    return;
                }
                return;
            case 1:
                Log.i(this.TAG, "Bluetooth acl connected, macAddress:" + address);
                BluetoothDevice currentBluetooth = this.callBack.getCurrentBluetooth();
                if (bluetoothDevice != null && !address.isEmpty() && currentBluetooth != null) {
                    address.equals(currentBluetooth.getAddress());
                    return;
                }
                return;
            case 2:
            case 5:
                int intExtra2 = intent.getIntExtra("android.bluetooth.profile.extra.STATE", -1);
                Log.i(this.TAG, String.format("Bluetooth a2dp state changed, state:%s, macAddress:%s", Integer.valueOf(intExtra2), address));
                if (intExtra2 == 2) {
                    Log.i(this.TAG, "Bluetooth a2dp connected");
                    CallBack callBack3 = this.callBack;
                    if (callBack3 != null && address != null && bluetoothDevice != null) {
                        callBack3.onBlueDeviceA2dp(bluetoothDevice);
                        return;
                    }
                    return;
                } else if (intExtra2 == 0) {
                    Log.i(this.TAG, "Bluetooth a2dp disconnected");
                    return;
                } else {
                    return;
                }
            case 3:
            case 4:
                int intExtra3 = intent.getIntExtra("android.bluetooth.profile.extra.STATE", -1);
                Log.i(this.TAG, String.format("Bluetooth hfp state changed, state:%s, macAddress:%s", Integer.valueOf(intExtra3), address));
                if (intExtra3 == 2) {
                    Log.i(this.TAG, "Bluetooth hfp connected");
                    CallBack callBack4 = this.callBack;
                    if (callBack4 != null && address != null && bluetoothDevice != null) {
                        callBack4.onBlueDeviceHfp(bluetoothDevice);
                        return;
                    }
                    return;
                } else if (intExtra3 == 0) {
                    Log.i(this.TAG, "Bluetooth hfp disconnected");
                    return;
                } else {
                    return;
                }
            case 6:
                Log.i(this.TAG, "Bluetooth acl disconnected, macAddress:" + address);
                return;
            default:
                return;
        }
    }

    public void setCallBack(CallBack callBack2) {
        this.callBack = callBack2;
    }
}
