package com.geely.carlink.broadcast;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.util.Log;
import android.view.KeyEvent;
import com.geely.carlink.constant.Const;
import com.geely.carlink.ext.HandlerManager;
import com.geely.carlink.service.CarLinkService;
import com.ucar.vehiclesdk.UCarAdapter;
import com.ucar.vehiclesdk.UCarCommon;
import java.util.Timer;
import java.util.TimerTask;

public class SimulationBroadcastReceiver extends BroadcastReceiver {
    private static final String SIMULATION_BROADCAST_ACTION_DAY_AND_NIGHT_MODE = "ACTION_DAY_AND_NIGHT_MODE";
    private static final String SIMULATION_BROADCAST_ACTION_DRIVE_MODE = "ACTION_DRIVE_MODE";
    private static final String SIMULATION_BROADCAST_ACTION_HEAD_UNIT_ACTIVATE = "ACTION_HEAD_UNIT_ACTIVATE";
    private static final String SIMULATION_BROADCAST_ACTION_HEAD_UNIT_DEACTIVATE = "ACTION_HEAD_UNIT_DEACTIVATE";
    private static final String SIMULATION_BROADCAST_ACTION_NAVIGATION_STATE = "ACTION_NAVIGATION_STATE";
    private static final String SIMULATION_BROADCAST_ACTION_WAKE_UP_KEY_EVENT = "ACTION_WAKE_UP_KEY_EVENT";
    private static final String SIMULATION_BROADCAST_ACTION_WHEEL_KEY_EVENT = "ACTION_WHEEL_KEY_EVENT";
    private static final int WAKE_UP_KEY_LONG_PRESS_TIME_OUT = 1200;
    private final String TAG = (Const.GLOBAL_TAG + getClass().getSimpleName());
    private boolean mIsLongPressReleased;
    private final Timer mWakeUpLongPressTimer = new Timer();
    CarLinkService service = null;

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public void onReceive(Context context, Intent intent) {
        char c;
        Log.i(this.TAG, "onReceive() Intent:" + intent);
        String action = intent.getAction();
        if (context instanceof CarLinkService) {
            this.service = (CarLinkService) context;
        }
        if (action == null || this.service == null) {
            Log.i(this.TAG, "Action is null or service is null, return");
            return;
        }
        action.hashCode();
        switch (action.hashCode()) {
            case -1943697383:
                if (action.equals(SIMULATION_BROADCAST_ACTION_HEAD_UNIT_DEACTIVATE)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -1007782690:
                if (action.equals(SIMULATION_BROADCAST_ACTION_DAY_AND_NIGHT_MODE)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case -843587475:
                if (action.equals(SIMULATION_BROADCAST_ACTION_WHEEL_KEY_EVENT)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -690095928:
                if (action.equals(SIMULATION_BROADCAST_ACTION_WAKE_UP_KEY_EVENT)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -586014463:
                if (action.equals(SIMULATION_BROADCAST_ACTION_DRIVE_MODE)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -158714408:
                if (action.equals(SIMULATION_BROADCAST_ACTION_HEAD_UNIT_ACTIVATE)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 158859398:
                if (action.equals("android.intent.action.CONFIGURATION_CHANGED")) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 678439279:
                if (action.equals(SIMULATION_BROADCAST_ACTION_NAVIGATION_STATE)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_HEAD_UNIT_DEACTIVATE");
                this.service.systemModeDeInit();
                return;
            case 1:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_DAY_AND_NIGHT_MODE");
                HandlerManager.getInstance().getExpandHandler().getDayNightMode();
                if (this.service.isDeviceConnected()) {
                    sendDayNightMode(HandlerManager.getInstance().getExpandHandler().getDayNightMode());
                    return;
                }
                return;
            case 2:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_WHEEL_KEY_EVENT");
                if (this.service.isDeviceConnected()) {
                    int intExtra = intent.getIntExtra("keyCode", -1);
                    int intExtra2 = intent.getIntExtra("keyAction", -1);
                    Log.i(this.TAG, String.format("keyCode:%s, keyAction:%s", Integer.valueOf(intExtra), Integer.valueOf(intExtra2)));
                    this.service.sendKeyEvent(new KeyEvent(intExtra2, intExtra));
                    return;
                }
                return;
            case 3:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_WAKE_UP_KEY_EVENT");
                int intExtra3 = intent.getIntExtra("keyAction", -1);
                Log.i(this.TAG, "wakeUpKeyAction:" + intExtra3);
                if (intExtra3 == 0) {
                    this.mIsLongPressReleased = false;
                    this.mWakeUpLongPressTimer.schedule(new TimerTask() {
                        /* class com.geely.carlink.broadcast.SimulationBroadcastReceiver.AnonymousClass1 */

                        public void run() {
                            if (SimulationBroadcastReceiver.this.mIsLongPressReleased) {
                                Log.e(SimulationBroadcastReceiver.this.TAG, "wake up key has released");
                                return;
                            }
                            SimulationBroadcastReceiver.this.mIsLongPressReleased = true;
                            UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_DOWN, UCarCommon.KeyCodeType.KEY_CODE_VR_START, 1);
                        }
                    }, 1200);
                    return;
                } else if (intExtra3 == 1 && !this.mIsLongPressReleased) {
                    this.mIsLongPressReleased = true;
                    UCarAdapter.getInstance().sendKeyEvent(UCarCommon.KeyEventActionType.KEY_EVENT_ACTION_DOWN, UCarCommon.KeyCodeType.KEY_CODE_VR_START, 1);
                    return;
                } else {
                    return;
                }
            case 4:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_DRIVE_MODE");
                return;
            case 5:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_HEAD_UNIT_ACTIVATE");
                this.service.systemModeInit();
                return;
            case 6:
                Log.i(this.TAG, "android.intent.action.CONFIGURATION_CHANGED");
                if (this.service.isDeviceConnected()) {
                    sendDayNightMode(HandlerManager.getInstance().getExpandHandler().getDayNightMode());
                    return;
                }
                return;
            case 7:
                Log.i(this.TAG, "onReceive: SIMULATION_BROADCAST_ACTION_NAVIGATION_STATE");
                Log.i(this.TAG, "isNativeNavWorking:" + intent.getBooleanExtra("isNativeNavWorking", false));
                this.service.isDeviceConnected();
                return;
            default:
                return;
        }
    }

    public IntentFilter createIntentFilter() {
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_HEAD_UNIT_ACTIVATE);
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_HEAD_UNIT_DEACTIVATE);
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_WHEEL_KEY_EVENT);
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_WAKE_UP_KEY_EVENT);
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_DAY_AND_NIGHT_MODE);
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_NAVIGATION_STATE);
        intentFilter.addAction(SIMULATION_BROADCAST_ACTION_DRIVE_MODE);
        intentFilter.addAction("android.intent.action.CONFIGURATION_CHANGED");
        return intentFilter;
    }

    public void sendDayNightMode(boolean z) {
        UCarCommon.DayNightMode dayNightMode;
        if (z) {
            dayNightMode = UCarCommon.DayNightMode.NIGHT_MODE;
        } else {
            dayNightMode = UCarCommon.DayNightMode.DAY_MODE;
        }
        Log.i(this.TAG, "sendDayNightMode = " + z);
        UCarAdapter.getInstance().notifySwitchDayOrNight(dayNightMode);
    }
}
