package com.geely.toolchain.hmi.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.text.TextPaint;
import android.util.AttributeSet;
import android.util.Log;
import com.geely.toolchain.hmi.R;

public class HmiIconButton extends HmiButton {
    public static final String TAG = "HmiIconButton";
    Rect bounds = new Rect();
    protected DrawablePositions drawablePosition;
    protected int drawableWidth;
    protected int iconPadding;

    /* access modifiers changed from: private */
    public enum DrawablePositions {
        NONE,
        LEFT_AND_RIGHT,
        LEFT,
        RIGHT
    }

    public HmiIconButton(Context context) {
        super(context);
    }

    public HmiIconButton(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        applyAttributes(attributeSet);
    }

    public HmiIconButton(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        applyAttributes(attributeSet);
    }

    /* access modifiers changed from: protected */
    public void applyAttributes(AttributeSet attributeSet) {
        if (this.bounds == null) {
            this.bounds = new Rect();
        }
        TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R.styleable.HmiIconButton);
        int dimensionPixelSize = obtainStyledAttributes.getDimensionPixelSize(R.styleable.HmiIconButton_iconPadding, getCompoundDrawablePadding());
        Log.i(TAG, "applyAttributes: HmiIconButton_iconPadding = " + dimensionPixelSize);
        setIconPadding(dimensionPixelSize);
        obtainStyledAttributes.recycle();
    }

    public void setIconPadding(int i) {
        Log.i(TAG, "setIconPadding: padding = " + i);
        this.iconPadding = i;
        requestLayout();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.widget.AppCompatButton
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        if (this.drawablePosition == DrawablePositions.NONE) {
            Drawable[] compoundDrawablesRelative = getCompoundDrawablesRelative();
            setCompoundDrawablesWithIntrinsicBounds(compoundDrawablesRelative[0], compoundDrawablesRelative[1], compoundDrawablesRelative[2], compoundDrawablesRelative[3]);
        }
        TextPaint paint = getPaint();
        String charSequence = getText().toString();
        paint.getTextBounds(charSequence, 0, charSequence.length(), this.bounds);
        int width = (int) ((((double) getWidth()) / 2.0d) - (((double) ((this.drawableWidth + (this.iconPadding * (this.drawablePosition == DrawablePositions.LEFT_AND_RIGHT ? 2 : 1))) + this.bounds.width())) / 2.0d));
        setCompoundDrawablePadding((-width) + this.iconPadding);
        int i5 = AnonymousClass1.$SwitchMap$com$geely$toolchain$hmi$view$HmiIconButton$DrawablePositions[this.drawablePosition.ordinal()];
        if (i5 == 1) {
            setPadding(width, getPaddingTop(), 0, getPaddingBottom());
        } else if (i5 == 2) {
            setPadding(0, getPaddingTop(), width, getPaddingBottom());
        } else if (i5 != 3) {
            setPadding(0, getPaddingTop(), 0, getPaddingBottom());
        } else {
            setPadding(width, getPaddingTop(), width, getPaddingBottom());
        }
    }

    /* renamed from: com.geely.toolchain.hmi.view.HmiIconButton$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$geely$toolchain$hmi$view$HmiIconButton$DrawablePositions;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|(3:5|6|8)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        static {
            int[] iArr = new int[DrawablePositions.values().length];
            $SwitchMap$com$geely$toolchain$hmi$view$HmiIconButton$DrawablePositions = iArr;
            iArr[DrawablePositions.LEFT.ordinal()] = 1;
            $SwitchMap$com$geely$toolchain$hmi$view$HmiIconButton$DrawablePositions[DrawablePositions.RIGHT.ordinal()] = 2;
            try {
                $SwitchMap$com$geely$toolchain$hmi$view$HmiIconButton$DrawablePositions[DrawablePositions.LEFT_AND_RIGHT.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    @Override // android.widget.TextView
    public void setCompoundDrawablesWithIntrinsicBounds(Drawable drawable, Drawable drawable2, Drawable drawable3, Drawable drawable4) {
        super.setCompoundDrawablesWithIntrinsicBounds(drawable, drawable2, drawable3, drawable4);
        if (drawable != null && drawable3 != null) {
            this.drawableWidth = drawable.getIntrinsicWidth() + drawable3.getIntrinsicWidth();
            this.drawablePosition = DrawablePositions.LEFT_AND_RIGHT;
        } else if (drawable != null) {
            this.drawableWidth = drawable.getIntrinsicWidth();
            this.drawablePosition = DrawablePositions.LEFT;
        } else if (drawable3 != null) {
            this.drawableWidth = drawable3.getIntrinsicWidth();
            this.drawablePosition = DrawablePositions.RIGHT;
        } else {
            this.drawablePosition = DrawablePositions.NONE;
        }
        requestLayout();
    }
}
